(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    247691,       9441]*)
(*NotebookOutlinePosition[    248633,       9473]*)
(*  CellTagsIndexPosition[    248589,       9469]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7.  Loads and Reactions", "Title"],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter describes how ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " is used to apply forces and moments to a mechanism model, and how the \
resulting reaction forces in the constraints are resolved. ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " uses a Lagrange multiplier method to resolve the applied and reaction \
loads on each body, and solves for a generalized force associated with each \
constraint. These generalized forces can then be converted back into the \
force and moment applied by a selected constraint to each body in the model \
with a standard ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["7.1  Load Objects"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Load objects are used to define the forces and moments that are to be \
applied to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. All ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load functions return load objects with the head ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". To apply the loads to the mechanism model, the load objects are passed \
to the ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. This syntax is analogous to the way that constraint objects are \
passed to ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to incorporate them into the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Load Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load functions are used to specify forces and moments applied to specific \
bodies in the mechanism model. In general, moments are specified by \
magnitude, and forces are specified by magnitude and line of action.\n\nBy \
using ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis objects to define the line of action, a force can be applied to a \
point attached to any body in the mechanism, and the direction of the force \
can be a global or local vector, or a line from one body to another. The \
magnitude of a force or moment applied to a static model can be a constant, \
or it can be a function of location or velocity-dependent variables or even a \
function of the reaction forces at specified constraints. An applied load \
that is a function of constraint reaction forces is often used to model \
friction. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, mag",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, mag",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the moment to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a second moment in the opposite sense to body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, axis, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object that applies a force to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " along a line of action specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, axis, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the force to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a second force in the opposite direction, on the same \
line of action, to body ",
  StyleBox["bnum2",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of load objects that applies forces of magnitude mass \
times ",
  StyleBox["G",
    FontSlant->"Italic"],
  " to the centroid of each body in the current model in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the gravitational force only to the bodies specified by their \
body numbers."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["2D load functions. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether the magnitude of the applied force is relative to \
the magnitude of the line of action of the force.\n \n",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the default, causes the magnitude of the applied force to be \
equal to ",
  StyleBox["mag",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied force to be equal to ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " times the length of the direction vector of the force. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load objects are typically used in a similar manner to ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects. They are defined prior to adding them to the model \
and then passed to ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Some examples of valid load objects follow. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a moment of magnitude 4 applied to the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(Moment[crank, 4]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Moment", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a moment applied to the crank with magnitude equal to twice the \
rotation angle of the crank. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Moment[crank, 2\ Rotation[crank]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here is a force applied to the crank passing through point {1,1} on the \
crank and pointing in the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, with magnitude equal to ",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " times the distance from the point of application to the global origin. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Force[crank, Axis[Point[crank, {1, 1}], Vector[ground, {1, 0}]], 
      k\ Distance[Point[crank, {1, 1}], Point[ground, 0]]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function needs to know the mass and the location of the centroid of each \
body to apply the gravitational force. These properties are defined with the \
",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options for the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, and added to the model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". See Section 8.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package so that ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be loaded."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Load Functions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load functions are used to specify forces and moments applied to specific \
bodies in the mechanism model. In general, moments are specified by magnitude \
and direction, and forces are specified by magnitude and line of action.\n\n\
By using ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " axis objects to define the line of action of forces, and ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " vector objects to define the direction of moments, a force can be applied \
to a point attached to any body in the mechanism, and the direction of a \
force or moment can be a global or local vector, a line from one body to \
another, or even the normal of a plane. The magnitude of a force or moment \
applied to a static model can be a constant, or it can be a function of \
location or velocity-dependent variables or even a function of the reaction \
forces at particular constraints. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, vector, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object that applies a moment of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Moment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, vector, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the moment to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a second moment in the opposite sense to body ",
  StyleBox["bnum2.",
    FontSlant->"Italic"],
  " \n \n",
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, axis, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object that applies a force of magnitude ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " along a line of action specified by ",
  StyleBox["axis",
    FontSlant->"Italic"],
  ". \n \n",
  StyleBox["Force[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, axis, mag, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the force to body ",
  StyleBox["bnum1",
    FontSlant->"Italic"],
  " and also applies a second force in the opposite direction to body ",
  StyleBox["bnum2.",
    FontSlant->"Italic"],
  " \n \n",
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of load objects that applies forces of magnitude mass \
times ",
  StyleBox["G",
    FontSlant->"Italic"],
  " to the centroid of each body in the current model in the direction of ",
  StyleBox["vector",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Gravity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["vector, G, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies the gravitational force only to the bodies specified by their \
body numbers. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["3D load functions. "], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether the magnitude of the applied load is relative to \
the magnitude of the line of action of the load.\n \n",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Absolute",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the default, causes the magnitude of the applied load to be \
equal to ",
  StyleBox["mag",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Magnitude",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Relative",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the magnitude of the applied load to be equal to ",
  StyleBox["mag",
    FontSlant->"Italic"],
  " times the length of the direction vector of the load."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load objects are typically used in a similar manner to ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint objects, they are defined prior to adding them to the model \
and then passed to ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Some examples of valid load objects follow. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech3D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a moment of magnitude 4 and a direction vector in the global ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction applied to the crank. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(Moment[crank, Vector[ground, {0, 0, 1}], 4]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Moment", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a moment applied to the crank with magnitude equal to twice the \
rotation angle of the crank, relative to the global reference frame, and \
direction vector on the local ",
  StyleBox["x",
    FontSlant->"Italic"],
  " axis."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Moment[crank, Vector[crank, {1, 0, 0}], 2\ First[Rotation[crank]]]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here is a force applied to the crank passing through point {1,1,0} on the \
crank and pointing in the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " direction, with magnitude equal to ",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " times the distance from the point of application to the global origin. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Force[crank, 
      Axis[Point[crank, {1, 1, 0}], Vector[ground, {1, 0, 0}]], 
      k\ Distance[Point[crank, {1, 1, 0}], Point[ground, 0]]]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Gravity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function needs to know the mass and the location of the centroid of each \
body to apply the gravitational force. These properties are defined with the \
",
  StyleBox["Mass",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Centroid",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " options for the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " ",
  StyleBox["Body",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, and added to the model with ",
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". See Section 8.1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Generalized Load Function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is analogous to the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allows the user to specify an algebraic expression to be added directly \
to the model's load vector, just as ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " allows an algebraic constraint to be added to the constraint list."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Load[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["sym, mag",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " retu",
  StyleBox["rns a ",
    FontFamily->"Times"],
  StyleBox["Mech",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" load object that applies a load of magnitude ",
    FontFamily->"Times"],
  StyleBox["mag",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" directly to the coordinate ",
    FontFamily->"Times"],
  StyleBox["sym",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[". ",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The generalized load function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is typically used only when special generalized coordinates have \
been added to the model, and it is necessary to apply a load directly to \
those coordinates. ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " basically allows expressions to be added directly to a model's load \
vector. Using ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to apply a load to a model's Cartesian coordinates is equivalent to \
applying a force or moment to a body in the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that are functionally equivalent."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Load[X2, 10]\), 
    \(Force[crank, Axis[crank, {0, 0, 0}, ground, {1, 0, 0}], 10]\)}], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Load", "<>"]\)], "Output"],

Cell[BoxData[
    \(SysLoad["Force", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In 3D models, the ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " argument to ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has a special caveat: if the ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution method was specified with ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", loads cannot be directly applied to the Euler parameters, because the \
load vector is formulated in terms of angular velocity. However, loads can be \
applied directly to the angular velocity coordinates, which is equivalent to \
applying a pure moment."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are ",
  StyleBox["Load",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that are functionally equivalent, when the ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " settings are as specified."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetSymbols[Method \[Rule] Angular]; \)\), 
    \(Load[Wy2, 10]\), 
    \(Moment[crank, Vector[ground, {0, 1, 0}], 10]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Load", "<>"]\)], "Output"],

Cell[BoxData[
    \(SysLoad["Moment", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["7.2  Static Solutions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Load objects are applied to the current model with the ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The actual load vector developed by ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not returned to the user, rather it is stored in several variables in \
the ",
  StyleBox["`Private`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " context of the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " packages. The use of load objects and ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is analogous to the use of constraint objects and ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". \n\n",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " uses a Lagrange multiplier method to resolve the constraint reaction \
forces in a mechanism model. There is one Lagrange multiplier named ",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on for each degree of freedom in the model. Thus, when ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " solves a loaded model what is returned to the user are the numerical \
values of the Lagrange multipliers. The Lagrange multipliers are actually the \
generalized forces related to a set of generalized coordinates in which each \
coordinate corresponds to the magnitude of the violation of a kinematic \
constraint.\n\nWhile the numerical values of the Lagrange multipliers are not \
directly very useful, they are converted into the reaction forces and moments \
that are applied by the constraints to each body in the model with the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. This is discussed in Section 7.3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s static force solution method a 2D model is developed that is subject to \
applied loads. A 3D model would be treated in the same manner as 2D with \
regard to the application of forces. The model is a simple ladder sliding \
down a wall consisting of one moving body, the ladder. \n\nThe input to the \
mechanism is to push the bottom of the ladder across the horizontal floor, in \
either direction. The ladder is constrained such that the bottom of the \
ladder must contact the floor and the top of the ladder must contact the \
vertical wall."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a graphic of the 2D ladder-on-wall model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.916667 0.0833333 0.0833333 0.0833333 [
[(-10)] .08333 0 0 2 Msboxa
[(-8)] .25 0 0 2 Msboxa
[(-6)] .41667 0 0 2 Msboxa
[(-4)] .58333 0 0 2 Msboxa
[(-2)] .75 0 0 2 Msboxa
[(0)] .91667 0 0 2 Msboxa
[(0)] -0.0125 .08333 1 0 Msboxa
[(2)] -0.0125 .25 1 0 Msboxa
[(4)] -0.0125 .41667 1 0 Msboxa
[(6)] -0.0125 .58333 1 0 Msboxa
[(8)] -0.0125 .75 1 0 Msboxa
[(10)] -0.0125 .91667 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08333 0 m
.08333 .00625 L
s
P
[(-10)] .08333 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(-8)] .25 0 0 2 Mshowa
p
.002 w
.41667 0 m
.41667 .00625 L
s
P
[(-6)] .41667 0 0 2 Mshowa
p
.002 w
.58333 0 m
.58333 .00625 L
s
P
[(-4)] .58333 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(-2)] .75 0 0 2 Mshowa
p
.002 w
.91667 0 m
.91667 .00625 L
s
P
[(0)] .91667 0 0 2 Mshowa
p
.001 w
.11667 0 m
.11667 .00375 L
s
P
p
.001 w
.15 0 m
.15 .00375 L
s
P
p
.001 w
.18333 0 m
.18333 .00375 L
s
P
p
.001 w
.21667 0 m
.21667 .00375 L
s
P
p
.001 w
.28333 0 m
.28333 .00375 L
s
P
p
.001 w
.31667 0 m
.31667 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.38333 0 m
.38333 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.48333 0 m
.48333 .00375 L
s
P
p
.001 w
.51667 0 m
.51667 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.61667 0 m
.61667 .00375 L
s
P
p
.001 w
.65 0 m
.65 .00375 L
s
P
p
.001 w
.68333 0 m
.68333 .00375 L
s
P
p
.001 w
.71667 0 m
.71667 .00375 L
s
P
p
.001 w
.78333 0 m
.78333 .00375 L
s
P
p
.001 w
.81667 0 m
.81667 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.88333 0 m
.88333 .00375 L
s
P
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.01667 0 m
.01667 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.98333 0 m
.98333 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(0)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .25 m
.00625 .25 L
s
P
[(2)] -0.0125 .25 1 0 Mshowa
p
.002 w
0 .41667 m
.00625 .41667 L
s
P
[(4)] -0.0125 .41667 1 0 Mshowa
p
.002 w
0 .58333 m
.00625 .58333 L
s
P
[(6)] -0.0125 .58333 1 0 Mshowa
p
.002 w
0 .75 m
.00625 .75 L
s
P
[(8)] -0.0125 .75 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(10)] -0.0125 .91667 1 0 Mshowa
p
.001 w
0 .11667 m
.00375 .11667 L
s
P
p
.001 w
0 .15 m
.00375 .15 L
s
P
p
.001 w
0 .18333 m
.00375 .18333 L
s
P
p
.001 w
0 .21667 m
.00375 .21667 L
s
P
p
.001 w
0 .28333 m
.00375 .28333 L
s
P
p
.001 w
0 .31667 m
.00375 .31667 L
s
P
p
.001 w
0 .35 m
.00375 .35 L
s
P
p
.001 w
0 .38333 m
.00375 .38333 L
s
P
p
.001 w
0 .45 m
.00375 .45 L
s
P
p
.001 w
0 .48333 m
.00375 .48333 L
s
P
p
.001 w
0 .51667 m
.00375 .51667 L
s
P
p
.001 w
0 .55 m
.00375 .55 L
s
P
p
.001 w
0 .61667 m
.00375 .61667 L
s
P
p
.001 w
0 .65 m
.00375 .65 L
s
P
p
.001 w
0 .68333 m
.00375 .68333 L
s
P
p
.001 w
0 .71667 m
.00375 .71667 L
s
P
p
.001 w
0 .78333 m
.00375 .78333 L
s
P
p
.001 w
0 .81667 m
.00375 .81667 L
s
P
p
.001 w
0 .85 m
.00375 .85 L
s
P
p
.001 w
0 .88333 m
.00375 .88333 L
s
P
p
.001 w
0 .05 m
.00375 .05 L
s
P
p
.001 w
0 .01667 m
.00375 .01667 L
s
P
p
.001 w
0 .95 m
.00375 .95 L
s
P
p
.001 w
0 .98333 m
.00375 .98333 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.08333 .99375 m
.08333 1 L
s
P
p
.002 w
.25 .99375 m
.25 1 L
s
P
p
.002 w
.41667 .99375 m
.41667 1 L
s
P
p
.002 w
.58333 .99375 m
.58333 1 L
s
P
p
.002 w
.75 .99375 m
.75 1 L
s
P
p
.002 w
.91667 .99375 m
.91667 1 L
s
P
p
.001 w
.11667 .99625 m
.11667 1 L
s
P
p
.001 w
.15 .99625 m
.15 1 L
s
P
p
.001 w
.18333 .99625 m
.18333 1 L
s
P
p
.001 w
.21667 .99625 m
.21667 1 L
s
P
p
.001 w
.28333 .99625 m
.28333 1 L
s
P
p
.001 w
.31667 .99625 m
.31667 1 L
s
P
p
.001 w
.35 .99625 m
.35 1 L
s
P
p
.001 w
.38333 .99625 m
.38333 1 L
s
P
p
.001 w
.45 .99625 m
.45 1 L
s
P
p
.001 w
.48333 .99625 m
.48333 1 L
s
P
p
.001 w
.51667 .99625 m
.51667 1 L
s
P
p
.001 w
.55 .99625 m
.55 1 L
s
P
p
.001 w
.61667 .99625 m
.61667 1 L
s
P
p
.001 w
.65 .99625 m
.65 1 L
s
P
p
.001 w
.68333 .99625 m
.68333 1 L
s
P
p
.001 w
.71667 .99625 m
.71667 1 L
s
P
p
.001 w
.78333 .99625 m
.78333 1 L
s
P
p
.001 w
.81667 .99625 m
.81667 1 L
s
P
p
.001 w
.85 .99625 m
.85 1 L
s
P
p
.001 w
.88333 .99625 m
.88333 1 L
s
P
p
.001 w
.05 .99625 m
.05 1 L
s
P
p
.001 w
.01667 .99625 m
.01667 1 L
s
P
p
.001 w
.95 .99625 m
.95 1 L
s
P
p
.001 w
.98333 .99625 m
.98333 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .25 m
1 .25 L
s
P
p
.002 w
.99375 .41667 m
1 .41667 L
s
P
p
.002 w
.99375 .58333 m
1 .58333 L
s
P
p
.002 w
.99375 .75 m
1 .75 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.001 w
.99625 .11667 m
1 .11667 L
s
P
p
.001 w
.99625 .15 m
1 .15 L
s
P
p
.001 w
.99625 .18333 m
1 .18333 L
s
P
p
.001 w
.99625 .21667 m
1 .21667 L
s
P
p
.001 w
.99625 .28333 m
1 .28333 L
s
P
p
.001 w
.99625 .31667 m
1 .31667 L
s
P
p
.001 w
.99625 .35 m
1 .35 L
s
P
p
.001 w
.99625 .38333 m
1 .38333 L
s
P
p
.001 w
.99625 .45 m
1 .45 L
s
P
p
.001 w
.99625 .48333 m
1 .48333 L
s
P
p
.001 w
.99625 .51667 m
1 .51667 L
s
P
p
.001 w
.99625 .55 m
1 .55 L
s
P
p
.001 w
.99625 .61667 m
1 .61667 L
s
P
p
.001 w
.99625 .65 m
1 .65 L
s
P
p
.001 w
.99625 .68333 m
1 .68333 L
s
P
p
.001 w
.99625 .71667 m
1 .71667 L
s
P
p
.001 w
.99625 .78333 m
1 .78333 L
s
P
p
.001 w
.99625 .81667 m
1 .81667 L
s
P
p
.001 w
.99625 .85 m
1 .85 L
s
P
p
.001 w
.99625 .88333 m
1 .88333 L
s
P
p
.001 w
.99625 .05 m
1 .05 L
s
P
p
.001 w
.99625 .01667 m
1 .01667 L
s
P
p
.001 w
.99625 .95 m
1 .95 L
s
P
p
.001 w
.99625 .98333 m
1 .98333 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
p
.006 w
.08333 .08333 m
.91667 .08333 L
.91667 .91667 L
s
P
P
p
[(P1)] .91667 .08333 1.6 -1.6 Mshowa
[(P2)] .08333 .08333 1.6 0 Mshowa
[(P3)] .91667 .91667 0 -1.6 Mshowa
P
p
p
.7 .2 1 r
.34859 .137 m
.40141 .09633 L
.90975 .75667 L
.85692 .79733 L
F
.004 w
.375 .11667 m
.375 .11667 .03333 0 365.73 arc
F
.88333 .777 m
.88333 .777 .03333 0 365.73 arc
F
P
p
.01 w
.375 .11667 Mdot
.88333 .777 Mdot
P
P
p
[(P1)] .375 .11667 0 4 Mshowa
[(P2)] .88333 .777 0 -4 Mshowa
p
.01 w
.375 .11667 m
.125 .11667 L
s
.33964 .08131 m
.375 .11667 L
.33964 .15202 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270, 270},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>00013Q000`40O003h00Oogoo3goo003oOol?
Ool00?moo`moo`00ogoo3goo000QOol50002Ool00`00Oomoo`0UOol00`00Oomoo`0VOol2000XOol3
000VOol3000UOol00`00Oomoo`0GOol002=oo`07001oogooOol007oo00009Goo00<007oo00009goo
00<007oo0000:7oo00<007ooOol09Goo00<007ooOol097oo00<007oo000067oo000MOol30003Ool0
1`00Oomoogoo001oo`00021oo`<0009oo`03001oo`00029oo`<0009oo`03001oo`00025oo`<0009o
o`@0025oo`<000=oo`03001oogoo02=oo`03001oo`0001Qoo`008goo00L007ooOomoo`00Ool0000V
Ool00`00Oomoo`0VOol2000WOol00`00Ool0000XOol00`00Oomoo`0SOol00`00Ool0000HOol002=o
o`07001oogooOol007oo00009Goo00<007oo00009goo00<007ooOol09goo0P009goo00<007oo0000
97oo00<007oo000067oo000ROol20004Ool00`00Oomoo`0UOol00`00Oomoo`0WOol2000XOol00`00
Oomoo`0VOol00`00Oomoo`0TOol00`00Oomoo`0GOol00?moo`moo`00ogoo3goo003oOol?Ool00?mo
o`moo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo000?Oool0003Ool000moo`05001oogoo
Ool00008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo
000?Ool00`00Oomoo`0BOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomo
o`0WOol00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03
001oogoo005oo`003goo00<007ooOol0EWoo0`000Woo1@00V7oo00<007ooOol00Goo000?Ool2001H
Ool00`00Oomoo`03Ool00`00Oomoo`2GOol20003Ool000moo`03001oogoo05Moo`<000=oo`03001o
ogoo09Qoo`03001oogoo005oo`003goo00<007ooOol0Egoo00@007ooOol0009oo`03001oogoo09Qo
o`03001oogoo005oo`003goo00<007ooOol0Egoo00@007ooOol0009oo`03001oogoo09Qoo`03001o
ogoo005oo`003goo00<007ooOol0EWoo10000Woo0P00VWoo00<007ooOol00Goo000?Ool00`00Oomo
o`3hOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0
n7oo00<007ooOol00Goo000?Ool2003hOol20003Ool000moo`03001oogoo0?Qoo`03001oogoo005o
o`003goo00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool0
00moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0n7oo00<007ooOol00Goo0009
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool30003Ool3003ZOol00`00Oomoo`01Ool000Qoo`03001o
o`0000Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo04Aoo`03001oogoo0:=oo`03001o
ogoo005oo`0027oo00<007oo000017oo0`001Woo0`000goo00<007ooOol00goodP004Woo0`000goo
0008Ool00`00Ool00004Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol0@goo0`000goo
1ESOQWoo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`06Ool0
2000Oomoo`00Ool007oo0015Ool3000;F=n2Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`03001oogoo00Eoo`@000=oo`03001oogoo04Eoo`<000]Hgh5oo`03001oogoo019o
o`03001oogoo005oo`003goo00<007ooOol0EGoo0`002eSOP7oo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`1DOol2F=l3000:F=n0Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo05Aoo`=Hg`<000YHggmoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0Dgoo1ESO0`002USOOWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1COol6
F=l3000:F=m`Ool30002Ool50003Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`8001aood80
00UHgg5oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo015oo`8000=oo`003goo00<007oo
Ool06goo@@002eSOL7oo0`000goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`1COol5F=l3000=F=m_Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`1COol4F=l3000?F=m^Ool01000Oomoo`000Woo00<0
07ooOol00goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1DOol2F=l3000@F=m]
Ool40002Ool20005Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo05Aoo`04F=l0
0000000BF=miOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo05Aoo`<001AHggQo
o`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Dgoo0`005USOMgoo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool2001COol30002OolFF=mfOol00`00Oomoo`0AOol20003Ool000mo
o`03001oogoo055oo`<000AooaEHggIoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0DWoo00<007ooOol00goo5USOMGoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`1IOolFF=mdOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo05YooaIHgg=oo`03
001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Fgoo5ESOLgoo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`1KOolFF=mbOol00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo05aooaIHgg5oo`03001oogoo019oo`03001oogoo005oo`003goo0P00GWoo5USOL7oo
00<007ooOol04Goo0P000goo000?Ool00`00Oomoo`1NOolEF=m`Ool00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo05mooaEHgfmoo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0Ggoo5USOKWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1POolFF=m]
Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo065ooaIHgfaoo`03001oogoo019o
o`03001oogoo005oo`003goo00<007ooOol0HWoo5ESOK7oo00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`1ROolFF=m[Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo
06=ooaIHgfYoo`03001oogoo019oo`03001oogoo005oo`003goo0P00IGoo5USOJGoo00<007ooOol0
4Goo0P000goo000?Ool00`00Oomoo`1UOolEF=mYOol00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo06IooaEHgfQoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0IWoo
5USOIgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1WOolFF=mVOol00`00Oomo
o`0BOol00`00Oomoo`01Ool000moo`03001oogoo06QooaEHgfIoo`03001oogoo019oo`03001oogoo
005oo`0027oo0`0017oo00<007ooOol0JGoo5ESOIGoo00<007ooOol04Woo00<007ooOol00Goo0008
Ool00`00Oomoo`04Ool00`00Oomoo`1YOolFF=mTOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Uo
o`03001oogoo00=oo`<006YooaIHgf=oo`03001oogoo011oo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0Jgoo5USOHWoo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool0
0`00Oomoo`1/OolEF=mROol00`00Oomoo`0BOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo06eooaEHgf5oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0KGoo5USO
H7oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1^OolFF=mOOol00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo06mooaEHgemoo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0L7oo5ESOGWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`1`OolFF=mMOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`80079ooaIHgeaoo`03001oogoo
015oo`8000=oo`003goo00<007ooOol0LWoo5ESOG7oo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`1cOolEF=mKOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo07Ao
oaEHgeYoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0M7oo5USOFGoo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1eOolFF=mHOol00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo07IooaEHgeQoo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0Mgoo5ESOEgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool2001hOolFF=mFOol00`00
Oomoo`0AOol20003Ool000moo`03001oogoo07QooaIHgeEoo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0NGoo5ESOEGoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`1jOolEF=mDOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo07]ooaEHge=oo`03
001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Ngoo5USODWoo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`1lOolEF=mBOol00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo07eooaEHge5oo`03001oogoo019oo`03001oogoo005oo`003goo0P00Ogoo5ESOD7oo
00<007ooOol04Goo0P000goo000?Ool00`00Oomoo`1nOolFF=m?Ool00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo07mooaIHgdioo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0P7oo5ESOCWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`21OolEF=m=
Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo085ooaIHgdaoo`03001oogoo019o
o`03001oogoo005oo`003goo00<007ooOol0PWoo5USOBgoo00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`23OolEF=m;Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo
08AooaEHgdYoo`03001oogoo019oo`03001oogoo005oo`003goo0P00QWoo5ESOBGoo00<007ooOol0
4Goo0P000goo000?Ool00`00Oomoo`25OolFF=m8Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo08IooaEHgdQoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Qgoo
5ESOAgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`28OolEF=m6Ool00`00Oomo
o`0BOol00`00Oomoo`01Ool000moo`03001oogoo08QooaIHgdEoo`03001oogoo019oo`03001oogoo
005oo`002Goo0`000goo00<007ooOol0RGoo5USOA7oo00<007ooOol04Woo00<007ooOol00Goo000:
Ool00`00Oomoo`02Ool00`00Oomoo`2:OolEF=m4Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000Qo
o`@000=oo`<008]ooaEHgd=oo`03001oogoo011oo`<000=oo`0027oo00<007oo000017oo00<007oo
Ool0S7oo5ESO@Woo00<007ooOol04Woo00<007ooOol00Goo0009Ool20004Ool00`00Oomoo`2<OolF
F=m1Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo08eooaEH
gd5oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0SWoo5ESO@7oo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`2?OolEF=loOol00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`03001oogoo08mooaIHgcioo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0T7oo5ESO?Woo00<007ooOol04Woo00<007ooOol00Goo000?Ool2002BOolEF=lmOol00`00Oomo
o`0AOol20003Ool000moo`03001oogoo099ooaEHgcaoo`03001oogoo019oo`03001oogoo005oo`00
3goo00<007ooOol0Tgoo5ESO>goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2C
OolFF=ljOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo09AooaEHgcYoo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0UGoo5ESO>Goo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`2FOolEF=lhOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo09IooaIHgcMoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Ugoo5ESO
=goo00<007ooOol04Woo00<007ooOol00Goo000?Ool2002IOolEF=lfOol00`00Oomoo`0AOol20003
Ool000moo`03001oogoo09UooaEHgcEoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0VWoo5ESO=7oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2JOolEF=ldOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo09]ooaEHgc=oo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0W7oo5ESO<Woo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`2MOolEF=laOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo09eo
oaIHgc1oo`03001oogoo019oo`03001oogoo005oo`003goo0P00Wgoo5ESO<7oo00<007ooOol04Goo
0P000goo000?Ool00`00Oomoo`2OOolEF=l_Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo0:1ooaEHgbioo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0XGoo5ESO
;Goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2QOolEF=l]Ool00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo0:9ooaEHgbaoo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0Xgoo5ESO:goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`2TOolEF=lZOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`800:EooaEHgbYoo`03001oogoo
015oo`8000=oo`003goo00<007ooOol0YGoo5ESO:Goo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`2VOolEF=lXOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0:Mo
oaEHgbMoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Z7oo5ESO9Woo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2XOolEF=lVOol00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo0:UooaEHgbEoo`03001oogoo019oo`03001oogoo005oo`0027oo0P00
1Goo00<007ooOol0ZWoo5ESO97oo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004
Ool00`00Oomoo`2[OolEF=lSOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Qoo`03001oo`0000Ao
o`<00:]ooaEHgb=oo`03001oogoo011oo`<000=oo`0027oo0P001Goo00<007ooOol0[7oo5ESO8Woo
00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Oomoo`04Ool00`00Oomoo`2]OolEF=lQOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo0:iooaEHgb1oo`03001oogoo
019oo`03001oogoo005oo`003goo00<007ooOol0[Woo5ESO87oo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`2_OolEF=lOOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001o
ogoo0;1ooaEHgaioo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0/Goo5ESO7Goo
00<007ooOol04Woo00<007ooOol00Goo000?Ool2002cOolEF=lLOol00`00Oomoo`0AOol20003Ool0
00moo`03001oogoo0;9ooaEHgaaoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0
/goo5ESO6goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2dOolEF=lJOol00`00
Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0;EooaEHgaUoo`03001oogoo019oo`03001o
ogoo005oo`003goo00<007ooOol0]Goo5ESO6Goo00<007ooOol04Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`2fOolEF=lHOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0;MooaEH
gaMoo`03001oogoo019oo`03001oogoo005oo`003goo0P00^Goo5ESO5Woo00<007ooOol04Goo0P00
0goo000?Ool00`00Oomoo`2iOolDF=lFOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001o
ogoo0;UooaEHgaEoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0^Woo5ESO57oo
00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2kOolEF=lCOol00`00Oomoo`0BOol0
0`00Oomoo`01Ool000moo`03001oogoo0;aooaEHga9oo`03001oogoo019oo`03001oogoo005oo`00
3goo00<007ooOol0_7oo5ESO4Woo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2m
OolEF=lAOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0;iooaEHga1oo`03001o
ogoo019oo`03001oogoo005oo`003goo0P00`7oo5ESO3goo00<007ooOol04Goo0P000goo000?Ool0
0`00Oomoo`30OolDF=l?Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0<1ooaEH
g`ioo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0`Goo5ESO3Goo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`32OolEF=l<Ool00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`03001oogoo0<=ooaAHg`aoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0`goo5ESO2goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`34OolEF=l:Ool0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`800<IooaEHg`Uoo`03001oogoo015oo`8000=oo`00
3goo00<007ooOol0aWoo5ESO27oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`37
OolDF=l8Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0<MooaEHg`Moo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0b7oo5ESO1Woo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`39OolEF=l5Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo0<YooaAHg`Eoo`03001oogoo019oo`03001oogoo005oo`002Goo00<007ooOol00goo00<0
07ooOol0bWoo5ESO17oo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00
Oomoo`3;OolEF=l3Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<00<ao
oaEHg`9oo`03001oogoo011oo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0cGoo55SO0Woo
00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`3>OolDF=l00goo
001oo`0COol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03001oogoo0<iooaEHg`03001oogoo
019oo`03001oogoo005oo`003goo00<007ooOol0cgoo55SO00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`3@OolCF=l00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0=5o
oa9Hg`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0dGoo2ESO00<005SOF=l01USO
00<007ooOol04Woo00<007ooOol00Goo000?Ool2003COolAF=l00`00Oomoo`0AOol20003Ool000mo
o`03001oogoo0==ooa1Hg`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0e7oo3USO
00=oo`00Ool04goo00<007ooOol00Goo000?Ool00`00Oomoo`3DOol=F=l2Ool00`00Oomoo`0BOol0
0`00Oomoo`01Ool000moo`03001oogoo0=Aoo`aHg`=oo`03001oogoo019oo`03001oogoo005oo`00
3goo00<007ooOol0eWoo2ESO17oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3G
Ool7F=l5Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0=Yoo`9Hg`Moo`03001o
ogoo019oo`03001oogoo005oo`003goo0P00i7oo00<007ooOol04Goo0P000goo000?Ool00`00Oomo
o`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00
Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo019o
o`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo
019oo`03001oogoo005oo`003goo0P00i7oo00<007ooOol04Goo0P000goo000?Ool00`00Oomoo`3S
Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001o
ogoo005oo`003goo00<007ooOol0eWoo0`000goo0`0017oo00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`3GOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo0=Moo`<000=oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo
005oo`003goo00<007ooOol0egoo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0egoo00P007ooOol007oo001oo`0017oo00<007ooOol04Woo
00<007ooOol00Goo000?Ool2003GOol40003Ool00`00Oomoo`03Ool00`00Oomoo`0AOol20003Ool0
00moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<0
07ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo
00<007ooOol04Woo00<007ooOol00Goo0002Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`3SOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000Aoo`07001oogooOol007oo000017oo00<007ooOol0hgoo
00<007ooOol04Woo00<007ooOol00Goo0004Ool01`00Oomoogoo001oo`0000Aoo`<00>=oo`03001o
ogoo011oo`<000=oo`0017oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3hOol00`00Oomoo`01
Ool000Aoo`07001oogooOol007oo000017oo00<007ooOol0n7oo00<007ooOol00Goo0003Ool20004
Ool00`00Oomoo`03Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03001o
ogoo005oo`003goo00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomo
o`01Ool000moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0gWoo0`000goo0P00
4Woo00<007ooOol00Goo000?Ool2003POol00`00Oomoo`04Ool00`00Oomoo`0>Ool20003Ool000mo
o`03001oogoo0=moo`<000=oo`03001oogoo011oo`03001oogoo005oo`003goo00<007ooOol0ggoo
00@007ooOol000=oo`03001oogoo00moo`03001oogoo005oo`003goo00<007ooOol0ggoo00P007oo
Ool007oo001oo`004Goo00<007ooOol00Goo000?Ool00`00Oomoo`3NOol40003Ool00`00Oomoo`0@
Ool00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0n7oo
00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000moo`800?Qoo`8000=oo`00
3goo00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000mo
o`05001oogooOol00008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomo
ogoo00000goo000?Oool0003Ool00001\
\>"],
  ImageRangeCache->{{{0, 269}, {269, 0}} -> {-11.7451, -1.86149, 0.0478571, 
  0.0478571}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Two body objects are defined for the ladder-on-wall model."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the body numbers in the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(ladder = 2; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The ground (body 1) uses three point definitions. \nP1 is the origin of the \
ground body.\nP2 is a point at {-10, 0} that defines the horizontal line of \
the floor. \nP3 is a point at {0, 10} that defines the vertical line of the \
wall."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ladder (body 2) uses two local point definitions.\nP1 is the center of \
the bottom of the ladder at local coordinate {0, 0}.\nP2 is the center of the \
top of the ladder at local coordinate {0, 10}."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the body objects for the ladder-on-wall model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"bd[ground] = Body[ground, PointList\[Rule]\n  {(*P1*) {  0,  0},\n   (*P2*) \
{-10,  0},\n   (*P3*) {  0, 10}} ];\n\nbd[ladder] = Body[ladder, PointList\
\[Rule]\n  {(*P1*) { 0  ,  0    },\n   (*P2*) { 0  , 10    }},\n  \
InitialGuess->{{-7.5, 0}, -\[Pi]/4.0}];"], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetBodies",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " incorporates the body properties into the current model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[bd[ground], bd[ladder]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three constraints, one of which is a driving constraint, are required to \
model the ladder-on-wall. The top and bottom tips of the ladder, which slide \
on the wall and floor, each have a small radius."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used as a driving constraint to push the bottom of the \
ladder across the floor. This constraint is a driving constraint because it \
is functionally dependent on the time variable, ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint places the bottom of the ladder in contact with the floor. ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used with its optional argument to specify offset. This models the 0.4 \
radius at the bottom of the ladder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["PointOnLine1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint places the top of the ladder in contact with the wall, also \
with a 0.4 radius."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraint objects for the ladder-on-wall."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = RelativeX1[1, Point[ladder, 1], \(-T\)]; \)\), 
    \(\(cs[2] = PointOnLine1[2, Point[ladder, 1], Line[ground, 2, 1], 0.4]; 
    \)\), 
    \(\(cs[3] = PointOnLine1[3, Point[ladder, 2], Line[ground, 1, 3], 0.4]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " incorporates the constraint objects into the current model."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[Array[cs, 3]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Applying Loads"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the core function for applying loads to a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model. ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes load objects that represent the physical loads applied to the model \
and builds them into a global load vector that represents the total force and \
moment applied at the origin of each body in the model. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetLoads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["loads, options",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load objects and applies them to the current mechanism model. The loads \
can be a nested list or sequence of loads. Each of the loads must be load \
objects with the head ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", such as are returned by the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load functions. ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["Null",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " upon success."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The load application function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " uses a Lagrange multiplier method to resolve the static and dynamic \
forces on a model, which will be discussed further in Section 7.3. It is \
usually not necessary to specify initial guesses for the Lagrange \
multipliers, because the equations of motion are linear in the Lagrange \
multipliers unless friction forces are applied. If initial guesses are \
needed, they can be specified with the ",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the initial guesses for all Lagrange multipliers.\n \n",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["number",
    FontSlant->"Italic"],
  " uses ",
  StyleBox["number",
    FontSlant->"Italic"],
  " for the initial guess for all Lagrange multipliers. \n \n",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n1, n2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes a list of numbers equal in length to the number of degrees of \
freedom in the model to specify initial guesses for each Lagrange multiplier.\
\n \n",
  StyleBox["LambdaGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is the default, leaves the current guesses unchanged. All guesses \
are initially set to 1.0. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Because forces and moments are additive quantities, it is not necessary to \
apply all of the loads to the model simultaneously. With the ",
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, loads can be applied to the model sequentially. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determines whether the specified loads are to be added to the \
currently defined loads, or to replace the current loads. \n \n",
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes the new loads to be added to the current ones.\n \n",
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default, causes the new loads to replace the current ones."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Loads for the Model"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three loads are defined for the model developed in the previous \
subsection."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 10 units is applied downward to the top of the ladder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 100 units is applied downward at the center of the ladder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 5 units is applied to the ladder in the counterclockwise sense. "
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here are the load objects for the ladder-on-wall model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ld[1] = 
      Force[ladder, 
        Axis[Point[ladder, 2], \n\t\t\tVector[ground, {0, \(-1\)}]], 10]; \n
    ld[2] = Force[ladder, 
        Axis[Point[ladder, {0, 5}], \n\t\t\tVector[ground, {0, \(-1\)}]], 
        100]; \nld[3] = Moment[ladder, 5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysLoad["Moment", "<>"]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Initially, only the two ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects are applied. ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " incorporates the loads into the model. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1], ld[2]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "By using the ",
  StyleBox["AddLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", additional loads can be applied to the model at any time. Thus, the ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can simply be added to the current loading. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This adds the ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object to the ladder-on-wall model. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[3], AddLoads \[Rule] True]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load objects can contain dependencies on other dependent variables. For \
example, to model the force applied by a linear spring, it is necessary to \
have the magnitude of the force be a function of the distance between two \
points.\n\nThe ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of an extension spring with a free length of 2 units and a spring \
constraint ",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attached between the top of the ladder and the top of the wall could be \
modeled as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a spring force."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(ld[4] = 
      Force[ladder, Line[ladder, 2, ground, 3], 
        k\ \((Magnitude[ladder, 2, ground, 3] - 2)\)]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Running the Loaded Model "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because of the presence of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the driving constraint ",
  StyleBox["cs[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the model can be run through its intended range of motion by varying ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " directly with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. The numerical value of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " specifies the distance between the bottom of the ladder and the wall.\n\n\
Although loads have been added to the model, the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " default option setting ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solves only for the location variables. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 7.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[7.5]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["7.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] \(-7.5`\)\), ",", 
        \(Y2 \[Rule] 0.4`\), ",", 
        \(Th2 \[Rule] \(-0.789498209346171986`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " must be told to solve for the static forces in the model with the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a setting for the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to solve for the static reaction forces in the model. \n \n",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to calculate the location of the mechanism bodies and the numeric values \
of the Lagrange multipliers, with all mechanism velocities and accelerations \
set to zero so that no dynamic forces are calculated."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option causes ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to resolve the forces applied to the model into Lagrange multipliers. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 8.5. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[8.5, Solution \[Rule] Static]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["8.5`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] \(-8.5`\)\), ",", 
        \(Y2 \[Rule] 0.4`\), ",", \(Th2 \[Rule] \(-0.944152115154156135`\)\), 
        ",", \(Lmb1 \[Rule] \(-82.0217419526764324`\)\), ",", 
        \(Lmb2 \[Rule] \(-11.0000000000000008`\)\), ",", 
        \(Lmb3 \[Rule] \(-8.20217419526764324`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the ladder-on-wall image at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 8.5."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.916667 0.0833333 0.0833333 0.0833333 [
[(-10)] .08333 0 0 2 Msboxa
[(-8)] .25 0 0 2 Msboxa
[(-6)] .41667 0 0 2 Msboxa
[(-4)] .58333 0 0 2 Msboxa
[(-2)] .75 0 0 2 Msboxa
[(0)] .91667 0 0 2 Msboxa
[(0)] -0.0125 .08333 1 0 Msboxa
[(2)] -0.0125 .25 1 0 Msboxa
[(4)] -0.0125 .41667 1 0 Msboxa
[(6)] -0.0125 .58333 1 0 Msboxa
[(8)] -0.0125 .75 1 0 Msboxa
[(10)] -0.0125 .91667 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08333 0 m
.08333 .00625 L
s
P
[(-10)] .08333 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(-8)] .25 0 0 2 Mshowa
p
.002 w
.41667 0 m
.41667 .00625 L
s
P
[(-6)] .41667 0 0 2 Mshowa
p
.002 w
.58333 0 m
.58333 .00625 L
s
P
[(-4)] .58333 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(-2)] .75 0 0 2 Mshowa
p
.002 w
.91667 0 m
.91667 .00625 L
s
P
[(0)] .91667 0 0 2 Mshowa
p
.001 w
.11667 0 m
.11667 .00375 L
s
P
p
.001 w
.15 0 m
.15 .00375 L
s
P
p
.001 w
.18333 0 m
.18333 .00375 L
s
P
p
.001 w
.21667 0 m
.21667 .00375 L
s
P
p
.001 w
.28333 0 m
.28333 .00375 L
s
P
p
.001 w
.31667 0 m
.31667 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.38333 0 m
.38333 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.48333 0 m
.48333 .00375 L
s
P
p
.001 w
.51667 0 m
.51667 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.61667 0 m
.61667 .00375 L
s
P
p
.001 w
.65 0 m
.65 .00375 L
s
P
p
.001 w
.68333 0 m
.68333 .00375 L
s
P
p
.001 w
.71667 0 m
.71667 .00375 L
s
P
p
.001 w
.78333 0 m
.78333 .00375 L
s
P
p
.001 w
.81667 0 m
.81667 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.88333 0 m
.88333 .00375 L
s
P
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.01667 0 m
.01667 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.98333 0 m
.98333 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .08333 m
.00625 .08333 L
s
P
[(0)] -0.0125 .08333 1 0 Mshowa
p
.002 w
0 .25 m
.00625 .25 L
s
P
[(2)] -0.0125 .25 1 0 Mshowa
p
.002 w
0 .41667 m
.00625 .41667 L
s
P
[(4)] -0.0125 .41667 1 0 Mshowa
p
.002 w
0 .58333 m
.00625 .58333 L
s
P
[(6)] -0.0125 .58333 1 0 Mshowa
p
.002 w
0 .75 m
.00625 .75 L
s
P
[(8)] -0.0125 .75 1 0 Mshowa
p
.002 w
0 .91667 m
.00625 .91667 L
s
P
[(10)] -0.0125 .91667 1 0 Mshowa
p
.001 w
0 .11667 m
.00375 .11667 L
s
P
p
.001 w
0 .15 m
.00375 .15 L
s
P
p
.001 w
0 .18333 m
.00375 .18333 L
s
P
p
.001 w
0 .21667 m
.00375 .21667 L
s
P
p
.001 w
0 .28333 m
.00375 .28333 L
s
P
p
.001 w
0 .31667 m
.00375 .31667 L
s
P
p
.001 w
0 .35 m
.00375 .35 L
s
P
p
.001 w
0 .38333 m
.00375 .38333 L
s
P
p
.001 w
0 .45 m
.00375 .45 L
s
P
p
.001 w
0 .48333 m
.00375 .48333 L
s
P
p
.001 w
0 .51667 m
.00375 .51667 L
s
P
p
.001 w
0 .55 m
.00375 .55 L
s
P
p
.001 w
0 .61667 m
.00375 .61667 L
s
P
p
.001 w
0 .65 m
.00375 .65 L
s
P
p
.001 w
0 .68333 m
.00375 .68333 L
s
P
p
.001 w
0 .71667 m
.00375 .71667 L
s
P
p
.001 w
0 .78333 m
.00375 .78333 L
s
P
p
.001 w
0 .81667 m
.00375 .81667 L
s
P
p
.001 w
0 .85 m
.00375 .85 L
s
P
p
.001 w
0 .88333 m
.00375 .88333 L
s
P
p
.001 w
0 .05 m
.00375 .05 L
s
P
p
.001 w
0 .01667 m
.00375 .01667 L
s
P
p
.001 w
0 .95 m
.00375 .95 L
s
P
p
.001 w
0 .98333 m
.00375 .98333 L
s
P
p
.002 w
0 0 m
0 1 L
s
P
P
p
p
.002 w
.08333 .99375 m
.08333 1 L
s
P
p
.002 w
.25 .99375 m
.25 1 L
s
P
p
.002 w
.41667 .99375 m
.41667 1 L
s
P
p
.002 w
.58333 .99375 m
.58333 1 L
s
P
p
.002 w
.75 .99375 m
.75 1 L
s
P
p
.002 w
.91667 .99375 m
.91667 1 L
s
P
p
.001 w
.11667 .99625 m
.11667 1 L
s
P
p
.001 w
.15 .99625 m
.15 1 L
s
P
p
.001 w
.18333 .99625 m
.18333 1 L
s
P
p
.001 w
.21667 .99625 m
.21667 1 L
s
P
p
.001 w
.28333 .99625 m
.28333 1 L
s
P
p
.001 w
.31667 .99625 m
.31667 1 L
s
P
p
.001 w
.35 .99625 m
.35 1 L
s
P
p
.001 w
.38333 .99625 m
.38333 1 L
s
P
p
.001 w
.45 .99625 m
.45 1 L
s
P
p
.001 w
.48333 .99625 m
.48333 1 L
s
P
p
.001 w
.51667 .99625 m
.51667 1 L
s
P
p
.001 w
.55 .99625 m
.55 1 L
s
P
p
.001 w
.61667 .99625 m
.61667 1 L
s
P
p
.001 w
.65 .99625 m
.65 1 L
s
P
p
.001 w
.68333 .99625 m
.68333 1 L
s
P
p
.001 w
.71667 .99625 m
.71667 1 L
s
P
p
.001 w
.78333 .99625 m
.78333 1 L
s
P
p
.001 w
.81667 .99625 m
.81667 1 L
s
P
p
.001 w
.85 .99625 m
.85 1 L
s
P
p
.001 w
.88333 .99625 m
.88333 1 L
s
P
p
.001 w
.05 .99625 m
.05 1 L
s
P
p
.001 w
.01667 .99625 m
.01667 1 L
s
P
p
.001 w
.95 .99625 m
.95 1 L
s
P
p
.001 w
.98333 .99625 m
.98333 1 L
s
P
p
.002 w
0 1 m
1 1 L
s
P
p
.002 w
.99375 .08333 m
1 .08333 L
s
P
p
.002 w
.99375 .25 m
1 .25 L
s
P
p
.002 w
.99375 .41667 m
1 .41667 L
s
P
p
.002 w
.99375 .58333 m
1 .58333 L
s
P
p
.002 w
.99375 .75 m
1 .75 L
s
P
p
.002 w
.99375 .91667 m
1 .91667 L
s
P
p
.001 w
.99625 .11667 m
1 .11667 L
s
P
p
.001 w
.99625 .15 m
1 .15 L
s
P
p
.001 w
.99625 .18333 m
1 .18333 L
s
P
p
.001 w
.99625 .21667 m
1 .21667 L
s
P
p
.001 w
.99625 .28333 m
1 .28333 L
s
P
p
.001 w
.99625 .31667 m
1 .31667 L
s
P
p
.001 w
.99625 .35 m
1 .35 L
s
P
p
.001 w
.99625 .38333 m
1 .38333 L
s
P
p
.001 w
.99625 .45 m
1 .45 L
s
P
p
.001 w
.99625 .48333 m
1 .48333 L
s
P
p
.001 w
.99625 .51667 m
1 .51667 L
s
P
p
.001 w
.99625 .55 m
1 .55 L
s
P
p
.001 w
.99625 .61667 m
1 .61667 L
s
P
p
.001 w
.99625 .65 m
1 .65 L
s
P
p
.001 w
.99625 .68333 m
1 .68333 L
s
P
p
.001 w
.99625 .71667 m
1 .71667 L
s
P
p
.001 w
.99625 .78333 m
1 .78333 L
s
P
p
.001 w
.99625 .81667 m
1 .81667 L
s
P
p
.001 w
.99625 .85 m
1 .85 L
s
P
p
.001 w
.99625 .88333 m
1 .88333 L
s
P
p
.001 w
.99625 .05 m
1 .05 L
s
P
p
.001 w
.99625 .01667 m
1 .01667 L
s
P
p
.001 w
.99625 .95 m
1 .95 L
s
P
p
.001 w
.99625 .98333 m
1 .98333 L
s
P
p
.002 w
1 0 m
1 1 L
s
P
P
p
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
p
.006 w
.08333 .08333 m
.91667 .08333 L
.91667 .91667 L
s
P
P
p
[(P1)] .91667 .08333 1.6 -1.6 Mshowa
[(P2)] .08333 .08333 1.6 0 Mshowa
[(P3)] .91667 .91667 0 -1.6 Mshowa
P
p
p
.7 .2 1 r
.18879 .14367 m
.22788 .08967 L
.90288 .57836 L
.86379 .63236 L
F
.004 w
.20833 .11667 m
.20833 .11667 .03333 0 365.73 arc
F
.88333 .60536 m
.88333 .60536 .03333 0 365.73 arc
F
P
p
.01 w
.20833 .11667 Mdot
.88333 .60536 Mdot
P
P
p
[(P1)] .20833 .11667 0 4 Mshowa
[(P2)] .88333 .60536 0 -4 Mshowa
p
.01 w
.20833 .11667 m
0 0 rlineto
0 .11667 m
.20833 .11667 L
s
s
.17298 .08131 m
.20833 .11667 L
.17298 .15202 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{270, 270},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004>00013Q000`40O003h00Oogoo3goo003oOol?
Ool00?moo`moo`00ogoo3goo000QOol50002Ool00`00Oomoo`0UOol00`00Oomoo`0VOol2000XOol3
000VOol3000UOol00`00Oomoo`0GOol002=oo`07001oogooOol007oo00009Goo00<007oo00009goo
00<007oo0000:7oo00<007ooOol09Goo00<007ooOol097oo00<007oo000067oo000MOol30003Ool0
1`00Oomoogoo001oo`00021oo`<0009oo`03001oo`00029oo`<0009oo`03001oo`00025oo`<0009o
o`@0025oo`<000=oo`03001oogoo02=oo`03001oo`0001Qoo`008goo00L007ooOomoo`00Ool0000V
Ool00`00Oomoo`0VOol2000WOol00`00Ool0000XOol00`00Oomoo`0SOol00`00Ool0000HOol002=o
o`07001oogooOol007oo00009Goo00<007oo00009goo00<007ooOol09goo0P009goo00<007oo0000
97oo00<007oo000067oo000ROol20004Ool00`00Oomoo`0UOol00`00Oomoo`0WOol2000XOol00`00
Oomoo`0VOol00`00Oomoo`0TOol00`00Oomoo`0GOol00?moo`moo`00ogoo3goo003oOol?Ool00?mo
o`moo`00ogoo3goo003oOol?Ool00?moo`moo`00ogoo3goo000?Oool0003Ool000moo`05001oogoo
Ool00008Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00
Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo
000?Ool00`00Oomoo`0BOol00`00Oomoo`0WOol00`00Oomoo`0WOol00`00Oomoo`0VOol00`00Oomo
o`0WOol00`00Oomoo`0WOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03
001oogoo005oo`003goo00<007ooOol0;7oo0`000Woo1@00`Woo00<007ooOol00Goo000?Ool2000^
Ool00`00Oomoo`03Ool00`00Oomoo`31Ool20003Ool000moo`03001oogoo02eoo`<000=oo`03001o
ogoo0<9oo`03001oogoo005oo`003goo00<007ooOol0;Goo00@007ooOol0009oo`03001oogoo0<9o
o`03001oogoo005oo`003goo00<007ooOol0;Goo00@007ooOol0009oo`03001oogoo0<9oo`03001o
ogoo005oo`003goo00<007ooOol0;7oo10000Woo0P00a7oo00<007ooOol00Goo000?Ool00`00Oomo
o`3hOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0
n7oo00<007ooOol00Goo000?Ool2003hOol20003Ool000moo`03001oogoo0?Qoo`03001oogoo005o
o`003goo00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool0
00moo`03001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0n7oo00<007ooOol00Goo0009
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool30003Ool3003ZOol00`00Oomoo`01Ool000Qoo`03001o
o`0000Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo0<eoo`03001o
ogoo005oo`0027oo00<007oo000017oo0`001Woo0`000goo00<007ooOol00goodP004Woo0`000goo
0008Ool00`00Ool00004Ool00`00Oomoo`06Ool01000Oomoo`000Woo00<007ooOol06Goo0`0017oo
1ESO[goo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`06Ool0
2000Oomoo`00Ool007oo000KOol3000;F=n/Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`03001oogoo00Eoo`@000=oo`03001oogoo01]oo`<000]Hgj]oo`03001oogoo019o
o`03001oogoo005oo`003goo00<007ooOol0:goo0`002eSOZWoo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`0ZOol2F=l3000<F=nXOol00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo02Yoo`=Hg`<000aHgjMoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0:Goo1ESO0`0035SOYWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`0YOol6
F=l3000=F=nGOol30002Ool50003Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000ioocL000eHgiMo
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo015oo`8000=oo`003Woo=P003eSOUWoo0`00
0goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`0YOol5F=l3
000BF=nDOol01000Oomoo`000Woo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`0YOol4F=l3000DF=nCOol01000Oomoo`000Woo00<007ooOol00goo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`0ZOol2F=l3000GF=n@Ool40002Ool20005Ool00`00
Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo02]oo`<001UHgiaoo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0:Woo0`006eSOVgoo00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`0YOol3000NF=nIOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`8002Uo
o`<000=ooaeHgiQoo`03001oogoo015oo`8000=oo`003goo00<007ooOol09goo0`001Goo7ESOUgoo
00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`0XOol00`00Oomoo`06OolMF=nEOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo039ooaeHgiAoo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0<goo7USOTWoo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`0eOolMF=nAOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo03Io
oaeHgi1oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0>7oo7ESOSWoo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool2000jOolMF=n=Ool00`00Oomoo`0AOol20003Ool000moo`03
001oogoo03YooaeHghaoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0?7oo7ESO
RWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`0mOolMF=n9Ool00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo03mooaeHghMoo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0@7oo7ESOQWoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`11OolMF=n5Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo04=ooaeHgh=oo`03
001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0A7oo7ESOPWoo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool20017OolLF=n1Ool00`00Oomoo`0AOol20003Ool000moo`03001oogoo04Mo
oaeHggmoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0B7oo7ESOOWoo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1:OolMF=mlOol00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo04]ooaeHgg]oo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0CGoo75SONWoo00<007ooOol04Woo00<007ooOol00Goo0008Ool30004Ool00`00Oomoo`1>
OolMF=mhOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`03001oogoo04mo
oaeHggMoo`03001oogoo019oo`03001oogoo005oo`002Goo00<007ooOol00goo0`00DGoo75SOMWoo
00<007ooOol047oo0`000goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1BOolMF=mdOol00`00Oomo
o`0BOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo05AooaaHgg=oo`03001oogoo
019oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0EGoo7ESOLGoo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`1FOolMF=m`Ool00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`03001oogoo05QooaaHgfmoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0FGoo7ESOKGoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1JOolMF=m/Ool0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo05aooaaHgf]oo`03001oogoo019oo`03
001oogoo005oo`003goo0P00GWoo7ESOJGoo00<007ooOol04Goo0P000goo000?Ool00`00Oomoo`1O
OolLF=mXOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo061ooaeHgfIoo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0HGoo7ESOIGoo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`1SOolLF=mTOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo06AooaeHgf9oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0IWoo75SO
HGoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1WOolLF=mPOol00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`8006UooaeHgeioo`03001oogoo015oo`8000=oo`003goo00<007oo
Ool0JWoo75SOGGoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1[OolMF=mKOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo06eooaaHgeYoo`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0KWoo75SOFGoo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`1_OolMF=mGOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo075o
oaaHgeIoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0LWoo75SOEGoo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool2001eOolLF=mCOol00`00Oomoo`0AOol20003Ool000moo`03
001oogoo07EooaaHge9oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0MWoo7ESO
D7oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`1hOolLF=m?Ool00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo07UooaaHgdioo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0Ngoo75SOC7oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomo
o`1lOolLF=m;Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo07eooaaHgdYoo`03
001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Ogoo75SOB7oo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool20021OolLF=m7Ool00`00Oomoo`0AOol20003Ool000moo`03001oogoo085o
oaeHgdEoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0Pgoo75SOA7oo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool00`00Oomoo`24OolLF=m3Ool00`00Oomoo`0BOol00`00Oomo
o`01Ool000moo`03001oogoo08IooaaHgd5oo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0Qgoo75SO@7oo00<007ooOol04Woo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`28
OolLF=loOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Yoo`03001oogoo009oo`03001oogoo08Yo
oaaHgceoo`03001oogoo019oo`03001oogoo005oo`0027oo10000goo0`00Rgoo75SO?7oo00<007oo
Ool047oo0`000goo0008Ool00`00Ool00004Ool00`00Oomoo`2=OolLF=ljOol00`00Oomoo`0BOol0
0`00Oomoo`01Ool000Uoo`8000Aoo`03001oogoo08iooaaHgcUoo`03001oogoo019oo`03001oogoo
005oo`002Woo00<007ooOol00Woo00<007ooOol0Sgoo75SO>7oo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`2AOolLF=lfOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001o
ogoo099ooaaHgcEoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0U7oo6eSO=7oo
00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2EOolLF=lbOol00`00Oomoo`0BOol0
0`00Oomoo`01Ool000moo`8009MooaaHgc5oo`03001oogoo015oo`8000=oo`003goo00<007ooOol0
V7oo75SO;goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2IOolLF=l^Ool00`00
Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo09]ooa]Hgbeoo`03001oogoo019oo`03001o
ogoo005oo`003goo00<007ooOol0W7oo75SO:goo00<007ooOol04Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`2MOolLF=lZOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo09mooa]H
gbUoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0X7oo75SO9goo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`2ROolKF=lVOol00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`800:AooaaHgbAoo`03001oogoo015oo`8000=oo`003goo00<007ooOol0Y7oo75SO8goo
00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2VOolKF=lROol00`00Oomoo`0BOol0
0`00Oomoo`01Ool000moo`03001oogoo0:MooaaHgb1oo`03001oogoo019oo`03001oogoo005oo`00
3goo00<007ooOol0ZGoo6eSO7goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2Z
OolKF=lNOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0:]ooaaHgaaoo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0[Goo6eSO6goo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool2002_OolLF=lIOol00`00Oomoo`0AOol20003Ool000moo`03001oogoo0:mooaaH
gaQoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0/Goo6eSO5goo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`2bOolLF=lEOol00`00Oomoo`0BOol00`00Oomoo`01
Ool000moo`03001oogoo0;Aooa]HgaAoo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0]Goo6eSO4goo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`2fOolLF=lAOol0
0`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0;Qooa]Hga1oo`03001oogoo019oo`03
001oogoo005oo`003goo0P00^Woo75SO3Woo00<007ooOol04Goo0P000goo000?Ool00`00Oomoo`2k
OolKF=l=Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0;aooa]Hg`aoo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0_Goo75SO2Woo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`2oOolKF=l9Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo0<1ooa]Hg`Qoo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0`Woo6eSO
1Woo00<007ooOol04Woo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`33OolKF=l5Ool00`00
Oomoo`0BOol00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`03001oogoo0<AooaaHg`=oo`03001o
ogoo019oo`03001oogoo005oo`0027oo00<007oo000017oo0`00aWoo6eSO0Woo00<007ooOol047oo
0`000goo0008Ool20005Ool00`00Oomoo`37OolKF=l00goo001oo`0COol00`00Oomoo`01Ool000Qo
o`03001oogoo00Aoo`03001oogoo0<UooaYHg`03001oogoo019oo`03001oogoo005oo`002Goo0P00
17oo00<007ooOol0bWoo6ESO00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3;OolH
F=l00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0<eooaIHg`03001oogoo019oo`03
001oogoo005oo`003goo00<007ooOol0cWoo35SO00<005SOF=l01USO00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`3@OolCF=l00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`800=9o
oa9Hg`03001oogoo015oo`8000=oo`003goo00<007ooOol0dWoo45SO00=oo`00Ool04goo00<007oo
Ool00Goo000?Ool00`00Oomoo`3DOol=F=l2Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo0=Aoo`aHg`=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0eWoo2ESO
17oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3GOol7F=l5Ool00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo0=Yoo`9Hg`Moo`03001oogoo019oo`03001oogoo005o
o`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool2003TOol00`00Oomo
o`0AOol20003Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0B
Ool00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo
00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomo
o`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`00
3goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?Ool2003TOol00`00Oomoo`0A
Ool20003Ool000moo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007oo
Ool0eWoo0`000goo0`0017oo00<007ooOol04Woo00<007ooOol00Goo000?Ool00`00Oomoo`3GOol0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo
0=Moo`<000=oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0
egoo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo005oo`003goo00<0
07ooOol0egoo00P007ooOol007oo001oo`0017oo00<007ooOol04Woo00<007ooOol00Goo000?Ool0
0`00Oomoo`3FOol40003Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`80
0>Aoo`03001oogoo015oo`8000=oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=o
o`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo
0>=oo`03001oogoo019oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0hgoo00<0
07ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool00004Ool00`00Oomoo`3SOol00`00Oomoo`0B
Ool00`00Oomoo`01Ool000Qoo`03001oo`0000Aoo`<00>=oo`03001oogoo011oo`<000=oo`002Goo
00<007ooOol00goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo0008Ool00`00Ool0
0004Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`03
001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol0
4Woo00<007ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000mo
o`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007oo
Ool04Woo00<007ooOol00Goo000?Ool2003TOol00`00Oomoo`0AOol20003Ool000moo`03001oogoo
0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001o
ogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo
00<007ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03
001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo0P00i7oo00<007ooOol04Goo0P00
0goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=o
o`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo
0>=oo`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<0
07ooOol00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001o
ogoo0>=oo`03001oogoo019oo`03001oogoo005oo`003goo0P00i7oo00<007ooOol04Goo0P000goo
000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03
001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol0
0Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=o
o`03001oogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007oo
Ool00Goo000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`800>Aoo`03
001oogoo015oo`8000=oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo000?
Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000moo`03001oogoo0>=oo`03001o
ogoo019oo`03001oogoo005oo`003goo00<007ooOol0hgoo00<007ooOol04Woo00<007ooOol00Goo
000?Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool0009oo`D0009oo`03001oogoo
00=oo`03001oogoo0>=oo`03001oogoo019oo`03001oogoo005oo`0017oo00L007ooOomoo`00Ool0
0004Ool00`00Oomoo`3SOol00`00Oomoo`0BOol00`00Oomoo`01Ool000Aoo`07001oogooOol007oo
000017oo0`00hgoo00<007ooOol047oo0`000goo0004Ool01`00Oomoogoo001oo`0000Aoo`03001o
ogoo0?Qoo`03001oogoo005oo`0017oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3hOol00`00
Oomoo`01Ool000=oo`8000Aoo`03001oogoo00=oo`03001oogoo0?Qoo`03001oogoo005oo`003goo
00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000moo`03
001oogoo0?Qoo`03001oogoo005oo`003goo00<007ooOol0n7oo00<007ooOol00Goo000?Ool00`00
Oomoo`3NOol30003Ool2000BOol00`00Oomoo`01Ool000moo`800>1oo`03001oogoo00Aoo`03001o
ogoo00ioo`8000=oo`003goo00<007ooOol0ggoo0`000goo00<007ooOol047oo00<007ooOol00Goo
000?Ool00`00Oomoo`3OOol01000Oomoo`000goo00<007ooOol03goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3OOol02000Oomoo`00Ool007oo000AOol00`00Oomoo`01Ool000moo`03001oogoo0=io
o`@000=oo`03001oogoo011oo`03001oogoo005oo`003goo00<007ooOol0n7oo00<007ooOol00Goo
000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000moo`03001oogoo0?Qoo`03001oogoo005oo`00
3goo0P00n7oo0P000goo000?Ool00`00Oomoo`3hOol00`00Oomoo`01Ool000moo`03001oogoo0?Qo
o`03001oogoo005oo`003goo00D007ooOomoo`0000Qoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`05001oogooOol00003Ool000mooo`000=oo`00\
\>"],
  ImageRangeCache->{{{0, 269}, {269, 0}} -> {-11.7451, -1.86149, 0.0478571, 
  0.0478571}}]
}, Open  ]],

Cell[TextData[{
  "The numeric values of the Lagrange multipliers returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are not directly very useful, unless one has a very good understanding of \
the exact form of the constraints. However, the set of Lagrange multipliers \
associated with a mechanism model completely determines all of the reaction \
forces in the constraints in the model. To find the actual reaction forces \
and moments at a specific constraint it is necessary to use the ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, which is described in the following section. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Ladder-on-Wall Graphics"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech2D`\"] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"groundGr = Graphics[{\n  Thickness[.006],\n  Edge[ground, {2,1,3}]}];"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"groundTx = Graphics[{ \n  Text[\"P1\",Location[ground,1],{ 1.6,-1.6}],\n  \
Text[\"P2\",Location[ground,2],{ 1.6, 0  }],\n  \
Text[\"P3\",Location[ground,3],{ 0  ,-1.6}] }];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"ladderGr = Graphics[{\n  {RGBColor[.7,.2,1], Bar[Line[ladder,1,2], .4, .4], \
\n   Disk[Location[ladder, 1], .4], \n   Disk[Location[ladder, 2], .4]},\n  \
PointSize[.01],Vertex[ladder, {1,2}]} ];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
ladderTx = Graphics[{Thickness[.01], 
  Text[\"P1\",Location[ladder,1],{ 0, 4.0}],
  Text[\"P2\",Location[ladder,2],{ 0,-4.0}], 
  Arrow[Axis[ladder, 1, ground, {-1,0}], 3, Reverse->True]}];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[{groundGr,groundTx,ladderGr,ladderTx}/.LastSolve[],\n\
Frame->True,PlotRange->{{-11,1},{-1,11}},\nAspectRatio->Automatic];"], "Input",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["7.3  Resultant Forces"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section describes the usage of the two ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions that are used to convert the Lagrange multipliers into reaction \
forces on specific bodies in a model, ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, the 2D ladder-on-wall model that was developed in Section 7.2 \
is used. The bodies and constraints of the model are redefined here in \
abbreviated form."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The following loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and completely defines the ladder-on-wall model. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(ladder = 2; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"SetBodies[\n  Body[ground, PointList \[Rule]\n  {(*P1*){  0,  0},\n   \
(*P2*){-10,  0},\n   (*P3*){  0, 10}} ],\n  Body[ladder, PointList \[Rule]\n  \
{(*P1*){ 0  ,  0    },\n   (*P2*){ 0  , 10    }},\n  InitialGuess \[Rule] \
{{-7.5, 0}, -\[Pi]/4.}] ]"], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRelativeX1[1, Point[ladder, 1], \(-T\)], \n\t
      PointOnLine1[2, \n\t\tPoint[ladder, 1], Line[ground, 2, 1], 0.4], \n\t
      PointOnLine1[3, \n\t\tPoint[ladder, 2], Line[ground, 1, 3], 0.4]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The model is run to prove that it works."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[7]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 7, X2 \[Rule] \(-7.`\), Y2 \[Rule] 0.4`, 
      Th2 \[Rule] \(-0.720818760868632502`\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Reaction "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used to convert the Lagrange multipliers that are returned by \
",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " into specific reaction forces and moments that are applied to each body \
by the constraints in the mechanism model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["um",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force and moment applied to body ",
  StyleBox["bnum ",
    FontSlant->"Italic"],
  "by constraint ",
  StyleBox["cnum",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" ca",
    FontFamily->"Times"],
  "lculated about the local origin of body ",
  StyleBox["bnum. ",
    FontSlant->"Italic"],
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of the form {",
  StyleBox["force",
    FontSlant->"Italic"],
  ", ",
  StyleBox["moment",
    FontSlant->"Italic"],
  "}.\n\n",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["Point[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum, lpn",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force and moment applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " calculated about local point ",
  StyleBox["lpnt",
    FontSlant->"Italic"],
  " on body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, bnum, point",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the reaction force and moment applied by constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " calculated about ",
  StyleBox["point",
    FontSlant->"Italic"],
  ". Only the reaction moment is affected by the point about which it is \
calculated, the reaction force is not a function of the location of ",
  StyleBox["point",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Reaction[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, symbol",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the generalized reaction applied to a single coordinate or \
parameter ",
  StyleBox["symbol",
    FontSlant->"Italic"],
  " that occurs in the model.  \n \n",
  StyleBox["Reaction[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum1, cnum2",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the sum of the reactions applied by several constraints ",
  StyleBox["cnumi",
    FontSlant->"Italic"],
  ".\n \n",
  StyleBox["Reaction[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eqn1, eqn2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the sum of the reactions applied by several specific equations ",
  StyleBox["eqni",
    FontSlant->"Italic"],
  " in constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The function for finding constraint reaction forces."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether the forces and moments returned are to be in \
global or local coordinates. In 2D models, reaction moments are scalars and \
are unaffected by the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option.\n \n",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return force and moment vectors in the local coordinate system \
attached to the body to which the reaction load is applied. \n \n",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default, causes ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return forces and moments in global coordinates."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", loads are applied to the ladder-on-wall model that was redefined in the \
previous subsection."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 10 units is applied downward to the top of the ladder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 100 units is applied downward at the center of the ladder."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " of 5 units is applied to the ladder in the counterclockwise sense. "
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the load objects for the ladder-on-wall model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ld[1] = 
      Force[ladder, Axis[Point[ladder, 2], Vector[ground, {0, \(-1\)}]], 10]; 
    \)\), 
    \(\(ld[2] = 
      Force[ladder, Axis[Point[ladder, {0, 5}], Vector[ground, {0, \(-1\)}]], 
        100]; \)\), 
    \(\(ld[3] = Moment[ladder, 5]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Only the first two loads are added to the model initially; the other load \
will be added later. The model can then be run with the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to solve for the Lagrange multipliers."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Load 1 and load 2 are applied to the current model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1], ld[2]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 6.0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[6.0, Solution \[Rule] Static]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["6.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", \(X2 \[Rule] \(-6.`\)\), ",", 
        \(Y2 \[Rule] 0.4`\), ",", \(Th2 \[Rule] \(-0.594385800001062136`\)\), 
        ",", \(Lmb1 \[Rule] \(-40.5555821651624714`\)\), ",", 
        \(Lmb2 \[Rule] \(-11.0000000000000008`\)\), ",", 
        \(Lmb3 \[Rule] \(-4.05555821651624714`\)\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Because the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function references constraints by number, names are given to each of the \
constraints for clarity. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the constraints in the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Off[General::"\<spell1\>"]\), 
    \(\(driver = 1; \)\), 
    \(\(floor = 2; \)\), 
    \(\(wall = 3; \)\), 
    \(On[General::"\<spell1\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The horizontal force at the bottom of the ladder that is required to hold \
the ladder in its current position is the reaction to constraint 1, the \
driving constraint. Note that the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " force and the moment sustained by the driving constraint are both zero, \
and always will be, because the driving constraint (",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") does not constrain motion in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " or ",
  StyleBox["theta",
    FontSlant->"Italic"],
  " directions, therefore, it cannot sustain any load in those directions."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the reaction to the driver."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[driver, Point[ladder, 1]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{40.5555821651624714`, 0}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "For the ladder to be in equilibrium, the force at the driver must be \
balanced by the force against the wall. Note that the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, like all other ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " output functions, returns a symbolic expression in terms of dependent \
variables. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the reaction against the wall. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Reaction[wall, Point[ladder, 2]]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{10\ Lmb3, 0}, 0}\)], "Output"],

Cell[BoxData[
    \({{\(-40.5555821651624714`\), 0}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Note that if a different point is chosen about which to calculate the \
reaction, only the moment is changed. A reaction force is not a function of \
the point about which the reaction is calculated, therefore, the choice of a \
calculation point never affects the force, only the moment. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction against the wall calculated about a point on the \
ground."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[wall, ladder, Point[ground, {2., 3.}]] /. LastSolve[]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-40.5555821651624714`\), 0}, 230.555486370577567`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Since there is no friction in this model, the sum of all of the vertical \
forces is applied to the floor. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the reaction against the floor."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[floor, Point[ladder, 1]] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 110.000000000000008`}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"When the applied moment, load 3, is added to the model, it shows up as added \
reaction force against the driver and the wall."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"The moment that was previously defined is added to the model. "], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[3], AddLoads \[Rule] True]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the reaction against the wall."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[wall, Point[ladder, 2]] /. 
      SolveMech[6.0, Solution \[Rule] Static]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{\(-39.9520764781808868`\), 0}, 0}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The actual load vector that is generated by ",
  StyleBox["SetLoads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be directly accessed with ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be very useful for debugging a model because it is often possible to \
read the load expressions directly and relate them to the function of the \
model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Loads[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the part of the current load vector associated with the specified \
bodies. The load vector is formed with respect to the current velocity \
coordinate system. Thus, if the current model uses the Euler coordinate \
system, the moment component of the applied loads are returned in Euler \
coordinates and have no physical meaning.\n\n",
  StyleBox["Loads[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire load vector of the current model.\n\n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum,",
    FontSlant->"Italic"],
  " ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["coordsys",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["force, moment",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " representing the total force and moment applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["force",
    FontSlant->"Italic"],
  " and ",
  StyleBox["moment",
    FontSlant->"Italic"],
  " are formed with respect to ",
  StyleBox["coordsys",
    FontSlant->"Italic"],
  ", either ",
  StyleBox["Global",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The load inspection function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies whether to return applied, reaction, or dynamic loads. \n \
\n",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Applied",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default, causes ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the total externally applied load on the body. \n \n",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the total load applied to the body by the constraints. \n \n",
  StyleBox["Type",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the total dynamic loads on the body. Given that ",
  StyleBox["F = ma",
    FontFamily->"Times",
    FontSlant->"Italic"],
  ", the dynamic loads are equal to ",
  StyleBox["-ma.",
    FontFamily->"Times",
    FontSlant->"Italic"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "If the ",
  StyleBox["Coordinates",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is not specified, ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns forces that are generalized to the current velocity coordinate \
system. Since velocity in the current model is represented by {",
  StyleBox["Xnd, Ynd, Thnd",
    FontSlant->"Italic"],
  "} the returned loads are {",
  StyleBox["Fx, Fy, M",
    FontSlant->"Italic"],
  "}, calculated about the local origin. Consider the 2D ladder-on-wall model \
of the previous subsection. ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to find the total load applied to the ladder resolved into a \
force applied to the origin of the ladder, and a moment. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the total load applied to the ladder."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Loads[ladder]\), 
    \(% /. SolveMech[6.0, Solution \[Rule] Static]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, \(-110\), 5 + 600\ Sin[Th2]}\)], "Output"],

Cell[BoxData[
    \({0, \(-110\), \(-330.99999999999996`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"In all cases, the sum of the applied, reaction, and dynamic loads on any \
body must be zero. Since there are no dynamic loads in this model, the total \
reaction loads on all constraints must be equal to the total applied loads. \
"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the total reaction load applied by the constraints to the ladder. "],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Loads[ladder, Type \[Rule] Reaction]\), 
    \(% /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-Lmb1\) + 10\ Lmb3, \(-10\)\ Lmb2, \(-100\)\ Lmb3\ Cos[Th2]}\)], 
  "Output"],

Cell[BoxData[
    \({0.`, 110.000000000000008`, 330.99999999999996`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The dynamic, or inertial, loads on the ladder are identically zero because \
there are no masses or moments of inertia defined. If there were, the dynamic \
loads would be functions of the model's acceleration variables, ",
  StyleBox["X3dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and so on. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the inertial loads on the ladder. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Loads[ladder, Type \[Rule] Dynamic]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the numerical sum of the loads is zero, but the algebraic terms \
are quite different. This basically shows part of the system of equations \
that was solved by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when the numeric values of the Lagrange multipliers were found. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["7.4  Multistage Loads"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section demonstrates how to use ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the context of a loaded mechanism model. The use of ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in a kinematic model is covered in Chapter 5. In general, switching \
forces on and off is treated in the same way as switching constraints on and \
off. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Stage and Time Switches "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used for loads in the same manner as it is used for \
constraints, with one important difference. Because loads are cumulative, ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can apply more than one of the switched loads at a time, or no loads at \
all. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["StageSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["test1, loads1, test2, loads2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load object that is used in place of a normal load object in a model. ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates all of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  ", and applies the sum of each of the ",
  StyleBox["loadsi",
    FontSlant->"Italic"],
  " corresponding to each of the ",
  StyleBox["testi",
    FontSlant->"Italic"],
  " that return ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The multistage mechanism load-switching function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Unlike most built-in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " switching functions, ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does evaluate its arguments immediately. This means that test functions \
such as ",
  StyleBox["SameQ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot be used because ",
  StyleBox["SameQ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " immediately, without waiting for some future condition to change and make \
it ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the context of the mechanism model. ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will fail if any of the test expressions fail to return ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at run time. \n\nEach of the loads supplied to the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load object with the head ",
  StyleBox["SysLoad",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or a nested list of load objects."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " might be used to model a force that is either a constant force in one \
direction or a function of ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in another direction. Which force is applied is determined by the value \
of the user-defined symbol ",
  StyleBox["whichload",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\), 
    \(whichload =. \)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(StageSwitch[\n\twhichload == 1, \n\t
      Force[slider, Line[ground, {0, 0}, {1, 0}], 10], \n\twhichload == 2, \n
      \tForce[slider, Line[ground, {0, 0}, {1, 3}], Sin[T\^2]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({SysLoad["Force", "<>"], SysLoad["Force", "<>"]}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[TextData[{
  "The ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is also used to apply loads in much the same way it is used to \
apply constraints. The primary difference is that the load object ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may have a leading time, before which no load is applied, and a trailing \
time, after which no load is applied."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["TimeSwitch[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time0, load0, time1, load1, ..., timen, loadn, time(n+1)",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load objects that are used in place of a normal load object in a model. ",
  
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies ",
  StyleBox["loadsi",
    FontSlant->"Italic"],
  " when the value of time is greater than ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " and less than ",
  StyleBox["time(i+1)",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["timei",
    FontSlant->"Italic"],
  " must evaluate to numbers in ascending order. ",
  StyleBox["time0",
    FontSlant->"Italic"],
  " and ",
  StyleBox["time(n+1)",
    FontSlant->"Italic"],
  " are optional. The default values of ",
  StyleBox["time0",
    FontSlant->"Italic"],
  " and ",
  StyleBox["time(n+1)",
    FontSlant->"Italic"],
  " are ",
  StyleBox["-$MaxMachineNumber",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["+$MaxMachineNumber",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", respectively. ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions analogously to ",
  StyleBox["Which",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The time-dependent, load switching function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Each of the loads supplied to the ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load object or a nested list of load objects."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following example shows how a ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " might be used to model a force applied to the slider that is to remain \
constraint in magnitude until the value of time reaches 2.0, at which time \
the force begins to increase linearly with time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a valid ",
  StyleBox["TimeSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeSwitch[\n\tForce[slider, Line[ground, {0, 0}, {4, 0}], 10], \n\t
      2.0, \n\tForce[slider, \n\t\tLine[ground, {0, 0}, {4, 0}], 
        10 + k\ \((T - 2.0)\)]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({SysLoad["Force", "<>"], SysLoad["Force", "<>"]}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism "], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To demonstrate the use of ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, a 2D model is developed that is subject to a variable applied \
load. The model is a simple piston-pump that has a nonlinear compression \
function applied to the piston. \n\nThe input to the model is to rotate the \
crankshaft. The pressure on the piston increases slowly but nonlinearly until \
near the end of its stroke, at which time the pressure decreases very rapidly \
back to zero. The pressure then remains at zero through the return stroke of \
the piston. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the 2D piston-pump graphic. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .46465  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.24507 0.0962001 0.232323 0.0962001 [ 
[(-2)] .05267 0 0 2 Msboxa 
[(0)] .24507 0 0 2 Msboxa 
[(2)] .43747 0 0 2 Msboxa 
[(4)] .62987 0 0 2 Msboxa 
[(6)] .82227 0 0 2 Msboxa 
[(-2)] -0.0125 .03992 1 0 Msboxa 
[(-1)] -0.0125 .13612 1 0 Msboxa 
[(0)] -0.0125 .23232 1 0 Msboxa 
[(1)] -0.0125 .32852 1 0 Msboxa 
[(2)] -0.0125 .42472 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 .46565 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.05267 0 m 
.05267 .00625 L 
s 
P 
[(-2)] .05267 0 0 2 Mshowa 
p 
.002 w 
.24507 0 m 
.24507 .00625 L 
s 
P 
[(0)] .24507 0 0 2 Mshowa 
p 
.002 w 
.43747 0 m 
.43747 .00625 L 
s 
P 
[(2)] .43747 0 0 2 Mshowa 
p 
.002 w 
.62987 0 m 
.62987 .00625 L 
s 
P 
[(4)] .62987 0 0 2 Mshowa 
p 
.002 w 
.82227 0 m 
.82227 .00625 L 
s 
P 
[(6)] .82227 0 0 2 Mshowa 
p 
.001 w 
.09115 0 m 
.09115 .00375 L 
s 
P 
p 
.001 w 
.12963 0 m 
.12963 .00375 L 
s 
P 
p 
.001 w 
.16811 0 m 
.16811 .00375 L 
s 
P 
p 
.001 w 
.20659 0 m 
.20659 .00375 L 
s 
P 
p 
.001 w 
.28355 0 m 
.28355 .00375 L 
s 
P 
p 
.001 w 
.32203 0 m 
.32203 .00375 L 
s 
P 
p 
.001 w 
.36051 0 m 
.36051 .00375 L 
s 
P 
p 
.001 w 
.39899 0 m 
.39899 .00375 L 
s 
P 
p 
.001 w 
.47595 0 m 
.47595 .00375 L 
s 
P 
p 
.001 w 
.51443 0 m 
.51443 .00375 L 
s 
P 
p 
.001 w 
.55291 0 m 
.55291 .00375 L 
s 
P 
p 
.001 w 
.59139 0 m 
.59139 .00375 L 
s 
P 
p 
.001 w 
.66835 0 m 
.66835 .00375 L 
s 
P 
p 
.001 w 
.70683 0 m 
.70683 .00375 L 
s 
P 
p 
.001 w 
.74531 0 m 
.74531 .00375 L 
s 
P 
p 
.001 w 
.78379 0 m 
.78379 .00375 L 
s 
P 
p 
.001 w 
.01419 0 m 
.01419 .00375 L 
s 
P 
p 
.001 w 
.86075 0 m 
.86075 .00375 L 
s 
P 
p 
.001 w 
.89923 0 m 
.89923 .00375 L 
s 
P 
p 
.001 w 
.93771 0 m 
.93771 .00375 L 
s 
P 
p 
.001 w 
.97619 0 m 
.97619 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .03992 m 
.00625 .03992 L 
s 
P 
[(-2)] -0.0125 .03992 1 0 Mshowa 
p 
.002 w 
0 .13612 m 
.00625 .13612 L 
s 
P 
[(-1)] -0.0125 .13612 1 0 Mshowa 
p 
.002 w 
0 .23232 m 
.00625 .23232 L 
s 
P 
[(0)] -0.0125 .23232 1 0 Mshowa 
p 
.002 w 
0 .32852 m 
.00625 .32852 L 
s 
P 
[(1)] -0.0125 .32852 1 0 Mshowa 
p 
.002 w 
0 .42472 m 
.00625 .42472 L 
s 
P 
[(2)] -0.0125 .42472 1 0 Mshowa 
p 
.001 w 
0 .05916 m 
.00375 .05916 L 
s 
P 
p 
.001 w 
0 .0784 m 
.00375 .0784 L 
s 
P 
p 
.001 w 
0 .09764 m 
.00375 .09764 L 
s 
P 
p 
.001 w 
0 .11688 m 
.00375 .11688 L 
s 
P 
p 
.001 w 
0 .15536 m 
.00375 .15536 L 
s 
P 
p 
.001 w 
0 .1746 m 
.00375 .1746 L 
s 
P 
p 
.001 w 
0 .19384 m 
.00375 .19384 L 
s 
P 
p 
.001 w 
0 .21308 m 
.00375 .21308 L 
s 
P 
p 
.001 w 
0 .25156 m 
.00375 .25156 L 
s 
P 
p 
.001 w 
0 .2708 m 
.00375 .2708 L 
s 
P 
p 
.001 w 
0 .29004 m 
.00375 .29004 L 
s 
P 
p 
.001 w 
0 .30928 m 
.00375 .30928 L 
s 
P 
p 
.001 w 
0 .34776 m 
.00375 .34776 L 
s 
P 
p 
.001 w 
0 .367 m 
.00375 .367 L 
s 
P 
p 
.001 w 
0 .38624 m 
.00375 .38624 L 
s 
P 
p 
.001 w 
0 .40548 m 
.00375 .40548 L 
s 
P 
p 
.001 w 
0 .02068 m 
.00375 .02068 L 
s 
P 
p 
.001 w 
0 .00144 m 
.00375 .00144 L 
s 
P 
p 
.001 w 
0 .44396 m 
.00375 .44396 L 
s 
P 
p 
.001 w 
0 .4632 m 
.00375 .4632 L 
s 
P 
p 
.002 w 
0 0 m 
0 .46465 L 
s 
P 
P 
p 
p 
.002 w 
.05267 .4584 m 
.05267 .46465 L 
s 
P 
p 
.002 w 
.24507 .4584 m 
.24507 .46465 L 
s 
P 
p 
.002 w 
.43747 .4584 m 
.43747 .46465 L 
s 
P 
p 
.002 w 
.62987 .4584 m 
.62987 .46465 L 
s 
P 
p 
.002 w 
.82227 .4584 m 
.82227 .46465 L 
s 
P 
p 
.001 w 
.09115 .4609 m 
.09115 .46465 L 
s 
P 
p 
.001 w 
.12963 .4609 m 
.12963 .46465 L 
s 
P 
p 
.001 w 
.16811 .4609 m 
.16811 .46465 L 
s 
P 
p 
.001 w 
.20659 .4609 m 
.20659 .46465 L 
s 
P 
p 
.001 w 
.28355 .4609 m 
.28355 .46465 L 
s 
P 
p 
.001 w 
.32203 .4609 m 
.32203 .46465 L 
s 
P 
p 
.001 w 
.36051 .4609 m 
.36051 .46465 L 
s 
P 
p 
.001 w 
.39899 .4609 m 
.39899 .46465 L 
s 
P 
p 
.001 w 
.47595 .4609 m 
.47595 .46465 L 
s 
P 
p 
.001 w 
.51443 .4609 m 
.51443 .46465 L 
s 
P 
p 
.001 w 
.55291 .4609 m 
.55291 .46465 L 
s 
P 
p 
.001 w 
.59139 .4609 m 
.59139 .46465 L 
s 
P 
p 
.001 w 
.66835 .4609 m 
.66835 .46465 L 
s 
P 
p 
.001 w 
.70683 .4609 m 
.70683 .46465 L 
s 
P 
p 
.001 w 
.74531 .4609 m 
.74531 .46465 L 
s 
P 
p 
.001 w 
.78379 .4609 m 
.78379 .46465 L 
s 
P 
p 
.001 w 
.01419 .4609 m 
.01419 .46465 L 
s 
P 
p 
.001 w 
.86075 .4609 m 
.86075 .46465 L 
s 
P 
p 
.001 w 
.89923 .4609 m 
.89923 .46465 L 
s 
P 
p 
.001 w 
.93771 .4609 m 
.93771 .46465 L 
s 
P 
p 
.001 w 
.97619 .4609 m 
.97619 .46465 L 
s 
P 
p 
.002 w 
0 .46465 m 
1 .46465 L 
s 
P 
p 
.002 w 
.99375 .03992 m 
1 .03992 L 
s 
P 
p 
.002 w 
.99375 .13612 m 
1 .13612 L 
s 
P 
p 
.002 w 
.99375 .23232 m 
1 .23232 L 
s 
P 
p 
.002 w 
.99375 .32852 m 
1 .32852 L 
s 
P 
p 
.002 w 
.99375 .42472 m 
1 .42472 L 
s 
P 
p 
.001 w 
.99625 .05916 m 
1 .05916 L 
s 
P 
p 
.001 w 
.99625 .0784 m 
1 .0784 L 
s 
P 
p 
.001 w 
.99625 .09764 m 
1 .09764 L 
s 
P 
p 
.001 w 
.99625 .11688 m 
1 .11688 L 
s 
P 
p 
.001 w 
.99625 .15536 m 
1 .15536 L 
s 
P 
p 
.001 w 
.99625 .1746 m 
1 .1746 L 
s 
P 
p 
.001 w 
.99625 .19384 m 
1 .19384 L 
s 
P 
p 
.001 w 
.99625 .21308 m 
1 .21308 L 
s 
P 
p 
.001 w 
.99625 .25156 m 
1 .25156 L 
s 
P 
p 
.001 w 
.99625 .2708 m 
1 .2708 L 
s 
P 
p 
.001 w 
.99625 .29004 m 
1 .29004 L 
s 
P 
p 
.001 w 
.99625 .30928 m 
1 .30928 L 
s 
P 
p 
.001 w 
.99625 .34776 m 
1 .34776 L 
s 
P 
p 
.001 w 
.99625 .367 m 
1 .367 L 
s 
P 
p 
.001 w 
.99625 .38624 m 
1 .38624 L 
s 
P 
p 
.001 w 
.99625 .40548 m 
1 .40548 L 
s 
P 
p 
.001 w 
.99625 .02068 m 
1 .02068 L 
s 
P 
p 
.001 w 
.99625 .00144 m 
1 .00144 L 
s 
P 
p 
.001 w 
.99625 .44396 m 
1 .44396 L 
s 
P 
p 
.001 w 
.99625 .4632 m 
1 .4632 L 
s 
P 
p 
.002 w 
1 0 m 
1 .46465 L 
s 
P 
P 
p 
P 
p 
p 
.006 w 
.02381 .01106 m 
.43747 .01106 L 
.50481 .13612 L 
.97619 .13612 L 
.97619 .32852 L 
.50481 .32852 L 
.43747 .45358 L 
.02381 .45358 L 
.02381 .01106 L 
s 
.14887 .01106 m 
.24507 .23232 L 
.34127 .01106 L 
s 
P 
p 
1 0 0 r 
.004 w 
newpath 
.24507 .23232 .20683 0 365.73 arc 
s 
.28112 .04333 m 
.28112 .04333 .01443 0 365.73 arc 
F 
.24507 .23232 m 
.24507 .23232 .01443 0 365.73 arc 
F 
P 
p 
p 
0 0 1 r 
.46358 .13612 m 
.75218 .13612 L 
.75218 .32852 L 
.46358 .32852 L 
F 
P 
.02 w 
.28112 .04333 m 
.55978 .23232 L 
s 
P 
P 
0 0 m 
1 0 L 
1 .46465 L 
0 .46465 L 
closepath 
clip 
newpath 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{413, 192},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0000`1000`40O003h00OogooWWoo003oOonN
Ool00?mooiioo`00ogooWWoo000_Ool30013Ool00`00Oomoo`14Ool30015Ool30014Ool2001@Ool0
02moo`03001oogoo049oo`03001oo`0004Eoo`03001oogoo04Ioo`03001oogoo04=oo`03001oo`00
04moo`00:Woo0`000goo00<007ooOol0@Goo00<007oo0000AWoo00<007ooOol0@goo1000A7oo00<0
07oo0000Cgoo000`Ool00`00Oomoo`11Ool00`00Ool00016Ool00`00Oomoo`13Ool00`00Ool00015
Ool2001@Ool002moo`03001oo`00049oo`03001oo`0004Eoo`03001oo`0004Eoo`8004Eoo`03001o
ogoo04moo`00<7oo00<007ooOol0@Woo00<007ooOol0AGoo00<007ooOol0AGoo00<007ooOol0A7oo
0P00Cgoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonN
Ool00?mooiioo`006gooo`00M@003Woo000KOol20003Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool2000>Ool001]oo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`006goo00<007ooOol047oo00<007ooOol0
AGoo00<007ooOol0A7oo00<007ooOol0AGoo00<007ooOol0A7oo00<007ooOol0?goo00<007ooOol0
37oo000KOol00`00Oomoo`0dOol00`00Oomoo`15Ool00`00Oomoo`0POol00`00Oomoo`3>Ool00`00
Oomoo`0<Ool001]oo`03001oogoo00Eooi/00=1oo`03001oogoo00aoo`006goo00<007ooOol01Goo
W000cgoo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000^Ool00`00Oomoo`13Ool00`00Oomo
o`0ROol00`00Oomoo`3=Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8002ioo`8004=oo`8002Aoo`80
0<eoo`8000ioo`006goo00<007ooOol01Goo0P00;goo00<007ooOol0@Goo00<007ooOol097oo00<0
07ooOol0c7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000_Ool00`00Oomoo`0GOolAO00I
Ool00`00Oomoo`0TOol2003=Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002moo`80015o
o`Ml015oo`Ml015oo`8002Moo`800<aoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P00<7oo
00<007ooOol02goo17`06goo27`03Goo00<007ooOol09goo00<007ooOol0bWoo00<007ooOol037oo
000BOol30006Ool00`00Oomoo`05Ool2000`Ool20008Ool4O00MOol2O0000`00O01l0002O003Ool4
O008Ool2000YOol2003;Ool00`00Oomoo`0<Ool0019oo`03001oogoo00Ioo`03001oogoo00Eoo`80
035oo`03001oogoo00Aoo`9l01moo`=l00@000=l00Ioo`03O01oogoo00Eoo`03001oogoo02Uoo`03
001oogoo0<Uoo`03001oogoo00aoo`003Goo0`000goo00<007ooOol01Goo0`001Goo0P00<Goo0P00
0Woo0g`08Goo0g`01@000W`01goo17`00Woo0P00:goo0P00b7oo0`003Woo000COol00`00Oomoo`05
Ool00`00Oomoo`05Ool2000bOol00`00O01l000TOol2O00800000g`0Oomoo`08Ool2O0000`00Oomo
o`0[Ool00`00Oomoo`38Ool00`00Oomoo`0<Ool0019oo`03001oo`0000Ioo`03001oogoo00Eoo`80
035oo`9l0003001oogoo02=oo`03O000000000P000]oo`03001l07`002aoo`800<Uoo`03001oogoo
00aoo`004goo00<007ooOol01Goo00<007ooOol01Goo0P00;Woo0g`00Woo00<007ooOol08goo00=l
000000002P002Goo00<007ooOol00g`0:Woo00<007ooOol0agoo00<007ooOol037oo000KOol00`00
Oomoo`05Ool2000/Ool2O005Ool00`00Oomoo`0TOol2O00;0008Ool00`00Oomoo`03Ool2O00XOol2
0038Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002]oo`03O01oogoo00Eoo`8002Eoo`=l
00`000Eoo`8000Moo`03O01oogoo02Ioo`03001oogoo0<Ioo`03001oogoo00aoo`006goo00<007oo
Ool01Goo0P00:Goo0W`02Goo00<007ooOol09Goo0g`02`0017oo00<007ooOol01goo0W`09Woo0P00
agoo00<007ooOol037oo000KOol20006Ool2000WOol2O00;Ool2000XOol2O00<00000goo0000000;
Ool2O00UOol20035Ool2000>Ool001]oo`03001oogoo00Eoo`8002Ioo`03O01oogoo00aoo`03001o
ogoo02Yoo``000ioo`03O01oogoo02=oo`03001oogoo0<Aoo`03001oogoo00aoo`006goo00<007oo
Ool01Goo0P0097oo0W`03goo0P00;7oo30003Woo0W`08goo0P00aGoo00<007ooOol037oo000KOol0
0`00Oomoo`05Ool2000SOol00g`0Oomoo`0@Ool00`00Oomoo`0/Ool;000>Ool00g`0Oomoo`0ROol0
0`00Oomoo`33Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002=oo`03O01oogoo011oo`03
001oogoo02eoo``000eoo`03O01oogoo025oo`800<Aoo`03001oogoo00aoo`006goo00<007ooOol0
1Goo0P008Goo0W`04goo0P00<7oo2`003Goo0W`08Woo00<007ooOol0`Woo00<007ooOol037oo000K
Ool00`00Oomoo`05Ool2000OOol2O00FOol00`00Oomoo`0_Ool<000=Ool2O00POol20033Ool00`00
Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001ioo`03O01oogoo01Ioo`80035oo``000ioo`03O01o
ogoo01ioo`03001oogoo0<5oo`03001oogoo00aoo`006goo0P001Woo0P007Goo00=l07ooOol067oo
00<007ooOol0;goo00<007oo00002`003Goo00=l07ooOol07Goo0P00`Goo0P003Woo000KOol00`00
Oomoo`05Ool2000LOol00g`0Oomoo`0IOol2000_Ool20003Ool;000=Ool00g`0Oomoo`0MOol00`00
Oomoo`30Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001]oo`03O01oogoo01]oo`03001o
ogoo02eoo`03001oogoo00=oo``000aoo`03O01oogoo01aoo`800<5oo`03001oogoo00aoo`006goo
00<007ooOol01Goo0P006Woo00=l07ooOol077oo0P00;Goo0P001goo2`0037oo00=l07ooOol077oo
00<007ooOol0_goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000JOol00g`0Oomoo`0MOol0
0`00Oomoo`0[Ool00`00Oomoo`07Ool;000;Ool00g`0Oomoo`0LOol20030Ool00`00Oomoo`0<Ool0
01]oo`03001oogoo00Eoo`8001Uoo`03O01oogoo01ioo`03001oogoo02]oo`03001oogoo00Uoo`/0
00Yoo`03O01oogoo01aoo`800;moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P005goo0W`0
8Goo0P00:goo0P0037oo2`002Woo0W`07Goo00<007ooOol0_Goo00<007ooOol037oo000KOol20006
Ool2000FOol00g`0Oomoo`0ROol00`00Oomoo`0YOol00`00Oomoo`0=Ool;000:Ool00g`0Oomoo`0J
Ool2002mOol2000>Ool001]oo`03001oogoo00Eoo`8001Eoo`03O01oogoo02=oo`8002Uoo`80011o
o`/000Yoo`03O01oogoo01Yoo`03001oogoo0;aoo`03001oogoo00aoo`006goo00<007ooOol01Goo
0P005Goo00=l07ooOol097oo00<007ooOol09goo00<007ooOol047oo300027oo00=l07ooOol06Woo
0P00_Goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000DOol00g`0Oomoo`0UOol2000WOol2
000DOol;0008Ool00g`0Oomoo`0JOol00`00Oomoo`2kOol00`00Oomoo`0<Ool001]oo`03001oogoo
00Eoo`8001=oo`03O01oogoo02Moo`03001oogoo02Eoo`03001oogoo01Aoo``000Ioo`03O01oogoo
01Yoo`800;aoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P004goo00=l07ooOol09goo00<0
07ooOol09Goo00<007ooOol05Woo2`001Woo00=l07ooOol06Woo00<007ooOol0^Woo00<007ooOol0
37oo000KOol00`00Oomoo`05Ool2000BOol00g`0Oomoo`0XOol2000UOol2000IOol<0004Ool00g`0
Oomoo`0JOol2002kOol00`00Oomoo`0<Ool001]oo`8000Ioo`80015oo`03O01oogoo02Yoo`03001o
ogoo02=oo`03001oogoo01Yoo`/000Aoo`03O01oogoo01Yoo`03001oogoo0;Qoo`8000ioo`006goo
00<007ooOol01Goo0P0047oo00=l07ooOol0:goo0P008goo0P007Goo30000goo00=l07ooOol06Goo
0P00^Woo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000?Ool00g`0Oomoo`0]Ool00`00Oomo
o`0QOol00`00Oomoo`0NOol;0003Ool00g`0Oomoo`0IOol2002iOol00`00Oomoo`0<Ool001]oo`03
001oogoo00Eoo`8000moo`03O01oogoo02eoo`80025oo`80025oo``0009oo`03O01oogoo01Uoo`03
001oogoo0;Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P003Woo00=l07ooOol0;goo00<0
07ooOol07goo00<007ooOol08Woo2`0000=oog`0Ool06Woo0P00^7oo00<007ooOol037oo000AOol5
0005Ool00`00Oomoo`05Ool2000=Ool00g`0Oomoo`0`Ool2000OOol2000UOol<000LOol00`00Oomo
o`2fOol00`00Oomoo`0<Ool001=oo`03001oogoo00Eoo`03001oogoo00Eoo`8000eoo`03O01oogoo
035oo`03001oogoo01eoo`03001oogoo02Ioo`/001]oo`800;Moo`03001oogoo00aoo`003Goo0`00
0goo00<007ooOol01Goo0`001Goo0P003Goo00=l07ooOol0<Goo00<007ooOol07Goo00<007ooOol0
9goo30006Goo/P001Goo0`003Woo000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000=Ool00g`0
Oomoo`0aOol2000MOol2000[Ool;000:Oom[01mE0007Ool00`00Oomoo`0<Ool001=oo`03001oogoo
00Eoo`03001oogoo00Eoo`8000aoo`03O01oogoo03=oo`03001oogoo01]oo`03001oogoo02]oo``0
00Qoof/07e=oo`8000Moo`03001oogoo00aoo`004Woo0P001goo00<007ooOol01Goo0P002goo00=l
07ooOol0=7oo0P006goo0P00;goo2`001gooJ`0ODgoo0P001goo00<007ooOol037oo000KOol00`00
Oomoo`05Ool2000;Ool00g`0Oomoo`0eOol00`00Oomoo`0IOol00`00Oomoo`0_Ool<0005Oom[01mC
Ool20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Yoo`03O01oogoo03Ioo`8001Uo
o`8003=oo`/000Aoof/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P002Woo
00=l07ooOol0=goo00<007ooOol05goo00<007ooOol0<goo30000WooJ`0ODgoo0P001goo00<007oo
Ool037oo000KOol20006Ool20009Ool00g`0Oomoo`0hOol00`00Oomoo`0GOol00`00Oomoo`0eOol;
00000goo01l07`1Y01mCOol20006Ool2000>Ool001]oo`03001oogoo00Eoo`8000Uoo`03O01oogoo
03Qoo`8001Moo`8003Qoo``006X07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo
0P002Goo00=l07ooOol0>Goo00<007ooOol05Goo00<007ooOol0>7oo00=l000000002@00J@0ODgoo
0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20009Ool00g`0Oomoo`0iOol2000EOol2
000kOol00g`00000000:001W01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`80
00Qoo`03O01oogoo03]oo`03001oogoo01=oo`03001oogoo03]oo`03O01oo`0000X006H07e=oo`80
00Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0027oo00=l07ooOol0>goo0P004goo0P00
?Goo00=l07ooOol03000I00ODgoo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20008
Ool00g`0Oomoo`0lOol00`00Oomoo`0AOol00`00Oomoo`0lOol00g`0Oomoo`02Ool;001S01mCOol2
0007Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8000Moo`03O01oogoo03eoo`80015oo`8003ioo`03
O01oogoo00=oo``006407e=oo`8000Ioo`8000ioo`006goo00<007ooOol01Goo0P001goo00=l07oo
Ool0?Woo00<007ooOol03goo00<007ooOol0?Woo00=l07ooOol017oo2`00H00ODgoo0P001goo00<0
07ooOol037oo000KOol00`00Oomoo`05Ool20006Ool00g`0Oomoo`0oOol00`00Oomoo`0?Ool00`00
Oomoo`0nOol00g`0Oomoo`04Ool00`0O00000009001O01mCOol20007Ool00`00Oomoo`0<Ool001]o
o`03001oogoo00Eoo`8000Ioo`03O01oogoo03moo`8000moo`80041oo`03O01oogoo00Aoo`<07`/0
05d07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Woo00=l07ooOol0@7oo
00<007ooOol03Goo00<007ooOol0?goo00=l07ooOol017oo100O2`00G00ODgoo0P001goo00<007oo
Ool037oo000KOol00`00Oomoo`05Ool20006Ool00g`0Oomoo`10Ool2000=Ool20012Ool00g`0Oomo
o`03Ool601l;001J01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03
O01oogoo045oo`03001oogoo00]oo`03001oogoo045oo`03O01oogoo00=oo`L07`/005T07e=oo`80
00Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Woo00=l07ooOol0@Goo0P002goo0P00
@goo00=l07ooOol00goo200O3000E`0ODgoo0P001goo00<007ooOol037oo000KOol20006Ool20005
Ool00g`0Oomoo`13Ool00`00Oomoo`09Ool00`00Oomoo`13Ool00g`0Oomoo`02Ool:01l;001F01mC
Ool20006Ool2000>Ool001]oo`03001oogoo00Eoo`8000Eoo`03O01oogoo04=oo`03001oogoo00Uo
o`03001oogoo04=oo`03O01oogoo009oo`/07``005@07e=oo`8000Moo`03001oogoo00aoo`006goo
00<007ooOol01Goo0P001Goo00=l07ooOol0@goo0P002Goo0P00AGoo00=l07ooOol00Woo3@0O2`00
D`0ODgoo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20005Ool00g`0Oomoo`14Ool0
0`00Oomoo`07Ool00`00Oomoo`14Ool00g`0Oomoo`02Ool>01l<001A01mCOol20007Ool00`00Oomo
o`0<Ool001]oo`03001oogoo00Eoo`8000Eoo`03O01oogoo04Aoo`8000Moo`8004Ioo`03O01oogoo
009ooa007`/005007e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0017oo00=l
07ooOol0AWoo00<007ooOol01Goo00<007ooOol0AGoo00=l07ooOol00Woo4@0O3000CP0ODgoo0P00
1goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20004Ool00g`0Oomoo`16Ool20005Ool20017
Ool00g`0Oomoo`02OolC01l;001=01mCOol20007Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8000Ao
o`03O01oogoo04Moo`03001oogoo00=oo`03001oogoo04Ioo`03O01oogoo009ooa@07``004/07e=o
o`8000Ioo`8000ioo`006goo00<007ooOol01Goo0P0017oo00=l07ooOol0Agoo0P000goo0P00BGoo
00Al07ooOomooaH07`/004X07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P00
17oo00=l07ooOol0B7oo17`000<007ooOol0B7oo00Al07ooOomooaL07``004P07e=oo`8000Moo`03
001oogoo00aoo`006goo00<007ooOol01Goo0P0017oo00=l07ooOol0AWoo27`0BGoo00Al07ooOomo
oaT07`/004L07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0017oo00=l07oo
Ool0AGoo2W`0B7oo00Al07ooOomooaX07``004D07e=oo`8000Moo`03001oogoo00aoo`004goo00<0
07ooOol01Goo00<007ooOol01Goo0P0017oo00=l07ooOol0AGoo2W`0B7oo00Al07ooOomooa`07`/0
04@07e=oo`8000Moo`03001oogoo00aoo`004Woo00<007oo00001Woo00<007ooOol01Goo0P0017oo
00=l07ooOol0AGoo2W`0B7oo00Al07ooOomooad07``004807e=oo`8000Moo`03001oogoo00aoo`00
4Woo00<007oo00001Woo0`001Goo0P0017oo00=l07ooOol0AGoo2W`0B7oo00Al07ooOomooal07`X0
04807e=oo`8000Eoo`<000ioo`004Woo00<007oo00001Woo00<007ooOol01Goo0P0017oo00=l07oo
Ool0AGoo2W`0B7oo00Al07ooOomoob007`P004<07e=oo`8000Moo`03001oogoo00aoo`004Woo00<0
07oo00001Woo00<007ooOol01Goo0P0017oo00=l07ooOol0AGoo2W`0B7oo00Al07ooOomoob807`D0
04@07e=oo`8000Moo`03001oogoo00aoo`004goo00<007ooOol01Goo00<007ooOol01Goo0P0017oo
00=l07ooOol0AWoo2G`0B7oo00Al07ooOomoob<07`@004@07e=oo`8000Moo`03001oogoo00aoo`00
6goo00<007ooOol01Goo0P0017oo00=l07ooOol0Agoo1g`0BGoo00Al07ooOomoobD07`0300007`0O
04<07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0017oo00=l07ooOol0B7oo
17`0Bgoo00Al07ooOomoof/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P00
17oo00=l07ooOol0Ugoo00Al07ooOomoof/07e=oo`8000Moo`03001oogoo00aoo`006goo0P001Woo
0P0017oo00=l07ooOol0UWoo00=l07ooOol00WooJ`0ODgoo0P001Woo0P003Woo000KOol00`00Oomo
o`05Ool20004Ool00g`0Oomoo`2FOol00g`0Oomoo`02Oom[01mCOol20007Ool00`00Oomoo`0<Ool0
01]oo`03001oogoo00Eoo`8000Eoo`03O01oogoo09Eoo`03O01oogoo009oof/07e=oo`8000Moo`03
001oogoo00aoo`006goo00<007ooOol01Goo0P001Goo00=l07ooOol0UGoo00=l07ooOol00WooJ`0O
Dgoo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20005Ool00g`0Oomoo`2EOol00g`0
Oomoo`02Oom[01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Eoo`03O01o
ogoo09Eoo`03O01oogoo009oof/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo
0P001Goo00=l07ooOol0UGoo00=l07ooOol00WooJ`0ODgoo0P001goo00<007ooOol037oo000KOol2
0006Ool20005Ool00g`0Oomoo`2DOol00g`0Oomoo`03Oom[01mCOol20006Ool2000>Ool001]oo`03
001oogoo00Eoo`8000Ioo`03O01oogoo09=oo`03O01oogoo00=oof/07e=oo`8000Moo`03001oogoo
00aoo`006goo00<007ooOol01Goo0P001Woo00=l07ooOol0Tgoo00=l07ooOol00gooJ`0ODgoo0P00
1goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20006Ool00g`0Oomoo`2COol00g`0Oomoo`03
Oom[01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03O01oogoo099o
o`03O01oogoo00Aoof/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Woo
00=l07ooOol0TWoo00=l07ooOol017ooJ`0ODgoo0P001goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool20006Ool00g`0Oomoo`2BOol00g`0Oomoo`04Oom[01mCOol20007Ool00`00Oomoo`0<Ool0
01]oo`8000Ioo`8000Moo`03O01oogoo095oo`03O01oogoo00Aoof/07e=oo`8000Ioo`8000ioo`00
6goo00<007ooOol01Goo0P001goo00=l07ooOol0T7oo00=l07ooOol01GooJ`0ODgoo0P001goo00<0
07ooOol037oo000KOol00`00Oomoo`05Ool20007Ool00g`0Oomoo`2@Ool00g`0Oomoo`05Oom[01mC
Ool20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Qoo`03O01oogoo08moo`03O01o
ogoo00Eoof/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0027oo00=l07oo
Ool0SWoo00=l07ooOol01WooJ`0ODgoo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2
0009Ool00g`0Oomoo`2=Ool00g`0Oomoo`06Oom[01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03
001oogoo00Eoo`8000Uoo`03O01oogoo08aoo`03O01oogoo00Moof/07e=oo`8000Moo`03001oogoo
00aoo`006goo0P001Woo0P002Goo00=l07ooOol0S7oo00=l07ooOol01gooJ`0ODgoo0P001Woo0P00
3Woo000KOol00`00Oomoo`05Ool20009Ool00g`0Oomoo`2<Ool00g`0Oomoo`07Oom[01mCOol20007
Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Yoo`03O01oogoo08]oo`03O01oogoo00Mo
of/07e=oo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P002goo00=l07ooOol0RGoo
00=l07ooOol027ooJ`0ODgoo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000;Ool0
0g`0Oomoo`28Ool00g`0Oomoo`09Oom[01mCOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo
00Eoo`8000aoo`03O01oogoo08Moo`03O01oogoo00Uoof/07e=oo`8000Moo`03001oogoo00aoo`00
4Goo1@001Goo00<007ooOol01Goo0P0037oo00=l07ooOol0QWoo00=l07ooOol02WooJ`0ODgoo0P00
1goo00<007ooOol037oo000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000=Ool00g`0Oomoo`25
Ool00g`0Oomoo`0:Oom[01mCOol20007Ool00`00Oomoo`0<Ool001=oo`03001oogoo00Eoo`<000Eo
o`8000eoo`03O01oogoo08Aoo`03O01oogoo00]oof/07eD000Eoo`<000ioo`004goo00<007ooOol0
1Goo00<007ooOol01Goo0P003Goo00=l07ooOol0Q7oo00=l07ooOol06Goo/P001goo00<007ooOol0
37oo000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000>Ool00g`0Oomoo`22Ool00g`0Oomoo`0J
Ool00`00Oomoo`2fOol00`00Oomoo`0<Ool0019oo`8000Moo`03001oogoo00Eoo`8000ioo`03O01o
ogoo085oo`03O01oogoo01Yoo`800;Qoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P003goo
00=l07ooOol0P7oo00=l07ooOol06Woo00<007ooOol0]goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool2000@Ool00g`0Oomoo`1nOol00g`0Oomoo`0JOol2002iOol00`00Oomoo`0<Ool001]oo`03
001oogoo00Eoo`80011oo`03O01oogoo07ioo`03O01oogoo01Uoo`800;Yoo`03001oogoo00aoo`00
6goo0P001Woo0P004Goo00=l07ooOol0O7oo00=l07ooOol06Woo00<007ooOol0^7oo0P003Woo000K
Ool00`00Oomoo`05Ool2000BOol00g`0Oomoo`1jOol00g`0Oomoo`0JOol2002kOol00`00Oomoo`0<
Ool001]oo`03001oogoo00Eoo`8001=oo`03O01oogoo07Uoo`03O01oogoo01Yoo`03001oogoo0;Yo
o`03001oogoo00aoo`006goo00<007ooOol01Goo0P0057oo00=l07ooOol0Mgoo00=l07ooOol06Woo
0P00_7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000EOol00g`0Oomoo`1eOol00g`0Oomo
o`0KOol00`00Oomoo`2kOol00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001Eoo`03O01oogoo
07Eoo`03O01oogoo01Yoo`800;eoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P005Woo00=l
07ooOol0Lgoo00=l07ooOol06goo00<007ooOol0_7oo00<007ooOol037oo000KOol20006Ool2000G
Ool00g`0Oomoo`1aOol00g`0Oomoo`0KOol2002mOol2000>Ool001]oo`03001oogoo00Eoo`8001Qo
o`03O01oogoo06moo`03O01oogoo01aoo`03001oogoo0;eoo`03001oogoo00aoo`006goo00<007oo
Ool01Goo0P006Goo00=l07ooOol0KGoo00=l07ooOol077oo0P00_goo00<007ooOol037oo000KOol0
0`00Oomoo`05Ool2000JOol00g`0Oomoo`1[Ool00g`0Oomoo`0LOol20030Ool00`00Oomoo`0<Ool0
01]oo`03001oogoo00Eoo`8001Yoo`03O01oogoo06]oo`03O01oogoo01aoo`03001oogoo0;moo`03
001oogoo00aoo`006goo00<007ooOol01Goo0P006goo00=l07ooOol0JGoo00=l07ooOol077oo0P00
`Goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000LOol2O01WOol2O00OOol00`00Oomoo`30
Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8001ioo`03O01oogoo06=oo`03O01oogoo01ioo`800<5o
o`8000ioo`006goo00<007ooOol01Goo0P007goo00=l07ooOol0HGoo00=l07ooOol07goo00<007oo
Ool0`Goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000POol00g`0Oomoo`1OOol00g`0Oomo
o`0OOol20033Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`80025oo`03O01oogoo05eoo`03
O01oogoo021oo`03001oogoo0<9oo`03001oogoo00aoo`006goo00<007ooOol01Goo0P008Woo0W`0
Fgoo0W`08Woo0P00a7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000TOol00g`0Oomoo`1G
Ool00g`0Oomoo`0ROol00`00Oomoo`33Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002Eo
o`9l05Eoo`9l02Aoo`800<Eoo`03001oogoo00aoo`006goo0P001Woo0P009goo00=l07ooOol0DGoo
00=l07ooOol097oo00<007ooOol0`goo0P003Woo000KOol00`00Oomoo`05Ool2000XOol2O01?Ool2
O00VOol20036Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002Yoo`03O01oogoo04Yoo`9l
02Moo`800<Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P00:goo0W`0BGoo00=l07ooOol0
9goo00<007ooOol0aWoo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000]Ool2O015Ool2O00Y
Ool20038Ool00`00Oomoo`0<Ool0019oo`<000Ioo`03001oogoo00Eoo`8002moo`9l045oo`9l02]o
o`03001oogoo0<Moo`03001oogoo00aoo`004Woo00<007ooOol01Woo00<007ooOol01Goo0P00<Goo
00=l07ooOol0?Goo00=l07ooOol0:Woo0P00bGoo00<007ooOol037oo000COol00`00Oomoo`05Ool3
0005Ool2000bOol4O00gOol4O00]Ool00`00Oomoo`36Ool3000>Ool001=oo`03001oogoo00Eoo`03
001oogoo00Eoo`8003Ioo`9l03=oo`9l031oo`800<Yoo`03001oogoo00aoo`004Woo00<007oo0000
1Woo00<007ooOol01Goo0P00>7oo0g`0;Goo0g`0<Woo00<007ooOol0bGoo00<007ooOol037oo000C
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool2000kOol4O00UOol4O00dOol2003;Ool00`00Oomoo`0<
Ool001]oo`03001oogoo00Eoo`8003moo`Il01Uoo`Il03Qoo`03001oogoo0<Yoo`03001oogoo00ao
o`006goo00<007ooOol01Goo0P00AGoo1g`02goo1g`0?Goo0P00c7oo00<007ooOol037oo000KOol0
0`00Oomoo`05Ool2001<Ool;O013Ool2003=Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8009Yoo`03
001oogoo0<]oo`8000ioo`006goo00<007ooOol01Goo0P00VGoo0P00cWoo00<007ooOol037oo000K
Ool00`00Oomoo`05Ool2002IOol00`00Oomoo`3=Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eo
o`8009Qoo`800<moo`03001oogoo00aoo`006goo00<007ooOol01GooV`00d7oo00<007ooOol037oo
000KOol00`00Oomoo`05OonK003@Ool00`00Oomoo`0<Ool001]oo`03001oogoo011oo`03001oogoo
04Eoo`03001oogoo04Aoo`03001oogoo04Eoo`03001oogoo04Aoo`03001oogoo03moo`03001oogoo
00aoo`006goo00<007ooOol00Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol037oo000KOooo001e000>Ool0
0001\
\>"],
  ImageRangeCache->{{{0, 412}, {191, 0}} -> {-3.31348, -2.91866, 0.0279797, 
  0.0279797}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Four constraints, one of which is a driving constraint, are required to \
model the piston-pump. Body objects are not defined for this model. The \
coordinates of the local points are simply entered directly in the point and \
axis objects in the constraints."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint constrains the center of the crank to be coincident with the \
global origin."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the connecting rod by placing the piston a constant \
distance from an eccentric point on the crank."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the piston and cylinder by constraining the piston to \
translate along a horizontal line on the ground body."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is the driving constraint that makes the crank angle a \
function of time."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Names are defined for each of the bodies in the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(piston = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the constraint objects for the model. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(cs[1] = Revolute2[1, Point[ground, 0], Point[crank, 0]]; \)\), 
    \(\(cs[2] = 
      RelativeDistance1[2, Point[crank, {2, 0}], Point[piston, 0], 3.5]; \)\),
   
    \(\(cs[3] = 
      Translate2[3, Axis[ground, 0, {6, 0}], Axis[piston, 0, {1, 0}]]; \)\), 
    \(cs[4] = RotationLock1[4, crank, ground, 2.0  \[Pi]\ T]; \n
    SetConstraints[Array[cs, 4]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a reasonable initial guess for the piston. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SetGuess[X3 \[Rule] 4]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Loads "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Only one load is applied to the piston-pump model, but this one load will \
be a two-stage ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load. Since the piston is initially at the top of its stroke and proceeds \
toward the bottom, there is no load on the piston for the first half turn of \
crank rotation. The two segments of the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are defined as follows."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Stage one is a ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " on the piston that rises from zero at bottom-dead-center to seven units \
when the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the piston is equal to 5.0."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Stage two is a ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " on the piston that falls from seven units back to zero as the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the piston goes from 5.0 to 5.5."
}], "Special2",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here are the two forces on the piston."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(f1 = 9.0\/\(6.0 - X3\) - 2.0; \)\), 
    \(\(f2 = 3.5\ \((1 - Sin[2\ \[Pi]\ \((X3 - 5.25)\)])\); \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must switch between ",
  StyleBox["f1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["f2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at the proper time. This is done by testing the value of the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the piston ",
  StyleBox["X3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and the angular coordinate of the crank ",
  StyleBox["Th2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Here is the ",
  StyleBox["StageSwitch",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load object for the pump. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ld[1] = 
      StageSwitch[\n\t\tX3 < 5.0 && Sin[Th2] < 0, \n\t\t
        Force[piston, Line[piston, 0, {\(-1\), 0}], f1], \n\t\t
        X3 > 5.0 && Sin[Th2] < 0, \n\t\t
        Force[piston, Line[piston, 0, {\(-1\), 0}], f2]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({SysLoad["Force", "<>"], SysLoad["Force", "<>"]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["The loads are incorporated into the model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[ld[1]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Running the Model "], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The loaded model can now be run with the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that all of the loads are zero at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1 because the force is \"turned off\"."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now run the model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.1, Solution \[Rule] Static]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        \(X2 \[Rule] \(-2.50153871239561276`*^-24\)\), ",", 
        \(Y2 \[Rule] 0.`\), ",", \(Th2 \[Rule] 0.628318530717958623`\), ",", 
        \(X3 \[Rule] 4.91470412522886412`\), ",", \(Y3 \[Rule] 0.`\), ",", 
        \(Th3 \[Rule] 0.`\), ",", \(Lmb1 \[Rule] 0.`\), ",", 
        \(Lmb2 \[Rule] 0.`\), ",", \(Lmb3 \[Rule] 0.`\), ",", 
        \(Lmb4 \[Rule] 0.`\), ",", \(Lmb5 \[Rule] 0.`\), ",", 
        \(Lmb6 \[Rule] 0.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the piston-pump model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%! 
%%Creator: Mathematica 
%%AspectRatio: .46465  
MathPictureStart 
%% Graphics 
/Courier findfont 10  scalefont  setfont 
% Scaling calculations 
0.24507 0.0962001 0.232323 0.0962001 [ 
[(-2)] .05267 0 0 2 Msboxa 
[(0)] .24507 0 0 2 Msboxa 
[(2)] .43747 0 0 2 Msboxa 
[(4)] .62987 0 0 2 Msboxa 
[(6)] .82227 0 0 2 Msboxa 
[(-2)] -0.0125 .03992 1 0 Msboxa 
[(-1)] -0.0125 .13612 1 0 Msboxa 
[(0)] -0.0125 .23232 1 0 Msboxa 
[(1)] -0.0125 .32852 1 0 Msboxa 
[(2)] -0.0125 .42472 1 0 Msboxa 
[ -0.001 -0.001 0 0 ] 
[ 1.001 .46565 0 0 ] 
] MathScale 
% Start of Graphics 
1 setlinecap 
1 setlinejoin 
newpath 
[ ] 0 setdash 
0 g 
p 
p 
.002 w 
.05267 0 m 
.05267 .00625 L 
s 
P 
[(-2)] .05267 0 0 2 Mshowa 
p 
.002 w 
.24507 0 m 
.24507 .00625 L 
s 
P 
[(0)] .24507 0 0 2 Mshowa 
p 
.002 w 
.43747 0 m 
.43747 .00625 L 
s 
P 
[(2)] .43747 0 0 2 Mshowa 
p 
.002 w 
.62987 0 m 
.62987 .00625 L 
s 
P 
[(4)] .62987 0 0 2 Mshowa 
p 
.002 w 
.82227 0 m 
.82227 .00625 L 
s 
P 
[(6)] .82227 0 0 2 Mshowa 
p 
.001 w 
.09115 0 m 
.09115 .00375 L 
s 
P 
p 
.001 w 
.12963 0 m 
.12963 .00375 L 
s 
P 
p 
.001 w 
.16811 0 m 
.16811 .00375 L 
s 
P 
p 
.001 w 
.20659 0 m 
.20659 .00375 L 
s 
P 
p 
.001 w 
.28355 0 m 
.28355 .00375 L 
s 
P 
p 
.001 w 
.32203 0 m 
.32203 .00375 L 
s 
P 
p 
.001 w 
.36051 0 m 
.36051 .00375 L 
s 
P 
p 
.001 w 
.39899 0 m 
.39899 .00375 L 
s 
P 
p 
.001 w 
.47595 0 m 
.47595 .00375 L 
s 
P 
p 
.001 w 
.51443 0 m 
.51443 .00375 L 
s 
P 
p 
.001 w 
.55291 0 m 
.55291 .00375 L 
s 
P 
p 
.001 w 
.59139 0 m 
.59139 .00375 L 
s 
P 
p 
.001 w 
.66835 0 m 
.66835 .00375 L 
s 
P 
p 
.001 w 
.70683 0 m 
.70683 .00375 L 
s 
P 
p 
.001 w 
.74531 0 m 
.74531 .00375 L 
s 
P 
p 
.001 w 
.78379 0 m 
.78379 .00375 L 
s 
P 
p 
.001 w 
.01419 0 m 
.01419 .00375 L 
s 
P 
p 
.001 w 
.86075 0 m 
.86075 .00375 L 
s 
P 
p 
.001 w 
.89923 0 m 
.89923 .00375 L 
s 
P 
p 
.001 w 
.93771 0 m 
.93771 .00375 L 
s 
P 
p 
.001 w 
.97619 0 m 
.97619 .00375 L 
s 
P 
p 
.002 w 
0 0 m 
1 0 L 
s 
P 
p 
.002 w 
0 .03992 m 
.00625 .03992 L 
s 
P 
[(-2)] -0.0125 .03992 1 0 Mshowa 
p 
.002 w 
0 .13612 m 
.00625 .13612 L 
s 
P 
[(-1)] -0.0125 .13612 1 0 Mshowa 
p 
.002 w 
0 .23232 m 
.00625 .23232 L 
s 
P 
[(0)] -0.0125 .23232 1 0 Mshowa 
p 
.002 w 
0 .32852 m 
.00625 .32852 L 
s 
P 
[(1)] -0.0125 .32852 1 0 Mshowa 
p 
.002 w 
0 .42472 m 
.00625 .42472 L 
s 
P 
[(2)] -0.0125 .42472 1 0 Mshowa 
p 
.001 w 
0 .05916 m 
.00375 .05916 L 
s 
P 
p 
.001 w 
0 .0784 m 
.00375 .0784 L 
s 
P 
p 
.001 w 
0 .09764 m 
.00375 .09764 L 
s 
P 
p 
.001 w 
0 .11688 m 
.00375 .11688 L 
s 
P 
p 
.001 w 
0 .15536 m 
.00375 .15536 L 
s 
P 
p 
.001 w 
0 .1746 m 
.00375 .1746 L 
s 
P 
p 
.001 w 
0 .19384 m 
.00375 .19384 L 
s 
P 
p 
.001 w 
0 .21308 m 
.00375 .21308 L 
s 
P 
p 
.001 w 
0 .25156 m 
.00375 .25156 L 
s 
P 
p 
.001 w 
0 .2708 m 
.00375 .2708 L 
s 
P 
p 
.001 w 
0 .29004 m 
.00375 .29004 L 
s 
P 
p 
.001 w 
0 .30928 m 
.00375 .30928 L 
s 
P 
p 
.001 w 
0 .34776 m 
.00375 .34776 L 
s 
P 
p 
.001 w 
0 .367 m 
.00375 .367 L 
s 
P 
p 
.001 w 
0 .38624 m 
.00375 .38624 L 
s 
P 
p 
.001 w 
0 .40548 m 
.00375 .40548 L 
s 
P 
p 
.001 w 
0 .02068 m 
.00375 .02068 L 
s 
P 
p 
.001 w 
0 .00144 m 
.00375 .00144 L 
s 
P 
p 
.001 w 
0 .44396 m 
.00375 .44396 L 
s 
P 
p 
.001 w 
0 .4632 m 
.00375 .4632 L 
s 
P 
p 
.002 w 
0 0 m 
0 .46465 L 
s 
P 
P 
p 
p 
.002 w 
.05267 .4584 m 
.05267 .46465 L 
s 
P 
p 
.002 w 
.24507 .4584 m 
.24507 .46465 L 
s 
P 
p 
.002 w 
.43747 .4584 m 
.43747 .46465 L 
s 
P 
p 
.002 w 
.62987 .4584 m 
.62987 .46465 L 
s 
P 
p 
.002 w 
.82227 .4584 m 
.82227 .46465 L 
s 
P 
p 
.001 w 
.09115 .4609 m 
.09115 .46465 L 
s 
P 
p 
.001 w 
.12963 .4609 m 
.12963 .46465 L 
s 
P 
p 
.001 w 
.16811 .4609 m 
.16811 .46465 L 
s 
P 
p 
.001 w 
.20659 .4609 m 
.20659 .46465 L 
s 
P 
p 
.001 w 
.28355 .4609 m 
.28355 .46465 L 
s 
P 
p 
.001 w 
.32203 .4609 m 
.32203 .46465 L 
s 
P 
p 
.001 w 
.36051 .4609 m 
.36051 .46465 L 
s 
P 
p 
.001 w 
.39899 .4609 m 
.39899 .46465 L 
s 
P 
p 
.001 w 
.47595 .4609 m 
.47595 .46465 L 
s 
P 
p 
.001 w 
.51443 .4609 m 
.51443 .46465 L 
s 
P 
p 
.001 w 
.55291 .4609 m 
.55291 .46465 L 
s 
P 
p 
.001 w 
.59139 .4609 m 
.59139 .46465 L 
s 
P 
p 
.001 w 
.66835 .4609 m 
.66835 .46465 L 
s 
P 
p 
.001 w 
.70683 .4609 m 
.70683 .46465 L 
s 
P 
p 
.001 w 
.74531 .4609 m 
.74531 .46465 L 
s 
P 
p 
.001 w 
.78379 .4609 m 
.78379 .46465 L 
s 
P 
p 
.001 w 
.01419 .4609 m 
.01419 .46465 L 
s 
P 
p 
.001 w 
.86075 .4609 m 
.86075 .46465 L 
s 
P 
p 
.001 w 
.89923 .4609 m 
.89923 .46465 L 
s 
P 
p 
.001 w 
.93771 .4609 m 
.93771 .46465 L 
s 
P 
p 
.001 w 
.97619 .4609 m 
.97619 .46465 L 
s 
P 
p 
.002 w 
0 .46465 m 
1 .46465 L 
s 
P 
p 
.002 w 
.99375 .03992 m 
1 .03992 L 
s 
P 
p 
.002 w 
.99375 .13612 m 
1 .13612 L 
s 
P 
p 
.002 w 
.99375 .23232 m 
1 .23232 L 
s 
P 
p 
.002 w 
.99375 .32852 m 
1 .32852 L 
s 
P 
p 
.002 w 
.99375 .42472 m 
1 .42472 L 
s 
P 
p 
.001 w 
.99625 .05916 m 
1 .05916 L 
s 
P 
p 
.001 w 
.99625 .0784 m 
1 .0784 L 
s 
P 
p 
.001 w 
.99625 .09764 m 
1 .09764 L 
s 
P 
p 
.001 w 
.99625 .11688 m 
1 .11688 L 
s 
P 
p 
.001 w 
.99625 .15536 m 
1 .15536 L 
s 
P 
p 
.001 w 
.99625 .1746 m 
1 .1746 L 
s 
P 
p 
.001 w 
.99625 .19384 m 
1 .19384 L 
s 
P 
p 
.001 w 
.99625 .21308 m 
1 .21308 L 
s 
P 
p 
.001 w 
.99625 .25156 m 
1 .25156 L 
s 
P 
p 
.001 w 
.99625 .2708 m 
1 .2708 L 
s 
P 
p 
.001 w 
.99625 .29004 m 
1 .29004 L 
s 
P 
p 
.001 w 
.99625 .30928 m 
1 .30928 L 
s 
P 
p 
.001 w 
.99625 .34776 m 
1 .34776 L 
s 
P 
p 
.001 w 
.99625 .367 m 
1 .367 L 
s 
P 
p 
.001 w 
.99625 .38624 m 
1 .38624 L 
s 
P 
p 
.001 w 
.99625 .40548 m 
1 .40548 L 
s 
P 
p 
.001 w 
.99625 .02068 m 
1 .02068 L 
s 
P 
p 
.001 w 
.99625 .00144 m 
1 .00144 L 
s 
P 
p 
.001 w 
.99625 .44396 m 
1 .44396 L 
s 
P 
p 
.001 w 
.99625 .4632 m 
1 .4632 L 
s 
P 
p 
.002 w 
1 0 m 
1 .46465 L 
s 
P 
P 
p 
P 
p 
p 
.006 w 
.02381 .01106 m 
.43747 .01106 L 
.50481 .13612 L 
.97619 .13612 L 
.97619 .32852 L 
.50481 .32852 L 
.43747 .45358 L 
.02381 .45358 L 
.02381 .01106 L 
s 
.14887 .01106 m 
.24507 .23232 L 
.34127 .01106 L 
s 
P 
p 
1 0 0 r 
.004 w 
newpath 
.24507 .23232 .20683 0 365.73 arc 
s 
.40072 .34541 m 
.40072 .34541 .01443 0 365.73 arc 
F 
.24507 .23232 m 
.24507 .23232 .01443 0 365.73 arc 
F 
P 
p 
p 
0 0 1 r 
.62166 .13612 m 
.91026 .13612 L 
.91026 .32852 L 
.62166 .32852 L 
F 
P 
.02 w 
.40072 .34541 m 
.71786 .23232 L 
s 
P 
P 
0 0 m 
1 0 L 
1 .46465 L 
0 .46465 L 
closepath 
clip 
newpath 
% End of Graphics 
MathPictureEnd 
 \
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{413, 192},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006M0000`1000`40O003h00OogooWWoo003oOonN
Ool00?mooiioo`00ogooWWoo000_Ool30013Ool00`00Oomoo`14Ool30015Ool30014Ool2001@Ool0
02moo`03001oogoo049oo`03001oo`0004Eoo`03001oogoo04Ioo`03001oogoo04=oo`03001oo`00
04moo`00:Woo0`000goo00<007ooOol0@Goo00<007oo0000AWoo00<007ooOol0@goo1000A7oo00<0
07oo0000Cgoo000`Ool00`00Oomoo`11Ool00`00Ool00016Ool00`00Oomoo`13Ool00`00Ool00015
Ool2001@Ool002moo`03001oo`00049oo`03001oo`0004Eoo`03001oo`0004Eoo`8004Eoo`03001o
ogoo04moo`00<7oo00<007ooOol0@Woo00<007ooOol0AGoo00<007ooOol0AGoo00<007ooOol0A7oo
0P00Cgoo003oOonNOol00?mooiioo`00ogooWWoo003oOonNOol00?mooiioo`00ogooWWoo003oOonN
Ool00?mooiioo`006gooo`00M@003Woo000KOol20003Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool0
0`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool2000>Ool001]oo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00]oo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`006goo00<007ooOol047oo00<007ooOol0
AGoo00<007ooOol0A7oo00<007ooOol0AGoo00<007ooOol0A7oo00<007ooOol0?goo00<007ooOol0
37oo000KOol00`00Oomoo`0dOol00`00Oomoo`15Ool00`00Oomoo`0POol00`00Oomoo`3>Ool00`00
Oomoo`0<Ool001]oo`03001oogoo00Eooi/00=1oo`03001oogoo00aoo`006goo00<007ooOol01Goo
W000cgoo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000^Ool00`00Oomoo`13Ool00`00Oomo
o`0ROol00`00Oomoo`3=Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8002ioo`8004=oo`8002Aoo`80
0<eoo`8000ioo`006goo00<007ooOol01Goo0P00;goo00<007ooOol0@Goo00<007ooOol097oo00<0
07ooOol0c7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000_Ool00`00Oomoo`0GOolAO00I
Ool00`00Oomoo`0TOol2003=Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002moo`80015o
o`Ml015oo`Ml015oo`8002Moo`800<aoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P00<7oo
00<007ooOol02goo17`07goo17`03Goo00<007ooOol09goo00<007ooOol0bWoo00<007ooOol037oo
000BOol30006Ool00`00Oomoo`05Ool2000`Ool20008Ool4O00WOol4O008Ool2000YOol2003;Ool0
0`00Oomoo`0<Ool0019oo`03001oogoo00Ioo`03001oogoo00Eoo`80035oo`03001oogoo00Aoo`9l
02moo`03O01oogoo00Eoo`03001oogoo02Uoo`03001oogoo0<Uoo`03001oogoo00aoo`003Goo0`00
0goo00<007ooOol01Goo0`001Goo0P00<Goo0P000Woo0g`0<Woo17`00Woo0P00:goo0P00b7oo0`00
3Woo000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000bOol00`00O01l000iOol2O0000`00Oomo
o`0[Ool00`00Oomoo`38Ool00`00Oomoo`0<Ool0019oo`03001oo`0000Ioo`03001oogoo00Eoo`80
035oo`9l0003001oogoo03Uoo`03001l07`002aoo`800<Uoo`03001oogoo00aoo`004goo00<007oo
Ool01Goo00<007ooOol01Goo0P00;Woo0g`00Woo00<007ooOol0>Goo00<007ooOol00g`0:Woo00<0
07ooOol0agoo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000/Ool2O005Ool00`00Oomoo`0i
Ool00`00Oomoo`03Ool2O00XOol20038Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002]o
o`03O01oogoo00Eoo`8003Uoo`8000Moo`03O01oogoo02Ioo`03001oogoo0<Ioo`03001oogoo00ao
o`006goo00<007ooOol01Goo0P00:Goo0W`02Goo00<007ooOol0=goo00<007ooOol01goo0W`09Woo
0P00agoo00<007ooOol037oo000KOol20006Ool2000WOol2O00;Ool2000gOol2000;Ool2O00UOol2
0035Ool2000>Ool001]oo`03001oogoo00Eoo`8002Ioo`03O01oogoo00aoo`03001oogoo03Eoo`03
001oogoo00aoo`03O01oogoo02=oo`03001oogoo0<Aoo`03001oogoo00aoo`006goo00<007ooOol0
1Goo0P0097oo0W`03goo0P00=Goo0P003goo0W`08goo0P00aGoo00<007ooOol037oo000KOol00`00
Oomoo`05Ool2000SOol00g`0Oomoo`0@Ool00`00Oomoo`0cOol00`00Oomoo`0?Ool00g`0Oomoo`0R
Ool00`00Oomoo`33Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002=oo`03O01oogoo011o
o`03001oogoo03=oo`03001oogoo011oo`03O01oogoo025oo`800<Aoo`03001oogoo00aoo`006goo
00<007ooOol01Goo0P008Goo0W`04goo0P00<goo0P004goo0W`08Woo00<007ooOol0`Woo00<007oo
Ool037oo000KOol00`00Oomoo`05Ool2000OOol2O00FOol00`00Oomoo`0aOol00`00Oomoo`0DOol2
O00POol20033Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001ioo`03O01oogoo01Ioo`80
035oo`8001Qoo`03O01oogoo01ioo`03001oogoo0<5oo`03001oogoo00aoo`006goo0P001Woo0P00
7Goo00=l07ooOol067oo00<007ooOol0;goo00<007ooOol067oo00=l07ooOol07Goo0P00`Goo0P00
3Woo000KOol00`00Oomoo`05Ool2000LOol00g`0Oomoo`0IOol2000_Ool2000KOol00g`0Oomoo`0M
Ool00`00Oomoo`30Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001]oo`03O01oogoo01]o
o`03001oogoo02eoo`03001oogoo01]oo`03O01oogoo01aoo`800<5oo`03001oogoo00aoo`006goo
00<007ooOol01Goo0P006Woo00=l07ooOol077oo0P00;Goo0P007Woo00=l07ooOol077oo00<007oo
Ool0_goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000JOol00g`0Oomoo`0MOol00`00Oomo
o`0[Ool00`00Oomoo`0MOol00g`0Oomoo`0LOol20030Ool00`00Oomoo`0<Ool001]oo`03001oogoo
00Eoo`8001Uoo`03O01oogoo01ioo`03001oogoo02]oo`03001oogoo01ioo`03O01oogoo01aoo`80
0;moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P005goo0W`08Goo0P00:goo0P008Goo0W`0
7Goo00<007ooOol0_Goo00<007ooOol037oo000KOol20006Ool2000FOol00g`0Oomoo`0ROol00`00
Oomoo`0YOol00`00Oomoo`0ROol00g`0Oomoo`0JOol2002mOol2000>Ool001]oo`03001oogoo00Eo
o`8001Eoo`03O01oogoo02=oo`8002Uoo`8002Eoo`03O01oogoo01Yoo`03001oogoo0;aoo`03001o
ogoo00aoo`006goo00<007ooOol01Goo0P005Goo00=l07ooOol097oo00<007ooOol09goo00<007oo
Ool097oo00=l07ooOol06Woo0P00_Goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000DOol0
0g`0Oomoo`0UOol2000WOol2000WOol00g`0Oomoo`0JOol00`00Oomoo`2kOol00`00Oomoo`0<Ool0
01]oo`03001oogoo00Eoo`8001=oo`03O01oogoo02Moo`03001oogoo02Eoo`03001oogoo02Ioo`03
O01oogoo01Yoo`800;aoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P004goo00=l07ooOol0
9goo00<007ooOol09Goo00<007ooOol09goo00=l07ooOol06Woo00<007ooOol0^Woo00<007ooOol0
37oo000KOol00`00Oomoo`05Ool2000BOol00g`0Oomoo`0XOol2000UOol2000YOol00g`0Oomoo`0J
Ool2002kOol00`00Oomoo`0<Ool001]oo`8000Ioo`80015oo`03O01oogoo02Yoo`03001oogoo02=o
o`03001oogoo02Uoo`03O01oogoo01Yoo`03001oogoo0;Qoo`8000ioo`006goo00<007ooOol01Goo
0P0047oo00=l07ooOol0:goo0P008goo0P00;7oo00=l07ooOol06Goo0P00^Woo00<007ooOol037oo
000KOol00`00Oomoo`05Ool2000?Ool00g`0Oomoo`0]Ool00`00Oomoo`0QOol00`00Oomoo`0/Ool0
0g`0Oomoo`0IOol2002iOol00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000moo`03O01oogoo
02eoo`80025oo`8002moo`03O01oogoo01Uoo`03001oogoo0;Moo`03001oogoo00aoo`006goo00<0
07ooOol01Goo0P003Woo00=l07ooOol0;goo00<007ooOol07goo00<007ooOol0;Woo00=l07ooOol0
6Goo0P00^7oo00<007ooOol037oo000AOol50005Ool00`00Oomoo`05Ool2000=Ool00g`0Oomoo`0`
Ool2000OOol2000`Ool00g`0Oomoo`0JOol00`00Oomoo`2fOol00`00Oomoo`0<Ool001=oo`03001o
ogoo00Eoo`03001oogoo00Eoo`8000eoo`03O01oogoo035oo`03001oogoo01eoo`03001oogoo031o
o`03O01oogoo01Uoo`800;Moo`03001oogoo00aoo`003Goo0`000goo00<007ooOol01Goo0`001Goo
0P003Goo00=l07ooOol0<Goo00<007ooOol07Goo00<007ooOol0<7oo00=l07ooOol06Goo/P001Goo
0`003Woo000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000=Ool00g`0Oomoo`0aOol2000MOol2
000cOol00g`0Oomoo`0HOol]001[01lJ0007Ool00`00Oomoo`0<Ool001=oo`03001oogoo00Eoo`03
001oogoo00Eoo`8000aoo`03O01oogoo03=oo`03001oogoo01]oo`03001oogoo03=oo`03O01oogoo
04Aoof/07aQoo`8000Moo`03001oogoo00aoo`004Woo0P001goo00<007ooOol01Goo0P002goo00=l
07ooOol0=7oo0P006goo0P00=Goo00=l07ooOol0A7ooJ`0O67oo0P001goo00<007ooOol037oo000K
Ool00`00Oomoo`05Ool2000;Ool00g`0Oomoo`0eOol00`00Oomoo`0IOol00`00Oomoo`0eOol00g`0
Oomoo`13Oom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Yoo`03O01o
ogoo03Ioo`8001Uoo`8003Moo`03O01oogoo04=oof/07aQoo`8000Moo`03001oogoo00aoo`006goo
00<007ooOol01Goo0P002Woo00=l07ooOol0=goo00<007ooOol05goo00<007ooOol0=goo00=l07oo
Ool0@WooJ`0O67oo0P001goo00<007ooOol037oo000KOol20006Ool20009Ool00g`0Oomoo`0hOol0
0`00Oomoo`0GOol00`00Oomoo`0gOol00g`0Oomoo`12Oom[01lHOol20006Ool2000>Ool001]oo`03
001oogoo00Eoo`8000Uoo`03O01oogoo03Qoo`8001Moo`8003Uoo`03O01oogoo049oof/07aQoo`80
00Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P002Goo00=l07ooOol0>Goo00<007ooOol0
5Goo00<007ooOol0>7oo00=l07ooOol0@WooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00
Oomoo`05Ool20009Ool00g`0Oomoo`0iOol2000EOol2000kOol00g`0Oomoo`11Oom[01lHOol20007
Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Qoo`03O01oogoo03]oo`03001oogoo01=o
o`03001oogoo03]oo`03O01oogoo041oof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007oo
Ool01Goo0P0027oo00=l07ooOol0>goo0P004goo0P00?Goo00=l07ooOol0@7ooJ`0O67oo0P001goo
00<007ooOol037oo000KOol00`00Oomoo`05Ool20008Ool00g`0Oomoo`0lOol00`00Oomoo`0AOol0
0`00Oomoo`0lOol00g`0Oomoo`10Oom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`8000Ioo`80
00Moo`03O01oogoo03eoo`80015oo`8003ioo`03O01oogoo041oof/07aQoo`8000Ioo`8000ioo`00
6goo00<007ooOol01Goo0P001goo00=l07ooOol0?Woo00<007ooOol03goo00<007ooOol0?Woo00=l
07ooOol0?gooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20006Ool00g`0
Oomoo`0oOol00`00Oomoo`0?Ool00`00Oomoo`0nOol00g`0Oomoo`0oOom[01lHOol20007Ool00`00
Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03O01oogoo03moo`8000moo`80041oo`03O01o
ogoo03moof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Woo00=l07oo
Ool0@7oo00<007ooOol03Goo00<007ooOol0?goo00=l07ooOol0?gooJ`0O67oo0P001goo00<007oo
Ool037oo000KOol00`00Oomoo`05Ool20006Ool00g`0Oomoo`10Ool2000=Ool20012Ool00g`0Oomo
o`0nOom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03O01oogoo
045oo`03001oogoo00]oo`03001oogoo045oo`03O01oogoo03ioof/07aQoo`8000Moo`03001oogoo
00aoo`006goo00<007ooOol01Goo0P001Woo00=l07ooOol0@Goo0P002goo0P00@goo00=l07ooOol0
?WooJ`0O67oo0P001goo00<007ooOol037oo000KOol20006Ool20005Ool00g`0Oomoo`13Ool00`00
Oomoo`09Ool00`00Oomoo`13Ool00g`0Oomoo`0mOom[01lHOol20006Ool2000>Ool001]oo`03001o
ogoo00Eoo`8000Eoo`03O01oogoo04=oo`03001oogoo00Uoo`03001oogoo04=oo`03O01oogoo03eo
of/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Goo00=l07ooOol0@goo
0P002Goo0P00AGoo00=l07ooOol0?GooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool20005Ool00g`0Oomoo`14Ool00`00Oomoo`07Ool00`00Oomoo`14Ool00g`0Oomoo`0mOom[
01lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Eoo`03O01oogoo04Aoo`80
00Moo`8004Ioo`03O01oogoo03eoof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol0
1Goo0P0017oo00=l07ooOol0AWoo00<007ooOol01Goo00<007ooOol0AGoo00=l07ooOol0?GooJ`0O
67oo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20004Ool00g`0Oomoo`16Ool20005
Ool20017Ool00g`0Oomoo`0mOom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8000Ao
o`03O01oogoo04Moo`03001oogoo00=oo`03001oogoo04Ioo`03O01oogoo03eoof/07aQoo`8000Io
o`8000ioo`006goo00<007ooOol01Goo0P0017oo00=l07ooOol0Agoo0P000goo0P00BGoo00=l07oo
Ool0?7ooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20004Ool00g`0Oomo
o`18Ool4O0000`00Oomoo`18Ool00g`0Oomoo`0lOom[01lHOol20007Ool00`00Oomoo`0<Ool001]o
o`03001oogoo00Eoo`8000Aoo`03O01oogoo04Ioo`Ql04Uoo`03O01oogoo03aoobH07`0300007`0O
04807aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0017oo00=l07ooOol0AGoo
2W`0B7oo00=l07ooOol0?7oo8`0O1000A00O67oo0P001goo00<007ooOol037oo000COol00`00Oomo
o`05Ool00`00Oomoo`05Ool20004Ool00g`0Oomoo`15Ool:O018Ool00g`0Oomoo`0lOolQ01l70013
01lHOol20007Ool00`00Oomoo`0<Ool0019oo`03001oo`0000Ioo`03001oogoo00Eoo`8000Aoo`03
O01oogoo04Eoo`Yl04Qoo`03O01oogoo03aooah07`X004<07aQoo`8000Moo`03001oogoo00aoo`00
4Woo00<007oo00001Woo0`001Goo0P0017oo00=l07ooOol0AGoo2W`0B7oo00=l07ooOol0?7oo6`0O
3@00@`0O67oo0P001Goo0`003Woo000BOol00`00Ool00006Ool00`00Oomoo`05Ool20004Ool00g`0
Oomoo`15Ool:O018Ool00g`0Oomoo`0lOolH01lA001201lHOol20007Ool00`00Oomoo`0<Ool0019o
o`03001oo`0000Ioo`03001oogoo00Eoo`8000Aoo`03O01oogoo04Eoo`Yl04Qoo`03O01oogoo03ao
oaD07a<004<07aQoo`8000Moo`03001oogoo00aoo`004goo00<007ooOol01Goo00<007ooOol01Goo
0P0017oo00=l07ooOol0AWoo2G`0B7oo00=l07ooOol0?7oo4`0O4P00AP0O67oo0P001goo00<007oo
Ool037oo000KOol00`00Oomoo`05Ool20004Ool00g`0Oomoo`17Ool7O019Ool00g`0Oomoo`0lOol@
01lC001801lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Aoo`03O01oogoo
04Qoo`Al04]oo`03O01oogoo03aoo`d07a<004/07aQoo`8000Moo`03001oogoo00aoo`006goo00<0
07ooOol01Goo0P0017oo00=l07ooOol0Ugoo00=l07ooOol0?7oo2P0O4`00CP0O67oo0P001goo00<0
07ooOol037oo000KOol20006Ool20004Ool00g`0Oomoo`2FOol00g`0Oomoo`0mOol701lC001A01lH
Ool20006Ool2000>Ool001]oo`03001oogoo00Eoo`8000Aoo`03O01oogoo09Ioo`03O01oogoo03eo
o`D07a8005@07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Goo00=l07oo
Ool0UGoo00=l07ooOol0?Goo0P0O4`00EP0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool20005Ool00g`0Oomoo`2EOol00g`0Oomoo`0lOolC001I01lHOol20007Ool00`00Oomoo`0<
Ool001]oo`03001oogoo00Eoo`8000Eoo`03O01oogoo09Eoo`03O01oogoo03Uooa<005`07aQoo`80
00Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Goo00=l07ooOol0UGoo00=l07ooOol0
=Woo4`00G`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20005Ool00g`0Oomo
o`2EOol00g`0Oomoo`0dOolB001R01lHOol20007Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8000Eo
o`03O01oogoo09Aoo`03O01oogoo039ooa<006@07aQoo`8000Ioo`8000ioo`006goo00<007ooOol0
1Goo0P001Woo00=l07ooOol0Tgoo00=l07ooOol0;goo4`00I`0O67oo0P001goo00<007ooOol037oo
000KOol00`00Oomoo`05Ool20006Ool00g`0Oomoo`2COol00g`0Oomoo`0/OolC001Z01lHOol20007
Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03O01oogoo09=oo`03O01oogoo02Uo
oa<0009oof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P001Woo00=l07oo
Ool0TWoo00=l07ooOol09goo4`001GooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool20006Ool00g`0Oomoo`2BOol00g`0Oomoo`0UOolC0007Oom[01lHOol20007Ool00`00Oomo
o`0<Ool001]oo`03001oogoo00Eoo`8000Ioo`03O01oogoo099oo`03O01oogoo029ooa<000Yoof/0
7aQoo`8000Moo`03001oogoo00aoo`006goo0P001Woo0P001goo00=l07ooOol0TGoo00=l07ooOol0
7goo4`003GooJ`0O67oo0P001Woo0P003Woo000KOol00`00Oomoo`05Ool20007Ool00g`0Oomoo`2@
Ool00g`0Oomoo`0MOolC000@Oom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eo
o`8000Moo`03O01oogoo091oo`03O01oogoo01Yooa<001=oof/07aQoo`8000Moo`03001oogoo00ao
o`006goo00<007ooOol01Goo0P0027oo00=l07ooOol0Sgoo00=l07ooOol067oo4P005WooJ`0O67oo
0P001goo00<007ooOol037oo000KOol00`00Oomoo`05Ool20008Ool00g`0Oomoo`2>Ool00g`0Oomo
o`0FOolC000HOom[01lHOol20007Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8000Uoo`03
O01oogoo08eoo`03O01oogoo01=ooa<001]oof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<0
07ooOol01Goo0P002Goo00=l07ooOol0S7oo00=l07ooOol04Goo4`007WooJ`0O67oo0P001goo00<0
07ooOol037oo000KOol20006Ool20009Ool00g`0Oomoo`2<Ool00g`0Oomoo`0>OolC000QOom[01lH
Ool20006Ool2000>Ool001]oo`03001oogoo00Eoo`8000Uoo`03O01oogoo08aoo`03O01oogoo00ao
oa8002Aoof/07aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P002Woo00=l07oo
Ool0Rgoo00=l07ooOol02Goo4`009WooJ`0O67oo0P001goo00<007ooOol037oo000KOol00`00Oomo
o`05Ool2000;Ool00g`0Oomoo`29Ool00g`0Oomoo`07OolC000YOom[01lHOol20007Ool00`00Oomo
o`0<Ool001]oo`03001oogoo00Eoo`8000]oo`03O01oogoo08Qoo`03O01oogoo00Eooa<002aoof/0
7aQoo`8000Moo`03001oogoo00aoo`006goo00<007ooOol01Goo0P0037oo00=l07ooOol0Qgoo00=l
07ooOol00Woo4`00;gooJ`0O67oo0P001goo00<007ooOol037oo000AOol50005Ool00`00Oomoo`05
Ool2000<Ool00g`0Oomoo`26Ool017`0Oomoogoo4P00<WooJ`0O67oo0P001goo00<007ooOol037oo
000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000=Ool00g`0Oomoo`25Ool00g`00000000A0008
Ool00`00Oomoo`0YOom[01lHOol20007Ool00`00Oomoo`0<Ool001=oo`03001oogoo00Eoo`<000Eo
o`8000eoo`03O01oogoo08=ooa<000Yoobd006/07aX000Eoo`<000ioo`004goo00<007ooOol01Goo
00<007ooOol01Goo0P003Goo00=l07ooOol0NGoo17`00goo4`003Goo/P001goo00<007ooOol037oo
000COol00`00Oomoo`05Ool00`00Oomoo`05Ool2000>Ool00g`0Oomoo`1fOol6O00C000@Ool00`00
Oomoo`2fOol00`00Oomoo`0<Ool0019oo`8000Moo`03001oogoo00Eoo`8000ioo`03O01oogoo07Eo
o`El0180019oo`800;Qoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P003goo00=l07ooOol0
M7oo0W`04`0057oo00<007ooOol0]goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000@Ool0
0g`0Oomoo`1cOol00g`00000000?000FOol2002iOol00`00Oomoo`0<Ool001]oo`03001oogoo00Eo
o`80011oo`03O01oogoo079oo`=l00d001Qoo`800;Yoo`03001oogoo00aoo`006goo0P001Woo0P00
4Goo00=l07ooOol0LWoo0W`02P006goo00<007ooOol0^7oo0P003Woo000KOol00`00Oomoo`05Ool2
000BOol00g`0Oomoo`1aOol2O00700000g`0Oomoo`0JOol2002kOol00`00Oomoo`0<Ool001]oo`03
001oogoo00Eoo`8001=oo`03O01oogoo075oo`9l00@000=l01aoo`03001oogoo0;Yoo`03001oogoo
00aoo`006goo00<007ooOol01Goo0P0057oo00=l07ooOol0LGoo00=l0000O00017`077oo0P00_7oo
00<007ooOol037oo000KOol00`00Oomoo`05Ool2000EOol00g`0Oomoo`1aOol5O00MOol00`00Oomo
o`2kOol00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8001Eoo`03O01oogoo07Eoo`03O01oogoo
01Yoo`800;eoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P005Woo00=l07ooOol0Lgoo00=l
07ooOol06goo00<007ooOol0_7oo00<007ooOol037oo000KOol20006Ool2000GOol00g`0Oomoo`1a
Ool00g`0Oomoo`0KOol2002mOol2000>Ool001]oo`03001oogoo00Eoo`8001Qoo`03O01oogoo06mo
o`03O01oogoo01aoo`03001oogoo0;eoo`03001oogoo00aoo`006goo00<007ooOol01Goo0P006Goo
00=l07ooOol0KGoo00=l07ooOol077oo0P00_goo00<007ooOol037oo000KOol00`00Oomoo`05Ool2
000JOol00g`0Oomoo`1[Ool00g`0Oomoo`0LOol20030Ool00`00Oomoo`0<Ool001]oo`03001oogoo
00Eoo`8001Yoo`03O01oogoo06]oo`03O01oogoo01aoo`03001oogoo0;moo`03001oogoo00aoo`00
6goo00<007ooOol01Goo0P006goo00=l07ooOol0JGoo00=l07ooOol077oo0P00`Goo00<007ooOol0
37oo000KOol00`00Oomoo`05Ool2000LOol2O01WOol2O00OOol00`00Oomoo`30Ool00`00Oomoo`0<
Ool001]oo`8000Ioo`8001ioo`03O01oogoo06=oo`03O01oogoo01ioo`800<5oo`8000ioo`006goo
00<007ooOol01Goo0P007goo00=l07ooOol0HGoo00=l07ooOol07goo00<007ooOol0`Goo00<007oo
Ool037oo000KOol00`00Oomoo`05Ool2000POol00g`0Oomoo`1OOol00g`0Oomoo`0OOol20033Ool0
0`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`80025oo`03O01oogoo05eoo`03O01oogoo021oo`03
001oogoo0<9oo`03001oogoo00aoo`006goo00<007ooOol01Goo0P008Woo0W`0Fgoo0W`08Woo0P00
a7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000TOol00g`0Oomoo`1GOol00g`0Oomoo`0R
Ool00`00Oomoo`33Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002Eoo`9l05Eoo`9l02Ao
o`800<Eoo`03001oogoo00aoo`006goo0P001Woo0P009goo00=l07ooOol0DGoo00=l07ooOol097oo
00<007ooOol0`goo0P003Woo000KOol00`00Oomoo`05Ool2000XOol2O01?Ool2O00VOol20036Ool0
0`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8002Yoo`03O01oogoo04Yoo`9l02Moo`800<Moo`03
001oogoo00aoo`006goo00<007ooOol01Goo0P00:goo0W`0BGoo00=l07ooOol09goo00<007ooOol0
aWoo00<007ooOol037oo000KOol00`00Oomoo`05Ool2000]Ool2O015Ool2O00YOol20038Ool00`00
Oomoo`0<Ool0019oo`<000Ioo`03001oogoo00Eoo`8002moo`9l045oo`9l02]oo`03001oogoo0<Mo
o`03001oogoo00aoo`004Woo00<007ooOol01Woo00<007ooOol01Goo0P00<Goo00=l07ooOol0?Goo
00=l07ooOol0:Woo0P00bGoo00<007ooOol037oo000COol00`00Oomoo`05Ool30005Ool2000bOol4
O00gOol4O00]Ool00`00Oomoo`36Ool3000>Ool001=oo`03001oogoo00Eoo`03001oogoo00Eoo`80
03Ioo`9l03=oo`9l031oo`800<Yoo`03001oogoo00aoo`004Woo00<007oo00001Woo00<007ooOol0
1Goo0P00>7oo0g`0;Goo0g`0<Woo00<007ooOol0bGoo00<007ooOol037oo000COol00`00Oomoo`05
Ool00`00Oomoo`05Ool2000kOol4O00UOol4O00dOol2003;Ool00`00Oomoo`0<Ool001]oo`03001o
ogoo00Eoo`8003moo`Il01Uoo`Il03Qoo`03001oogoo0<Yoo`03001oogoo00aoo`006goo00<007oo
Ool01Goo0P00AGoo1g`02goo1g`0?Goo0P00c7oo00<007ooOol037oo000KOol00`00Oomoo`05Ool2
001<Ool;O013Ool2003=Ool00`00Oomoo`0<Ool001]oo`8000Ioo`8009Yoo`03001oogoo0<]oo`80
00ioo`006goo00<007ooOol01Goo0P00VGoo0P00cWoo00<007ooOol037oo000KOol00`00Oomoo`05
Ool2002IOol00`00Oomoo`3=Ool00`00Oomoo`0<Ool001]oo`03001oogoo00Eoo`8009Qoo`800<mo
o`03001oogoo00aoo`006goo00<007ooOol01GooV`00d7oo00<007ooOol037oo000KOol00`00Oomo
o`05OonK003@Ool00`00Oomoo`0<Ool001]oo`03001oogoo011oo`03001oogoo04Eoo`03001oogoo
04Aoo`03001oogoo04Eoo`03001oogoo04Aoo`03001oogoo03moo`03001oogoo00aoo`006goo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol02goo00<007ooOol02goo00<007ooOol02goo00<007ooOol037oo00<0
07ooOol02goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02goo00<0
07ooOol037oo00<007ooOol01Goo00<007ooOol037oo000KOooo001e000>Ool00001\
\>"],
  ImageRangeCache->{{{0, 412}, {191, 0}} -> {-3.31348, -2.91866, 0.0279797, 
  0.0279797}}]
}, Open  ]],

Cell[TextData[{
  "By creating a large table of solution points, plots can be made of various \
forces, moments, and reactions in the model using ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here is a list of 81 solutions. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(statictab = SolveMech[{0, 1}, 81, Solution \[Rule] Static]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function returns the total load on the piston."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Loads[piston] /. 
      statictab\[LeftDoubleBracket]70\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-3.811016572180284`\), 0.`, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The force on the piston can be plotted as a function of piston travel. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{X3, 
          \(-\(Loads[piston]\)\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\)}
           /. statictab, PlotJoined \[Rule] True, PlotRange \[Rule] All]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.333333 0.238095 0.0147151 0.093538 [
[.38095 .00222 -3 -9 ]
[.38095 .00222 3 0 ]
[.61905 .00222 -3 -9 ]
[.61905 .00222 3 0 ]
[.85714 .00222 -3 -9 ]
[.85714 .00222 3 0 ]
[.13036 .10825 -6 -4.5 ]
[.13036 .10825 0 4.5 ]
[.13036 .20179 -6 -4.5 ]
[.13036 .20179 0 4.5 ]
[.13036 .29533 -6 -4.5 ]
[.13036 .29533 0 4.5 ]
[.13036 .38887 -6 -4.5 ]
[.13036 .38887 0 4.5 ]
[.13036 .48241 -6 -4.5 ]
[.13036 .48241 0 4.5 ]
[.13036 .57594 -6 -4.5 ]
[.13036 .57594 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.38095 .01472 m
.38095 .02097 L
s
[(3)] .38095 .00222 0 1 Mshowa
.61905 .01472 m
.61905 .02097 L
s
[(4)] .61905 .00222 0 1 Mshowa
.85714 .01472 m
.85714 .02097 L
s
[(5)] .85714 .00222 0 1 Mshowa
.125 Mabswid
.19048 .01472 m
.19048 .01847 L
s
.2381 .01472 m
.2381 .01847 L
s
.28571 .01472 m
.28571 .01847 L
s
.33333 .01472 m
.33333 .01847 L
s
.42857 .01472 m
.42857 .01847 L
s
.47619 .01472 m
.47619 .01847 L
s
.52381 .01472 m
.52381 .01847 L
s
.57143 .01472 m
.57143 .01847 L
s
.66667 .01472 m
.66667 .01847 L
s
.71429 .01472 m
.71429 .01847 L
s
.7619 .01472 m
.7619 .01847 L
s
.80952 .01472 m
.80952 .01847 L
s
.09524 .01472 m
.09524 .01847 L
s
.04762 .01472 m
.04762 .01847 L
s
0 .01472 m
0 .01847 L
s
.90476 .01472 m
.90476 .01847 L
s
.95238 .01472 m
.95238 .01847 L
s
1 .01472 m
1 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.14286 .10825 m
.14911 .10825 L
s
[(1)] .13036 .10825 1 0 Mshowa
.14286 .20179 m
.14911 .20179 L
s
[(2)] .13036 .20179 1 0 Mshowa
.14286 .29533 m
.14911 .29533 L
s
[(3)] .13036 .29533 1 0 Mshowa
.14286 .38887 m
.14911 .38887 L
s
[(4)] .13036 .38887 1 0 Mshowa
.14286 .48241 m
.14911 .48241 L
s
[(5)] .13036 .48241 1 0 Mshowa
.14286 .57594 m
.14911 .57594 L
s
[(6)] .13036 .57594 1 0 Mshowa
.125 Mabswid
.14286 .03342 m
.14661 .03342 L
s
.14286 .05213 m
.14661 .05213 L
s
.14286 .07084 m
.14661 .07084 L
s
.14286 .08955 m
.14661 .08955 L
s
.14286 .12696 m
.14661 .12696 L
s
.14286 .14567 m
.14661 .14567 L
s
.14286 .16438 m
.14661 .16438 L
s
.14286 .18308 m
.14661 .18308 L
s
.14286 .2205 m
.14661 .2205 L
s
.14286 .23921 m
.14661 .23921 L
s
.14286 .25791 m
.14661 .25791 L
s
.14286 .27662 m
.14661 .27662 L
s
.14286 .31404 m
.14661 .31404 L
s
.14286 .33274 m
.14661 .33274 L
s
.14286 .35145 m
.14661 .35145 L
s
.14286 .37016 m
.14661 .37016 L
s
.14286 .40757 m
.14661 .40757 L
s
.14286 .42628 m
.14661 .42628 L
s
.14286 .44499 m
.14661 .44499 L
s
.14286 .4637 m
.14661 .4637 L
s
.14286 .50111 m
.14661 .50111 L
s
.14286 .51982 m
.14661 .51982 L
s
.14286 .53853 m
.14661 .53853 L
s
.14286 .55724 m
.14661 .55724 L
s
.14286 .59465 m
.14661 .59465 L
s
.14286 .61336 m
.14661 .61336 L
s
.25 Mabswid
.14286 0 m
.14286 .61803 L
s
.5 Mabswid
.97619 .01472 m
.97388 .01472 L
.96699 .01472 L
.95559 .01472 L
.93979 .01472 L
.91977 .01472 L
.89576 .01472 L
.86801 .01472 L
.83683 .01472 L
.80259 .01472 L
.76566 .01472 L
.72648 .01472 L
.6855 .01472 L
.64321 .01472 L
.60009 .01472 L
.55664 .01472 L
.51335 .01472 L
.47068 .01472 L
.42908 .01472 L
.38892 .01472 L
.35054 .01472 L
.3142 .01472 L
.2801 .01472 L
.24835 .01472 L
.21904 .01472 L
.19218 .01472 L
.16771 .01472 L
.14559 .01472 L
.12571 .01472 L
.10796 .01472 L
.09223 .01472 L
.07839 .01472 L
.06634 .01472 L
.05597 .01472 L
.04718 .01472 L
.03989 .01472 L
.03402 .01472 L
.02952 .01472 L
.02634 .01472 L
.02444 .01472 L
.02381 .01472 L
.02444 .01483 L
.02634 .01516 L
.02952 .01572 L
.03402 .01652 L
.03989 .01757 L
.04718 .01889 L
.05597 .0205 L
.06634 .02245 L
.07839 .02476 L
Mistroke
.09223 .02748 L
.10796 .03066 L
.12571 .03438 L
.14559 .03871 L
.16771 .04374 L
.19218 .04959 L
.21904 .0564 L
.24835 .06432 L
.2801 .07353 L
.3142 .08427 L
.35054 .09679 L
.38892 .11142 L
.42908 .12853 L
.47068 .14857 L
.51335 .1721 L
.55664 .19979 L
.60009 .23244 L
.64321 .27106 L
.6855 .31683 L
.72648 .37119 L
.76566 .43581 L
.80259 .51255 L
.83683 .60332 L
.86801 .01472 L
.89576 .01472 L
.91977 .01472 L
.93979 .01472 L
.95559 .01472 L
.96699 .01472 L
.97388 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo001ZOol2
000nOol3000lOol00`00Oomoo`0/Ool006aoo`03001oogoo03aoo`03001oogoo03Yoo`03001oo`00
02eoo`00Jgoo00<007ooOol0>goo1000?Goo00<007ooOol0:goo001/Ool00`00Oomoo`0jOol00`00
Ool0000lOol2000^Ool006Yoo`03001oo`0003eoo`8003aoo`03001oogoo02eoo`00Jgoo00<007oo
Ool0?Goo00<007ooOol0>Woo0`00;Goo003oOolIOol00?mooaUoo`00;7oo00<007ooOol0jGoo000/
Ool00`00Oomoo`3YOol002aoo`03001oogoo0>Uoo`00;7oo00<007ooOol0jGoo0007Oooo000:0008
Ool000Moo`03001oogoo00Moo`H000Uoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oo`0000Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00Ioo`005goo1P003goo00<007ooOol0_Goo00<007ooOol0:Goo
000MOol4000;Ool00`00Oomoo`2mOol00`00Oomoo`0YOol0025oo`D000Ioo`03001oogoo0;eoo`03
001oogoo02Uoo`009Woo1@0000=oo`000000_Woo00<007ooOol0:Goo000[Ool5002lOol00`00Oomo
o`0YOol002aoo`04001oogooOol5002gOol00`00Oomoo`0YOol002aoo`03001oogoo00Ioo`@00;=o
o`03001oogoo02Uoo`00;7oo00<007ooOol02Woo0`00/7oo00<007ooOol0:Goo000/Ool2000>Ool4
002[Ool00`00Oomoo`0ZOol002aoo`03001oogoo015oo`<00:Qoo`03001oogoo02Yoo`00;7oo00<0
07ooOol057oo1000Y7oo00<007ooOol0:Woo000/Ool00`00Oomoo`0HOol4002POol00`00Oomoo`0Z
Ool002aoo`03001oogoo01aoo`@009aoo`03001oogoo02Yoo`00;7oo0P008Goo1000V7oo00<007oo
Ool0:Woo000/Ool00`00Oomoo`0TOol3002EOol00`00Oomoo`0ZOol002aoo`03001oogoo02Moo`<0
099oo`03001oogoo02Yoo`00;7oo00<007ooOol0:Woo0`00Sgoo00<007ooOol0:Woo000/Ool00`00
Oomoo`0]Ool2002=Ool00`00Oomoo`0ZOol002aoo`80031oo`8008]oo`03001oogoo02Yoo`00;7oo
00<007ooOol0<Goo0P00RGoo00<007ooOol0:Woo000/Ool00`00Oomoo`0cOol30026Ool00`00Oomo
o`0ZOol002Aoo`D000=oo`03001oogoo03Ioo`@0089oo`03001oogoo02Yoo`009Woo00<007ooOol0
0goo00<007ooOol0>Woo1000OWoo00<007ooOol0:Woo000VOol00`00Oomoo`03Ool3000nOol2001l
Ool00`00Oomoo`0ZOol002Ioo`03001oogoo00=oo`03001oogoo041oo`8007Yoo`03001oogoo02Yo
o`009Woo00<007ooOol00goo00<007ooOol0@Woo0P00N7oo00<007ooOol0:Woo000UOol20005Ool0
0`00Oomoo`14Ool2001fOol00`00Oomoo`0ZOol002aoo`03001oogoo04Ioo`8007Aoo`03001oogoo
02Yoo`00;7oo0P00BGoo0`00L7oo00<007ooOol0:goo000/Ool00`00Oomoo`1;Ool2001^Ool00`00
Oomoo`0[Ool002aoo`03001oogoo04eoo`8006aoo`03001oogoo02]oo`00;7oo00<007ooOol0Cgoo
0P00JWoo00<007ooOol0:goo000/Ool2001BOol2001XOol00`00Oomoo`0[Ool002aoo`03001oogoo
05=oo`8006Ioo`03001oogoo02]oo`00;7oo00<007ooOol0EGoo0P00I7oo00<007ooOol0:goo000/
Ool00`00Oomoo`1GOol2001ROol00`00Oomoo`0[Ool002aoo`03001oogoo05Uoo`80061oo`03001o
ogoo02]oo`00;7oo0P00G7oo0P00GWoo00<007ooOol0:goo000/Ool00`00Oomoo`1MOol2001LOol0
0`00Oomoo`0[Ool002aoo`03001oogoo05moo`8005Yoo`03001oogoo02]oo`00;7oo00<007ooOol0
HGoo0P00F7oo00<007ooOol0:goo000/Ool00`00Oomoo`1SOol00`00Oomoo`1EOol00`00Oomoo`0[
Ool002aoo`8006Eoo`03001oogoo05Aoo`03001oogoo02]oo`00;7oo00<007ooOol0IGoo0P00E7oo
00<007ooOol0:goo000/Ool00`00Oomoo`1WOol00`00Oomoo`1AOol00`00Oomoo`0[Ool002Eoo`<0
00Aoo`03001oogoo06Qoo`03001oogoo051oo`03001oogoo02]oo`009Goo00<007ooOol017oo00<0
07ooOol0JGoo0P00D7oo00<007ooOol0:goo000VOol00`00Oomoo`03Ool3001[Ool00`00Oomoo`1<
Ool00`00Oomoo`0/Ool002Ioo`03001oogoo00=oo`03001oogoo06aoo`8004aoo`03001oogoo02ao
o`009Goo00<007oo000017oo00<007ooOol0KWoo00<007ooOol0BGoo00<007ooOol0;7oo000VOol0
0`00Oomoo`03Ool00`00Oomoo`1_Ool00`00Oomoo`18Ool00`00Oomoo`0/Ool002aoo`03001oogoo
071oo`8004Qoo`03001oogoo02aoo`00;7oo0P00Lgoo00<007ooOol0AGoo00<007ooOol0;7oo000/
Ool00`00Oomoo`1cOol00`00Oomoo`14Ool00`00Oomoo`0/Ool002aoo`03001oogoo07Aoo`8004Ao
o`03001oogoo02aoo`00;7oo00<007ooOol0MWoo00<007ooOol0@Goo00<007ooOol0;7oo000/Ool0
0`00Oomoo`1gOol00`00Oomoo`10Ool00`00Oomoo`0/Ool002aoo`8007Uoo`03001oogoo03moo`03
001oogoo02aoo`00;7oo00<007ooOol0NGoo00<007ooOol0?Woo00<007ooOol0;7oo000/Ool00`00
Oomoo`1jOol00`00Oomoo`0mOol00`00Oomoo`0/Ool002aoo`03001oogoo07]oo`03001oogoo03ao
o`03001oogoo02aoo`00;7oo00<007ooOol0O7oo0P00?7oo00<007ooOol0;7oo000/Ool2001oOol0
0`00Oomoo`0iOol00`00Oomoo`0/Ool002aoo`03001oogoo07moo`03001oogoo03Qoo`03001oogoo
02aoo`00;7oo00<007ooOol0P7oo00<007ooOol0=goo00<007ooOol0;7oo000/Ool00`00Oomoo`21
Ool00`00Oomoo`0fOol00`00Oomoo`0/Ool002aoo`03001oogoo089oo`03001oogoo03Eoo`03001o
ogoo02aoo`00;7oo0P00Q7oo00<007ooOol0<goo00<007ooOol0;Goo000/Ool00`00Oomoo`24Ool0
0`00Oomoo`0bOol00`00Oomoo`0]Ool002aoo`03001oogoo08Eoo`03001oogoo035oo`03001oogoo
02eoo`009Goo0P001Goo00<007ooOol0QWoo00<007ooOol0<7oo00<007ooOol0;Goo000WOol00`00
Oomoo`02Ool00`00Oomoo`27Ool00`00Oomoo`0_Ool00`00Oomoo`0]Ool002Ioo`03001oogoo00=o
o`<008Moo`03001oogoo02moo`03001oogoo02eoo`009goo00<007ooOol00Woo00<007ooOol0R7oo
00<007ooOol0;Woo00<007ooOol0;Goo000UOol00`00Ool00004Ool00`00Oomoo`29Ool00`00Oomo
o`0]Ool00`00Oomoo`0]Ool002Ioo`03001oogoo00=oo`03001oogoo08Yoo`03001oogoo02aoo`03
001oogoo02eoo`00;7oo00<007ooOol0Rgoo00<007ooOol0:goo00<007ooOol0;Goo000/Ool2002=
Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool002aoo`03001oogoo08eoo`03001oogoo02Uoo`03001o
ogoo02eoo`00;7oo00<007ooOol0SWoo00<007ooOol0:7oo00<007ooOol0;Goo000/Ool00`00Oomo
o`2?Ool00`00Oomoo`0WOol00`00Oomoo`0]Ool002aoo`03001oogoo08moo`03001oogoo02Moo`03
001oogoo02eoo`00;7oo0P00TGoo00<007ooOol09Woo00<007ooOol0;Goo000/Ool00`00Oomoo`2A
Ool00`00Oomoo`0UOol00`00Oomoo`0]Ool002aoo`03001oogoo099oo`03001oogoo02Aoo`03001o
ogoo02eoo`00;7oo00<007ooOol0TWoo00<007ooOol097oo00<007ooOol0;Goo000/Ool00`00Oomo
o`2COol00`00Oomoo`0ROol00`00Oomoo`0^Ool002aoo`8009Eoo`03001oogoo025oo`03001oogoo
02ioo`00;7oo00<007ooOol0UGoo00<007ooOol087oo00<007ooOol0;Woo000/Ool00`00Oomoo`2F
Ool00`00Oomoo`0OOol00`00Oomoo`0^Ool002aoo`03001oogoo09Ioo`03001oogoo01moo`03001o
ogoo02ioo`00;7oo00<007ooOol0Ugoo00<007ooOol07Woo00<007ooOol0;Woo000/Ool2002IOol0
0`00Oomoo`0MOol00`00Oomoo`0^Ool002aoo`03001oogoo09Uoo`03001oogoo01aoo`03001oogoo
02ioo`00;7oo00<007ooOol0VGoo00<007ooOol077oo00<007ooOol0;Woo000VOol30003Ool00`00
Oomoo`2JOol00`00Oomoo`0KOol00`00Oomoo`0^Ool002Moo`03001oogoo009oo`03001oogoo09Yo
o`03001oogoo01]oo`03001oogoo02ioo`009Goo10000goo0`00Vgoo00<007ooOol06Woo00<007oo
Ool0;Woo000UOol00`00Ool00004Ool00`00Oomoo`2LOol00`00Oomoo`0IOol00`00Oomoo`0^Ool0
02Ioo`8000Aoo`03001oogoo09aoo`03001oogoo01Uoo`03001oogoo02ioo`009goo00<007ooOol0
0Woo00<007ooOol0WGoo00<007ooOol067oo00<007ooOol0;Woo000/Ool00`00Oomoo`2MOol00`00
Oomoo`0HOol00`00Oomoo`0^Ool002aoo`8009moo`03001oogoo01Moo`03001oogoo02ioo`00;7oo
00<007ooOol0WWoo00<007ooOol05goo00<007ooOol0;Woo000/Ool00`00Oomoo`2OOol00`00Oomo
o`0FOol00`00Oomoo`0^Ool002aoo`03001oogoo0:1oo`03001oogoo01Eoo`03001oogoo02ioo`00
;7oo00<007ooOol0X7oo00<007ooOol057oo00<007ooOol0;goo000/Ool2002ROol00`00Oomoo`0C
Ool00`00Oomoo`0_Ool002aoo`03001oogoo0:5oo`03001oogoo01=oo`03001oogoo02moo`00;7oo
00<007ooOol0XWoo00<007ooOol04Woo00<007ooOol0;goo000/Ool00`00Oomoo`2ROol00`00Oomo
o`0BOol00`00Oomoo`0_Ool002aoo`03001oogoo0:=oo`03001oogoo015oo`03001oogoo02moo`00
;7oo0P00Y7oo00<007ooOol04Goo00<007ooOol0;goo000/Ool00`00Oomoo`2TOol00`00Oomoo`0@
Ool00`00Oomoo`0_Ool002aoo`03001oogoo0:Aoo`03001oogoo011oo`03001oogoo02moo`00;7oo
00<007ooOol0YGoo00<007ooOol03goo00<007ooOol0;goo000/Ool00`00Oomoo`2UOol00`00Oomo
o`0?Ool00`00Oomoo`0_Ool002aoo`800:Moo`03001oogoo00ioo`03001oogoo02moo`00;7oo00<0
07ooOol0YWoo00<007ooOol03Woo00<007ooOol0;goo000/Ool00`00Oomoo`2WOol00`00Oomoo`0=
Ool00`00Oomoo`0_Ool002Ioo`03001oogoo00=oo`03001oogoo0:Moo`03001oogoo00eoo`03001o
ogoo02moo`009Goo00<007oo000017oo00<007ooOol0Z7oo00<007ooOol037oo00<007ooOol0;goo
000WOol00`00Oomoo`02Ool3002XOol00`00Oomoo`0<Ool00`00Oomoo`0_Ool002Eoo`8000Eoo`03
001oogoo0:Uoo`03001oogoo00]oo`03001oogoo02moo`009Goo00<007ooOol017oo00<007ooOol0
ZGoo00<007ooOol02goo00<007ooOol0;goo000UOol30004Ool00`00Oomoo`2ZOol00`00Oomoo`09
Ool00`00Oomoo`0`Ool002aoo`03001oogoo0:Yoo`03001oogoo00Uoo`03001oogoo031oo`00;7oo
0P00[7oo00<007ooOol027oo00<007ooOol0<7oo000/Ool00`00Oomoo`2[Ool00`00Oomoo`08Ool0
0`00Oomoo`0`Ool002aoo`03001oogoo0:aoo`03001oogoo00Moo`03001oogoo031oo`00;7oo00<0
07ooOol0[7oo00<007ooOol01goo00<007ooOol0<7oo000/Ool00`00Oomoo`2/Ool00`00Oomoo`07
Ool00`00Oomoo`0`Ool002aoo`800:ioo`03001oogoo00Ioo`03001oogoo031oo`00;7oo00<007oo
Ool0[Goo00<007ooOol01Woo00<007ooOol0<7oo000/Ool00`00Oomoo`2]Ool00`00Oomoo`06Ool0
0`00Oomoo`0`Ool002aoo`03001oogoo0:ioo`03001oogoo00Eoo`03001oogoo031oo`00;7oo0P00
[goo00<007ooOol01Goo00<007ooOol0<7oo000/Ool00`00Oomoo`2_Ool00`00Oomoo`04Ool00`00
Oomoo`0`Ool002aoo`03001oogoo0:moo`03001oogoo00Aoo`03001oogoo031oo`00;7oo00<007oo
Ool0[goo00<007ooOol017oo00<007ooOol0<7oo000/Ool00`00Oomoo`2`Ool00`00Oomoo`03Ool0
0`00Oomoo`0`Ool002aoo`800;5oo`03001oogoo00=oo`03001oogoo031oo`00;7oo00<007ooOol0
/7oo00<007ooOol00goo00<007ooOol0<7oo000/Ool00`00Oomoo`2aOol00`00Oomoo`02Ool00`00
Oomoo`0`Ool002Eoo`8000Eoo`03001oogoo0;5oo`03001oogoo009oo`03001oogoo031oo`009Goo
00<007oo000017oo00<007ooOol0/Woo00@007ooOol003=oo`009Goo00<007oo000017oo0`00/Woo
00@007ooOol003=oo`009Goo0P001Goo00<007ooOol0/Woo00@007ooOol003=oo`009Goo00<007oo
Ool017oo00<007ooOol0/goo00<007oo0000<goo000VOol20004Ool00`00Oomoo`2cOol00`00Ool0
000cOol002aoo`03001oogoo0;=oo`03001oo`0003=oo`00;7oo0P00]Goo0P00<goo000/Ool00`00
Oomoo`2dOol2000cOol002aoo`03001oogoo0;Eoo`03001oogoo035oo`00;7oo00<007ooOol0]Goo
00<007ooOol0<Goo000/Ool00`00Oomoo`3YOol002aoo`800>Yoo`00;7oo00<007ooOol0jGoo0000
\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {1.28646, -0.497127, 0.0158677, 
  0.0403901}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The reaction forces at the constraints can be found with the ",
  StyleBox["Reaction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. Constraint 4 is the ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " driving constraint, so its reaction is the moment applied to the crank. \
Constraint 1 is the ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint that positions the crank axis, so its reactions are the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " forces supporting the crank axis. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the moment required to rotate the crank."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[4, crank] /. 
      statictab\[LeftDoubleBracket]70\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 8.18398204693967556`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction at the crank as a function of time. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, 
          \(Reaction[4, crank]\)\[LeftDoubleBracket]2\[RightDoubleBracket]}
           /. statictab, PlotJoined \[Rule] True, PlotRange \[Rule] All]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.0533725 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .12146 -6 -4.5 ]
[.01131 .12146 0 4.5 ]
[.01131 .22821 -6 -4.5 ]
[.01131 .22821 0 4.5 ]
[.01131 .33495 -6 -4.5 ]
[.01131 .33495 0 4.5 ]
[.01131 .4417 -6 -4.5 ]
[.01131 .4417 0 4.5 ]
[.01131 .54844 -12 -4.5 ]
[.01131 .54844 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .12146 m
.03006 .12146 L
s
[(2)] .01131 .12146 1 0 Mshowa
.02381 .22821 m
.03006 .22821 L
s
[(4)] .01131 .22821 1 0 Mshowa
.02381 .33495 m
.03006 .33495 L
s
[(6)] .01131 .33495 1 0 Mshowa
.02381 .4417 m
.03006 .4417 L
s
[(8)] .01131 .4417 1 0 Mshowa
.02381 .54844 m
.03006 .54844 L
s
[(10)] .01131 .54844 1 0 Mshowa
.125 Mabswid
.02381 .0414 m
.02756 .0414 L
s
.02381 .06809 m
.02756 .06809 L
s
.02381 .09477 m
.02756 .09477 L
s
.02381 .14815 m
.02756 .14815 L
s
.02381 .17483 m
.02756 .17483 L
s
.02381 .20152 m
.02756 .20152 L
s
.02381 .25489 m
.02756 .25489 L
s
.02381 .28158 m
.02756 .28158 L
s
.02381 .30826 m
.02756 .30826 L
s
.02381 .36164 m
.02756 .36164 L
s
.02381 .38832 m
.02756 .38832 L
s
.02381 .41501 m
.02756 .41501 L
s
.02381 .46838 m
.02756 .46838 L
s
.02381 .49507 m
.02756 .49507 L
s
.02381 .52175 m
.02756 .52175 L
s
.02381 .57513 m
.02756 .57513 L
s
.02381 .60181 m
.02756 .60181 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.03571 .01472 L
.04762 .01472 L
.05952 .01472 L
.07143 .01472 L
.08333 .01472 L
.09524 .01472 L
.10714 .01472 L
.11905 .01472 L
.13095 .01472 L
.14286 .01472 L
.15476 .01472 L
.16667 .01472 L
.17857 .01472 L
.19048 .01472 L
.20238 .01472 L
.21429 .01472 L
.22619 .01472 L
.2381 .01472 L
.25 .01472 L
.2619 .01472 L
.27381 .01472 L
.28571 .01472 L
.29762 .01472 L
.30952 .01472 L
.32143 .01472 L
.33333 .01472 L
.34524 .01472 L
.35714 .01472 L
.36905 .01472 L
.38095 .01472 L
.39286 .01472 L
.40476 .01472 L
.41667 .01472 L
.42857 .01472 L
.44048 .01472 L
.45238 .01472 L
.46429 .01472 L
.47619 .01472 L
.4881 .01472 L
.5 .01472 L
.5119 .01472 L
.52381 .01475 L
.53571 .01483 L
.54762 .015 L
.55952 .01529 L
.57143 .01574 L
.58333 .0164 L
.59524 .01736 L
.60714 .01867 L
Mistroke
.61905 .02046 L
.63095 .02285 L
.64286 .02599 L
.65476 .03008 L
.66667 .03533 L
.67857 .04202 L
.69048 .05044 L
.70238 .06093 L
.71429 .07383 L
.72619 .08953 L
.7381 .10838 L
.75 .13074 L
.7619 .15689 L
.77381 .18708 L
.78571 .22146 L
.79762 .26008 L
.80952 .30283 L
.82143 .34942 L
.83333 .39929 L
.84524 .45151 L
.85714 .50461 L
.86905 .55633 L
.88095 .60332 L
.89286 .59241 L
.90476 .40953 L
.91667 .21699 L
.92857 .09123 L
.94048 .03435 L
.95238 .0174 L
.96429 .0148 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000nOol0
0`00Oomoo`02Ool01000Oomoogoo0`009goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Qoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qo
o`D000Qoo`00?Goo00<007oo00001goo00<007ooOol09Woo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo00009Woo00<007oo00001goo00<007oo0000:goo00<007ooOol027oo
000mOol00`00Ool00008Ool00`00Oomoo`0UOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000VOol00`00Ool00007Ool00`00Ool0000[Ool00`00Oomoo`08Ool003eoo`03001oo`00
00Qoo`03001oogoo02Eoo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Moo`03
001oo`0000Qoo`03001oogoo02Yoo`03001oogoo00Qoo`00?Goo00<007oo00001goo00<007oo0000
9Woo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol09Woo00<007oo00001goo00<0
07oo0000:goo00<007ooOol027oo000nOol00`00Oomoo`07Ool00`00Oomoo`0VOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000WOol00`00Oomoo`07Ool00`00Oomoo`0YOol2000:
Ool00?mooaUoo`00ogoo6Goo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?moo`Eoo`00
4Goo00<007ooOol0ogoo1Goo000AOol00`00Oomoo`3oOol5Ool000]oool000/000=oo`004Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Goo2@0017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol00goo0P001Goo00<0
07ooOol01goo000AOol00`00Oomoo`2MOol3001BOol00`00Oomoo`0?Ool0015oo`03001oogoo0:1o
o`<004ioo`03001oogoo011oo`004Goo00<007ooOol0Xgoo0`00Bgoo00<007ooOol047oo000AOol0
0`00Oomoo`2VOol30017Ool00`00Oomoo`0AOol0015oo`03001oogoo0:Uoo`8004Eoo`03001oogoo
015oo`004Goo0P00[7oo00<007ooOol0@Woo00<007ooOol04Goo000AOol00`00Oomoo`2/Ool20011
Ool00`00Oomoo`0BOol0015oo`03001oogoo0:ioo`03001oogoo03ioo`03001oogoo019oo`004Goo
00<007ooOol0[goo00<007ooOol0?Goo00<007ooOol04Woo000AOol00`00Oomoo`2`Ool00`00Oomo
o`0lOol00`00Oomoo`0BOol0015oo`03001oogoo0;5oo`03001oogoo03]oo`03001oogoo019oo`00
4Goo00<007ooOol0/Woo00<007ooOol0>Goo00<007ooOol04goo000AOol2002dOol00`00Oomoo`0h
Ool00`00Oomoo`0COol0015oo`03001oogoo0;Aoo`03001oogoo03Moo`03001oogoo01=oo`004Goo
00<007ooOol0]Goo00<007ooOol0=Woo00<007ooOol04goo000AOol00`00Oomoo`2eOol00`00Oomo
o`0fOol00`00Oomoo`0COol0015oo`03001oogoo0;Ioo`03001oogoo03Aoo`03001oogoo01Aoo`00
4Goo00<007ooOol0]Woo00<007ooOol0=7oo00<007ooOol057oo000AOol00`00Oomoo`2gOol00`00
Oomoo`0cOol00`00Oomoo`0DOol0015oo`800;Uoo`03001oogoo039oo`03001oogoo01Aoo`004Goo
00<007ooOol0^Goo00<007ooOol0<Goo00<007ooOol057oo000AOol00`00Oomoo`2iOol00`00Oomo
o`0aOol00`00Oomoo`0DOol0015oo`03001oogoo0;Yoo`03001oogoo031oo`03001oogoo01Aoo`00
4Goo00<007ooOol0^goo00<007ooOol0;goo00<007ooOol057oo000:Ool30004Ool00`00Oomoo`2k
Ool00`00Oomoo`0^Ool00`00Oomoo`0EOol000Yoo`03001oogoo00Aoo`03001oogoo0;aoo`03001o
ogoo02eoo`03001oogoo01Eoo`002goo00<007ooOol00goo0`00_7oo00<007ooOol0;Goo00<007oo
Ool05Goo000;Ool00`00Oomoo`03Ool00`00Oomoo`2mOol00`00Oomoo`0/Ool00`00Oomoo`0EOol0
00Yoo`03001oo`0000Aoo`03001oogoo0;eoo`03001oogoo02aoo`03001oogoo01Eoo`002goo00<0
07ooOol00goo00<007ooOol0_Woo00<007ooOol0:goo00<007ooOol05Goo000AOol00`00Oomoo`2n
Ool00`00Oomoo`0[Ool00`00Oomoo`0EOol0015oo`03001oogoo0;moo`03001oogoo02Yoo`03001o
ogoo01Eoo`004Goo00<007ooOol0_goo00<007ooOol0:Woo00<007ooOol05Goo000AOol20031Ool0
0`00Oomoo`0YOol00`00Oomoo`0EOol0015oo`03001oogoo0<1oo`03001oogoo02Uoo`03001oogoo
01Eoo`004Goo00<007ooOol0`Goo00<007ooOol09goo00<007ooOol05Woo000AOol00`00Oomoo`31
Ool00`00Oomoo`0WOol00`00Oomoo`0FOol0015oo`03001oogoo0<9oo`03001oogoo02Ioo`03001o
ogoo01Ioo`004Goo00<007ooOol0`Woo00<007ooOol09Woo00<007ooOol05Woo000AOol00`00Oomo
o`32Ool00`00Oomoo`0VOol00`00Oomoo`0FOol0015oo`800<Aoo`03001oogoo02Eoo`03001oogoo
01Ioo`004Goo00<007ooOol0`goo00<007ooOol09Goo00<007ooOol05Woo000AOol00`00Oomoo`34
Ool00`00Oomoo`0TOol00`00Oomoo`0FOol0015oo`03001oogoo0<Aoo`03001oogoo02Aoo`03001o
ogoo01Ioo`004Goo00<007ooOol0a7oo00<007ooOol097oo00<007ooOol05Woo000AOol00`00Oomo
o`35Ool00`00Oomoo`0SOol00`00Oomoo`0FOol0015oo`03001oogoo0<Eoo`03001oogoo029oo`03
001oogoo01Moo`004Goo0P00aWoo00<007ooOol08Woo00<007ooOol05goo000AOol00`00Oomoo`35
Ool00`00Oomoo`0ROol00`00Oomoo`0GOol0015oo`03001oogoo0<Ioo`03001oogoo025oo`03001o
ogoo01Moo`004Goo00<007ooOol0aWoo00<007ooOol08Goo00<007ooOol05goo000AOol00`00Oomo
o`36Ool00`00Oomoo`0QOol00`00Oomoo`0GOol000]oo`<000=oo`03001oogoo0<Moo`03001oogoo
021oo`03001oogoo01Moo`0037oo00<007ooOol00Woo00<007ooOol0agoo00<007ooOol087oo00<0
07ooOol05goo000:Ool40003Ool30037Ool00`00Oomoo`0POol00`00Oomoo`0GOol000Yoo`03001o
o`0000Aoo`03001oogoo0<Qoo`03001oogoo01moo`03001oogoo01Moo`002goo0P0017oo00<007oo
Ool0b7oo00<007ooOol07goo00<007ooOol05goo000<Ool00`00Oomoo`02Ool00`00Oomoo`38Ool0
0`00Oomoo`0OOol00`00Oomoo`0GOol0015oo`03001oogoo0<Qoo`03001oogoo01moo`03001oogoo
01Moo`004Goo00<007ooOol0bGoo00<007ooOol07Woo00<007ooOol05goo000AOol00`00Oomoo`39
Ool00`00Oomoo`0MOol00`00Oomoo`0HOol0015oo`800<Yoo`03001oogoo01eoo`03001oogoo01Qo
o`004Goo00<007ooOol0bWoo00<007ooOol077oo00<007ooOol067oo000AOol00`00Oomoo`3:Ool0
0`00Oomoo`0LOol00`00Oomoo`0HOol0015oo`03001oogoo0<Yoo`03001oogoo01aoo`03001oogoo
01Qoo`004Goo00<007ooOol0bgoo00<007ooOol06goo00<007ooOol067oo000AOol00`00Oomoo`3;
Ool00`00Oomoo`0KOol00`00Oomoo`0HOol0015oo`03001oogoo0<]oo`03001oogoo01]oo`03001o
ogoo01Qoo`004Goo0P00c7oo00<007ooOol06goo00<007ooOol067oo000AOol00`00Oomoo`3<Ool0
0`00Oomoo`0JOol00`00Oomoo`0HOol0015oo`03001oogoo0<aoo`03001oogoo01Yoo`03001oogoo
01Qoo`004Goo00<007ooOol0c7oo00<007ooOol06Woo00<007ooOol067oo000AOol00`00Oomoo`3<
Ool00`00Oomoo`0JOol00`00Oomoo`0HOol0015oo`03001oogoo0<eoo`03001oogoo01Uoo`03001o
ogoo01Qoo`004Goo00<007ooOol0cGoo00<007ooOol06Goo00<007ooOol067oo000AOol00`00Oomo
o`3=Ool00`00Oomoo`0IOol00`00Oomoo`0HOol0015oo`800<moo`03001oogoo01Qoo`03001oogoo
01Qoo`004Goo00<007ooOol0cWoo00<007ooOol05goo00<007ooOol06Goo000AOol00`00Oomoo`3>
Ool00`00Oomoo`0GOol00`00Oomoo`0IOol0015oo`03001oogoo0<moo`03001oogoo01Ioo`03001o
ogoo01Uoo`004Goo00<007ooOol0cgoo00<007ooOol05Woo00<007ooOol06Goo000:Ool20005Ool0
0`00Oomoo`3?Ool00`00Oomoo`0FOol00`00Oomoo`0IOol000Yoo`03001oo`0000Aoo`03001oogoo
0=1oo`03001oogoo01Eoo`03001oogoo01Uoo`002Woo00<007oo000017oo0`00d7oo00<007ooOol0
5Goo00<007ooOol06Goo000:Ool20005Ool00`00Oomoo`3@Ool00`00Oomoo`0EOol00`00Oomoo`0I
Ool000Yoo`03001oogoo00Aoo`03001oogoo0=5oo`03001oogoo01Aoo`03001oogoo01Uoo`002goo
0P0017oo00<007ooOol0dGoo00<007ooOol057oo00<007ooOol06Goo000AOol00`00Oomoo`3AOol0
0`00Oomoo`0DOol00`00Oomoo`0IOol0015oo`03001oogoo0=5oo`03001oogoo01Aoo`03001oogoo
01Uoo`004Goo00<007ooOol0dWoo00<007ooOol04goo00<007ooOol06Goo000AOol2003COol00`00
Oomoo`0COol00`00Oomoo`0IOol0015oo`03001oogoo0=9oo`03001oogoo01=oo`03001oogoo01Uo
o`004Goo00<007ooOol0dWoo00<007ooOol04goo00<007ooOol06Goo000AOol00`00Oomoo`3BOol0
0`00Oomoo`0COol00`00Oomoo`0IOol0015oo`03001oogoo0==oo`03001oogoo015oo`03001oogoo
01Yoo`004Goo00<007ooOol0dgoo00<007ooOol04Goo00<007ooOol06Woo000AOol00`00Oomoo`3C
Ool00`00Oomoo`0AOol00`00Oomoo`0JOol0015oo`800=Aoo`03001oogoo015oo`03001oogoo01Yo
o`004Goo00<007ooOol0e7oo00<007ooOol047oo00<007ooOol06Woo000AOol00`00Oomoo`3DOol0
0`00Oomoo`0@Ool00`00Oomoo`0JOol0015oo`03001oogoo0=Aoo`03001oogoo011oo`03001oogoo
01Yoo`004Goo00<007ooOol0e7oo00<007ooOol047oo00<007ooOol06Woo000AOol00`00Oomoo`3D
Ool00`00Oomoo`0@Ool00`00Oomoo`0JOol0015oo`03001oogoo0=Eoo`03001oogoo00moo`03001o
ogoo01Yoo`004Goo0P00eWoo00<007ooOol03goo00<007ooOol06Woo000AOol00`00Oomoo`3EOol0
0`00Oomoo`0?Ool00`00Oomoo`0JOol0015oo`03001oogoo0=Eoo`03001oogoo00moo`03001oogoo
01Yoo`004Goo00<007ooOol0eWoo00<007ooOol03Woo00<007ooOol06Woo000AOol00`00Oomoo`3F
Ool00`00Oomoo`0>Ool00`00Oomoo`0JOol000]oo`03001oogoo00=oo`03001oogoo0=Ioo`03001o
ogoo00eoo`03001oogoo01]oo`002Woo00<007oo000017oo00<007ooOol0eWoo00<007ooOol03Goo
00<007ooOol06goo000:Ool00`00Ool00004Ool3003GOol00`00Oomoo`0<Ool00`00Oomoo`0KOol0
00]oo`03001oogoo00=oo`03001oogoo0=Moo`03001oogoo00aoo`03001oogoo01]oo`002Woo00<0
07oo000017oo00<007ooOol0egoo00<007ooOol037oo00<007ooOol06goo000;Ool00`00Oomoo`03
Ool00`00Oomoo`3GOol00`00Oomoo`0<Ool00`00Oomoo`0KOol0015oo`03001oogoo0=Moo`03001o
ogoo00aoo`03001oogoo01]oo`004Goo00<007ooOol0f7oo00<007ooOol02goo00<007ooOol06goo
000AOol00`00Oomoo`3HOol00`00Oomoo`0;Ool00`00Oomoo`0KOol0015oo`800=Uoo`03001oogoo
00]oo`03001oogoo01]oo`004Goo00<007ooOol0f7oo00<007ooOol02goo00<007ooOol06goo000A
Ool00`00Oomoo`3HOol00`00Oomoo`0;Ool00`00Oomoo`0KOol0015oo`03001oogoo0=Uoo`03001o
ogoo00Uoo`03001oogoo01aoo`004Goo00<007ooOol0fGoo00<007ooOol02Goo00<007ooOol077oo
000AOol00`00Oomoo`3IOol00`00Oomoo`09Ool00`00Oomoo`0LOol0015oo`03001oogoo0=Uoo`03
001oogoo00Uoo`03001oogoo01aoo`004Goo0P00fgoo00<007ooOol027oo00<007ooOol077oo000A
Ool00`00Oomoo`3JOol00`00Oomoo`08Ool00`00Oomoo`0LOol0015oo`03001oogoo0=Yoo`03001o
ogoo00Qoo`03001oogoo01aoo`004Goo00<007ooOol0fWoo00<007ooOol027oo00<007ooOol077oo
000AOol00`00Oomoo`3JOol00`00Oomoo`08Ool00`00Oomoo`0LOol0015oo`03001oogoo0=]oo`03
001oogoo00Moo`03001oogoo01aoo`004Goo00<007ooOol0fgoo00<007ooOol01goo00<007ooOol0
77oo000AOol2003LOol00`00Oomoo`07Ool00`00Oomoo`0LOol0015oo`03001oogoo0=]oo`03001o
ogoo00Ioo`03001oogoo01eoo`004Goo00<007ooOol0fgoo00<007ooOol01Woo00<007ooOol07Goo
000AOol00`00Oomoo`3LOol00`00Oomoo`05Ool00`00Oomoo`0MOol0015oo`03001oogoo0=aoo`03
001oogoo00Eoo`03001oogoo01eoo`0017oo1@000Woo00<007ooOol00goo00<007ooOol0g7oo00<0
07ooOol01Goo00<007ooOol07Goo0006Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0=aoo`03
001oogoo00Eoo`03001oogoo01eoo`001Woo00L007ooOomoo`00Ool00004Ool3003MOol00`00Oomo
o`04Ool00`00Oomoo`0MOol000Ioo`07001oogooOol007oo000017oo00<007ooOol0gGoo00<007oo
Ool017oo00<007ooOol07Goo0006Ool01`00Oomoogoo001oo`0000Aoo`03001oogoo0=eoo`03001o
ogoo00Aoo`03001oogoo01eoo`001Goo0P0017oo00<007ooOol00goo00<007ooOol0gGoo00<007oo
Ool017oo00<007ooOol07Goo000AOol00`00Oomoo`3MOol00`00Oomoo`04Ool00`00Oomoo`0MOol0
015oo`03001oogoo0=ioo`03001oogoo00=oo`03001oogoo01eoo`004Goo00<007ooOol0gWoo00<0
07ooOol00Woo00<007ooOol07Woo000AOol2003OOol00`00Oomoo`02Ool00`00Oomoo`0NOol0015o
o`03001oogoo0=ioo`03001oogoo009oo`03001oogoo01ioo`004Goo00<007ooOol0ggoo00D007oo
Oomoo`00021oo`004Goo00<007ooOol0ggoo00D007ooOomoo`00021oo`004Goo00<007ooOol0ggoo
00D007ooOomoo`00021oo`004Goo00<007ooOol0ggoo00D007ooOomoo`00021oo`004Goo00<007oo
Ool0h7oo00<007oo00008Goo000AOol2003QOol2000ROol0015oo`03001oogoo0>1oo`03001oogoo
025oo`004Goo00<007ooOol0ogoo1Goo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?mo
o`Eoo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0712482, -0.871241, 
  0.00396691, 0.0707858}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  " \nBecause ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not able to plot two lists simultaneously, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " graphics primitives are used directly to plot the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " reactions. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " reaction forces at the crank axis as a function of time."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      Graphics[{
          Line[{T, 
                \(Reaction[1, crank]\)\[LeftDoubleBracket]1, 1
                  \[RightDoubleBracket]} /. statictab], 
          Line[{T, 
                \(Reaction[1, crank]\)\[LeftDoubleBracket]1, 2
                  \[RightDoubleBracket]} /. statictab]}], 
      PlotRange \[Rule] All, Axes \[Rule] True]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.0858387 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10055 -6 -4.5 ]
[.01131 .10055 0 4.5 ]
[.01131 .18639 -6 -4.5 ]
[.01131 .18639 0 4.5 ]
[.01131 .27223 -6 -4.5 ]
[.01131 .27223 0 4.5 ]
[.01131 .35807 -6 -4.5 ]
[.01131 .35807 0 4.5 ]
[.01131 .44391 -6 -4.5 ]
[.01131 .44391 0 4.5 ]
[.01131 .52975 -6 -4.5 ]
[.01131 .52975 0 4.5 ]
[.01131 .61559 -6 -4.5 ]
[.01131 .61559 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10055 m
.03006 .10055 L
s
[(1)] .01131 .10055 1 0 Mshowa
.02381 .18639 m
.03006 .18639 L
s
[(2)] .01131 .18639 1 0 Mshowa
.02381 .27223 m
.03006 .27223 L
s
[(3)] .01131 .27223 1 0 Mshowa
.02381 .35807 m
.03006 .35807 L
s
[(4)] .01131 .35807 1 0 Mshowa
.02381 .44391 m
.03006 .44391 L
s
[(5)] .01131 .44391 1 0 Mshowa
.02381 .52975 m
.03006 .52975 L
s
[(6)] .01131 .52975 1 0 Mshowa
.02381 .61559 m
.03006 .61559 L
s
[(7)] .01131 .61559 1 0 Mshowa
.125 Mabswid
.02381 .03188 m
.02756 .03188 L
s
.02381 .04905 m
.02756 .04905 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .08339 m
.02756 .08339 L
s
.02381 .11772 m
.02756 .11772 L
s
.02381 .13489 m
.02756 .13489 L
s
.02381 .15206 m
.02756 .15206 L
s
.02381 .16922 m
.02756 .16922 L
s
.02381 .20356 m
.02756 .20356 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2379 m
.02756 .2379 L
s
.02381 .25506 m
.02756 .25506 L
s
.02381 .2894 m
.02756 .2894 L
s
.02381 .30657 m
.02756 .30657 L
s
.02381 .32373 m
.02756 .32373 L
s
.02381 .3409 m
.02756 .3409 L
s
.02381 .37524 m
.02756 .37524 L
s
.02381 .39241 m
.02756 .39241 L
s
.02381 .40957 m
.02756 .40957 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .46108 m
.02756 .46108 L
s
.02381 .47824 m
.02756 .47824 L
s
.02381 .49541 m
.02756 .49541 L
s
.02381 .51258 m
.02756 .51258 L
s
.02381 .54691 m
.02756 .54691 L
s
.02381 .56408 m
.02756 .56408 L
s
.02381 .58125 m
.02756 .58125 L
s
.02381 .59842 m
.02756 .59842 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .01472 m
.03571 .01472 L
.04762 .01472 L
.05952 .01472 L
.07143 .01472 L
.08333 .01472 L
.09524 .01472 L
.10714 .01472 L
.11905 .01472 L
.13095 .01472 L
.14286 .01472 L
.15476 .01472 L
.16667 .01472 L
.17857 .01472 L
.19048 .01472 L
.20238 .01472 L
.21429 .01472 L
.22619 .01472 L
.2381 .01472 L
.25 .01472 L
.2619 .01472 L
.27381 .01472 L
.28571 .01472 L
.29762 .01472 L
.30952 .01472 L
.32143 .01472 L
.33333 .01472 L
.34524 .01472 L
.35714 .01472 L
.36905 .01472 L
.38095 .01472 L
.39286 .01472 L
.40476 .01472 L
.41667 .01472 L
.42857 .01472 L
.44048 .01472 L
.45238 .01472 L
.46429 .01472 L
.47619 .01472 L
.4881 .01472 L
.5 .01472 L
.5119 .01482 L
.52381 .01512 L
.53571 .01563 L
.54762 .01637 L
.55952 .01733 L
.57143 .01854 L
.58333 .02003 L
.59524 .02181 L
.60714 .02393 L
Mistroke
.61905 .02643 L
.63095 .02935 L
.64286 .03276 L
.65476 .03673 L
.66667 .04135 L
.67857 .04672 L
.69048 .05297 L
.70238 .06023 L
.71429 .06869 L
.72619 .07855 L
.7381 .09004 L
.75 .10346 L
.7619 .11916 L
.77381 .13755 L
.78571 .15914 L
.79762 .18455 L
.80952 .21452 L
.82143 .24996 L
.83333 .29196 L
.84524 .34185 L
.85714 .40115 L
.86905 .47157 L
.88095 .55487 L
.89286 .60332 L
.90476 .47263 L
.91667 .29054 L
.92857 .14299 L
.94048 .05805 L
.95238 .02352 L
.96429 .01527 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.03571 .01472 L
.04762 .01472 L
.05952 .01472 L
.07143 .01472 L
.08333 .01472 L
.09524 .01472 L
.10714 .01472 L
.11905 .01472 L
.13095 .01472 L
.14286 .01472 L
.15476 .01472 L
.16667 .01472 L
.17857 .01472 L
.19048 .01472 L
.20238 .01472 L
.21429 .01472 L
.22619 .01472 L
.2381 .01472 L
.25 .01472 L
.2619 .01472 L
.27381 .01472 L
.28571 .01472 L
.29762 .01472 L
.30952 .01472 L
.32143 .01472 L
.33333 .01472 L
.34524 .01472 L
.35714 .01472 L
.36905 .01472 L
.38095 .01472 L
.39286 .01472 L
.40476 .01472 L
.41667 .01472 L
.42857 .01472 L
.44048 .01472 L
.45238 .01472 L
.46429 .01472 L
.47619 .01472 L
.4881 .01472 L
.5 .01472 L
.5119 .01472 L
.52381 .01475 L
.53571 .01484 L
.54762 .01501 L
.55952 .0153 L
.57143 .01574 L
.58333 .01638 L
.59524 .01725 L
.60714 .0184 L
Mistroke
.61905 .01989 L
.63095 .02177 L
.64286 .02412 L
.65476 .027 L
.66667 .03047 L
.67857 .03461 L
.69048 .03948 L
.70238 .04514 L
.71429 .05162 L
.72619 .05896 L
.7381 .06716 L
.75 .07623 L
.7619 .08612 L
.77381 .09681 L
.78571 .10822 L
.79762 .12029 L
.80952 .13291 L
.82143 .14596 L
.83333 .15926 L
.84524 .17254 L
.85714 .18541 L
.86905 .1973 L
.88095 .20733 L
.89286 .19885 L
.90476 .13772 L
.91667 .07653 L
.92857 .03773 L
.94048 .02055 L
.95238 .01551 L
.96429 .01474 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo000mOol0
0`00Oomoo`02Ool01000Oomoogoo0`009Goo00<007ooOol00Woo00<007ooOol00Woo0`009Goo00<0
07ooOol00Woo00@007ooOomoo`8002Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Mo
o`D000ioo`00?7oo00<007oo00001goo00<007ooOol097oo00<007oo00002Goo00<007ooOol08goo
00<007oo00001goo00<007oo000097oo00<007oo00001goo00<007oo0000:Woo00<007ooOol03Woo
000lOol00`00Ool00008Ool00`00Oomoo`0SOol00`00Ool00007Ool4000TOol00`00Ool00007Ool0
0`00Ool0000TOol00`00Ool00007Ool00`00Ool0000ZOol00`00Oomoo`0>Ool003aoo`03001oo`00
00Qoo`03001oogoo02=oo`03001oo`0000Moo`03001oo`0002Eoo`03001oo`0000Moo`8002Eoo`03
001oo`0000Qoo`03001oogoo02Uoo`03001oogoo00ioo`00?7oo00<007oo00001goo00<007oo0000
97oo00<007oo000027oo0P009Goo00<007oo00001goo00<007ooOol097oo00<007oo00001goo00<0
07oo0000:Woo00<007ooOol03Woo000mOol00`00Oomoo`07Ool00`00Oomoo`0TOol00`00Oomoo`08
Ool00`00Oomoo`0TOol00`00Oomoo`07Ool2000UOol00`00Oomoo`07Ool00`00Oomoo`0XOol2000@
Ool00?mooaUoo`00ogoo6Goo000AOol00`00Oomoo`3oOol5Ool0015oo`03001oogoo0?moo`Eoo`00
4Goo00<007ooOol0ogoo1Goo000AOol00`00Oomoo`3oOol5Ool000]oool000D000Uoo`004Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol00Woo1P0000=oo`00Ool01P0017oo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
0P000goo0P000goo00<007ooOol03Goo000AOol00`00Oomoo`2@Ool60003Ool6001:Ool01000Oomo
ogoo0P005Goo000AOol00`00Oomoo`2FOol30006Ool40016Ool01@00Oomoogoo00005Woo000AOol2
002JOol60004Ool30012Ool01@00Oomoogoo00005goo000AOol00`00Oomoo`2OOol30004Ool3000o
Ool01@00Oomoogoo00005goo000AOol00`00Oomoo`2ROol20005Ool2000lOol00`00Oomoo`02Ool0
0`00Oomoo`0EOol0015oo`03001oogoo0:Aoo`8000Eoo`8003Yoo`05001oogooOol0000HOol0015o
o`03001oogoo0:Ioo`8000Eoo`8003Moo`03001oogoo009oo`03001oogoo01Ioo`004Goo0P00ZGoo
0P001Goo0P00=Goo00<007ooOol00Woo00<007ooOol05Woo000AOol00`00Oomoo`2ZOol20005Ool2
000cOol01@00Oomoogoo00006Goo000AOol00`00Oomoo`2/Ool20005Ool00`00Oomoo`0_Ool00`00
Oomoo`02Ool00`00Oomoo`0GOol0015oo`03001oogoo0:ioo`03001oogoo00=oo`8002moo`03001o
ogoo009oo`03001oogoo01Moo`004Goo0P00/7oo00<007ooOol017oo00<007ooOol0;7oo00<007oo
Ool00Woo00<007ooOol05goo000AOol00`00Oomoo`2`Ool00`00Oomoo`04Ool00`00Oomoo`0[Ool0
0`00Oomoo`02Ool00`00Oomoo`0GOol0015oo`03001oogoo0;5oo`8000Eoo`03001oogoo02Uoo`03
001oogoo009oo`03001oogoo01Qoo`004Goo00<007ooOol0/goo00<007ooOol00goo00<007ooOol0
:7oo00<007ooOol00Woo00<007ooOol067oo000AOol2002eOol00`00Oomoo`03Ool2000XOol00`00
Oomoo`02Ool00`00Oomoo`0HOol0015oo`03001oogoo0;Eoo`03001oogoo00Aoo`03001oogoo02Eo
o`03001oogoo009oo`03001oogoo01Qoo`004Goo00<007ooOol0]Woo00<007ooOol017oo00<007oo
Ool08goo00<007ooOol00goo00<007ooOol067oo0009Ool50003Ool00`00Oomoo`2gOol00`00Oomo
o`04Ool00`00Oomoo`0ROol00`00Oomoo`03Ool00`00Oomoo`0HOol000]oo`03001oogoo00=oo`03
001oogoo0;Moo`03001oogoo00Eoo`03001oogoo025oo`03001oogoo00=oo`03001oogoo01Qoo`00
2goo00<007ooOol00goo0`00^7oo00<007ooOol01Goo00<007ooOol087oo00<007ooOol00Woo00<0
07ooOol06Goo000;Ool00`00Oomoo`03Ool00`00Oomoo`2iOol00`00Oomoo`05Ool00`00Oomoo`0O
Ool00`00Oomoo`02Ool00`00Oomoo`0IOol000]oo`03001oogoo00=oo`03001oogoo0;Yoo`03001o
ogoo00Eoo`03001oogoo01eoo`03001oogoo00=oo`03001oogoo01Uoo`002Woo0P001Goo00<007oo
Ool0^Woo00<007ooOol01Woo00<007ooOol077oo00<007ooOol00goo00<007ooOol06Goo000AOol2
002lOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`03Ool00`00Oomoo`0IOol0015oo`03
001oogoo0;aoo`03001oogoo00Ioo`03001oogoo01Yoo`03001oogoo00=oo`03001oogoo01Uoo`00
4Goo00<007ooOol0_Goo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol00goo00<007ooOol0
6Goo000AOol00`00Oomoo`2mOol00`00Oomoo`07Ool2000IOol00`00Oomoo`03Ool00`00Oomoo`0I
Ool0015oo`03001oogoo0;ioo`03001oogoo00Qoo`03001oogoo01Eoo`03001oogoo00=oo`03001o
ogoo01Yoo`004Goo0P00`7oo00<007ooOol027oo00<007ooOol057oo00<007ooOol00goo00<007oo
Ool06Woo000AOol00`00Oomoo`2oOol00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`03Ool0
0`00Oomoo`0JOol0015oo`03001oogoo0<1oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo
00=oo`03001oogoo01Yoo`004Goo00<007ooOol0`7oo00<007ooOol02Goo00<007ooOol04Woo00<0
07ooOol00goo00<007ooOol06Woo000AOol20032Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00
Oomoo`04Ool00`00Oomoo`0JOol0015oo`03001oogoo0<5oo`03001oogoo00Yoo`03001oogoo00mo
o`03001oogoo00Aoo`03001oogoo01Yoo`004Goo00<007ooOol0`Woo00<007ooOol02Woo00<007oo
Ool03Woo00<007ooOol017oo00<007ooOol06Woo000AOol00`00Oomoo`32Ool00`00Oomoo`0;Ool0
0`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0JOol0015oo`03001oogoo0<=oo`03001oogoo
00Yoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo01Yoo`004Goo0P00a7oo00<007ooOol0
2goo00<007ooOol02goo00<007ooOol017oo00<007ooOol06goo000AOol00`00Oomoo`34Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0KOol000Yoo`<000Aoo`03001o
ogoo0<Aoo`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo01]oo`002Woo
00<007ooOol017oo00<007ooOol0aGoo00<007ooOol037oo00<007ooOol027oo00<007ooOol017oo
00<007ooOol06goo000;Ool00`00Oomoo`03Ool30035Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`0KOol000]oo`03001oogoo00=oo`03001oogoo0<Ioo`03001oogoo
00eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo01]oo`002Woo00<007oo000017oo00<0
07ooOol0aWoo00<007ooOol03Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol06goo000;
Ool00`00Oomoo`03Ool00`00Oomoo`37Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`0KOol0015oo`03001oogoo0<Moo`03001oogoo00moo`05001oogooOol00008Ool0
0`00Oomoo`0KOol0015oo`800<Uoo`03001oogoo00moo`03001oo`0000Uoo`03001oogoo01]oo`00
4Goo00<007ooOol0b7oo00<007ooOol047oo00<007ooOol027oo00<007ooOol06goo000AOol00`00
Oomoo`39Ool00`00Oomoo`0JOol00`00Oomoo`0KOol0015oo`03001oogoo0<Uoo`03001oogoo01Uo
o`03001oogoo01aoo`004Goo0P00bgoo00<007ooOol067oo00<007ooOol077oo000AOol00`00Oomo
o`3:Ool00`00Oomoo`0HOol00`00Oomoo`0LOol0015oo`03001oogoo0<Yoo`03001oogoo01Qoo`03
001oogoo01aoo`004Goo00<007ooOol0bWoo00<007ooOol067oo00<007ooOol077oo000AOol2003<
Ool00`00Oomoo`0GOol00`00Oomoo`0LOol0015oo`03001oogoo0<]oo`03001oogoo01Moo`03001o
ogoo01aoo`004Goo00<007ooOol0bgoo00<007ooOol05goo00<007ooOol077oo000AOol00`00Oomo
o`3<Ool00`00Oomoo`0FOol00`00Oomoo`0LOol0015oo`03001oogoo0<aoo`03001oogoo01Ioo`03
001oogoo01aoo`004Goo0P00cGoo00<007ooOol05Woo00<007ooOol077oo000AOol00`00Oomoo`3=
Ool00`00Oomoo`0EOol00`00Oomoo`0LOol000Yoo`8000Eoo`03001oogoo0<eoo`03001oogoo01Eo
o`03001oogoo01aoo`0037oo00<007ooOol00Woo00<007ooOol0cGoo00<007ooOol057oo00<007oo
Ool07Goo000;Ool00`00Oomoo`03Ool3003=Ool00`00Oomoo`0DOol00`00Oomoo`0MOol000aoo`03
001oogoo009oo`03001oogoo0<ioo`03001oogoo01=oo`03001oogoo01eoo`002Woo00<007oo0000
17oo00<007ooOol0cWoo00<007ooOol04goo00<007ooOol07Goo000;Ool00`00Oomoo`03Ool00`00
Oomoo`3>Ool00`00Oomoo`0COol00`00Oomoo`0MOol0015oo`03001oogoo0<moo`03001oogoo019o
o`03001oogoo01eoo`004Goo0P00d7oo00<007ooOol04Woo00<007ooOol07Goo000AOol00`00Oomo
o`3?Ool00`00Oomoo`0BOol00`00Oomoo`0MOol0015oo`03001oogoo0<moo`03001oogoo019oo`03
001oogoo01eoo`004Goo00<007ooOol0d7oo00<007ooOol04Goo00<007ooOol07Goo000AOol2003A
Ool00`00Oomoo`0AOol00`00Oomoo`0MOol0015oo`03001oogoo0=1oo`03001oogoo015oo`03001o
ogoo01eoo`004Goo00<007ooOol0d7oo00<007ooOol04Goo00<007ooOol07Goo000AOol00`00Oomo
o`3AOol00`00Oomoo`0@Ool00`00Oomoo`0MOol0015oo`03001oogoo0=5oo`03001oogoo00moo`03
001oogoo01ioo`004Goo0P00dWoo00<007ooOol03goo00<007ooOol07Woo000AOol00`00Oomoo`3A
Ool00`00Oomoo`0?Ool00`00Oomoo`0NOol0015oo`03001oogoo0=9oo`03001oogoo00ioo`03001o
ogoo01ioo`004Goo00<007ooOol0dWoo00<007ooOol03Woo00<007ooOol07Woo000AOol2003COol0
0`00Oomoo`0>Ool00`00Oomoo`0NOol0015oo`03001oogoo0=9oo`03001oogoo00ioo`03001oogoo
01ioo`002goo0`000goo00<007ooOol0dWoo00<007ooOol03Woo00<007ooOol07Woo000<Ool00`00
Oomoo`02Ool00`00Oomoo`3COol00`00Oomoo`0=Ool00`00Oomoo`0NOol000Yoo`@000=oo`<00==o
o`03001oogoo00eoo`03001oogoo01ioo`002Woo00<007oo000017oo00<007ooOol0dgoo00<007oo
Ool03Goo00<007ooOol07Woo000;Ool20004Ool00`00Oomoo`3COol00`00Oomoo`0=Ool00`00Oomo
o`0NOol000aoo`03001oogoo009oo`03001oogoo0==oo`03001oogoo00eoo`03001oogoo01ioo`00
4Goo00<007ooOol0dgoo00<007ooOol03Goo00<007ooOol07Woo000AOol2003EOol00`00Oomoo`0<
Ool00`00Oomoo`0NOol0015oo`03001oogoo0=Aoo`03001oogoo00aoo`03001oogoo01ioo`004Goo
00<007ooOol0e7oo00<007ooOol02goo00<007ooOol07goo000AOol00`00Oomoo`3DOol00`00Oomo
o`0;Ool00`00Oomoo`0OOol0015oo`800=Eoo`03001oogoo00]oo`03001oogoo01moo`004Goo00<0
07ooOol0eGoo00<007ooOol02Woo00<007ooOol07goo000AOol00`00Oomoo`3EOol00`00Oomoo`0:
Ool00`00Oomoo`0OOol0015oo`03001oogoo0=Eoo`03001oogoo00Yoo`03001oogoo01moo`004Goo
00<007ooOol0eGoo00<007ooOol02Woo00<007ooOol07goo000AOol2003FOol00`00Oomoo`0:Ool0
0`00Oomoo`0OOol0015oo`03001oogoo0=Eoo`03001oogoo00Yoo`03001oogoo01moo`004Goo00<0
07ooOol0eWoo00<007ooOol02Goo00<007ooOol07goo000AOol00`00Oomoo`3FOol00`00Oomoo`09
Ool00`00Oomoo`0OOol0015oo`800=Moo`03001oogoo00Uoo`03001oogoo01moo`004Goo00<007oo
Ool0eWoo00<007ooOol02Goo00<007ooOol07goo000AOol00`00Oomoo`3FOol00`00Oomoo`09Ool0
0`00Oomoo`0OOol000]oo`03001oogoo00=oo`03001oogoo0=Ioo`03001oogoo00Uoo`03001oogoo
01moo`002Woo00<007oo000017oo00<007ooOol0egoo00<007ooOol027oo00<007ooOol07goo000<
Ool00`00Oomoo`02Ool3003GOol00`00Oomoo`07Ool00`00Oomoo`0POol000Yoo`8000Eoo`03001o
ogoo0=Moo`03001oogoo00Moo`03001oogoo021oo`002Woo00<007ooOol017oo00<007ooOol0egoo
00<007ooOol01goo00<007ooOol087oo000:Ool30004Ool00`00Oomoo`3GOol00`00Oomoo`07Ool0
0`00Oomoo`0POol0015oo`800=Qoo`03001oogoo00Moo`03001oogoo021oo`004Goo00<007ooOol0
f7oo00<007ooOol01Woo00<007ooOol087oo000AOol00`00Oomoo`3HOol00`00Oomoo`06Ool00`00
Oomoo`0POol0015oo`03001oogoo0=Qoo`03001oogoo00Ioo`03001oogoo021oo`004Goo00<007oo
Ool0f7oo00<007ooOol01Woo00<007ooOol087oo000AOol2003IOol00`00Oomoo`06Ool00`00Oomo
o`0POol0015oo`03001oogoo0=Qoo`03001oogoo00Ioo`03001oogoo021oo`004Goo00<007ooOol0
fGoo00<007ooOol01Goo00<007ooOol087oo000AOol00`00Oomoo`3IOol00`00Oomoo`05Ool00`00
Oomoo`0POol0015oo`800=Yoo`03001oogoo00Aoo`03001oogoo025oo`004Goo00<007ooOol0fGoo
00<007ooOol017oo00<007ooOol08Goo000AOol00`00Oomoo`3IOol00`00Oomoo`04Ool00`00Oomo
o`0QOol0015oo`03001oogoo0=Uoo`03001oogoo00Aoo`03001oogoo025oo`004Goo0P00fWoo00<0
07ooOol017oo00<007ooOol08Goo000AOol00`00Oomoo`3JOol00`00Oomoo`03Ool00`00Oomoo`0Q
Ool0015oo`03001oogoo0=Yoo`03001oogoo00=oo`03001oogoo025oo`002Woo0P001Goo00<007oo
Ool0fWoo00<007ooOol00goo00<007ooOol08Goo000:Ool00`00Ool00004Ool00`00Oomoo`3JOol0
0`00Oomoo`03Ool00`00Oomoo`0QOol000Yoo`03001oo`0000Aoo`<00=Yoo`03001oogoo00=oo`03
001oogoo025oo`002Woo0P001Goo00<007ooOol0fWoo00<007ooOol00goo00<007ooOol08Goo000:
Ool00`00Oomoo`04Ool00`00Oomoo`3JOol00`00Oomoo`02Ool00`00Oomoo`0ROol000]oo`8000Ao
o`03001oogoo0=]oo`05001oogooOol0000TOol0015oo`800=aoo`05001oogooOol0000TOol0015o
o`03001oogoo0=]oo`05001oogooOol0000TOol0015oo`03001oogoo0=]oo`05001oogooOol0000T
Ool0015oo`03001oogoo0=]oo`05001oogooOol0000TOol0015oo`03001oogoo0=]oo`05001oogoo
Ool0000TOol0015oo`800=eoo`04001oogoo000TOol0015oo`03001oogoo0=aoo`04001oogoo000T
Ool0015oo`03001oogoo0=aoo`04001oogoo000TOol0015oo`03001oogoo0=aoo`04001oogoo000T
Ool0015oo`800=ioo`03001oo`0002Aoo`004Goo00<007ooOol0gGoo0P009Goo000AOol00`00Oomo
o`3MOol2000UOol0015oo`03001oogoo0=eoo`8002Eoo`004Goo00<007ooOol0gWoo00<007ooOol0
8goo000AOol2003OOol00`00Oomoo`0SOol0015oo`03001oogoo0=ioo`03001oogoo02=oo`002goo
00<007ooOol00goo00<007ooOol0ogoo1Goo000;Ool00`00Oomoo`03Ool00`00Oomoo`3oOol5Ool0
00]oo`03001oogoo00=oo`<00?moo`Eoo`0037oo00<007ooOol00Woo00<007ooOol0ogoo1Goo000:
Ool00`00Ool0003oOol<Ool000Yoo`<00?moo`aoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.0730932, -0.551349, 
  0.00406337, 0.0450832}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Piston-Pump Graphics"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Mech`Mech2D`\"] "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"groundGr = Graphics[{\n  Thickness[.006],\n  \
Line[{{-2.3,-2.3},{2,-2.3},{2.7,-1},{7.6,-1}, \n        \
{7.6,1},{2.7,1},{2,2.3},{-2.3,2.3},{-2.3,-2.3}}], \n  \
Line[{{-1,-2.3},{0,0},{1,-2.3}}]}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"crankGr = Graphics[{\n  RGBColor[1,0,0],\n  Circle[{0,0},2.15], \n  \
Disk[Location[crank, {2,0}], .15], \n  Disk[{0,0}, .15]} ];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"pistonGr = Graphics[{ \n  {RGBColor[0,0,1], \n  \
Box[piston,{{-1,-1},{2,1}}]}, \n  Thickness[.02], \n  \
Line[{Location[crank,{2,0}],Location[piston,0]}]}]; "], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Show[{groundGr,crankGr,pistonGr}/.LastSolve[],
Frame->True,PlotRange->All,
AspectRatio->Automatic];\
\>", "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["KillMech[]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{81, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 40, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1796, 55, 78, 2, 47, "Subsection"],
Cell[1877, 59, 743, 18, 128, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2657, 82, 118, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2778, 87, 782, 25, 112, "Text"],

Cell[CellGroupData[{
Cell[3585, 116, 97, 2, 47, "Subsection"],
Cell[3685, 120, 1017, 22, 206, "Text"],

Cell[CellGroupData[{
Cell[4727, 146, 2991, 113, 300, "Special3"],
Cell[7721, 261, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[7880, 269, 1033, 35, 147, "Special3"],
Cell[8916, 306, 202, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[9133, 318, 508, 16, 73, "Text"],

Cell[CellGroupData[{
Cell[9666, 338, 188, 8, 24, "SmallText"],
Cell[9857, 348, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9978, 355, 133, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[10136, 362, 130, 4, 65, "Input"],
Cell[10269, 368, 57, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10363, 374, 183, 4, 24, "SmallText"],
Cell[10549, 380, 98, 2, 25, "Input"]
}, Open  ]]
}, Open  ]],
Cell[10674, 386, 422, 12, 40, "SmallText"],
Cell[11099, 400, 189, 3, 65, "Input"],
Cell[11291, 405, 795, 30, 94, "Text"],

Cell[CellGroupData[{
Cell[12111, 439, 292, 12, 24, "SmallText"],
Cell[12406, 453, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[12524, 461, 97, 2, 31, "Subsection"],
Cell[12624, 465, 1113, 25, 225, "Text"],

Cell[CellGroupData[{
Cell[13762, 494, 3069, 115, 285, "Special3"],
Cell[16834, 611, 122, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[16993, 619, 1111, 39, 147, "Special3"],
Cell[18107, 660, 286, 13, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[18408, 676, 508, 16, 73, "Text"],

Cell[CellGroupData[{
Cell[18941, 696, 188, 8, 24, "SmallText"],
Cell[19132, 706, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19253, 713, 235, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[19513, 724, 157, 4, 65, "Input"],
Cell[19673, 730, 57, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19767, 736, 318, 9, 40, "SmallText"],
Cell[20088, 747, 136, 3, 45, "Input"]
}, Open  ]]
}, Open  ]],
Cell[20251, 754, 424, 12, 40, "SmallText"],
Cell[20678, 768, 207, 5, 65, "Input"],
Cell[20888, 775, 795, 30, 94, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21720, 810, 105, 2, 31, "Subsection"],
Cell[21828, 814, 675, 24, 74, "Text"],

Cell[CellGroupData[{
Cell[22528, 842, 732, 29, 55, "Special3"],
Cell[23263, 873, 133, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[23411, 879, 692, 20, 112, "Text"],

Cell[CellGroupData[{
Cell[24128, 903, 296, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[24449, 919, 145, 4, 45, "Input"],
Cell[24597, 925, 55, 1, 29, "Output"],
Cell[24655, 928, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[24738, 933, 723, 22, 111, "Text"],

Cell[CellGroupData[{
Cell[25486, 959, 417, 16, 40, "SmallText"],

Cell[CellGroupData[{
Cell[25928, 979, 180, 4, 65, "Input"],
Cell[26111, 985, 55, 1, 29, "Output"],
Cell[26169, 988, 57, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[26275, 995, 190, 8, 24, "SmallText"],
Cell[26468, 1005, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26598, 1014, 122, 3, 33, "Section",
  PageBreakAbove->True],
Cell[26723, 1019, 2015, 56, 305, "Text"],

Cell[CellGroupData[{
Cell[28763, 1079, 100, 2, 47, "Subsection"],
Cell[28866, 1083, 706, 14, 166, "Text"],

Cell[CellGroupData[{
Cell[29597, 1101, 188, 8, 24, "SmallText"],
Cell[29788, 1111, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29909, 1118, 130, 3, 24, "SmallText"],
Cell[30042, 1123, 24243, 1080, 278, 6360, 854, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54322, 2208, 89, 2, 43, "Subsubsection"],
Cell[54414, 2212, 133, 3, 33, "Text"],

Cell[CellGroupData[{
Cell[54572, 2219, 140, 3, 24, "SmallText"],
Cell[54715, 2224, 104, 3, 45, "Input"]
}, Open  ]],
Cell[54834, 2230, 318, 6, 76, "Special1"],
Cell[55155, 2238, 282, 5, 59, "Special1"],

Cell[CellGroupData[{
Cell[55462, 2247, 135, 3, 24, "SmallText"],
Cell[55600, 2252, 315, 5, 169, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55952, 2262, 218, 7, 24, "SmallText"],
Cell[56173, 2271, 92, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[56314, 2279, 94, 2, 29, "Subsubsection"],
Cell[56411, 2283, 277, 5, 71, "Text"],
Cell[56691, 2290, 442, 14, 61, "Special1"],
Cell[57136, 2306, 439, 13, 61, "Special1"],
Cell[57578, 2321, 263, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[57866, 2334, 135, 3, 24, "SmallText"],
Cell[58004, 2339, 290, 6, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58331, 2350, 226, 7, 24, "SmallText"],
Cell[58560, 2359, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58708, 2368, 94, 2, 31, "Subsection"],
Cell[58805, 2372, 554, 16, 91, "Text"],

Cell[CellGroupData[{
Cell[59384, 2392, 900, 33, 87, "Special3"],
Cell[60287, 2427, 133, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[60435, 2433, 703, 19, 110, "Text"],

Cell[CellGroupData[{
Cell[61163, 2456, 1338, 46, 178, "Special3"],
Cell[62504, 2504, 205, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[62724, 2516, 356, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[63105, 2529, 849, 28, 117, "Special3"],
Cell[63957, 2559, 205, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[64199, 2573, 102, 2, 43, "Subsubsection"],
Cell[64304, 2577, 152, 4, 33, "Text"],
Cell[64459, 2583, 222, 8, 26, "Special1"],
Cell[64684, 2593, 226, 8, 26, "Special1"],
Cell[64913, 2603, 233, 8, 26, "Special1"],
Cell[65149, 2613, 135, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[65309, 2620, 309, 7, 105, "Input"],
Cell[65621, 2629, 57, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65715, 2635, 330, 12, 24, "SmallText"],
Cell[66048, 2649, 81, 2, 25, "Input"]
}, Open  ]],
Cell[66144, 2654, 461, 16, 54, "Text"],

Cell[CellGroupData[{
Cell[66630, 2674, 215, 8, 24, "SmallText"],
Cell[66848, 2684, 97, 2, 25, "Input"]
}, Open  ]],
Cell[66960, 2689, 694, 19, 148, "Text"],

Cell[CellGroupData[{
Cell[67679, 2712, 102, 2, 24, "SmallText"],
Cell[67784, 2716, 176, 4, 45, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[68021, 2727, 105, 2, 31, "Subsection"],
Cell[68129, 2731, 1082, 37, 133, "Text"],

Cell[CellGroupData[{
Cell[69236, 2772, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[69448, 2784, 73, 2, 25, "Input"],
Cell[69524, 2788, 322, 8, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[69873, 2800, 369, 14, 54, "Text"],

Cell[CellGroupData[{
Cell[70267, 2818, 976, 33, 117, "Special3"],
Cell[71246, 2853, 206, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[71467, 2865, 421, 16, 53, "Text"],

Cell[CellGroupData[{
Cell[71913, 2885, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[72126, 2897, 98, 2, 25, "Input"],
Cell[72227, 2901, 487, 10, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[72763, 2917, 202, 8, 24, "SmallText"],
Cell[72968, 2927, 23907, 1078, 278, 6409, 857, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[96890, 4008, 784, 19, 131, "Text"],

Cell[CellGroupData[{
Cell[97699, 4031, 190, 8, 24, "SmallText"],
Cell[97892, 4041, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[98010, 4049, 91, 2, 31, "Subsection"],
Cell[98104, 4053, 106, 2, 43, "Subsubsection"],
Cell[98213, 4057, 99, 2, 25, "Input"],
Cell[98315, 4061, 148, 4, 61, "Input"],
Cell[98466, 4067, 249, 5, 79, "Input"],
Cell[98718, 4074, 272, 5, 97, "Input"],
Cell[98993, 4081, 263, 7, 97, "Input"],
Cell[99259, 4090, 205, 5, 61, "Input"],
Cell[99467, 4097, 86, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[99602, 4105, 122, 3, 33, "Section",
  PageBreakAbove->True],
Cell[99727, 4110, 456, 16, 73, "Text"],

Cell[CellGroupData[{
Cell[100208, 4130, 101, 2, 47, "Subsection"],
Cell[100312, 4134, 406, 13, 72, "Text"],

Cell[CellGroupData[{
Cell[100743, 4151, 246, 8, 24, "SmallText"],
Cell[100992, 4161, 140, 4, 65, "Input"],
Cell[101135, 4167, 307, 5, 169, "Input"],
Cell[101445, 4174, 275, 5, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101757, 4184, 119, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[101901, 4190, 71, 2, 25, "Input"],
Cell[101975, 4194, 132, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[102168, 4203, 89, 2, 31, "Subsection"],
Cell[102260, 4207, 441, 14, 73, "Text"],

Cell[CellGroupData[{
Cell[102726, 4225, 3861, 149, 331, "Special3"],
Cell[106590, 4376, 156, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[106783, 4385, 1250, 42, 163, "Special3"],
Cell[108036, 4429, 205, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[108256, 4441, 283, 9, 53, "Text"],
Cell[108542, 4452, 222, 8, 26, "Special1"],
Cell[108767, 4462, 226, 8, 26, "Special1"],
Cell[108996, 4472, 233, 8, 26, "Special1"],

Cell[CellGroupData[{
Cell[109254, 4484, 135, 3, 24, "SmallText"],
Cell[109392, 4489, 316, 8, 105, "Input"]
}, Open  ]],
Cell[109723, 4500, 427, 13, 72, "Text"],

Cell[CellGroupData[{
Cell[110175, 4517, 131, 3, 24, "SmallText"],
Cell[110309, 4522, 81, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[110427, 4529, 188, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[110640, 4541, 98, 2, 25, "Input"],
Cell[110741, 4545, 485, 10, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[111253, 4559, 275, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[111553, 4572, 140, 3, 24, "SmallText"],
Cell[111696, 4577, 201, 6, 105, "Input"]
}, Open  ]],
Cell[111912, 4586, 732, 20, 110, "Text"],

Cell[CellGroupData[{
Cell[112669, 4610, 114, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[112808, 4616, 108, 2, 25, "Input"],
Cell[112919, 4620, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[113010, 4625, 447, 13, 72, "Text"],

Cell[CellGroupData[{
Cell[113482, 4642, 118, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[113625, 4648, 120, 3, 45, "Input"],
Cell[113748, 4653, 52, 1, 29, "Output"],
Cell[113803, 4656, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[113899, 4661, 364, 6, 90, "Text"],

Cell[CellGroupData[{
Cell[114288, 4671, 159, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[114472, 4679, 124, 3, 45, "Input"],
Cell[114599, 4684, 88, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[114714, 4689, 182, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[114921, 4697, 118, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[115064, 4703, 107, 2, 25, "Input"],
Cell[115174, 4707, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[115265, 4712, 201, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[115491, 4720, 144, 4, 24, "SmallText"],
Cell[115638, 4726, 97, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[115772, 4733, 117, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[115914, 4739, 141, 3, 45, "Input"],
Cell[116058, 4744, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[116188, 4752, 86, 2, 31, "Subsection"],
Cell[116277, 4756, 552, 18, 73, "Text"],

Cell[CellGroupData[{
Cell[116854, 4778, 1999, 74, 193, "Special3"],
Cell[118856, 4854, 132, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[119025, 4862, 1474, 55, 193, "Special3"],
Cell[120502, 4919, 202, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[120719, 4931, 871, 25, 130, "Text"],

Cell[CellGroupData[{
Cell[121615, 4960, 124, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[121764, 4966, 129, 3, 45, "Input"],
Cell[121896, 4971, 66, 1, 29, "Output"],
Cell[121965, 4974, 73, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[122065, 4979, 307, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[122397, 4989, 157, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[122579, 4997, 124, 3, 45, "Input"],
Cell[122706, 5002, 100, 2, 29, "Output"],
Cell[122809, 5006, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[122918, 5011, 470, 14, 72, "Text"],

Cell[CellGroupData[{
Cell[123413, 5029, 122, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[123560, 5035, 94, 2, 25, "Input"],
Cell[123657, 5039, 43, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[123727, 5044, 398, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[124150, 5058, 191, 8, 24, "SmallText"],
Cell[124344, 5068, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[124474, 5077, 122, 3, 33, "Section",
  PageBreakAbove->True],
Cell[124599, 5082, 672, 22, 92, "Text"],

Cell[CellGroupData[{
Cell[125296, 5108, 104, 2, 47, "Subsection"],
Cell[125403, 5112, 525, 17, 73, "Text"],

Cell[CellGroupData[{
Cell[125953, 5133, 885, 33, 72, "Special3"],
Cell[126841, 5168, 152, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[127008, 5174, 1620, 60, 192, "Text"],

Cell[CellGroupData[{
Cell[128653, 5238, 91, 2, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[128769, 5244, 188, 8, 24, "SmallText"],
Cell[128960, 5254, 84, 2, 25, "Input"]
}, Open  ]],
Cell[129059, 5259, 557, 18, 74, "Text"],

Cell[CellGroupData[{
Cell[129641, 5281, 198, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[129864, 5293, 128, 4, 65, "Input"],
Cell[129995, 5299, 237, 4, 107, "Input"],
Cell[130235, 5305, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[130356, 5311, 504, 14, 89, "Text"],

Cell[CellGroupData[{
Cell[130885, 5329, 1569, 61, 135, "Special3"],
Cell[132457, 5392, 147, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[132619, 5398, 305, 11, 53, "Text"],

Cell[CellGroupData[{
Cell[132949, 5413, 91, 2, 43, "Subsubsection"],
Cell[133043, 5417, 396, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[133464, 5431, 197, 8, 24, "SmallText"],
Cell[133664, 5441, 104, 3, 45, "Input"],

Cell[CellGroupData[{
Cell[133793, 5448, 225, 4, 105, "Input"],
Cell[134021, 5454, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[134176, 5463, 101, 2, 31, "Subsection"],
Cell[134280, 5467, 723, 17, 167, "Text"],

Cell[CellGroupData[{
Cell[135028, 5488, 115, 2, 24, "SmallText"],
Cell[135146, 5492, 26286, 985, 200, 6568, 736, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161469, 6482, 94, 2, 43, "Subsubsection"],
Cell[161566, 6486, 334, 6, 71, "Text"],
Cell[161903, 6494, 257, 9, 43, "Special1"],
Cell[162163, 6505, 295, 9, 43, "Special1"],
Cell[162461, 6516, 297, 9, 43, "Special1"],
Cell[162761, 6527, 258, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[163044, 6540, 135, 3, 24, "SmallText"],
Cell[163182, 6545, 130, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163349, 6554, 126, 2, 24, "SmallText"],
Cell[163478, 6558, 419, 9, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163934, 6572, 131, 3, 24, "SmallText"],
Cell[164068, 6577, 87, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[164204, 6585, 89, 2, 29, "Subsubsection"],
Cell[164296, 6589, 559, 15, 93, "Text"],
Cell[164858, 6606, 351, 12, 43, "Special1"],
Cell[165212, 6620, 335, 11, 43, "Special2"],

Cell[CellGroupData[{
Cell[165572, 6635, 117, 2, 24, "SmallText"],
Cell[165692, 6639, 162, 3, 58, "Input"]
}, Open  ]],
Cell[165869, 6645, 674, 27, 74, "Text"],
Cell[166546, 6674, 208, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[166779, 6686, 286, 6, 105, "Input"],
Cell[167068, 6694, 82, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167187, 6700, 121, 2, 24, "SmallText"],
Cell[167311, 6704, 74, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[167434, 6712, 101, 2, 29, "Subsubsection"],
Cell[167538, 6716, 542, 20, 73, "Text"],

Cell[CellGroupData[{
Cell[168105, 6740, 187, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[168317, 6752, 98, 2, 25, "Input"],
Cell[168418, 6756, 637, 13, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[169104, 6775, 200, 8, 24, "SmallText"],
Cell[169307, 6785, 26188, 983, 200, 6568, 736, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[195510, 7771, 289, 9, 53, "Text"],
Cell[195802, 7782, 111, 2, 24, "SmallText"],
Cell[195916, 7786, 126, 3, 25, "Input"],
Cell[196045, 7791, 214, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[196284, 7803, 135, 3, 25, "Input"],
Cell[196422, 7808, 67, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[196526, 7814, 154, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[196705, 7822, 236, 5, 45, "Input"],
Cell[196944, 7829, 13887, 439, 181, 4451, 316, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[210858, 8272, 720, 23, 93, "Text"],

Cell[CellGroupData[{
Cell[211603, 8299, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[211755, 8305, 140, 3, 25, "Input"],
Cell[211898, 8310, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[212011, 8317, 137, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[212173, 8324, 232, 5, 45, "Input"],
Cell[212408, 8331, 14738, 423, 181, 4156, 286, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[227173, 8758, 441, 17, 72, "Text"],

Cell[CellGroupData[{
Cell[227639, 8779, 256, 10, 24, "SmallText"],

Cell[CellGroupData[{
Cell[227920, 8793, 417, 10, 85, "Input"],
Cell[228340, 8805, 17655, 563, 181, 6053, 414, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[246044, 9374, 191, 8, 24, "SmallText"],
Cell[246238, 9384, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[246368, 9393, 91, 2, 31, "Subsection"],
Cell[246462, 9397, 103, 2, 43, "Subsubsection"],
Cell[246568, 9401, 99, 2, 25, "Input"],
Cell[246670, 9405, 273, 6, 97, "Input"],
Cell[246946, 9413, 205, 4, 97, "Input"],
Cell[247154, 9419, 234, 5, 97, "Input"],
Cell[247391, 9426, 172, 6, 61, "Input"],
Cell[247566, 9434, 85, 2, 25, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

