(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    526053,      21108]*)
(*NotebookOutlinePosition[    526994,      21140]*)
(*  CellTagsIndexPosition[    526950,      21136]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["10.  Underconstrained Systems", "Title"],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter covers ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions, which are used to synthesize the dynamic motion of \
underconstrained mechanical systems. ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses an adaptive multistep integration algorithm to integrate the \
equations of motion built by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and returns the dynamic motion profile of the model in the form of \
standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " interpolating functions. ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are also used to find the equilibrium configuration of underconstrained \
models that are subject to conservative static loading, or the equilibrium \
velocity of underconstrained models subject to velocity-dependent loading.\n\n\
The ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions are used to find the motion trajectories of models with one or \
more nonholonomic constraints. All ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " models must first be defined as fully constrained systems with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " before they can be modified with ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["10.1  Equilibrium Configuration"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section describes the use of the ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions to find the equilibrium configuration of an underconstrained \
mechanism subject to static forces. A planar model of a pendulum sliding on a \
massless rope is used to demonstrate the use of ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The pendulum-on-a-rope model in the following example consists of two planar \
bodies, a slider that moves without friction along an infinitely flexible, \
inextensible, massless rope, and a pendulum that hangs below the slider and \
is attached to the ground by a spring. Before an equilibrium analysis can be \
done, the model must have a full set of kinematic constraints so that it can \
be assembled and each body can be moved to a reasonable position to use as an \
initial guess for the equilibrium analysis. Some of these kinematic \
constraints are then dropped to make the model underconstrained. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and turns off the general spelling warnings. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(Off[General::"\<spell1\>"]\), 
    \(Off[General::"\<spell\>"]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Bodies"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Three body objects are defined for the pendulum model. Note that the zeroth \
point, which is defined to be {0,0} by default, is used in each body."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The ground (body 1) requires three point definitions. \nP0 is the origin of \
the ground body and the attachment point of the left end of the rope.\nP1 is \
the attachment point of the right end of the rope.\nP2 is the attachment \
point of a spring that is used to pull the pendulum to one side."], "Special1",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The slider (body 2) requires three point definitions.\nP0 is the origin of \
the slider and the point where the pendulum is attached.\nP1 is the point \
where the rope exits the left side of the slider.\nP2 is the point where the \
rope exits the right side of the slider."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The pendulum (body 3) requires two point definitions.\nP0 is the origin of \
the pendulum and its center of mass.\nP1 is the point where the pendulum is \
attached to the slider."], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Names are defined for each of the body numbers."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(slider = 2; \)\), 
    \(\(pendulum = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the three body objects, including inertia properties."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\tBody[ground, PointList \[Rule] {{4, 0}, {5, \(-3\)}}], \n
      \tBody[slider, PointList \[Rule] {{\(-0.5\), 0.3}, {0.5, 0.3}}, 
        InitialGuess \[Rule] {{2.0, \(-1.5\)}, 0}, Mass \[Rule] 1.0, 
        Centroid \[Rule] {0, 0.2}], \n\t
      Body[pendulum, PointList \[Rule] {{0, 1.8}}, 
        InitialGuess \[Rule] {{2.0, \(-3.0\)}, 0}, Mass \[Rule] 2.0]]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraints"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Seven constraints are used to model the pendulum-on-a-rope."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is used to model the left side of the rope. Since only the \
total length of the rope is known, the distance from the left end of the \
slider to the attachment point of the rope on the ground is simply \
constrained to be the unknown ",
  StyleBox["s",
    FontSlant->"Italic"],
  ". The symbol ",
  StyleBox["s",
    FontSlant->"Italic"],
  " is then added to the model as a dependent variable with the ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Another ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint models the right side of the rope. The length of the right \
side of the rope is simply the total length of the rope minus the length of \
the slider and the length of the left side, 5 - 1 - ",
  StyleBox["s",
    FontSlant->"Italic"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is used only to introduce the variable ",
  StyleBox["s",
    FontSlant->"Italic"],
  ", and its initial guess, into the model as a dependent variable. The ",
  StyleBox["Constraint",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no constraint equation, so it constrains zero degrees of freedom, but \
it does add one degree of freedom to the model by introducing ",
  StyleBox["s",
    FontSlant->"Italic"],
  "."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint attaches the pendulum to the slider."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RelativeX1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint initially controls the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the slider. This constraint is dropped for the equilibrium \
analysis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint initially controls the rotation of the slider. This constraint \
is dropped for the equilibrium analysis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint initially controls the rotation of the pendulum. This \
constraint is dropped for the equilibrium analysis."
}], "Special1",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the seven constraint objects for the pendulum-on-a-rope model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      RelativeDistance1[1, \n\t\tPoint[ground, 0], Point[slider, 1], s], \n\t
      RelativeDistance1[2, \n\t\tPoint[ground, 1], Point[slider, 2], 4 - s], 
      \n\tConstraint[3, {}, {s, 2.5}], \n\t
      Revolute2[4, Point[slider, 0], Point[pendulum, 1]], \n\t
      RelativeX1[5, Point[slider, 0], 2], \n\tRotationLock1[6, slider, 0], \n
      \tRotationLock1[7, pendulum, 0]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Run Time"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Because there is no occurrence of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the model, the model can be run with the ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command with no time argument. Since there are no other symbolic \
parameters, the model can only achieve one configuration, the one specified \
by the constraints."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
      \(X2 \[Rule] 2.`\), ",", \(Y2 \[Rule] \(-1.62287565554484185`\)\), ",", 
        \(Th2 \[Rule] 0.`\), ",", 
        RowBox[{"X3", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        \(Y3 \[Rule] \(-3.42287565554484185`\)\), ",", \(Th3 \[Rule] 0.`\), 
        ",", \(s \[Rule] 2.`\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the pendulum-on-a-rope model in its initial configuration."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[(1)] .2 0 0 2 Msboxa
[(2)] .4 0 0 2 Msboxa
[(3)] .6 0 0 2 Msboxa
[(4)] .8 0 0 2 Msboxa
[(5)] 1 0 0 2 Msboxa
[(-4)] -0.0125 0 1 0 Msboxa
[(-3.5)] -0.0125 .1 1 0 Msboxa
[(-3)] -0.0125 .2 1 0 Msboxa
[(-2.5)] -0.0125 .3 1 0 Msboxa
[(-2)] -0.0125 .4 1 0 Msboxa
[(-1.5)] -0.0125 .5 1 0 Msboxa
[(-1)] -0.0125 .6 1 0 Msboxa
[(-0.5)] -0.0125 .7 1 0 Msboxa
[(0)] -0.0125 .8 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(1)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(2)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(3)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(4)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(5)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-4)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .1 m
.00625 .1 L
s
P
[(-3.5)] -0.0125 .1 1 0 Mshowa
p
.002 w
0 .2 m
.00625 .2 L
s
P
[(-3)] -0.0125 .2 1 0 Mshowa
p
.002 w
0 .3 m
.00625 .3 L
s
P
[(-2.5)] -0.0125 .3 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(-2)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(-1.5)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .6 m
.00625 .6 L
s
P
[(-1)] -0.0125 .6 1 0 Mshowa
p
.002 w
0 .7 m
.00625 .7 L
s
P
[(-0.5)] -0.0125 .7 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(0)] -0.0125 .8 1 0 Mshowa
p
.001 w
0 .02 m
.00375 .02 L
s
P
p
.001 w
0 .04 m
.00375 .04 L
s
P
p
.001 w
0 .06 m
.00375 .06 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .12 m
.00375 .12 L
s
P
p
.001 w
0 .14 m
.00375 .14 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18 m
.00375 .18 L
s
P
p
.001 w
0 .22 m
.00375 .22 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .26 m
.00375 .26 L
s
P
p
.001 w
0 .28 m
.00375 .28 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34 m
.00375 .34 L
s
P
p
.001 w
0 .36 m
.00375 .36 L
s
P
p
.001 w
0 .38 m
.00375 .38 L
s
P
p
.001 w
0 .42 m
.00375 .42 L
s
P
p
.001 w
0 .44 m
.00375 .44 L
s
P
p
.001 w
0 .46 m
.00375 .46 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .52 m
.00375 .52 L
s
P
p
.001 w
0 .54 m
.00375 .54 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58 m
.00375 .58 L
s
P
p
.001 w
0 .62 m
.00375 .62 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .66 m
.00375 .66 L
s
P
p
.001 w
0 .68 m
.00375 .68 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74 m
.00375 .74 L
s
P
p
.001 w
0 .76 m
.00375 .76 L
s
P
p
.001 w
0 .78 m
.00375 .78 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .79375 m
0 .8 L
s
P
p
.002 w
.2 .79375 m
.2 .8 L
s
P
p
.002 w
.4 .79375 m
.4 .8 L
s
P
p
.002 w
.6 .79375 m
.6 .8 L
s
P
p
.002 w
.8 .79375 m
.8 .8 L
s
P
p
.001 w
.04 .79625 m
.04 .8 L
s
P
p
.001 w
.08 .79625 m
.08 .8 L
s
P
p
.001 w
.12 .79625 m
.12 .8 L
s
P
p
.001 w
.16 .79625 m
.16 .8 L
s
P
p
.001 w
.24 .79625 m
.24 .8 L
s
P
p
.001 w
.28 .79625 m
.28 .8 L
s
P
p
.001 w
.32 .79625 m
.32 .8 L
s
P
p
.001 w
.36 .79625 m
.36 .8 L
s
P
p
.001 w
.44 .79625 m
.44 .8 L
s
P
p
.001 w
.48 .79625 m
.48 .8 L
s
P
p
.001 w
.52 .79625 m
.52 .8 L
s
P
p
.001 w
.56 .79625 m
.56 .8 L
s
P
p
.001 w
.64 .79625 m
.64 .8 L
s
P
p
.001 w
.68 .79625 m
.68 .8 L
s
P
p
.001 w
.72 .79625 m
.72 .8 L
s
P
p
.001 w
.76 .79625 m
.76 .8 L
s
P
p
.001 w
.84 .79625 m
.84 .8 L
s
P
p
.001 w
.88 .79625 m
.88 .8 L
s
P
p
.001 w
.92 .79625 m
.92 .8 L
s
P
p
.001 w
.96 .79625 m
.96 .8 L
s
P
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .1 m
1 .1 L
s
P
p
.002 w
.99375 .2 m
1 .2 L
s
P
p
.002 w
.99375 .3 m
1 .3 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .6 m
1 .6 L
s
P
p
.002 w
.99375 .7 m
1 .7 L
s
P
p
.001 w
.99625 .02 m
1 .02 L
s
P
p
.001 w
.99625 .04 m
1 .04 L
s
P
p
.001 w
.99625 .06 m
1 .06 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .12 m
1 .12 L
s
P
p
.001 w
.99625 .14 m
1 .14 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18 m
1 .18 L
s
P
p
.001 w
.99625 .22 m
1 .22 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .26 m
1 .26 L
s
P
p
.001 w
.99625 .28 m
1 .28 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34 m
1 .34 L
s
P
p
.001 w
.99625 .36 m
1 .36 L
s
P
p
.001 w
.99625 .38 m
1 .38 L
s
P
p
.001 w
.99625 .42 m
1 .42 L
s
P
p
.001 w
.99625 .44 m
1 .44 L
s
P
p
.001 w
.99625 .46 m
1 .46 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .52 m
1 .52 L
s
P
p
.001 w
.99625 .54 m
1 .54 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58 m
1 .58 L
s
P
p
.001 w
.99625 .62 m
1 .62 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .66 m
1 .66 L
s
P
p
.001 w
.99625 .68 m
1 .68 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74 m
1 .74 L
s
P
p
.001 w
.99625 .76 m
1 .76 L
s
P
p
.001 w
.99625 .78 m
1 .78 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.3 .53542 L
.5 .53542 L
.8 .8 L
s
P
p
0 .7 0 r
p
.4 .47542 m
.3 .51542 L
.3 .55542 L
.5 .55542 L
.5 .51542 L
F
P
P
p
0 0 .7 r
p
.03 w
.4 .11542 m
.4 .47542 L
s
P
.03 w
.4 .11542 m
.4 .11542 .06 0 360 arc
F
P
p
.04 w
.4 .47542 Mdot
0 .8 Mdot
.8 .8 Mdot
P
p
.012 w
.4 .11542 m
1 .2 L
s
.97594 .16804 m
1 .2 L
.96804 .22406 L
s
P
p
.012 w
.2 .4 m
.2 .2 L
s
.17172 .22828 m
.2 .2 L
.22828 .22828 L
s
P
p
/Times-Bold findfont 14 scalefont setfont
[(F)] .92 .22 0 0 Mshowa
P
p
/Times-Bold findfont 14 scalefont setfont
[(G)] .24 .3 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{330, 263},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005:00011a000`40O003h00OogooBgoo003oOom;
Ool00?mood]oo`00ogooBgoo001COol5000gOol3000iOol2000jOol3000iOol00`00Oomoo`04Ool0
05Eoo`03001oogoo03Moo`03001oogoo03]oo`03001oogoo03Qoo`03001oogoo03Moo`03001oo`00
00Eoo`00EGoo00<007ooOol0>7oo00<007ooOol0>Goo00<007ooOol0=goo1000>Woo00<007ooOol0
0goo001EOol00`00Oomoo`0hOol00`00Oomoo`0jOol00`00Oomoo`0fOol00`00Ool0000iOol20006
Ool005Eoo`03001oogoo03Moo`03001oo`0003Uoo`03001oo`0003Uoo`8003Uoo`03001oogoo00Eo
o`00E7oo0P00>Woo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0=goo0`001Goo003oOom;
Ool00?mood]oo`00ogooBgoo003oOom;Ool00?mood]oo`00ogooBgoo000COol3003oOoleOol001Ao
o`03001oogoo0?moocAoo`003Goo0`000Woo100017ooo`00:`001Woo000BOol00`00Ool00005Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool0
0`00Oomoo`04Ool001=oo`8000Eoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Aoo`0057oo00<007ooOol00goo00<007ooOol0
ogoo9goo00<007ooOol017oo000JOol00`00Oomoo`3oOolWOol00`00Oomoo`04Ool001Yoo`03001o
ogoo0?moobMoo`03001oogoo00Aoo`006Woo0P00ogoo9goo0P001Woo000JOol00`00Oomoo`3oOolW
Ool00`00Oomoo`04Ool001Yoo`03001oogoo0?moobMoo`03001oogoo00Aoo`006Woo00<007ooOol0
ogoo9goo00<007ooOol017oo000JOol00`00Oomoo`3oOolWOol00`00Oomoo`04Ool001Yoo`03001o
ogoo0?moobMoo`03001oogoo00Aoo`006Woo0P00ogoo9goo0P001Woo000JOol00`00Oomoo`3oOolW
Ool00`00Oomoo`04Ool001Yoo`03001oogoo0?moobMoo`03001oogoo00Aoo`006Woo00<007ooOol0
ogoo9goo00<007ooOol017oo000JOol00`00Oomoo`3oOolWOol00`00Oomoo`04Ool001Yoo`03001o
ogoo0?moobMoo`03001oogoo00Aoo`006Woo0P00L7oo2P0F[7oo0P001Woo000JOol00`00Oomoo`1[
OolA01JZOol00`00Oomoo`04Ool001Yoo`03001oogoo06Yooa@05ZQoo`03001oogoo00Aoo`006Woo
00<007ooOol0JGoo5P0FYgoo00<007ooOol017oo000JOol00`00Oomoo`1WOolI01JVOol00`00Oomo
o`04Ool001Yoo`03001oogoo06MooaX05ZEoo`03001oogoo00Aoo`006Woo0P00Igoo700FXgoo0P00
1Woo000JOol00`00Oomoo`1UOolN01JSOol00`00Oomoo`04Ool001Yoo`03001oogoo06Aoob005Z9o
o`03001oogoo00Aoo`006Woo00<007ooOol0I7oo800FXWoo00<007ooOol017oo0008Ool20004Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1SOolQ01JROol00`00Oomoo`04Ool000Yoo`03
001oogoo00Eoo`03001oo`0000Eoo`03001oogoo06=oob805Z5oo`03001oogoo00Aoo`000goo0`00
0goo00<007ooOol027oo00<007ooOol00goo0`00Hgoo8P0FX7oo0P001Woo000:Ool00`00Oomoo`05
Ool20006Ool00`00Oomoo`1ROolS01JQOol00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001o
ogoo00Eoo`03001oogoo069oob@05Z1oo`03001oogoo00Aoo`002Goo00<007ooOol01Woo0`001Goo
00<007ooOol0HWoo900FX7oo00<007ooOol017oo000JOol00`00Oomoo`1ROolA01H5000>01JPOol0
0`00Oomoo`04Ool001Yoo`03001oogoo069ooa405P`000L05Z1oo`03001oogoo00Aoo`006Woo0P00
Hgoo4@0F4`00Wgoo0P001Woo000JOol00`00Oomoo`1ROolF01HE002IOol00`00Oomoo`04Ool001Yo
o`03001oogoo069ooad05QD0099oo`03001oogoo00Aoo`006Woo00<007ooOol0Hgoo8P0F00=oo`00
00005000RWoo00<007ooOol017oo000JOol00`00Oomoo`1SOolR01H8OolF0023Ool00`00Oomoo`04
Ool001Yoo`03001oogoo06=oob805PmooaH007aoo`03001oogoo00Aoo`006Woo0P00I7oo8@0F67oo
5@00M7oo0P001Woo000JOol00`00Oomoo`1TOolP01HOOolE001^Ool00`00Oomoo`04Ool001Yoo`03
001oogoo06Eooal05RIooaD006Moo`03001oogoo00Aoo`006Woo00<007ooOol0IGoo7P0F;Woo5@00
H7oo00<007ooOol017oo000JOol00`00Oomoo`1VOolL01HfOolE001IOol00`00Oomoo`04Ool001Yo
o`03001oogoo06MooaT05SmooaH0055oo`03001oogoo00Aoo`006Woo0P00JGoo600FAWoo5P00BGoo
0P001Woo000JOol00`00Oomoo`1YOolF01I>OolF000kOol30005Ool00`00Oomoo`04Ool001Yoo`03
001oogoo06Yooa@05UMooaD003Aoo`<000Eoo`03001oogoo00Aoo`006Woo00<007ooOol0Jgoo4@0F
H7oo5@00;Goo100017oo00<007ooOol017oo000JOol00`00Oomoo`1_Ool:01IZOolE000WOol40003
Ool00`00Oomoo`04Ool001Yoo`03001oogoo071oo`P05W9ooaD0025oo`<000=oo`03001oogoo00Ao
o`006Woo0P00LGoo200FNGoo5P006Goo100000=oo`0000001Woo000JOol00`00Oomoo`1`Ool801J0
OolF000COol400000goo001oo`05Ool001Yoo`03001oogoo071oo`P05XMooaH000eoo`D000Ioo`00
6Woo00<007ooOol0L7oo200FSgoo5@001goo10001Woo000BOol20006Ool00`00Oomoo`0hOol00`00
Oomoo`0eOol801JFOolI0006Ool001Aoo`03001oogoo00=oo`03001oogoo03Moo`<003Ioo`P05Yeo
oa<000Eoo`003Goo0`000goo00<007ooOol017oo0`00=Woo1@00=Goo200FY7oo30001Goo000DOol0
0`00Oomoo`03Ool00`00Oomoo`0eOol7000dOol801JCOol4000DOol50005Ool0019oo`03001oo`00
00Eoo`03001oogoo03Aoo`T003=oo`P05YAoo`8001=oo`H000Ioo`004goo00<007ooOol017oo00<0
07ooOol0<goo2`00<Woo200FU7oo0P004Woo1@0000=oo`00Ool01Goo000JOol00`00Oomoo`0bOol4
00001Goo00000000Ool01000<Goo200FU7oo0P004Goo1@000Woo00<007ooOol017oo000JOol00`00
Oomoo`0aOol40002Ool30002Ool4000`Ool801JDOol20002Ool00`00Oomoo`0;Ool40004Ool00`00
Oomoo`04Ool001Yoo`80035oo`@000=oo`<000=oo`@002moo`P05YAoo`D000]oo`D000Aoo`8000Io
o`006Woo00<007ooOol0;goo100017oo0`0017oo1000;Woo200FU7oo0P000Woo00<007ooOol02Goo
10001Woo00<007ooOol017oo000JOol00`00Oomoo`0^Ool40005Ool30005Ool5000/Ool801JDOol2
000>Ool30007Ool00`00Oomoo`04Ool001Yoo`03001oogoo02moo`8000Ioo`<000Ioo`<002eoo`P0
5YAoo`8000Aoo`03001oogoo015oo`03001oogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F
Tgoo20004goo00<007ooOol017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04
Ool001Yoo`8003Qoo`<003Ioo`P05Zeoo`8000Ioo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo
00<007ooOol017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`03
001oogoo03Moo`<003Ioo`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F
[Woo00<007ooOol017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yo
o`8003Qoo`<003Ioo`P05Zeoo`8000Ioo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007oo
Ool017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`03001oogoo
03Moo`<003Ioo`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<0
07ooOol017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`8003Qo
o`<003Ioo`P05Zeoo`8000Ioo`006Woo00<007ooOol0=goo0`0027oo1@00:Goo200F[Woo00<007oo
Ool017oo000JOol00`00Oomoo`0gOol30007Ool20003Ool2000XOol801J^Ool00`00Oomoo`04Ool0
01Yoo`03001oogoo03Moo`<000Ioo`8000Aoo`8002Qoo`P05Zioo`03001oogoo00Aoo`0027oo0`00
0goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0=goo0`001Woo0P000goo10009goo200F
[Woo00<007ooOol017oo0008Ool00`00Oomoo`07Ool00`00Ool00005Ool00`00Oomoo`0gOol30006
Ool2000^Ool801J^Ool00`00Oomoo`04Ool000=oo`<000=oo`03001oogoo00Qoo`03001oogoo00=o
o`<003Moo`<000Ioo`8002ioo`P05Zeoo`8000Ioo`002Goo00<007ooOol01Woo0P001Woo00<007oo
Ool0=goo0`001Woo0P00;Woo200F[Woo00<007ooOol017oo0008Ool00`00Ool00007Ool00`00Oomo
o`05Ool00`00Oomoo`0gOol30006Ool20005Ool00`00Oomoo`0VOol801J^Ool00`00Oomoo`04Ool0
00Uoo`03001oogoo00Ioo`<000Eoo`03001oogoo03Moo`<000Moo`8000=oo`8002Qoo`P05Zioo`03
001oogoo00Aoo`006Woo00<007ooOol0=goo0`0027oo100000=oo`00Ool09goo200F[Woo00<007oo
Ool017oo000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`8003Qoo`<0
03Ioo`P05Zeoo`8000Ioo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000J
Ool00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`03001oogoo03Moo`<003Io
o`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo
000JOol00`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`8003Qoo`<003Ioo`P0
5Zeoo`8000Ioo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000JOol00`00
Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`03001oogoo03Moo`<003Ioo`P05Zio
o`03001oogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000JOol0
0`00Oomoo`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`8003Qoo`<003Ioo`P05Zeoo`80
00Ioo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000JOol00`00Oomoo`0g
Ool3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`03001oogoo03Moo`<003Ioo`P05Zioo`03001o
ogoo00Aoo`006Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000JOol00`00Oomo
o`0gOol3000fOol801J^Ool00`00Oomoo`04Ool001Yoo`8003Qoo`<003Ioo`P05Zeoo`8000Ioo`00
6Woo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo000JOol00`00Oomoo`0gOol3000f
Ool801J^Ool00`00Oomoo`04Ool0019oo`<000Eoo`03001oogoo03Moo`<003Ioo`P05Zioo`03001o
ogoo00Aoo`004Woo00<007ooOol01Goo00<007ooOol0=goo0`00=Woo200F[Woo00<007ooOol017oo
000=Ool30003Ool00`00Oomoo`04Ool3000gOol3000fOol801J]Ool20006Ool001=oo`03001oogoo
00Aoo`03001oogoo03Moo`<003Ioo`P05Zioo`03001oogoo00Aoo`004Woo00<007oo00001Goo00<0
07ooOol0L7oo200F[Woo00<007ooOol017oo000COol00`00Oomoo`04Ool00`00Oomoo`1`Ool801J^
Ool00`00Oomoo`04Ool001Yoo`03001oogoo071oo`P05Zioo`03001oogoo00Aoo`006Woo00<007oo
Ool0L7oo200F[Woo00<007ooOol017oo000JOol2001aOol801J]Ool20006Ool001Yoo`03001oogoo
071oo`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0L7oo200F[Woo00<007ooOol017oo000J
Ool00`00Oomoo`1`Ool801J^Ool00`00Oomoo`04Ool001Yoo`03001oogoo071oo`P05Zioo`03001o
ogoo00Aoo`006Woo00<007ooOol0L7oo200F[Woo00<007ooOol017oo000JOol2001aOol801J]Ool2
0006Ool001Yoo`03001oogoo071oo`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0L7oo200F
[Woo00<007ooOol017oo000JOol00`00Oomoo`1`Ool801J^Ool00`00Oomoo`04Ool001Yoo`03001o
ogoo071oo`P05Zioo`03001oogoo00Aoo`006Woo00<007ooOol0L7oo200F[Woo00<007ooOol017oo
000JOol2001aOol801J]Ool20006Ool001Yoo`03001oogoo071oo`805P8000@05Zioo`03001oogoo
00Aoo`006Woo00<007ooOol0L7oo1P000P0F[Woo00<007ooOol017oo000JOol00`00Oomoo`1_Ool8
00000`0FOomoo`2/Ool00`00Oomoo`04Ool001Yoo`03001oogoo06moo`P0000301Ioogoo0:aoo`03
001oogoo00Aoo`006Woo00<007ooOol0KWoo2P00[Woo00<007ooOol017oo000JOol2001_Ool:002]
Ool20006Ool001Yoo`03001oogoo06moo`P0000301H2`7oo0:aoo`03001oogoo00Aoo`006Woo00<0
07ooOol0KGoo0P;0200000<05P;00/000P;0ZWoo00<007ooOol017oo000JOol00`00Oomoo`1ZOol6
0/06000201H60/2XOol00`00Oomoo`04Ool000Moo`D0009oo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo06Qoo`X2`08000d2`:Eoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007oo
00001Goo00<007ooOol0IGoo7P;0Xgoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool3001SOolS0/2OOol20006Ool000Uoo`03001oogoo00Ioo`8000Ioo`03001oogoo
061oobP2`9ioo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol0
GWoo;@;0Vgoo00<007ooOol017oo0008Ool20008Ool30005Ool00`00Oomoo`1KOolb0/2IOol00`00
Oomoo`04Ool001Yoo`03001oogoo05UoocL2`9Ioo`03001oogoo00Aoo`006Woo00<007ooOol0EWoo
?0;0U7oo00<007ooOol017oo000JOol2001GOoll0/2COol20006Ool001Yoo`03001oogoo05Iooc`2
`9Aoo`03001oogoo00Aoo`006Woo00<007ooOol0EWoo?0;0U7oo00<007ooOol017oo000JOol00`00
Oomoo`1FOoll0/2DOol00`00Oomoo`04Ool001Yoo`03001oogoo05Iooc`2`003F01oogoo095oo`03
001oogoo00Aoo`006Woo00<007ooOol0EGoo00=H00;00/00>P;00UP0TWoo00<007ooOol017oo000J
Ool2001EOol2F00l0/03F02@Ool20006Ool001Yoo`03001oogoo05=oo`=H03`2`004OomH05P0F02@
Ool00`00Oomoo`04Ool001Yoo`03001oogoo055oo`AH0003Ool2`0;003X2`09oo`AH08ioo`03001o
ogoo00Aoo`006Woo00<007ooOol0D7oo15P00Woo?0;00goo15P0SGoo00<007ooOol017oo000JOol0
0`00Oomoo`1?Ool3F004Ooll0/05Ool3F02<Ool00`00Oomoo`04Ool001Yoo`03001oogoo04ioo`=H
00Eooc`2`0Ioo`=H08]oo`03001oogoo00Aoo`006Woo0P00CWoo0eP0BGoo0eP0RGoo0P001Woo000J
Ool00`00Oomoo`1<Ool3F01;Ool3F029Ool00`00Oomoo`04Ool001Yoo`03001oogoo04]oo`=H04eo
o`=H08Qoo`03001oogoo00Aoo`006Woo00<007ooOol0BGoo15P0Cgoo15P0QWoo00<007ooOol017oo
000JOol00`00Oomoo`18Ool4F01AOol4F025Ool00`00Oomoo`04Ool001Yoo`03001oogoo04Moo`=H
05Eoo`=H08Aoo`03001oogoo00Aoo`006Woo0P00Agoo0eP0Egoo0eP0PWoo0P001Woo000JOol00`00
Oomoo`15Ool3F01IOol3F022Ool00`00Oomoo`04Ool001Yoo`03001oogoo04Aoo`=H05]oo`=H085o
o`03001oogoo00Aoo`006Woo00<007ooOol0@goo0eP0GGoo0eP0P7oo00<007ooOol017oo000AOol5
0004Ool00`00Oomoo`11Ool4F01OOol4F01nOol00`00Oomoo`04Ool001=oo`03001oogoo00Aoo`03
001oogoo041oo`AH065oo`AH07eoo`03001oogoo00Aoo`003Goo0`000goo00<007ooOol017oo0`00
?goo0eP0IGoo0eP0Ngoo0P001Woo000COol00`00Oomoo`04Ool00`00Oomoo`0nOol3F01WOol3F01k
Ool00`00Oomoo`04Ool001=oo`03001oogoo00Aoo`03001oogoo03eoo`=H06Uoo`=H07Yoo`03001o
ogoo00Aoo`004Woo0P001Woo00<007ooOol0?7oo0eP0Jgoo0eP0NGoo00<007ooOol017oo000JOol0
0`00Oomoo`0kOol3F01]Ool3F01hOol00`00Oomoo`04Ool001Yoo`03001oogoo03Uoo`AH06moo`AH
07Ioo`03001oogoo00Aoo`006Woo0P00>Goo15P0LGoo15P0M7oo0P001Woo000JOol00`00Oomoo`0g
Ool3F01eOol3F01dOol00`00Oomoo`04Ool001Yoo`03001oogoo03Ioo`=H07Moo`=H07=oo`03001o
ogoo00Aoo`006Woo00<007ooOol0=Goo0eP0NGoo0eP0LWoo00<007ooOol017oo000JOol00`00Oomo
o`0dOol3F01kOol3F01aOol00`00Oomoo`04Ool001Yoo`03001oogoo03=oo`=H07eoo`=H071oo`03
001oogoo00Aoo`006Woo0P00<Woo15P0Ogoo15P0KGoo0P001Woo000JOol00`00Oomoo`0`Ool4F021
Ool4F01]Ool00`00Oomoo`04Ool001Yoo`03001oogoo02moo`=H08Eoo`=H06aoo`03001oogoo00Ao
o`006Woo00<007ooOol0;Woo0eP0Qgoo0eP0Jgoo00<007ooOol017oo000JOol00`00Oomoo`0]Ool3
F029Ool3F01ZOol00`00Oomoo`04Ool001Yoo`03001oogoo02aoo`=H08]oo`=H06Uoo`03001oogoo
00Aoo`006Woo0P00;7oo0eP0SGoo0eP0Igoo0P001Woo000JOol00`00Oomoo`0YOol4F02?Ool3F01W
Ool00`00Oomoo`04Ool001Yoo`03001oogoo02Qoo`AH095oo`AH06Eoo`03001oogoo00Aoo`006Woo
00<007ooOol09goo0eP0U7oo15P0I7oo00<007ooOol017oo000JOol00`00Oomoo`0VOol3F02GOol3
F01SOol00`00Oomoo`04Ool001Yoo`03001oogoo02Eoo`=H09Uoo`=H069oo`03001oogoo00Aoo`00
6Woo0P009Goo0eP0Vgoo0eP0H7oo0P001Woo000JOol00`00Oomoo`0SOol3F02MOol3F01POol00`00
Oomoo`04Ool001Yoo`03001oogoo029oo`=H09moo`=H05moo`03001oogoo00Aoo`006Woo00<007oo
Ool087oo15P0XGoo15P0GGoo00<007ooOol017oo0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`0OOol4F02SOol4F01LOol00`00Oomoo`04Ool000Qoo`03001oo`00
00Moo`03001oo`0000Eoo`03001oogoo01ioo`=H0:Moo`=H05]oo`03001oogoo00Aoo`000goo0`00
0Woo00<007oo00002Goo00<007ooOol00goo0`007Goo0eP0ZGoo0eP0FGoo0P001Woo0008Ool00`00
Ool00007Ool20006Ool00`00Oomoo`0LOol3F02[Ool3F01IOol00`00Oomoo`04Ool000Qoo`03001o
o`0000Moo`03001oogoo00Eoo`03001oogoo01]oo`=H0:eoo`=H05Qoo`03001oogoo00Aoo`002Goo
00<007ooOol01Woo0`001Goo00<007ooOol06Woo0eP0[goo0eP0Egoo00<007ooOol017oo000JOol0
0`00Oomoo`0HOol4F02aOol4F01EOol00`00Oomoo`04Ool001Yoo`03001oogoo01Moo`AH0;=oo`AH
05Aoo`03001oogoo00Aoo`006Woo0P005goo0eP0]goo0eP0DWoo0P001Woo000JOol00`00Oomoo`0E
Ool3F02iOol3F01BOol00`00Oomoo`04Ool001Yoo`03001oogoo01Aoo`=H0;]oo`=H055oo`03001o
ogoo00Aoo`006Woo00<007ooOol04goo0eP0_Goo0eP0D7oo00<007ooOol017oo000JOol00`00Oomo
o`0BOol3F02oOol3F01?Ool00`00Oomoo`04Ool001Yoo`03001oogoo011oo`AH0<5oo`AH04eoo`03
001oogoo00Aoo`006Woo0P0047oo15P0`goo15P0Bgoo0P001Woo000JOol00`00Oomoo`0>Ool3F037
Ool3F01;Ool00`00Oomoo`04Ool001Yoo`03001oogoo00eoo`=H0<Uoo`=H04Yoo`03001oogoo00Ao
o`006Woo00<007ooOol037oo0eP0bgoo0eP0BGoo00<007ooOol017oo000JOol00`00Oomoo`0;Ool3
F03=Ool3F018Ool00`00Oomoo`04Ool001Yoo`03001oogoo00Yoo`=H0<moo`=H04Moo`03001oogoo
00Aoo`006Woo0P002Goo15P0dGoo15P0A7oo0P001Woo000JOol00`00Oomoo`07Ool4F03COol4F014
Ool00`00Oomoo`04Ool001Yoo`03001oogoo00Ioo`=H0=Moo`=H04=oo`03001oogoo00Aoo`006Woo
00<007ooOol01Goo0eP0fGoo0eP0@Woo00<007ooOol017oo000JOol00`00Oomoo`04Ool3F03KOol3
F011Ool00`00Oomoo`04Ool001Yoo`03001oogoo00=oo`=H0=eoo`=H041oo`03001oogoo00Aoo`00
6Woo0P000goo0eP0ggoo0eP0?Woo0P001Woo000JOol00`00Oomoo`04F03QOol4F00mOol00`00Oomo
o`04Ool001Qoo`<00003OomH05P0009H0>=oo`=H008003]oo`03001oogoo00Aoo`004goo00<007oo
Ool01P000UP0iWoo1P00>Goo00<007ooOol017oo000BOol00`00Ool000080009Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`04Ool80009Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`04Ool0019oo`03001oo`000?l0
030000Ioo`004Woo00<007oo00002@00i7oo2P00?Woo000BOol00`00Ool00009003TOol:000nOol0
01=oo`03001oo`0000L00>Ioo`P003moo`005Goo2000iWoo2000?goo000FOol6003XOol60010Ool0
01Qoo`800>aoo`80049oo`00\
\>"],
  ImageRangeCache->{{{0, 329}, {262, 0}} -> {-0.443044, -4.30254, 0.0168069, 
  0.0168069}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Forces"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A model must have some nonzero loads applied to it in order to have a unique \
equilibrium position. The pendulum-on-a-rope model has three forces applied \
to it: a spring force applied to the pendulum, and gravity applied to the \
pendulum and the slider."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the loads applied to the pendulum and slider."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[\n\t
      Force[pendulum, Line[pendulum, 0, ground, 2], 
        10\ \((Magnitude[pendulum, 0, ground, 2] - 1)\)], \n\t
      Gravity[{0, \(-1\)}, 9.81]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the reaction to constraint 7 that prevents the pendulum from \
rotating. The constraint applies a clockwise moment to the pendulum to \
constrain it against the force of the spring."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[7, pendulum] /. SolveMech[Solution \[Rule] Static]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, \(-36.1762023601391291`\)}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Finding Equilibrium"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the equilibrium configuration of a mechanism, a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that contains a new set of equations of motion with one \
or more constraints removed from the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dropcon",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the mathematical equations required to find equilibrium position \
of the current model, and returns them in a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint number(s) to be dropped to \
make the model underconstrained.\n\n",
  StyleBox["SolveFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solves a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object and returns a list of rules representing the location and \
generalized forces at the equilibrium position. "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Finding equilibrium configuration."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The pendulum-on-a-rope model has three constraints that are present only to \
complete the kinematic model, constraints 5, 6, and 7. Each of these \
constraints is dropped, one at a time, and the equilibrium position is found \
with each new degree of freedom. The first constraint to be dropped is \
constraint 7, which locks the rotation of the pendulum relative to the \
slider. This allows the pendulum to rotate, but the slider stays locked at \
the center of the rope."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["This drops constraint 7."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(fsys = SetFree[7]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(FreeSystem[Static, "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveFree[fsys] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 2.`, Y2 \[Rule] \(-1.62287565553229544`\), 
      Th2 \[Rule] 0, X3 \[Rule] 2.90923081526037243`, 
      Y3 \[Rule] \(-3.17635540266558802`\), 
      Th3 \[Rule] 0.529530538357320956`, s \[Rule] 2.`, 
      Lmb1 \[Rule] 5.38730840361439522`, Lmb2 \[Rule] 5.38730840361439522`, 
      Lmb3 \[Rule] \(-10.9430773549849646`\), 
      Lmb4 \[Rule] 18.6969565439441431`, Lmb5 \[Rule] 10.9430773549849646`, 
      Lmb6 \[Rule] 0, Lmb7 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the pendulum model with constraint 7 dropped."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[(1)] .2 0 0 2 Msboxa
[(2)] .4 0 0 2 Msboxa
[(3)] .6 0 0 2 Msboxa
[(4)] .8 0 0 2 Msboxa
[(5)] 1 0 0 2 Msboxa
[(-4)] -0.0125 0 1 0 Msboxa
[(-3.5)] -0.0125 .1 1 0 Msboxa
[(-3)] -0.0125 .2 1 0 Msboxa
[(-2.5)] -0.0125 .3 1 0 Msboxa
[(-2)] -0.0125 .4 1 0 Msboxa
[(-1.5)] -0.0125 .5 1 0 Msboxa
[(-1)] -0.0125 .6 1 0 Msboxa
[(-0.5)] -0.0125 .7 1 0 Msboxa
[(0)] -0.0125 .8 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(1)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(2)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(3)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(4)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(5)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-4)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .1 m
.00625 .1 L
s
P
[(-3.5)] -0.0125 .1 1 0 Mshowa
p
.002 w
0 .2 m
.00625 .2 L
s
P
[(-3)] -0.0125 .2 1 0 Mshowa
p
.002 w
0 .3 m
.00625 .3 L
s
P
[(-2.5)] -0.0125 .3 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(-2)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(-1.5)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .6 m
.00625 .6 L
s
P
[(-1)] -0.0125 .6 1 0 Mshowa
p
.002 w
0 .7 m
.00625 .7 L
s
P
[(-0.5)] -0.0125 .7 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(0)] -0.0125 .8 1 0 Mshowa
p
.001 w
0 .02 m
.00375 .02 L
s
P
p
.001 w
0 .04 m
.00375 .04 L
s
P
p
.001 w
0 .06 m
.00375 .06 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .12 m
.00375 .12 L
s
P
p
.001 w
0 .14 m
.00375 .14 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18 m
.00375 .18 L
s
P
p
.001 w
0 .22 m
.00375 .22 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .26 m
.00375 .26 L
s
P
p
.001 w
0 .28 m
.00375 .28 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34 m
.00375 .34 L
s
P
p
.001 w
0 .36 m
.00375 .36 L
s
P
p
.001 w
0 .38 m
.00375 .38 L
s
P
p
.001 w
0 .42 m
.00375 .42 L
s
P
p
.001 w
0 .44 m
.00375 .44 L
s
P
p
.001 w
0 .46 m
.00375 .46 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .52 m
.00375 .52 L
s
P
p
.001 w
0 .54 m
.00375 .54 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58 m
.00375 .58 L
s
P
p
.001 w
0 .62 m
.00375 .62 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .66 m
.00375 .66 L
s
P
p
.001 w
0 .68 m
.00375 .68 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74 m
.00375 .74 L
s
P
p
.001 w
0 .76 m
.00375 .76 L
s
P
p
.001 w
0 .78 m
.00375 .78 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .79375 m
0 .8 L
s
P
p
.002 w
.2 .79375 m
.2 .8 L
s
P
p
.002 w
.4 .79375 m
.4 .8 L
s
P
p
.002 w
.6 .79375 m
.6 .8 L
s
P
p
.002 w
.8 .79375 m
.8 .8 L
s
P
p
.001 w
.04 .79625 m
.04 .8 L
s
P
p
.001 w
.08 .79625 m
.08 .8 L
s
P
p
.001 w
.12 .79625 m
.12 .8 L
s
P
p
.001 w
.16 .79625 m
.16 .8 L
s
P
p
.001 w
.24 .79625 m
.24 .8 L
s
P
p
.001 w
.28 .79625 m
.28 .8 L
s
P
p
.001 w
.32 .79625 m
.32 .8 L
s
P
p
.001 w
.36 .79625 m
.36 .8 L
s
P
p
.001 w
.44 .79625 m
.44 .8 L
s
P
p
.001 w
.48 .79625 m
.48 .8 L
s
P
p
.001 w
.52 .79625 m
.52 .8 L
s
P
p
.001 w
.56 .79625 m
.56 .8 L
s
P
p
.001 w
.64 .79625 m
.64 .8 L
s
P
p
.001 w
.68 .79625 m
.68 .8 L
s
P
p
.001 w
.72 .79625 m
.72 .8 L
s
P
p
.001 w
.76 .79625 m
.76 .8 L
s
P
p
.001 w
.84 .79625 m
.84 .8 L
s
P
p
.001 w
.88 .79625 m
.88 .8 L
s
P
p
.001 w
.92 .79625 m
.92 .8 L
s
P
p
.001 w
.96 .79625 m
.96 .8 L
s
P
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .1 m
1 .1 L
s
P
p
.002 w
.99375 .2 m
1 .2 L
s
P
p
.002 w
.99375 .3 m
1 .3 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .6 m
1 .6 L
s
P
p
.002 w
.99375 .7 m
1 .7 L
s
P
p
.001 w
.99625 .02 m
1 .02 L
s
P
p
.001 w
.99625 .04 m
1 .04 L
s
P
p
.001 w
.99625 .06 m
1 .06 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .12 m
1 .12 L
s
P
p
.001 w
.99625 .14 m
1 .14 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18 m
1 .18 L
s
P
p
.001 w
.99625 .22 m
1 .22 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .26 m
1 .26 L
s
P
p
.001 w
.99625 .28 m
1 .28 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34 m
1 .34 L
s
P
p
.001 w
.99625 .36 m
1 .36 L
s
P
p
.001 w
.99625 .38 m
1 .38 L
s
P
p
.001 w
.99625 .42 m
1 .42 L
s
P
p
.001 w
.99625 .44 m
1 .44 L
s
P
p
.001 w
.99625 .46 m
1 .46 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .52 m
1 .52 L
s
P
p
.001 w
.99625 .54 m
1 .54 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58 m
1 .58 L
s
P
p
.001 w
.99625 .62 m
1 .62 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .66 m
1 .66 L
s
P
p
.001 w
.99625 .68 m
1 .68 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74 m
1 .74 L
s
P
p
.001 w
.99625 .76 m
1 .76 L
s
P
p
.001 w
.99625 .78 m
1 .78 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.3 .53542 L
.5 .53542 L
.8 .8 L
s
P
p
0 .7 0 r
p
.4 .47542 m
.3 .51542 L
.3 .55542 L
.5 .55542 L
.5 .51542 L
F
P
P
p
0 0 .7 r
p
.03 w
.58185 .16473 m
.4 .47542 L
s
P
.03 w
.58185 .16473 m
.58185 .16473 .06 30.3399 390.34 arc
F
P
p
.04 w
.4 .47542 Mdot
0 .8 Mdot
.8 .8 Mdot
P
p
.012 w
.58185 .16473 m
1 .2 L
s
.97419 .16944 m
1 .2 L
.96944 .22581 L
s
P
p
.012 w
.2 .4 m
.2 .2 L
s
.17172 .22828 m
.2 .2 L
.22828 .22828 L
s
P
p
/Times-Bold findfont 14 scalefont setfont
[(F)] .92 .22 0 0 Mshowa
P
p
/Times-Bold findfont 14 scalefont setfont
[(G)] .24 .3 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 225},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000hA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0019Ool5000^Ool3000_Ool2000aOol3000_Ool00`00Oomoo`04Ool0
04]oo`03001oogoo02ioo`03001oogoo035oo`03001oogoo02moo`03001oogoo02eoo`03001oo`00
00Eoo`00Bgoo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;Woo1000<7oo00<007ooOol0
0goo001;Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool0000_Ool20006
Ool004]oo`03001oogoo02ioo`03001oo`0002moo`03001oo`00031oo`8002moo`03001oogoo00Eo
o`00BWoo0P00<Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0;Goo0`001Goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000COol3003oOol5Ool001Ao
o`03001oogoo0?moo`Aoo`003Goo0`000Woo10000goon`001Woo000BOol00`00Ool00004Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool001=oo`8000Aoo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001o
ogoo02moo`03001oogoo02moo`03001oogoo00Aoo`0057oo00<007ooOol00Woo00<007ooOol0mgoo
00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`00
6Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uo
o`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol2
003gOol20006Ool001Uoo`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<0
07ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03001oogoo0?Moo`03001o
ogoo00Aoo`006Goo0P00mgoo0P001Woo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03
001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00
Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`006Goo00<007ooOol0mgoo00<007oo
Ool017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool000Qoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo0?Moo`03001oogoo00Aoo`002Woo00<007ooOol01Goo00<007oo0000
17oo00<007ooOol0mgoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool3003fOol20006Ool000Yoo`03001oogoo00Eoo`8000Eoo`03001oogoo0?Moo`03001oogoo00Ao
o`0027oo00<007oo00001goo00<007ooOol017oo00<007ooOol0mgoo00<007ooOol017oo0009Ool0
0`00Oomoo`06Ool30004Ool00`00Oomoo`28Ool<01ISOol00`00Oomoo`04Ool001Uoo`03001oogoo
08Moo`l05V5oo`03001oogoo00Aoo`006Goo0P00Qgoo4`0FGGoo0P001Woo000IOol00`00Oomoo`25
OolE01IMOol00`00Oomoo`04Ool001Uoo`03001oogoo08AooaL05Uaoo`03001oogoo00Aoo`006Goo
00<007ooOol0Pgoo600FG7oo00<007ooOol017oo000IOol00`00Oomoo`22OolJ01IKOol00`00Oomo
o`04Ool001Uoo`8008=ooaX05UYoo`8000Ioo`006Goo00<007ooOol0PWoo6`0FFWoo00<007ooOol0
17oo000IOol00`00Oomoo`21OolL01IJOol00`00Oomoo`04Ool001Uoo`03001oogoo085ooa`05UYo
o`03001oogoo00Aoo`006Goo00<007ooOol0PGoo7@0FFGoo00<007ooOol017oo000IOol20021OolN
01IHOol20006Ool001Uoo`03001oogoo081oo`h05PP000P05U=oo`03001oogoo00=oo`03001oogoo
00Aoo`006Goo00<007ooOol0P7oo3P0F5@00CGoo0P001Goo00<007ooOol017oo000IOol00`00Oomo
o`20Ool>01HR0010Ool30004Ool00`00Oomoo`04Ool001Uoo`03001oogoo081ooaH05RL003=oo`@0
00=oo`03001oogoo00Aoo`006Goo0P00PGoo7P0F1Goo9`009goo100000=oo`0000001Woo000IOol0
0`00Oomoo`21OolM01HBOolW000KOol400000goo001oo`05Ool001Uoo`03001oogoo085ooa`05R1o
obL000moo`D000Ioo`004Woo0P001Goo00<007ooOol0;goo00<007ooOol0Cgoo700F;Goo9`000goo
10001Woo000DOol00`00Oomoo`02Ool00`00Oomoo`0^Ool3001AOolJ01HkOolR0005Ool000eoo`<0
00=oo`03001oogoo00=oo`<002ioo`<0059ooaT05TQooaD000Eoo`0057oo00<007ooOol00Woo00<0
07ooOol0;Goo1@00DGoo600FA7oo10003Woo20001Goo000BOol00`00Ool00004Ool00`00Oomoo`0/
Ool7001AOolF01I6Ool2000AOol50006Ool001=oo`03001oogoo00=oo`03001oogoo02]oo`T0055o
oa@05TMoo`80011oo`@00003Ool007oo00Eoo`006Goo00<007ooOol0:Woo2`00Cgoo500FB7oo0P00
3goo10000Woo00<007ooOol017oo000IOol2000ZOol400001Goo00000000Ool01000CWoo4@0FBgoo
0P000Woo00<007ooOol02Goo10000Woo0P001Woo000IOol00`00Oomoo`0XOol40002Ool30002Ool4
001<Ool@01I=Ool5000:Ool40004Ool00`00Oomoo`04Ool001Uoo`03001oogoo02Moo`@000=oo`<0
00=oo`@004]oo`L05P=oo`<05U1oo`80009oo`03001oogoo00Moo`@000Eoo`03001oogoo00Aoo`00
6Goo00<007ooOol09goo0`0017oo0`0017oo0`00BWoo200FEWoo0P003Goo0P001Woo00<007ooOol0
17oo000IOol00`00Oomoo`0WOol20005Ool30005Ool20019Ool801IGOol20004Ool00`00Oomoo`0>
Ool00`00Oomoo`04Ool001Uoo`8002Uoo`03001oogoo00=oo`<000Eoo`03001oogoo04Qoo`P05UIo
o`P000moo`8000Ioo`006Goo00<007ooOol0;Woo0`00Cgoo200FKgoo00<007ooOol017oo000IOol0
0`00Oomoo`0^Ool3001?Ool701I`Ool00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<004ioo`P0
5W1oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00CGoo200FLGoo00<007ooOol017oo000I
Ool2000_Ool3001=Ool801I`Ool20006Ool001Uoo`03001oogoo02ioo`<004aoo`P05W9oo`03001o
ogoo00Aoo`006Goo00<007ooOol0;Woo0`00C7oo1`0FLgoo00<007ooOol017oo000IOol00`00Oomo
o`0^Ool3001;Ool801IcOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<004Yoo`P05WAoo`03
001oogoo00Aoo`006Goo0P00;goo0`00BWoo200FLgoo0P001Woo000IOol00`00Oomoo`0^Ool30006
Ool5000nOol801IeOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<000Eoo`8000=oo`8003eo
o`L05WIoo`03001oogoo00Aoo`0027oo0`000goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool0;Woo0`0017oo0P0017oo0P00?7oo200FMWoo00<007ooOol017oo0008Ool00`00Oomoo`07Ool0
0`00Ool00004Ool00`00Oomoo`0^Ool30004Ool20003Ool4000jOol801IgOol00`00Oomoo`04Ool0
00=oo`<000=oo`03001oogoo00Qoo`03001oogoo009oo`<002ioo`<000Aoo`80045oo`P05WIoo`80
00Ioo`002Goo00<007ooOol01Woo0P001Goo00<007ooOol0;Woo0`0017oo0P00@7oo200FN7oo00<0
07ooOol017oo0008Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool30004Ool20010
Ool701IiOol00`00Oomoo`04Ool000Uoo`03001oogoo00Ioo`<000Aoo`03001oogoo02ioo`<000Ao
o`8000Eoo`03001oogoo03Moo`P05WUoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`001Goo
0P000goo0P00>7oo200FNWoo00<007ooOol017oo000IOol2000_Ool30006Ool400000goo001oo`0g
Ool801IiOol20006Ool001Uoo`03001oogoo02ioo`<004=oo`P05W]oo`03001oogoo00Aoo`006Goo
00<007ooOol0;Woo0`00@goo1`0FO7oo00<007ooOol017oo000IOol00`00Oomoo`0^Ool30012Ool8
01IlOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<0049oo`L05Weoo`03001oogoo00Aoo`00
6Goo0P00;goo0`00@Goo200FO7oo0P001Woo000IOol00`00Oomoo`0^Ool30010Ool801InOol00`00
Oomoo`04Ool001Uoo`03001oogoo02ioo`<0041oo`P05Wioo`03001oogoo00Aoo`006Goo00<007oo
Ool0;Woo0`00?goo200FOgoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3000oOol701J0Ool0
0`00Oomoo`04Ool001Uoo`8002moo`<003ioo`P05Wmoo`8000Ioo`006Goo00<007ooOol0;Woo0`00
?Goo200FPGoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3000mOol801J1Ool00`00Oomoo`04
Ool001Uoo`03001oogoo02ioo`<003aoo`P05X9oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo
0`00?7oo1`0FPgoo00<007ooOol017oo000IOol2000_Ool3000kOol801J2Ool20006Ool001Uoo`03
001oogoo02ioo`<003Yoo`P05XAoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00>Woo200F
Q7oo00<007ooOol017oo000BOol30004Ool00`00Oomoo`0^Ool3000iOol801J5Ool00`00Oomoo`04
Ool0019oo`03001oogoo00Aoo`03001oogoo02ioo`<003Uoo`L05XIoo`03001oogoo00Aoo`003Goo
0`000goo00<007ooOol00goo0`00;Woo0`00>7oo200FQGoo0P001Woo000COol00`00Oomoo`03Ool0
0`00Oomoo`0^Ool3000gOol801J7Ool00`00Oomoo`04Ool0019oo`03001oo`0000Aoo`03001oogoo
06Qoo`P05XMoo`03001oogoo00Aoo`004goo00<007ooOol00goo00<007ooOol0Igoo200FR7oo00<0
07ooOol017oo000IOol00`00Oomoo`1WOol701J9Ool00`00Oomoo`04Ool001Uoo`8006Moo`P05XQo
o`8000Ioo`006Goo00<007ooOol0IGoo200FRWoo00<007ooOol017oo000IOol00`00Oomoo`1UOol8
01J:Ool00`00Oomoo`04Ool001Uoo`03001oogoo06Aoo`P05X]oo`03001oogoo00Aoo`006Goo00<0
07ooOol0I7oo1`0FS7oo00<007ooOol017oo000IOol2001TOol801J;Ool20006Ool001Uoo`03001o
ogoo069oo`P05Xeoo`03001oogoo00Aoo`006Goo00<007ooOol0HWoo200FSGoo00<007ooOol017oo
000IOol00`00Oomoo`1QOol801J>Ool00`00Oomoo`04Ool001Uoo`03001oogoo065oo`L05Xmoo`03
001oogoo00Aoo`006Goo0P00HGoo200FSWoo0P001Woo000IOol00`00Oomoo`1OOol201H00`0001H0
5P0301J@Ool00`00Oomoo`04Ool001Uoo`03001oogoo05ioo`H000<05Y1oo`03001oogoo00Aoo`00
6Goo00<007ooOol0GWoo1`0000<05WooOol0Sgoo00<007ooOol017oo000IOol00`00Oomoo`1NOol7
002BOol00`00Oomoo`04Ool001Uoo`8005ioo`T0091oo`8000Ioo`006Goo00<007ooOol0G7oo0P;0
1`0000<2`7ooOol0Sgoo00<007ooOol017oo000IOol00`00Oomoo`1JOol40/0700040/2>Ool00`00
Oomoo`04Ool000Moo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo05Moo`L2`0H0
00L2`8aoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007oo000017oo00<007ooOol0EGoo
30;000<000;00/002P;0RGoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomo
o`02Ool3001BOolN0/26Ool20006Ool000Uoo`03001oogoo00Ioo`8000Eoo`03001oogoo051oob<2
`8Aoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0CGoo:0;0
PWoo00<007ooOol017oo0008Ool20008Ool30004Ool00`00Oomoo`1;Ool]0/1oOol00`00Oomoo`04
Ool001Uoo`03001oogoo04Qooc82`7eoo`03001oogoo00Aoo`006Goo0P00BGoo<P;0O7oo0P001Woo
000IOol00`00Oomoo`18Oolb0/1mOol00`00Oomoo`04Ool001Uoo`03001oogoo04Qooc82`7eoo`03
001oogoo00Aoo`006Goo00<007ooOol0B7oo<P;000=H07ooOol0NWoo00<007ooOol017oo000IOol0
0`00Oomoo`17Ool00eP00/02`00`0/02F01kOol00`00Oomoo`04Ool001Uoo`8004Moo`9H0382`0=H
07Uoo`8000Ioo`006Goo00<007ooOol0AGoo0eP0<P;000AooeP0F01H07Uoo`03001oogoo00Aoo`00
6Goo00<007ooOol0@goo15P000=oo`;00/00<0;00Woo15P0Mgoo00<007ooOol017oo000IOol00`00
Oomoo`12Ool4F002Oolb0/03Ool4F01fOol00`00Oomoo`04Ool001Uoo`03001oogoo045oo`=H00Ao
oc82`0Eoo`=H07Eoo`03001oogoo00Aoo`006Goo0P00@Goo0eP0?Goo0eP0Lgoo0P001Woo000IOol0
0`00Oomoo`0oOol3F00oOol3F01cOol00`00Oomoo`04Ool001Uoo`03001oogoo03ioo`=H045oo`=H
079oo`03001oogoo00Aoo`006Goo00<007ooOol0?Goo0eP0@goo0eP0LGoo00<007ooOol017oo000I
Ool00`00Oomoo`0kOol4F015Ool4F01_Ool00`00Oomoo`04Ool001Uoo`8003]oo`AH04Moo`AH06eo
o`8000Ioo`006Goo00<007ooOol0>Goo0eP0Bgoo0eP0KGoo00<007ooOol017oo000IOol00`00Oomo
o`0hOol3F01=Ool3F01/Ool00`00Oomoo`04Ool0015oo`D000=oo`03001oogoo03Moo`=H04moo`=H
06]oo`03001oogoo00Aoo`004goo00<007ooOol00goo00<007ooOol0=Woo0eP0DGoo0eP0JWoo00<0
07ooOol017oo000=Ool30003Ool00`00Oomoo`03Ool3000eOol3F01COol3F01XOol20006Ool001=o
o`03001oogoo00=oo`03001oogoo03Aoo`=H05Eoo`=H06Qoo`03001oogoo00Aoo`004goo00<007oo
Ool00goo00<007ooOol0<Woo15P0Egoo15P0IWoo00<007ooOol017oo000BOol20005Ool00`00Oomo
o`0aOol4F01IOol4F01UOol00`00Oomoo`04Ool001Uoo`03001oogoo031oo`=H05eoo`=H06Aoo`03
001oogoo00Aoo`006Goo0P00<7oo0eP0Ggoo0eP0HWoo0P001Woo000IOol00`00Oomoo`0^Ool3F01Q
Ool3F01ROol00`00Oomoo`04Ool001Uoo`03001oogoo02eoo`=H06=oo`=H065oo`03001oogoo00Ao
o`006Goo00<007ooOol0;7oo0eP0IGoo0eP0H7oo00<007ooOol017oo000IOol00`00Oomoo`0ZOol4
F01WOol4F01NOol00`00Oomoo`04Ool001Uoo`8002Yoo`AH06Uoo`AH05aoo`8000Ioo`006Goo00<0
07ooOol0:7oo0eP0KGoo0eP0G7oo00<007ooOol017oo000IOol00`00Oomoo`0WOol3F01_Ool3F01K
Ool00`00Oomoo`04Ool001Uoo`03001oogoo02Ioo`=H075oo`=H05Yoo`03001oogoo00Aoo`006Goo
00<007ooOol09Goo0eP0Lgoo0eP0FGoo00<007ooOol017oo000IOol2000UOol3F01eOol3F01GOol2
0006Ool001Uoo`03001oogoo029oo`AH07Moo`=H05Moo`03001oogoo00Aoo`006Goo00<007ooOol0
8Goo15P0NGoo15P0EGoo00<007ooOol017oo000IOol00`00Oomoo`0POol3F01lOol4F01DOol00`00
Oomoo`04Ool001Uoo`03001oogoo01moo`=H07moo`=H05=oo`03001oogoo00Aoo`006Goo0P007goo
0eP0PGoo0eP0DGoo0P001Woo000IOol00`00Oomoo`0MOol3F023Ool3F01AOol00`00Oomoo`04Ool0
01Uoo`03001oogoo01aoo`=H08Eoo`=H051oo`03001oogoo00Aoo`002Goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol06goo0eP0Qgoo0eP0Cgoo00<007ooOol017oo0008
Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`0IOol4F029Ool4F01=Ool00`00Oomoo`04
Ool000=oo`<0009oo`03001oo`0000Uoo`03001oogoo009oo`<001Qoo`AH08]oo`AH04]oo`8000Io
o`0027oo00<007oo00001goo0P001Goo00<007ooOol05goo0eP0Sgoo0eP0Bgoo00<007ooOol017oo
0008Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0FOol3F02AOol3F01:Ool00`00Oomo
o`04Ool000Uoo`03001oogoo00Ioo`<000Aoo`03001oogoo01Eoo`=H09=oo`=H04Uoo`03001oogoo
00Aoo`006Goo00<007ooOol057oo0eP0UGoo0eP0B7oo00<007ooOol017oo000IOol2000DOol3F02G
Ool3F016Ool20006Ool001Uoo`03001oogoo015oo`AH09Uoo`AH04Eoo`03001oogoo00Aoo`006Goo
00<007ooOol047oo15P0Vgoo15P0A7oo00<007ooOol017oo000IOol00`00Oomoo`0?Ool3F02OOol3
F013Ool00`00Oomoo`04Ool001Uoo`03001oogoo00ioo`=H0:5oo`=H049oo`03001oogoo00Aoo`00
6Goo0P003Woo0eP0Xgoo0eP0@7oo0P001Woo000IOol00`00Oomoo`0<Ool3F02UOol3F010Ool00`00
Oomoo`04Ool001Uoo`03001oogoo00]oo`=H0:Moo`=H03moo`03001oogoo00Aoo`006Goo00<007oo
Ool02Woo0eP0ZGoo0eP0?Woo00<007ooOol017oo000IOol00`00Oomoo`08Ool4F02[Ool4F00lOol0
0`00Oomoo`04Ool001Uoo`8000Qoo`AH0:eoo`AH03Yoo`8000Ioo`006Goo00<007ooOol01Woo0eP0
/Goo0eP0>Woo00<007ooOol017oo000IOol00`00Oomoo`05Ool3F02cOol3F00iOol00`00Oomoo`04
Ool001Uoo`03001oogoo00Aoo`=H0;Eoo`=H03Qoo`03001oogoo00Aoo`006Goo00<007ooOol00goo
0eP0]goo0eP0=goo00<007ooOol017oo000IOol20003Ool3F02iOol3F00eOol20006Ool001Uoo`03
001oogoo00AH0;]oo`AH03Aoo`03001oogoo00Aoo`006Goo00<007ooF0000eP0_Goo15P000=oo`00
Ool0<7oo00<007ooOol017oo000COol00`00Oomoo`0600000eP0Oomoo`2oOol6000_Ool00`00Oomo
o`04Ool0019oo`04001oo`00Ool7000^Ool00`00Oomoo`0_Ool00`00Oomoo`0_Ool00`00Oomoo`0/
Ool7000^Ool00`00Oomoo`04Ool0019oo`04001oo`00Ooon0006Ool0019oo`03001oo`0000T00;mo
o`T003Aoo`004Woo00@007oo001oo`L00<5oo`L003Eoo`004goo00<007ooOol01`00`Goo1`00=Goo
000FOol60032Ool6000fOol001Uoo`03001oogoo0<Eoo`03001oogoo03Ioo`00ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {224, 0}} -> {-0.51628, -4.36002, 0.0200002, 
  0.0200002}}]
}, Open  ]],

Cell[TextData[{
  "Next, constraint 5 is dropped, allowing the slider to move along the rope. \
Finally, constraint 6 is dropped, allowing the slider to rotate. The ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to pass ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the solution to the last ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is named ",
  StyleBox["sol",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This solution is a better initial guess than the defaults pulled from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the initial guesses that are used by the equilibrium \
solution routine. The default, ",
  StyleBox["InitialGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", uses the default initial guesses obtained from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". When ",
  StyleBox["SolveFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["freesys",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run, the initial guesses contained within ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " are updated to the new solution, if ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " is a symbol that evaluates to a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is another ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with constraints 5 and 7 dropped."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fsys = SetFree[{5, 7}, InitialGuess \[Rule] sol]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. Note that ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has increased because the slider has moved to the right."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveFree[fsys] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 2.69023698178209835`, 
      Y2 \[Rule] \(-1.54159701500885493`\), Th2 \[Rule] 0, 
      X3 \[Rule] 3.31629039065630681`, Y3 \[Rule] \(-3.22921578986204549`\), 
      Th3 \[Rule] 0.355231530176678811`, s \[Rule] 2.51767773633657387`, 
      Lmb1 \[Rule] 4.25123624526832699`, Lmb2 \[Rule] 7.220591034075853`, 
      Lmb3 \[Rule] \(-6.92849450721756099`\), 
      Lmb4 \[Rule] 18.6767730134617693`, Lmb6 \[Rule] 5.7652903944509406`, 
      Lmb5 \[Rule] 0, Lmb7 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the equilibrium position with constraints 5 and 7 dropped."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[(1)] .2 0 0 2 Msboxa
[(2)] .4 0 0 2 Msboxa
[(3)] .6 0 0 2 Msboxa
[(4)] .8 0 0 2 Msboxa
[(5)] 1 0 0 2 Msboxa
[(-4)] -0.0125 0 1 0 Msboxa
[(-3.5)] -0.0125 .1 1 0 Msboxa
[(-3)] -0.0125 .2 1 0 Msboxa
[(-2.5)] -0.0125 .3 1 0 Msboxa
[(-2)] -0.0125 .4 1 0 Msboxa
[(-1.5)] -0.0125 .5 1 0 Msboxa
[(-1)] -0.0125 .6 1 0 Msboxa
[(-0.5)] -0.0125 .7 1 0 Msboxa
[(0)] -0.0125 .8 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(1)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(2)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(3)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(4)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(5)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-4)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .1 m
.00625 .1 L
s
P
[(-3.5)] -0.0125 .1 1 0 Mshowa
p
.002 w
0 .2 m
.00625 .2 L
s
P
[(-3)] -0.0125 .2 1 0 Mshowa
p
.002 w
0 .3 m
.00625 .3 L
s
P
[(-2.5)] -0.0125 .3 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(-2)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(-1.5)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .6 m
.00625 .6 L
s
P
[(-1)] -0.0125 .6 1 0 Mshowa
p
.002 w
0 .7 m
.00625 .7 L
s
P
[(-0.5)] -0.0125 .7 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(0)] -0.0125 .8 1 0 Mshowa
p
.001 w
0 .02 m
.00375 .02 L
s
P
p
.001 w
0 .04 m
.00375 .04 L
s
P
p
.001 w
0 .06 m
.00375 .06 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .12 m
.00375 .12 L
s
P
p
.001 w
0 .14 m
.00375 .14 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18 m
.00375 .18 L
s
P
p
.001 w
0 .22 m
.00375 .22 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .26 m
.00375 .26 L
s
P
p
.001 w
0 .28 m
.00375 .28 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34 m
.00375 .34 L
s
P
p
.001 w
0 .36 m
.00375 .36 L
s
P
p
.001 w
0 .38 m
.00375 .38 L
s
P
p
.001 w
0 .42 m
.00375 .42 L
s
P
p
.001 w
0 .44 m
.00375 .44 L
s
P
p
.001 w
0 .46 m
.00375 .46 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .52 m
.00375 .52 L
s
P
p
.001 w
0 .54 m
.00375 .54 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58 m
.00375 .58 L
s
P
p
.001 w
0 .62 m
.00375 .62 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .66 m
.00375 .66 L
s
P
p
.001 w
0 .68 m
.00375 .68 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74 m
.00375 .74 L
s
P
p
.001 w
0 .76 m
.00375 .76 L
s
P
p
.001 w
0 .78 m
.00375 .78 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .79375 m
0 .8 L
s
P
p
.002 w
.2 .79375 m
.2 .8 L
s
P
p
.002 w
.4 .79375 m
.4 .8 L
s
P
p
.002 w
.6 .79375 m
.6 .8 L
s
P
p
.002 w
.8 .79375 m
.8 .8 L
s
P
p
.001 w
.04 .79625 m
.04 .8 L
s
P
p
.001 w
.08 .79625 m
.08 .8 L
s
P
p
.001 w
.12 .79625 m
.12 .8 L
s
P
p
.001 w
.16 .79625 m
.16 .8 L
s
P
p
.001 w
.24 .79625 m
.24 .8 L
s
P
p
.001 w
.28 .79625 m
.28 .8 L
s
P
p
.001 w
.32 .79625 m
.32 .8 L
s
P
p
.001 w
.36 .79625 m
.36 .8 L
s
P
p
.001 w
.44 .79625 m
.44 .8 L
s
P
p
.001 w
.48 .79625 m
.48 .8 L
s
P
p
.001 w
.52 .79625 m
.52 .8 L
s
P
p
.001 w
.56 .79625 m
.56 .8 L
s
P
p
.001 w
.64 .79625 m
.64 .8 L
s
P
p
.001 w
.68 .79625 m
.68 .8 L
s
P
p
.001 w
.72 .79625 m
.72 .8 L
s
P
p
.001 w
.76 .79625 m
.76 .8 L
s
P
p
.001 w
.84 .79625 m
.84 .8 L
s
P
p
.001 w
.88 .79625 m
.88 .8 L
s
P
p
.001 w
.92 .79625 m
.92 .8 L
s
P
p
.001 w
.96 .79625 m
.96 .8 L
s
P
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .1 m
1 .1 L
s
P
p
.002 w
.99375 .2 m
1 .2 L
s
P
p
.002 w
.99375 .3 m
1 .3 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .6 m
1 .6 L
s
P
p
.002 w
.99375 .7 m
1 .7 L
s
P
p
.001 w
.99625 .02 m
1 .02 L
s
P
p
.001 w
.99625 .04 m
1 .04 L
s
P
p
.001 w
.99625 .06 m
1 .06 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .12 m
1 .12 L
s
P
p
.001 w
.99625 .14 m
1 .14 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18 m
1 .18 L
s
P
p
.001 w
.99625 .22 m
1 .22 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .26 m
1 .26 L
s
P
p
.001 w
.99625 .28 m
1 .28 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34 m
1 .34 L
s
P
p
.001 w
.99625 .36 m
1 .36 L
s
P
p
.001 w
.99625 .38 m
1 .38 L
s
P
p
.001 w
.99625 .42 m
1 .42 L
s
P
p
.001 w
.99625 .44 m
1 .44 L
s
P
p
.001 w
.99625 .46 m
1 .46 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .52 m
1 .52 L
s
P
p
.001 w
.99625 .54 m
1 .54 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58 m
1 .58 L
s
P
p
.001 w
.99625 .62 m
1 .62 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .66 m
1 .66 L
s
P
p
.001 w
.99625 .68 m
1 .68 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74 m
1 .74 L
s
P
p
.001 w
.99625 .76 m
1 .76 L
s
P
p
.001 w
.99625 .78 m
1 .78 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.43805 .55168 L
.63805 .55168 L
.8 .8 L
s
P
p
0 .7 0 r
p
.53805 .49168 m
.43805 .53168 L
.43805 .57168 L
.63805 .57168 L
.63805 .53168 L
F
P
P
p
0 0 .7 r
p
.03 w
.66326 .15416 m
.53805 .49168 L
s
P
.03 w
.66326 .15416 m
.66326 .15416 .06 20.3533 380.353 arc
F
P
p
.04 w
.53805 .49168 Mdot
0 .8 Mdot
.8 .8 Mdot
P
p
.012 w
.66326 .15416 m
1 .2 L
s
.97579 .16816 m
1 .2 L
.96816 .22421 L
s
P
p
.012 w
.2 .4 m
.2 .2 L
s
.17172 .22828 m
.2 .2 L
.22828 .22828 L
s
P
p
/Times-Bold findfont 14 scalefont setfont
[(F)] .92 .22 0 0 Mshowa
P
p
/Times-Bold findfont 14 scalefont setfont
[(G)] .24 .3 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 225},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000hA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0019Ool5000^Ool3000_Ool2000aOol3000_Ool00`00Oomoo`04Ool0
04]oo`03001oogoo02ioo`03001oogoo035oo`03001oogoo02moo`03001oogoo02eoo`03001oo`00
00Eoo`00Bgoo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;Woo1000<7oo00<007ooOol0
0goo001;Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool0000_Ool20006
Ool004]oo`03001oogoo02ioo`03001oo`0002moo`03001oo`00031oo`8002moo`03001oogoo00Eo
o`00BWoo0P00<Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0;Goo0`001Goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000COol3003oOol5Ool001Ao
o`03001oogoo0?moo`Aoo`003Goo0`000Woo10000goon`001Woo000BOol00`00Ool00004Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool001=oo`8000Aoo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001o
ogoo02moo`03001oogoo02moo`03001oogoo00Aoo`0057oo00<007ooOol00Woo00<007ooOol0mgoo
00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`00
6Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uo
o`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol2
003gOol20006Ool001Uoo`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<0
07ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03001oogoo0?Moo`03001o
ogoo00Aoo`006Goo0P00mgoo0P001Woo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03
001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00
Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`006Goo00<007ooOol0mgoo00<007oo
Ool017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool000Qoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo0?Moo`03001oogoo00Aoo`002Woo00<007ooOol01Goo00<007oo0000
17oo00<007ooOol0mgoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool3002MOol;01I>Ool20006Ool000Yoo`03001oogoo00Eoo`8000Eoo`03001oogoo09aoo`l05Tao
o`03001oogoo00Aoo`0027oo00<007oo00001goo00<007ooOol017oo00<007ooOol0VWoo4P0FBgoo
00<007ooOol017oo0009Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`2IOolD01I:Ool00`00Oomo
o`04Ool001Uoo`03001oogoo09QooaH05TUoo`03001oogoo00Aoo`006Goo0P00V7oo600FAgoo0P00
1Woo000IOol00`00Oomoo`2FOolJ01I7Ool00`00Oomoo`04Ool001Uoo`03001oogoo09Iooa/05TIo
o`03001oogoo00Aoo`006Goo00<007ooOol0UWoo6`0FAWoo00<007ooOol017oo000IOol00`00Oomo
o`2EOolM01I5Ool00`00Oomoo`04Ool001Uoo`8009Iooad05TAoo`8000Ioo`006Goo00<007ooOol0
UGoo7@0FAGoo00<007ooOol017oo000IOol00`00Oomoo`2DOolN01I5Ool00`00Oomoo`04Ool001Uo
o`03001oogoo09Aoo`h05PD000/05TEoo`03001oogoo00Aoo`006Goo00<007ooOol0U7oo3P0F3@00
0`0FAGoo00<007ooOol017oo000IOol2002EOol>01HE000oOol20006Ool001Uoo`03001oogoo09Eo
oa805QL003=oo`03001oogoo00=oo`03001oogoo00Aoo`006Goo00<007ooOol0UGoo6P0F5`00:Woo
0P001Goo00<007ooOol017oo000IOol00`00Oomoo`2EOolM01H5OolF000SOol30004Ool00`00Oomo
o`04Ool001Uoo`03001oogoo09Eooa`05PeooaL001]oo`@000=oo`03001oogoo00Aoo`006Goo0P00
UWoo700F5Goo5`0057oo100000=oo`0000001Woo000IOol00`00Oomoo`2FOolK01HLOolG000>Ool4
00000goo001oo`05Ool001Uoo`03001oogoo09MooaT05REooaL000Moo`D000Ioo`004Woo0P001Goo
00<007ooOol0;goo00<007ooOol0IGoo600F;Woo6`001Woo000DOol00`00Oomoo`02Ool00`00Oomo
o`0^Ool3001WOolF01HfOolE0005Ool000eoo`<000=oo`03001oogoo00=oo`<002ioo`<006Qooa@0
5Smoo`h000Aoo`0057oo00<007ooOol00Woo00<007ooOol0;Goo1@00J7oo4P0F<goo10004Goo1@00
1Goo000BOol00`00Ool00004Ool00`00Oomoo`0/Ool7001XOol@01HeOol2000AOol50006Ool001=o
o`03001oogoo00=oo`03001oogoo02]oo`T006Moo`h05SMoo`80011oo`@00003Ool007oo00Eoo`00
6Goo00<007ooOol0:Woo2`00IWoo300F>Goo0P003goo10000Woo00<007ooOol017oo000IOol2000Z
Ool400001Goo00000000Ool01000I7oo1`0F?goo0P000Woo00<007ooOol02Goo10000Woo0P001Woo
000IOol00`00Oomoo`0XOol40002Ool30002Ool4001SOol701HoOol5000:Ool40004Ool00`00Oomo
o`04Ool001Uoo`03001oogoo02Moo`@000=oo`<000=oo`@0065oo`L05T1oo`80009oo`03001oogoo
00Ioo`D000Eoo`03001oogoo00Aoo`006Goo00<007ooOol09goo0`0017oo0`0017oo0`00HGoo1`0F
@7oo0P0037oo0`001Woo00<007ooOol017oo000IOol00`00Oomoo`0WOol20005Ool30005Ool2001Q
Ool601I1Ool20004Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool001Uoo`8002Uoo`03001oogoo00=o
o`<000Eoo`03001oogoo05moo`L05T1oo`P000moo`8000Ioo`006Goo00<007ooOol0;Woo0`00Igoo
1`0FF7oo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001WOol601IIOol00`00Oomoo`04Ool0
01Uoo`03001oogoo02ioo`<006Ioo`L05UUoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00
IWoo1`0FFGoo00<007ooOol017oo000IOol2000_Ool3001VOol601IIOol20006Ool001Uoo`03001o
ogoo02ioo`<006Eoo`L05UYoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00IGoo1`0FFWoo
00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001TOol701IKOol00`00Oomoo`04Ool001Uoo`03
001oogoo02ioo`<006Aoo`L05U]oo`03001oogoo00Aoo`006Goo0P00;goo0`00I7oo1P0FFgoo0P00
1Woo000IOol00`00Oomoo`0^Ool30006Ool5001HOol701ILOol00`00Oomoo`04Ool001Uoo`03001o
ogoo02ioo`<000Eoo`8000=oo`8005Moo`L05Uaoo`03001oogoo00Aoo`0027oo0`000goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol0;Woo0`0017oo0P0017oo0P00Egoo1P0FGGoo00<007oo
Ool017oo0008Ool00`00Oomoo`07Ool00`00Ool00004Ool00`00Oomoo`0^Ool30004Ool20003Ool4
001EOol701IMOol00`00Oomoo`04Ool000=oo`<000=oo`03001oogoo00Qoo`03001oogoo009oo`<0
02ioo`<000Aoo`8005aoo`L05Uaoo`8000Ioo`002Goo00<007ooOol01Woo0P001Goo00<007ooOol0
;Woo0`0017oo0P00Fgoo1`0FGWoo00<007ooOol017oo0008Ool00`00Ool00007Ool00`00Oomoo`04
Ool00`00Oomoo`0^Ool30004Ool2001KOol701INOol00`00Oomoo`04Ool000Uoo`03001oogoo00Io
o`<000Aoo`03001oogoo02ioo`<000Aoo`8000Eoo`03001oogoo05=oo`H05Umoo`03001oogoo00Ao
o`006Goo00<007ooOol0;Woo0`001Goo0P000goo0P00E7oo1`0FGgoo00<007ooOol017oo000IOol2
000_Ool30006Ool400000goo001oo`1COol701INOol20006Ool001Uoo`03001oogoo02ioo`<0061o
o`H05V1oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00Ggoo1`0FH7oo00<007ooOol017oo
000IOol00`00Oomoo`0^Ool3001OOol701IPOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<0
05moo`H05V5oo`03001oogoo00Aoo`006Goo0P00;goo0`00GWoo1`0FH7oo0P001Woo000IOol00`00
Oomoo`0^Ool3001NOol701IQOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<005eoo`L05V9o
o`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00GGoo1`0FHWoo00<007ooOol017oo000IOol0
0`00Oomoo`0^Ool3001MOol601ISOol00`00Oomoo`04Ool001Uoo`8002moo`<005aoo`L05V9oo`80
00Ioo`006Goo00<007ooOol0;Woo0`00G7oo1`0FHgoo00<007ooOol017oo000IOol00`00Oomoo`0^
Ool3001LOol601ITOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<005]oo`L05VAoo`03001o
ogoo00Aoo`006Goo00<007ooOol0;Woo0`00Fgoo1`0FI7oo00<007ooOol017oo000IOol2000_Ool3
001JOol701ITOol20006Ool001Uoo`03001oogoo02ioo`<005Yoo`L05VEoo`03001oogoo00Aoo`00
6Goo00<007ooOol0;Woo0`00FWoo1P0FIWoo00<007ooOol017oo000BOol30004Ool00`00Oomoo`0^
Ool3001IOol701IVOol00`00Oomoo`04Ool0019oo`03001oogoo00Aoo`03001oogoo02ioo`<005Uo
o`L05VIoo`03001oogoo00Aoo`003Goo0`000goo00<007ooOol00goo0`00;Woo0`00FGoo1P0FIWoo
0P001Woo000COol00`00Oomoo`03Ool00`00Oomoo`0^Ool3001HOol701IWOol00`00Oomoo`04Ool0
019oo`03001oo`0000Aoo`03001oogoo08Uoo`L05VMoo`03001oogoo00Aoo`004goo00<007ooOol0
0goo00<007ooOol0RGoo1P0FJ7oo00<007ooOol017oo000IOol00`00Oomoo`28Ool701IXOol00`00
Oomoo`04Ool001Uoo`8008Uoo`L05VMoo`8000Ioo`006Goo00<007ooOol0Qgoo1`0FJGoo00<007oo
Ool017oo000IOol00`00Oomoo`27Ool701IYOol00`00Oomoo`04Ool001Uoo`03001oogoo08Moo`H0
5VYoo`03001oogoo00Aoo`006Goo00<007ooOol0QWoo1`0FJWoo00<007ooOol017oo000IOol20027
Ool701IYOol20006Ool001Uoo`03001oogoo08Ioo`H05V]oo`03001oogoo00Aoo`006Goo00<007oo
Ool0QGoo1`0FJgoo00<007ooOol017oo000IOol00`00Oomoo`25Ool701I[Ool00`00Oomoo`04Ool0
01Uoo`03001oogoo08Aoo`L05Vaoo`03001oogoo00Aoo`006Goo0P00QGoo1`0FJgoo0P001Woo000I
Ool00`00Oomoo`24Ool601I]Ool00`00Oomoo`04Ool001Uoo`03001oogoo08=oo`L05Veoo`03001o
ogoo00Aoo`006Goo00<007ooOol0Pgoo1`0FKGoo00<007ooOol017oo000IOol00`00Oomoo`23Ool6
01I^Ool00`00Oomoo`04Ool001Uoo`8008=oo`0301H0000F00@05Veoo`8000Ioo`006Goo00<007oo
Ool0P7oo1P000`0FKWoo00<007ooOol017oo000IOol00`00Oomoo`20Ool700000`0FOomoo`1]Ool0
0`00Oomoo`04Ool000Moo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo081oo`L0
000301Ioogoo06eoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007oo000017oo00<007oo
Ool0Ogoo2@00Kgoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool3
001oOol00`;00000000500020/1]Ool20006Ool000Uoo`03001oogoo00Ioo`8000Eoo`03001oogoo
07eoo`<2`0L000D2`6]oo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol0NWoo1P;01P0020;0JGoo00<007ooOol017oo0008Ool20008Ool30004Ool00`00Oomoo`1h
Ool;0/000`000/02`00;0/1VOol00`00Oomoo`04Ool001Uoo`03001oogoo07Eooah2`6Aoo`03001o
ogoo00Aoo`006Goo0P00M7oo8`;0H7oo0P001Woo000IOol00`00Oomoo`1`OolX0/1OOol00`00Oomo
o`04Ool001Uoo`03001oogoo06ioobd2`5aoo`03001oogoo00Aoo`006Goo00<007ooOol0Jgoo<P;0
FWoo00<007ooOol017oo000IOol00`00Oomoo`1[Oolb0/1JOol00`00Oomoo`04Ool001Uoo`8006ao
oc82`5Uoo`8000Ioo`006Goo00<007ooOol0Jgoo<P;0FWoo00<007ooOol017oo000IOol00`00Oomo
o`1[Oolb0/000eP0Oomoo`1GOol00`00Oomoo`04Ool001Uoo`03001oogoo06Uoo`9H0382`003F01o
ogoo05Moo`03001oogoo00Aoo`006Goo00<007ooOol0Igoo15P0<P;00UP0F7oo00<007ooOol017oo
000IOol2001WOol4F0000goo0/02`00`0/000gooF01H001FOol20006Ool001Uoo`03001oogoo06Ao
o`AH00=ooc82`09oo`03F01oogoo05Eoo`03001oogoo00Aoo`006Goo00<007ooOol0HWoo1EP017oo
<P;00Woo0UP0EWoo00<007ooOol017oo000IOol00`00Oomoo`1POol5F006Oolb0/03Ool2F01EOol0
0`00Oomoo`04Ool001Uoo`03001oogoo05moo`AH03ioo`03F01oogoo05=oo`03001oogoo00Aoo`00
6Goo0P00GWoo15P0@7oo0UP0Dgoo0P001Woo000IOol00`00Oomoo`1KOol5F012Ool00eP0Oomoo`1B
Ool00`00Oomoo`04Ool001Uoo`03001oogoo05Uoo`EH04Aoo`9H05=oo`03001oogoo00Aoo`004Goo
1@000goo00<007ooOol0Egoo1EP0Agoo0UP0DWoo00<007ooOol017oo000COol00`00Oomoo`03Ool0
0`00Oomoo`1FOol4F01:Ool00eP0Oomoo`1@Ool00`00Oomoo`04Ool000eoo`<000=oo`03001oogoo
00=oo`<005Aoo`AH04aoo`9H051oo`8000Ioo`004goo00<007ooOol00goo00<007ooOol0DWoo1EP0
CWoo0UP0D7oo00<007ooOol017oo000COol00`00Oomoo`03Ool00`00Oomoo`1@Ool5F01AOol00eP0
Oomoo`1>Ool00`00Oomoo`04Ool0019oo`8000Eoo`03001oogoo04moo`AH05=oo`9H04moo`03001o
ogoo00Aoo`006Goo00<007ooOol0CGoo15P0EWoo0UP0CWoo00<007ooOol017oo000IOol2001<Ool5
F01HOol00eP0Oomoo`1;Ool20006Ool001Uoo`03001oogoo04Uoo`EH05Yoo`9H04eoo`03001oogoo
00Aoo`006Goo00<007ooOol0B7oo15P0GGoo0UP0C7oo00<007ooOol017oo000IOol00`00Oomoo`16
Ool4F01POol00eP0Oomoo`1:Ool00`00Oomoo`04Ool001Uoo`03001oogoo04Aoo`EH065oo`9H04]o
o`03001oogoo00Aoo`006Goo0P00@goo1EP0I7oo0UP0BGoo0P001Woo000IOol00`00Oomoo`10Ool5
F01WOol00eP0Oomoo`18Ool00`00Oomoo`04Ool001Uoo`03001oogoo03moo`AH06Uoo`9H04Uoo`03
001oogoo00Aoo`006Goo00<007ooOol0?Goo15P0K7oo00=H07ooOol0Agoo00<007ooOol017oo000I
Ool00`00Oomoo`0kOol5F01]Ool2F018Ool00`00Oomoo`04Ool001Uoo`8003Yoo`EH071oo`9H04Io
o`8000Ioo`006Goo00<007ooOol0>7oo15P0Lgoo00=H07ooOol0AGoo00<007ooOol017oo000IOol0
0`00Oomoo`0fOol4F01eOol2F016Ool00`00Oomoo`04Ool001Uoo`03001oogoo03Aoo`EH07Moo`9H
04Eoo`03001oogoo00Aoo`006Goo00<007ooOol0<Woo1EP0NWoo00=H07ooOol0@goo00<007ooOol0
17oo000IOol2000aOol5F01lOol2F013Ool20006Ool001Uoo`03001oogoo02moo`AH07moo`9H04=o
o`03001oogoo00Aoo`006Goo00<007ooOol0;Goo15P0PWoo00=H07ooOol0@Goo00<007ooOol017oo
0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0[Ool5F023Ool2
F012Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo02Uoo`EH
08Ioo`9H045oo`03001oogoo00Aoo`000goo0`000Woo00<007oo00002Goo00<007ooOol00Woo0`00
:7oo15P0RGoo00=H07ooOol0?Woo0P001Woo0008Ool00`00Ool00007Ool20005Ool00`00Oomoo`0V
Ool4F02;Ool2F010Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oogoo00Aoo`03001o
ogoo02Aoo`EH08eoo`03F01oogoo03ioo`03001oogoo00Aoo`002Goo00<007ooOol01Woo0`0017oo
00<007ooOol08Woo1EP0Sgoo0UP0?goo00<007ooOol017oo000IOol00`00Oomoo`0POol5F02BOol2
F00nOol00`00Oomoo`04Ool001Uoo`80021oo`AH09Eoo`03F01oogoo03]oo`8000Ioo`006Goo00<0
07ooOol07Goo15P0Ugoo0UP0?Goo00<007ooOol017oo000IOol00`00Oomoo`0KOol5F02IOol2F00l
Ool00`00Oomoo`04Ool001Uoo`03001oogoo01Uoo`EH09aoo`03F01oogoo03Yoo`03001oogoo00Ao
o`006Goo00<007ooOol067oo15P0WWoo0UP0>goo00<007ooOol017oo000IOol2000GOol4F02QOol2
F00iOol20006Ool001Uoo`03001oogoo01Aoo`EH0:=oo`03F01oogoo03Qoo`03001oogoo00Aoo`00
6Goo00<007ooOol04Woo1EP0YGoo0UP0>Goo00<007ooOol017oo000IOol00`00Oomoo`0AOol4F02X
Ool2F00hOol00`00Oomoo`04Ool001Uoo`03001oogoo00moo`AH0:]oo`03F01oogoo03Ioo`03001o
ogoo00Aoo`006Goo0P003Woo1EP0[7oo0UP0=Woo0P001Woo000IOol00`00Oomoo`0;Ool5F02_Ool2
F00fOol00`00Oomoo`04Ool001Uoo`03001oogoo00Uoo`EH0;9oo`03F01oogoo03Aoo`03001oogoo
00Aoo`006Goo00<007ooOol027oo15P0]7oo0UP0=Goo00<007ooOol017oo000IOol00`00Oomoo`06
Ool4F02gOol00eP0Oomoo`0cOol00`00Oomoo`04Ool001Uoo`8000Eoo`EH0;Qoo`9H03=oo`8000Io
o`006Goo00<007ooOol00Woo1EP0^goo0UP0<goo00<007ooOol017oo000IOol01000Oomoogoo15P0
_Woo00=H07oo0000<Goo00<007ooOol017oo000COol00`00Oomoo`060003F02oOol6000_Ool00`00
Oomoo`04Ool0019oo`04001oo`00Ool700000eP0Oomoo`0[Ool00`00Oomoo`0_Ool00`00Oomoo`0_
Ool00`00Oomoo`0/Ool7000^Ool00`00Oomoo`04Ool0019oo`04001oo`00Ooon0006Ool0019oo`03
001oo`0000T00;moo`T003Aoo`004Woo00@007oo001oo`L00<5oo`L003Eoo`004goo00<007ooOol0
1`00`Goo1`00=Goo000FOol60032Ool6000fOol001Uoo`03001oogoo0<Eoo`03001oogoo03Ioo`00
ogoo6goo0000\
\>"],
  ImageRangeCache->{{{0, 281}, {224, 0}} -> {-0.51628, -4.36002, 0.0200002, 
  0.0200002}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with constraints 5, 6, and 7 dropped is built and solved."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fsys = SetFree[{5, 6, 7}, InitialGuess \[Rule] sol]; \)\), 
    \(sol = SolveFree[fsys] // Chop\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 2.81608738304427408`, 
      Y2 \[Rule] \(-1.53438212935137201`\), 
      Th2 \[Rule] 0.234578357810310489`, X3 \[Rule] 3.38660253569543412`, 
      Y3 \[Rule] \(-3.24157645355568568`\), 
      Th3 \[Rule] 0.322514970751720708`, s \[Rule] 2.63708355258924198`, 
      Lmb1 \[Rule] 4.02673484722002594`, Lmb2 \[Rule] 7.79125987980795908`, 
      Lmb3 \[Rule] \(-6.2442219382633386`\), 
      Lmb4 \[Rule] 18.6850431623738408`, Lmb5 \[Rule] 0, Lmb6 \[Rule] 0, 
      Lmb7 \[Rule] 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the complete equilibrium position of the pendulum-on-a-rope model."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[(1)] .2 0 0 2 Msboxa
[(2)] .4 0 0 2 Msboxa
[(3)] .6 0 0 2 Msboxa
[(4)] .8 0 0 2 Msboxa
[(5)] 1 0 0 2 Msboxa
[(-4)] -0.0125 0 1 0 Msboxa
[(-3.5)] -0.0125 .1 1 0 Msboxa
[(-3)] -0.0125 .2 1 0 Msboxa
[(-2.5)] -0.0125 .3 1 0 Msboxa
[(-2)] -0.0125 .4 1 0 Msboxa
[(-1.5)] -0.0125 .5 1 0 Msboxa
[(-1)] -0.0125 .6 1 0 Msboxa
[(-0.5)] -0.0125 .7 1 0 Msboxa
[(0)] -0.0125 .8 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(1)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(2)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(3)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(4)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(5)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-4)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .1 m
.00625 .1 L
s
P
[(-3.5)] -0.0125 .1 1 0 Mshowa
p
.002 w
0 .2 m
.00625 .2 L
s
P
[(-3)] -0.0125 .2 1 0 Mshowa
p
.002 w
0 .3 m
.00625 .3 L
s
P
[(-2.5)] -0.0125 .3 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(-2)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(-1.5)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .6 m
.00625 .6 L
s
P
[(-1)] -0.0125 .6 1 0 Mshowa
p
.002 w
0 .7 m
.00625 .7 L
s
P
[(-0.5)] -0.0125 .7 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(0)] -0.0125 .8 1 0 Mshowa
p
.001 w
0 .02 m
.00375 .02 L
s
P
p
.001 w
0 .04 m
.00375 .04 L
s
P
p
.001 w
0 .06 m
.00375 .06 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .12 m
.00375 .12 L
s
P
p
.001 w
0 .14 m
.00375 .14 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18 m
.00375 .18 L
s
P
p
.001 w
0 .22 m
.00375 .22 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .26 m
.00375 .26 L
s
P
p
.001 w
0 .28 m
.00375 .28 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34 m
.00375 .34 L
s
P
p
.001 w
0 .36 m
.00375 .36 L
s
P
p
.001 w
0 .38 m
.00375 .38 L
s
P
p
.001 w
0 .42 m
.00375 .42 L
s
P
p
.001 w
0 .44 m
.00375 .44 L
s
P
p
.001 w
0 .46 m
.00375 .46 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .52 m
.00375 .52 L
s
P
p
.001 w
0 .54 m
.00375 .54 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58 m
.00375 .58 L
s
P
p
.001 w
0 .62 m
.00375 .62 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .66 m
.00375 .66 L
s
P
p
.001 w
0 .68 m
.00375 .68 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74 m
.00375 .74 L
s
P
p
.001 w
0 .76 m
.00375 .76 L
s
P
p
.001 w
0 .78 m
.00375 .78 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .79375 m
0 .8 L
s
P
p
.002 w
.2 .79375 m
.2 .8 L
s
P
p
.002 w
.4 .79375 m
.4 .8 L
s
P
p
.002 w
.6 .79375 m
.6 .8 L
s
P
p
.002 w
.8 .79375 m
.8 .8 L
s
P
p
.001 w
.04 .79625 m
.04 .8 L
s
P
p
.001 w
.08 .79625 m
.08 .8 L
s
P
p
.001 w
.12 .79625 m
.12 .8 L
s
P
p
.001 w
.16 .79625 m
.16 .8 L
s
P
p
.001 w
.24 .79625 m
.24 .8 L
s
P
p
.001 w
.28 .79625 m
.28 .8 L
s
P
p
.001 w
.32 .79625 m
.32 .8 L
s
P
p
.001 w
.36 .79625 m
.36 .8 L
s
P
p
.001 w
.44 .79625 m
.44 .8 L
s
P
p
.001 w
.48 .79625 m
.48 .8 L
s
P
p
.001 w
.52 .79625 m
.52 .8 L
s
P
p
.001 w
.56 .79625 m
.56 .8 L
s
P
p
.001 w
.64 .79625 m
.64 .8 L
s
P
p
.001 w
.68 .79625 m
.68 .8 L
s
P
p
.001 w
.72 .79625 m
.72 .8 L
s
P
p
.001 w
.76 .79625 m
.76 .8 L
s
P
p
.001 w
.84 .79625 m
.84 .8 L
s
P
p
.001 w
.88 .79625 m
.88 .8 L
s
P
p
.001 w
.92 .79625 m
.92 .8 L
s
P
p
.001 w
.96 .79625 m
.96 .8 L
s
P
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .1 m
1 .1 L
s
P
p
.002 w
.99375 .2 m
1 .2 L
s
P
p
.002 w
.99375 .3 m
1 .3 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .6 m
1 .6 L
s
P
p
.002 w
.99375 .7 m
1 .7 L
s
P
p
.001 w
.99625 .02 m
1 .02 L
s
P
p
.001 w
.99625 .04 m
1 .04 L
s
P
p
.001 w
.99625 .06 m
1 .06 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .12 m
1 .12 L
s
P
p
.001 w
.99625 .14 m
1 .14 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18 m
1 .18 L
s
P
p
.001 w
.99625 .22 m
1 .22 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .26 m
1 .26 L
s
P
p
.001 w
.99625 .28 m
1 .28 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34 m
1 .34 L
s
P
p
.001 w
.99625 .36 m
1 .36 L
s
P
p
.001 w
.99625 .38 m
1 .38 L
s
P
p
.001 w
.99625 .42 m
1 .42 L
s
P
p
.001 w
.99625 .44 m
1 .44 L
s
P
p
.001 w
.99625 .46 m
1 .46 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .52 m
1 .52 L
s
P
p
.001 w
.99625 .54 m
1 .54 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58 m
1 .58 L
s
P
p
.001 w
.99625 .62 m
1 .62 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .66 m
1 .66 L
s
P
p
.001 w
.99625 .68 m
1 .68 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74 m
1 .74 L
s
P
p
.001 w
.99625 .76 m
1 .76 L
s
P
p
.001 w
.99625 .78 m
1 .78 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.45201 .52824 L
.64653 .57472 L
.8 .8 L
s
P
p
0 .7 0 r
p
.56322 .49312 m
.45666 .50878 L
.44736 .54769 L
.64188 .59418 L
.65118 .55527 L
F
P
P
p
0 0 .7 r
p
.03 w
.67732 .15168 m
.56322 .49312 L
s
P
.03 w
.67732 .15168 m
.67732 .15168 .06 18.4788 378.479 arc
F
P
p
.04 w
.56322 .49312 Mdot
0 .8 Mdot
.8 .8 Mdot
P
p
.012 w
.67732 .15168 m
1 .2 L
s
.97622 .16784 m
1 .2 L
.96784 .22378 L
s
P
p
.012 w
.2 .4 m
.2 .2 L
s
.17172 .22828 m
.2 .2 L
.22828 .22828 L
s
P
p
/Times-Bold findfont 14 scalefont setfont
[(F)] .92 .22 0 0 Mshowa
P
p
/Times-Bold findfont 14 scalefont setfont
[(G)] .24 .3 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 225},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000hA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0019Ool5000^Ool3000_Ool2000aOol3000_Ool00`00Oomoo`04Ool0
04]oo`03001oogoo02ioo`03001oogoo035oo`03001oogoo02moo`03001oogoo02eoo`03001oo`00
00Eoo`00Bgoo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;Woo1000<7oo00<007ooOol0
0goo001;Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool0000_Ool20006
Ool004]oo`03001oogoo02ioo`03001oo`0002moo`03001oo`00031oo`8002moo`03001oogoo00Eo
o`00BWoo0P00<Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0;Goo0`001Goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000COol3003oOol5Ool001Ao
o`03001oogoo0?moo`Aoo`003Goo0`000Woo10000goon`001Woo000BOol00`00Ool00004Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool001=oo`8000Aoo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001o
ogoo02moo`03001oogoo02moo`03001oogoo00Aoo`0057oo00<007ooOol00Woo00<007ooOol0mgoo
00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`00
6Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uo
o`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol2
003gOol20006Ool001Uoo`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<0
07ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03001oogoo0?Moo`03001o
ogoo00Aoo`006Goo0P00mgoo0P001Woo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03
001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00
Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`006Goo00<007ooOol0mgoo00<007oo
Ool017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool000Qoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo0?Moo`03001oogoo00Aoo`002Woo00<007ooOol01Goo00<007oo0000
17oo00<007ooOol0Xgoo1P0FCWoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00
Oomoo`02Ool3002POol>01I8Ool20006Ool000Yoo`03001oogoo00Eoo`8000Eoo`03001oogoo09mo
oa005TQoo`03001oogoo00Aoo`0027oo00<007oo00001goo00<007ooOol017oo00<007ooOol0WGoo
4`0FAgoo00<007ooOol017oo0009Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`2LOolF01I5Ool0
0`00Oomoo`04Ool001Uoo`03001oogoo09]ooaP05TAoo`03001oogoo00Aoo`006Goo0P00W7oo6@0F
@Woo0P001Woo000IOol00`00Oomoo`2JOolJ01I3Ool00`00Oomoo`04Ool001Uoo`03001oogoo09Yo
oaX05T=oo`03001oogoo00Aoo`006Goo00<007ooOol0VGoo700F@Woo00<007ooOol017oo000IOol0
0`00Oomoo`2HOolM01I2Ool00`00Oomoo`04Ool001Uoo`8009Uooah05T1oo`8000Ioo`006Goo00<0
07ooOol0V7oo7P0F@Goo00<007ooOol017oo000IOol00`00Oomoo`2HOol>01H5000;01I1Ool00`00
Oomoo`04Ool001Uoo`03001oogoo09Qoo`h05P`000@05T5oo`03001oogoo00Aoo`006Goo00<007oo
Ool0V7oo3P0F4P00?goo00<007ooOol017oo000IOol2002IOolC01HD000bOol00`00Oomoo`02Ool2
0006Ool001Uoo`03001oogoo09QooaX05Q@002Yoo`<000Aoo`03001oogoo00Aoo`006Goo00<007oo
Ool0V7oo7P0F0Woo500097oo0`0017oo00<007ooOol017oo000IOol00`00Oomoo`2IOolL01H:OolD
000NOol30003Ool00`00Oomoo`04Ool001Uoo`03001oogoo09Uooa`05Q5ooa<001Qoo`@0009oo`03
001oogoo00Aoo`006Goo0P00VWoo700F5goo50004Woo0`0000=oo`0000001Woo000IOol00`00Oomo
o`2JOolJ01HOOolD000<Ool300000goo001oo`05Ool001Uoo`03001oogoo09]ooaP05RIooa@000Io
o`D000Ioo`004Woo0P001Goo00<007ooOol0;goo00<007ooOol0JGoo5`0F;Woo60001Woo000DOol0
0`00Oomoo`02Ool00`00Oomoo`0^Ool3001[OolE01HfOolB0005Ool000eoo`<000=oo`03001oogoo
00=oo`<002ioo`<006aooa<05Seoo``000Eoo`0057oo00<007ooOol00Woo00<007ooOol0;Goo1@00
KGoo400F<7oo10004Goo1@001Goo000BOol00`00Ool00004Ool00`00Oomoo`0/Ool7001/Ool>01Hc
Ool2000@Ool60006Ool001=oo`03001oogoo00=oo`03001oogoo02]oo`T006]oo``05SEoo`8000mo
o`D00003Ool007oo00Eoo`006Goo00<007ooOol0:Woo2`00JWoo1P0F>goo0P003Woo1@000Woo00<0
07ooOol017oo000IOol2000ZOol400001Goo00000000Ool01000J7oo1`0F>goo0P000Woo00<007oo
Ool01goo1@000goo0P001Woo000IOol00`00Oomoo`0XOol40002Ool30002Ool4001WOol701HkOol5
0009Ool40005Ool00`00Oomoo`04Ool001Uoo`03001oogoo02Moo`@000=oo`<000=oo`@006Ioo`H0
5Saoo`80009oo`03001oogoo00Moo`<000Ioo`03001oogoo00Aoo`006Goo00<007ooOol09goo0`00
17oo0`0017oo0`00IGoo1`0F?7oo0P005Goo00<007ooOol017oo000IOol00`00Oomoo`0WOol20005
Ool30005Ool2001UOol701HlOol20004Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool001Uoo`8002Uo
o`03001oogoo00=oo`<000Eoo`03001oogoo06Aoo`H05Saoo`P000moo`8000Ioo`006Goo00<007oo
Ool0;Woo0`00Jgoo1`0FE7oo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001[Ool701IDOol0
0`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<006]oo`H05UEoo`03001oogoo00Aoo`006Goo00<0
07ooOol0;Woo0`00JWoo1`0FEGoo00<007ooOol017oo000IOol2000_Ool3001ZOol701IDOol20006
Ool001Uoo`03001oogoo02ioo`<006Yoo`H05UIoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo
0`00JGoo1`0FEWoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001YOol701IFOol00`00Oomo
o`04Ool001Uoo`03001oogoo02ioo`<006Uoo`H05UMoo`03001oogoo00Aoo`006Goo0P00;goo0`00
J7oo1`0FEWoo0P001Woo000IOol00`00Oomoo`0^Ool30006Ool5001MOol701IGOol00`00Oomoo`04
Ool001Uoo`03001oogoo02ioo`<000Eoo`8000=oo`8005aoo`H05UQoo`03001oogoo00Aoo`0027oo
0`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;Woo0`0017oo0P0017oo0P00Fgoo
1`0FF7oo00<007ooOol017oo0008Ool00`00Oomoo`07Ool00`00Ool00004Ool00`00Oomoo`0^Ool3
0004Ool20003Ool4001JOol701IHOol00`00Oomoo`04Ool000=oo`<000=oo`03001oogoo00Qoo`03
001oogoo009oo`<002ioo`<000Aoo`80065oo`H05UQoo`8000Ioo`002Goo00<007ooOol01Woo0P00
1Goo00<007ooOol0;Woo0`0017oo0P00H7oo1`0FFGoo00<007ooOol017oo0008Ool00`00Ool00007
Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool30004Ool2001POol701IIOol00`00Oomoo`04Ool000Uo
o`03001oogoo00Ioo`<000Aoo`03001oogoo02ioo`<000Aoo`8000Eoo`03001oogoo05Qoo`H05UYo
o`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`001Goo0P000goo0P00FGoo1`0FFWoo00<007oo
Ool017oo000IOol2000_Ool30006Ool400000goo001oo`1HOol701IIOol20006Ool001Uoo`03001o
ogoo02ioo`<006Eoo`H05U]oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00I7oo1`0FFgoo
00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001TOol701IKOol00`00Oomoo`04Ool001Uoo`03
001oogoo02ioo`<006Aoo`H05Uaoo`03001oogoo00Aoo`006Goo0P00;goo0`00Hgoo1`0FFgoo0P00
1Woo000IOol00`00Oomoo`0^Ool3001SOol701ILOol00`00Oomoo`04Ool001Uoo`03001oogoo02io
o`<006=oo`H05Ueoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00HWoo1`0FGGoo00<007oo
Ool017oo000IOol00`00Oomoo`0^Ool3001ROol701IMOol00`00Oomoo`04Ool001Uoo`8002moo`<0
069oo`H05Ueoo`8000Ioo`006Goo00<007ooOol0;Woo0`00HGoo1`0FGWoo00<007ooOol017oo000I
Ool00`00Oomoo`0^Ool3001QOol701INOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<0065o
o`H05Umoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00H7oo1`0FGgoo00<007ooOol017oo
000IOol2000_Ool3001POol701INOol20006Ool001Uoo`03001oogoo02ioo`<0061oo`H05V1oo`03
001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00Ggoo1`0FH7oo00<007ooOol017oo000BOol30004
Ool00`00Oomoo`0^Ool3001OOol701IPOol00`00Oomoo`04Ool0019oo`03001oogoo00Aoo`03001o
ogoo02ioo`<005moo`H05V5oo`03001oogoo00Aoo`003Goo0`000goo00<007ooOol00goo0`00;Woo
0`00GWoo1`0FH7oo0P001Woo000COol00`00Oomoo`03Ool00`00Oomoo`0^Ool3001NOol701IQOol0
0`00Oomoo`04Ool0019oo`03001oo`0000Aoo`03001oogoo08moo`H05V9oo`03001oogoo00Aoo`00
4goo00<007ooOol00goo00<007ooOol0SWoo1`0FHWoo00<007ooOol017oo000IOol00`00Oomoo`2>
Ool701IROol00`00Oomoo`04Ool001Uoo`8008moo`H05V9oo`8000Ioo`006Goo00<007ooOol0SGoo
1`0FHgoo00<007ooOol017oo000IOol00`00Oomoo`2=Ool701ISOol00`00Oomoo`04Ool001Uoo`03
001oogoo08eoo`H05VAoo`03001oogoo00Aoo`006Goo00<007ooOol0S7oo1`0FI7oo00<007ooOol0
17oo000IOol2002=Ool701ISOol20006Ool001Uoo`03001oogoo08aoo`H05VEoo`03001oogoo00Ao
o`006Goo00<007ooOol0Rgoo1`0FIGoo00<007ooOol017oo000IOol00`00Oomoo`2;Ool701IUOol0
0`00Oomoo`04Ool001Uoo`03001oogoo08]oo`H05VIoo`03001oogoo00Aoo`006Goo0P00Rgoo1`0F
IGoo0P001Woo000IOol00`00Oomoo`2:Ool701IVOol00`00Oomoo`04Ool001Uoo`03001oogoo08Yo
o`H05VMoo`03001oogoo00Aoo`006Goo00<007ooOol0RGoo1`0FIgoo00<007ooOol017oo000IOol0
0`00Oomoo`29Ool701IWOol00`00Oomoo`04Ool001Uoo`8008Yoo`0301H0000F00<05VMoo`8000Io
o`006Goo00<007ooOol0Qgoo1P000P0FJ7oo00<007ooOol017oo000IOol00`00Oomoo`27Ool70000
0`0FOomoo`1VOol00`00Oomoo`04Ool000Moo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo08Moo`L006Uoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007oo000017oo00<0
07ooOol0QWoo2@00J7oo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool30024Ool30/07001XOol20006Ool000Uoo`03001oogoo00Ioo`8000Eoo`03001oogoo07eoo`T2
`00301H0000000D006Uoo`03001oogoo00Aoo`002Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol0MWoo4@;01P000P;0J7oo00<007ooOol017oo0008Ool20008Ool30004Ool00`00Oomoo`1_
OolK0/000`0001H2`0030/1WOol00`00Oomoo`04Ool001Uoo`03001oogoo06moob<2`6Eoo`03001o
ogoo00Aoo`006Goo0P00L7oo90;0Hgoo0P001Woo000IOol00`00Oomoo`1_OolV0/1ROol00`00Oomo
o`04Ool001Uoo`03001oogoo06eoo`9H02L2`65oo`03001oogoo00Aoo`006Goo00<007ooOol0K7oo
0UP0:P;0Ggoo00<007ooOol017oo000IOol00`00Oomoo`1[Ool3F00[0/1NOol00`00Oomoo`04Ool0
01Uoo`8006Yoo`AH0003Ool2`0;002/2`5]oo`8000Ioo`006Goo00<007ooOol0Igoo1EP00Woo;P;0
Fgoo00<007ooOol017oo000IOol00`00Oomoo`1VOol4F003Oola0/1IOol00`00Oomoo`04Ool001Uo
o`03001oogoo06Aoo`AH00Yoobd2`5Qoo`03001oogoo00Aoo`006Goo00<007ooOol0HWoo1EP03goo
:P;0Egoo00<007ooOol017oo000IOol2001ROol4F00EOolV0/1FOol20006Ool001Uoo`03001oogoo
05moo`AH01]oob82`5Moo`03001oogoo00Aoo`006Goo00<007ooOol0GGoo1EP087oo7P;0Egoo00<0
07ooOol017oo000IOol00`00Oomoo`1KOol5F00VOolJ0/1GOol00`00Oomoo`04Ool001Uoo`03001o
ogoo05Yoo`AH02aooaD2`003F01oogoo05Eoo`03001oogoo00Aoo`006Goo0P00FGoo15P0<Woo4@;0
0UP0EGoo0P001Woo000IOol00`00Oomoo`1FOol5F00gOol=0/000gooF01H001EOol00`00Oomoo`04
Ool001Uoo`03001oogoo05Eoo`AH03eoo`T2`09oo`03F01oogoo05=oo`03001oogoo00Aoo`004Goo
1@000goo00<007ooOol0Dgoo15P0@goo1@;00Woo0UP0E7oo00<007ooOol017oo000COol00`00Oomo
o`03Ool00`00Oomoo`1AOol5F01<Ool2F01COol00`00Oomoo`04Ool000eoo`<000=oo`03001oogoo
00=oo`<0051oo`AH04moo`03F01oogoo051oo`8000Ioo`004goo00<007ooOol00goo00<007ooOol0
CWoo15P0DGoo0UP0DWoo00<007ooOol017oo000COol00`00Oomoo`03Ool00`00Oomoo`1<Ool5F01C
Ool2F01AOol00`00Oomoo`04Ool0019oo`8000Eoo`03001oogoo04]oo`AH05Ioo`03F01oogoo04mo
o`03001oogoo00Aoo`006Goo00<007ooOol0BGoo15P0F7oo0UP0D7oo00<007ooOol017oo000IOol2
0018Ool5F01JOol2F01>Ool20006Ool001Uoo`03001oogoo04Ioo`AH05eoo`03F01oogoo04eoo`03
001oogoo00Aoo`006Goo00<007ooOol0A7oo15P0Ggoo0UP0CWoo00<007ooOol017oo000IOol00`00
Oomoo`12Ool5F01QOol2F01=Ool00`00Oomoo`04Ool001Uoo`03001oogoo041oo`EH06Aoo`9H04ao
o`03001oogoo00Aoo`006Goo0P00@7oo15P0Igoo00=H07ooOol0BGoo0P001Woo000IOol00`00Oomo
o`0mOol4F01YOol2F01;Ool00`00Oomoo`04Ool001Uoo`03001oogoo03]oo`EH06]oo`9H04Yoo`03
001oogoo00Aoo`006Goo00<007ooOol0>Woo15P0KWoo00=H07ooOol0B7oo00<007ooOol017oo000I
Ool00`00Oomoo`0hOol4F01`Ool2F019Ool00`00Oomoo`04Ool001Uoo`8003Moo`EH079oo`9H04Mo
o`8000Ioo`006Goo00<007ooOol0=Goo15P0MGoo00=H07ooOol0AWoo00<007ooOol017oo000IOol0
0`00Oomoo`0cOol4F01gOol2F017Ool00`00Oomoo`04Ool001Uoo`03001oogoo035oo`EH07Uoo`9H
04Ioo`03001oogoo00Aoo`006Goo00<007ooOol0<7oo15P0O7oo00=H07ooOol0A7oo00<007ooOol0
17oo000IOol2000_Ool4F01nOol2F014Ool20006Ool001Uoo`03001oogoo02aoo`EH081oo`9H04Ao
o`03001oogoo00Aoo`006Goo00<007ooOol0:goo15P0Pgoo00=H07ooOol0@Woo00<007ooOol017oo
0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0YOol4F025Ool2
F013Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo02Moo`EH
08Moo`9H049oo`03001oogoo00Aoo`000goo0`000Woo00<007oo00002Goo00<007ooOol00Woo0`00
9Goo1EP0RWoo00=H07ooOol0?goo0P001Woo0008Ool00`00Ool00007Ool20005Ool00`00Oomoo`0T
Ool4F02<Ool2F011Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oogoo00Aoo`03001o
ogoo029oo`AH08moo`9H041oo`03001oogoo00Aoo`002Goo00<007ooOol01Woo0`0017oo00<007oo
Ool087oo1EP0TGoo00=H07ooOol0?Woo00<007ooOol017oo000IOol00`00Oomoo`0OOol4F02COol2
F00oOol00`00Oomoo`04Ool001Uoo`8001ioo`AH09Ioo`9H03eoo`8000Ioo`006Goo00<007ooOol0
6goo1EP0V7oo00=H07ooOol0?7oo00<007ooOol017oo000IOol00`00Oomoo`0JOol4F02JOol2F00m
Ool00`00Oomoo`04Ool001Uoo`03001oogoo01Qoo`AH09eoo`9H03aoo`03001oogoo00Aoo`006Goo
00<007ooOol05Woo1EP0Wgoo00=H07ooOol0>Woo00<007ooOol017oo000IOol2000FOol4F02QOol2
F00jOol20006Ool001Uoo`03001oogoo01=oo`AH0:Aoo`9H03Yoo`03001oogoo00Aoo`006Goo00<0
07ooOol04Goo1EP0YWoo0UP0>Goo00<007ooOol017oo000IOol00`00Oomoo`0@Ool4F02YOol00eP0
Oomoo`0gOol00`00Oomoo`04Ool001Uoo`03001oogoo00ioo`AH0:]oo`9H03Qoo`03001oogoo00Ao
o`006Goo0P003Goo1EP0[Goo0UP0=Woo0P001Woo000IOol00`00Oomoo`0:Ool5F02`Ool00eP0Oomo
o`0eOol00`00Oomoo`04Ool001Uoo`03001oogoo00Uoo`AH0;9oo`9H03Ioo`03001oogoo00Aoo`00
6Goo00<007ooOol01goo15P0]Goo0UP0=Goo00<007ooOol017oo000IOol00`00Oomoo`05Ool5F02g
Ool00eP0Oomoo`0cOol00`00Oomoo`04Ool001Uoo`8000Eoo`AH0;Uoo`9H03=oo`8000Ioo`006Goo
00<007ooOol00Woo15P0_7oo0UP0<goo00<007ooOol017oo000IOol00`00Oomoo`05F02nOol00eP0
Ool0000aOol00`00Oomoo`04Ool001=oo`03001oogoo00H000=H0;moo`H002moo`03001oogoo00Ao
o`004Woo00@007oo001oo`L002ioo`03001oogoo02moo`03001oogoo02moo`03001oogoo02aoo`L0
02ioo`03001oogoo00Aoo`004Woo00@007oo001oooh000Ioo`004Woo00<007oo00002@00_goo2@00
=7oo000BOol01000Ool007oo1`00`Goo1`00=Goo000COol00`00Oomoo`070031Ool7000eOol001Io
o`H00<9oo`H003Ioo`006Goo00<007ooOol0aGoo00<007ooOol0=Woo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {224, 0}} -> {-0.51628, -4.36002, 0.0200002, 
  0.0200002}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph:=Graphics[{\n  {Thickness[0.01],RGBColor[.7,0,0],\n   Edge[{{0,0}, \
Point[slider,1], Point[slider, 2],\n     Point[ground, 1]}]},\n  \
{RGBColor[0,.7,0],\n   Facet[slider, {0, \
{-.5,.2},{-.5,.4},{.5,.4},{.5,.2}}]},\n  \
{Thickness[0.03],RGBColor[0,0,.7],Edge[pendulum, {0, 1}],\n   \
Wheel[Point[pendulum, 0], .3]},\n  PointSize[0.04],Thickness[0.012],\n  \
Vertex[{Point[slider,0],{0,0},{4,0}}],\n  Arrow[Line[pendulum,0,ground,2],1,\n\
    Magnitude \[Rule] Relative,Head \[Rule] .2],\n  \
Arrow[Axis[ground,{1,-2},{0,-1}],1],\n  \
Text[FontForm[\"F\",{\"Times-Bold\",14}],{4.6,-2.9}],\n  \
Text[FontForm[\"G\",{\"Times-Bold\",14}],{1.2,-2.5}]},\n  Frame \[Rule] \
True,AspectRatio \[Rule] Automatic,\n  PlotRange \[Rule] {{0,5},{-4,0}}]"], 
  "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[graph/.LastSolve[]]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["10.2  Equilibrium Velocity"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the use of the ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions to find the equilibrium velocity of a mechanism that has \
velocity-dependent loading. A mechanism must have some loading that is a \
direct function of velocity for it to have a defined equilibrium velocity. \
Note that the centrifugal forces in a model, although they are explicitly \
functions of velocity, are inertial forces and do not appear in a velocity \
equilibrium analysis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"This simple planar slider-crank model is presented with little explanation \
because all of the techniques used in the model have been explored in \
previous chapters.\n\nThe one feature of interest in this model is the \
velocity-dependent applied loading. Two loads are applied, a driving moment \
on the crank and a viscous friction on the slider. Note that the driving \
moment applied to the crank is a function of velocity such that the moment \
drops to zero as velocity increases. This is done so that the velocity will \
not approach infinity when the piston is not moving at top-dead-center and \
bottom-dead-center."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and defines names for each of the body numbers."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(slider = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints for the slider-crank model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetConstraints[\n\tRevolute2[1, Point[ground, 0], Point[crank, 0]], \n\t
      RotationLock1[2, crank, 2\ N[\[Pi]]\ T], \n\t
      Translate2[3, \n\t\tLine[ground, 0, {1, 0}], Line[slider, 0, {1, 0}]], 
      \n\tRelativeDistance1[4, \n\t\tPoint[crank, {1, 0}], Point[slider, 0], 
        3]]\), 
    \(SetBodies[Body[slider, InitialGuess \[Rule] {{4, 0}, 0}]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the velocity-dependent applied loads. Note that the force on the \
slider always opposes its direction of motion."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[\n\t
      Moment[crank, 
        5\ \((10 - 
              \(Velocity[crank]\)\[LeftDoubleBracket]3\[RightDoubleBracket])
            \)], \n\tForce[slider, Axis[slider, 0, {\(-1\), 0}], 
        10\ \(Velocity[slider]\)\[LeftDoubleBracket]1\[RightDoubleBracket]]]
      \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the moment that is applied to the crank by the rotational \
constraint at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[2, crank] /. SolveMech[0.2, Solution \[Rule] Kinematic]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 51.2630182460194117`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the slider-crank model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.2."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .53488 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.267442 0.116279 0.267442 0.116279 [
[ 0 0 0 0 ]
[ 1 .53488 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .53488 L
0 .53488 L
closepath
clip
newpath
p
.01 w
.38372 .01163 m
.26744 .26744 L
.15116 .01163 L
.90698 .01163 L
.90698 .23837 L
.44186 .23837 L
s
p
1 0 0 r
.02 w
.26744 .26744 m
.26744 .26744 .05814 0 365.73 arc
F
p
.26744 .26744 m
.30337 .37803 L
s
P
0 1 0 r
.30337 .37803 m
.63422 .26744 L
s
0 0 1 r
.57608 .23837 m
.69236 .23837 L
.69236 .29651 L
.57608 .29651 L
F
P
.02 w
.63422 .26744 Mdot
.26744 .26744 Mdot
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .30337 .37803 .96306 -1.13407 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .15685 .30337 .96306 -1.13407 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .26744 .26744 .96306 -1.13407 Mshowa
P
.002 w
.30337 .37803 m
.26744 .26744 L
.15685 .30337 L
s
.30725 .35232 m
.30337 .37803 L
.28513 .35951 L
s
.17538 .28513 m
.15685 .30337 L
.18256 .30725 L
s
P
p
p
/Courier findfont 8 scalefont setfont
[(x)] .7505 .26744 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .63422 .38372 -1.5 -0.9 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(3)] .63422 .26744 -1.5 -0.9 Mshowa
P
.002 w
.7505 .26744 m
.63422 .26744 L
.63422 .38372 L
s
.72724 .25581 m
.7505 .26744 L
.72724 .27907 L
s
.62259 .36047 m
.63422 .38372 L
.64585 .36047 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 150},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000UQ000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00:goo00<007ooOol0?Woo00<007ooOol0Zgoo000ZOooD000LOol002Yoom@001ao
o`00;7oo00<007ooOol0?7oo00<007ooOol0SWoo0P0077oo000/Ool2000lOol2002@Ool2000LOol0
02eoo`03001oogoo03Yoo`03001oogoo08moo`8001aoo`00;Goo00<007ooOol0>Goo0P00TGoo0P00
77oo000]Ool2000jOol00`00Oomoo`2@Ool2000LOol002ioo`03001oogoo03Qoo`03001oogoo091o
o`8001aoo`00;Woo0P00>7oo0P00TWoo0P0077oo000_Ool00`00Oomoo`0fOol00`00Oomoo`2AOol2
000LOol002moo`8003Ioo`8009=oo`8001aoo`00<7oo00<007ooOol0=7oo00<007ooOol0TWoo0P00
77oo000`Ool2000dOol2002DOol2000LOol0035oo`03001oogoo039oo`03001oogoo09=oo`8001ao
o`00<Goo0P00<Woo0P00UGoo0P0077oo000bOol00`00Oomoo`0`Ool00`00Oomoo`2DOol2000LOol0
039oo`03001oogoo02moo`8009Ioo`8001aoo`00<Woo0P00<7oo00<007ooOol0UGoo0P0077oo000c
Ool00`00Oomoo`0]Ool2002GOol2000LOol003=oo`8002ioo`03001oogoo09Ioo`8001aoo`00=7oo
00<007ooOol0:goo0P00V7oo0P0077oo000dOol2000/Ool00`00Oomoo`2GOol2000LOol003Eoo`03
001oogoo02Yoo`03001oogoo09Moo`8001aoo`00=Goo0P00:Woo0P00VGoo0P0077oo000fOol00`00
Oomoo`0XOol00`00Oomoo`2HOol2000LOol003Ioo`03001oogoo02Moo`8009Yoo`8001aoo`00=Woo
0P00:7oo00<007ooOol0VGoo0P0077oo000gOol00`00Oomoo`0UOol2002KOol2000LOol003Moo`80
02Ioo`03001oogoo09Yoo`8001aoo`00>7oo00<007ooOol08goo0P00W7oo0P0077oo000hOol2000T
Ool00`00Oomoo`2KOol2000LOol003Uoo`03001oogoo025oo`8009eoo`8001aoo`00>Goo0P008Woo
00<007ooOol0W7oo0P0077oo000jOol00`00Oomoo`0OOol2002NOol2000LOol003Yoo`80021oo`03
001oogoo09eoo`8001aoo`00>goo00<007ooOol07Goo0P00Wgoo0P0077oo000kOol00`00Oomoo`0M
Ool00`00Oomoo`2NOol2000LOol003]oo`8001ioo`03001oogoo09ioo`8001aoo`00?7oo00<007oo
Ool06goo0P00X7oo0P0077oo000lOol2000LOol00`00Oomoo`2OOol2000LOol003eoo`03001oogoo
01Uoo`800:5oo`8001aoo`00?Goo0P006Woo00<007ooOol0X7oo0P0077oo000nOol00`00Oomoo`0G
Ool2002ROol2000LOol003ioo`8001Qoo`03001oogoo0:5oo`8001aoo`00?goo00<007ooOol05Goo
0P00Xgoo0P0077oo000oOol2000FOol00`00Oomoo`2ROol2000LOol0041oo`03001oogoo01=oo`80
0:Aoo`8001aoo`00@7oo00<007ooOol04goo00<007ooOol0Xgoo0P0077oo0010Ool2000COol2002U
Ool2000LOol0045oo`03001oogoo015oo`03001oogoo0:Aoo`8001aoo`00@Goo0P004Woo00<007oo
Ool0Y7oo0P0077oo0012Ool00`00Oomoo`0?Ool2002VOol2000LOol0049oo`80011oo`03001oogoo
0:Eoo`8001aoo`00@goo00<007ooOol03Goo0P00Ygoo0P0077oo0013Ool2000>Ool00`00Oomoo`2V
Ool2000LOol004Aoo`03001oogoo00]oo`800:Qoo`8001aoo`00A7oo00<007ooO0002g`000<007oo
Ool0Ygoo0P0077oo0013Ool@O02YOol2000LOol0049ooa=l0:Moo`8001aoo`00@Goo5G`0YWoo0P00
77oo0010OolGO02UOol2000LOol003iooaYl0:Aoo`8001aoo`00?Woo6g`0Xgoo0P0077oo000nOolK
O00ROon3000LOol003eooael025oobH002407c`001aoo`00?7oo7g`0AWoo8@0OF7oo000lOolOO016
OolQ01mHOol003aooaml04Ioob407eQoo`00?7oo7g`0AWoo8@0O2Goo0P00CGoo000kOolPO016OolQ
01l;Ool2001;Ool003]oo`ml008000ml04Ioo`l07`8001007`eoo`8004Uoo`00>goo3W`010003W`0
AWoo3P0O9000Agoo000kOol<O006000>O016Ool>01l4000?01l=Ool20019Ool003]oo`Ul00<000=l
00<000il04Ioo`l07`8001007`]oo`8004]oo`00?7oo1G`00`0027`000<007`0O00037`0AWoo400O
00<0000O01l00`002`0O2Goo0P001Woo0P0000=oo`00Ool0@Woo000lOol2O0030006O0030002O000
0`00O01l000<O013Ool30n0@01l00`0001l07`0201l00`0001l07`0901lCOol00`00Oomoo`12Ool0
039oo`03001oogoo00Eoo`@000Ul008000Al0003001l07`000]l041oo`H3h1007`0500007`0O01l0
000<01lBOol00`00Ool00013Ool0035oo`03001oogoo00=oo`<0009oo`el0005001l07`0O000000<
O00nOol90n0@01l00`0001l07`0201l00`0001l07`0901mHOol0031oo`04001oogooOol30006Ool<
O0001@00O01l07`0000037`0>goo30?P400O00<0000O01l00`002`0OF7oo000^Ool2000017oo0000
00002Goo2W`00`0017`000<007`0O0002G`0>7oo3`?P400O00<0000O01l03P0OF7oo000]Ool4000=
Ool@O0000`00O01l0008O00fOol@0n0BOol00`00Oomoo`1VOol002aoo`@000moo`ml0003001l07`0
00Ql03=ooa03h1Eoo`03001oogoo06Ioo`00<7oo1@002Woo47`000<007`0O0001W`0<Goo40?P67oo
00<007ooOol0IWoo000XOol2000GOol>O0000`00O01l0005O00_Ool@0n0KOol00`00Oomoo`1VOol0
02Uoo`03001oogoo01Ioo`el0003001l07`000Al02eooa03h1ioo`03001oogoo06Ioo`00:Goo00<0
07ooOol067oo37`000@007`0O01l02aooa03h25oo`03001oogoo06Ioo`00:7oo00<007oo00006Woo
2g`000<007`0O000:Woo40?P97oo00<007ooOol0IWoo000XOol01000Ool0000077oo27`000<007`0
O0009goo40?P9goo00<007ooOol0IWoo001>Ool2O0001000O01l07`08goo40?P:Woo00<007ooOol0
IWoo001?Ool2O0000`00O01l000POol@0n0]Ool00`00Oomoo`1VOol004moo`9l0003001l07`001eo
oa03h31oo`03001oogoo06Ioo`00Cgoo0W`000@007`0O01l01Uooa03h3=oo`03001oogoo06Ioo`00
D7oo0W`000<007`0O0005Woo40?P=Woo00<007ooOol0IWoo001@Ool2O0000`00O01l000COol@0n0i
Ool00`00Oomoo`1VOol0051oo`9l0004001l07`0O00?Ool@0n0lOol00`00Oomoo`1VOol0055oo`9l
0004001l07`0000;Ool@0n0oOol00`00Oomoo`1VOol0055oo`9l0004001l07`00008Ool@0n12Ool0
0`00Oomoo`1VOol0051oo`04001l07`00002O0000`00Oomoo`03Ool@0n12Ool01000Oomoo`000goo
00<007ooOol0HWoo001AOol01P00O01l0000O000009ooa03h4Eoo`04001oogoo0002Ool00`00Oomo
o`1SOol0059oo`05001l0000001l000?0n19Ool00`00Ool00002Ool00`00Oomoo`1SOol0059oo`04
O0000000000=0n1<Ool01@00Ool007oo0000IWoo001COol00`?P0000000:0n1@Ool3001WOol005=o
o`83h0030003h0?P00D3h5=oo`<006Moo`00Dgoo1`?PEgoo00<007ooOol0IWoo001COol50n1LOol2
001TOol0051oo`800003Ool000?P061oo`03001oogoo069oo`00DWoo00<007ooOol0H7oo00<007oo
Ool0HWoo001AOol00`00Ool0001POol00`00Ool0001SOol00;Aoo`04001oo`00001ROol00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003o
OolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003o
OolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]o
o`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00\
\>"],
  ImageRangeCache->{{{0, 281}, {149, 0}} -> {-2.3376, -2.30003, 0.0308726, 
  0.0308726}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Finding Equilibrium Velocity"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the equilibrium velocity of a mechanism, a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that contains a new set of equations of motion with one \
or more constraints removed from the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dropcon, ",
    FontSlant->"Italic"],
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Kinematic]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the mathematical equations required to find equilibrium velocity \
of the current model, and returns them in a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint numbers that are dropped to \
make the model underconstrained."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Velocity equilibrium."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[
"The driving constraint is dropped from the slider-crank model to give the \
model one degree of freedom."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This drops the constraint that controls rotation of the crank."], "SmallText",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fsys = SetFree[2, Solution \[Rule] Kinematic]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. Note that the angular velocity of the crank ",
  StyleBox["Th2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is less than the driven angular velocity of 2 pi."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = SolveFree[fsys] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.2`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Th2 \[Rule] 1.25663706143591724`\), ",", 
        \(X3 \[Rule] 3.15427471606075737`\), ",", \(Y3 \[Rule] 0\), ",", 
        \(Th3 \[Rule] 0\), ",", \(X2d \[Rule] 0\), ",", \(Y2d \[Rule] 0\), 
        ",", \(Th2d \[Rule] 3.10240866607122445`\), ",", 
        \(X3d \[Rule] \(-3.27102026357208819`\)\), ",", \(Y3d \[Rule] 0\), 
        ",", \(Th3d \[Rule] 0\), ",", 
        \(Lmb1 \[Rule] \(-32.7102026357208819`\)\), ",", 
        \(Lmb2 \[Rule] 10.9337200384101151`\), ",", 
        \(Lmb4 \[Rule] 34.4879566696438777`\), ",", 
        \(Lmb5 \[Rule] \(-10.9337200384101151`\)\), ",", 
        \(Lmb6 \[Rule] 5.74819679539260608`\), ",", \(Lmb3 \[Rule] 0\)}], 
      "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To find the equilibrium velocity at a sequence of positions through a full \
cycle of the mechanism, the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to pass ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " a new set of initial conditions at each position where the equilibrium \
velocity is to be found. Thus, it is not necessary to create a new ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object for each solution point."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies the initial conditions needed to solve for equilibrium \
velocity or acceleration. For equilibrium velocity, ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be a list of rules specifying the location of each body in the \
model. For equilibrium acceleration, ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must specify the location and velocity of each body. The default ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the default initial guesses obtained from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for initial conditions."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This generates a list of 20 rules to be used as initial conditions for the \
equilibrium velocity solution."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(\(postab = SolveMech[{0, 1}, 21]; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object at each initial condition in ",
  StyleBox["postab",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(eqtab = \((SolveFree[fsys, InitialCondition \[Rule] #1]&)\)/@postab; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the equilibrium velocity of the crank through a full cycle \
of the mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[{T, Th2d} /. eqtab, PlotJoined \[Rule] True]; \)\)], "Input",\

  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.250028 0.0853347 [
[.21429 -0.00652 -9 -9 ]
[.21429 -0.00652 9 0 ]
[.40476 -0.00652 -9 -9 ]
[.40476 -0.00652 9 0 ]
[.59524 -0.00652 -9 -9 ]
[.59524 -0.00652 9 0 ]
[.78571 -0.00652 -9 -9 ]
[.78571 -0.00652 9 0 ]
[.97619 -0.00652 -3 -9 ]
[.97619 -0.00652 3 0 ]
[.01131 .09131 -6 -4.5 ]
[.01131 .09131 0 4.5 ]
[.01131 .17665 -6 -4.5 ]
[.01131 .17665 0 4.5 ]
[.01131 .26198 -6 -4.5 ]
[.01131 .26198 0 4.5 ]
[.01131 .34731 -6 -4.5 ]
[.01131 .34731 0 4.5 ]
[.01131 .43265 -6 -4.5 ]
[.01131 .43265 0 4.5 ]
[.01131 .51798 -6 -4.5 ]
[.01131 .51798 0 4.5 ]
[.01131 .60332 -12 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .00598 m
.21429 .01223 L
s
[(0.2)] .21429 -0.00652 0 1 Mshowa
.40476 .00598 m
.40476 .01223 L
s
[(0.4)] .40476 -0.00652 0 1 Mshowa
.59524 .00598 m
.59524 .01223 L
s
[(0.6)] .59524 -0.00652 0 1 Mshowa
.78571 .00598 m
.78571 .01223 L
s
[(0.8)] .78571 -0.00652 0 1 Mshowa
.97619 .00598 m
.97619 .01223 L
s
[(1)] .97619 -0.00652 0 1 Mshowa
.125 Mabswid
.07143 .00598 m
.07143 .00973 L
s
.11905 .00598 m
.11905 .00973 L
s
.16667 .00598 m
.16667 .00973 L
s
.2619 .00598 m
.2619 .00973 L
s
.30952 .00598 m
.30952 .00973 L
s
.35714 .00598 m
.35714 .00973 L
s
.45238 .00598 m
.45238 .00973 L
s
.5 .00598 m
.5 .00973 L
s
.54762 .00598 m
.54762 .00973 L
s
.64286 .00598 m
.64286 .00973 L
s
.69048 .00598 m
.69048 .00973 L
s
.7381 .00598 m
.7381 .00973 L
s
.83333 .00598 m
.83333 .00973 L
s
.88095 .00598 m
.88095 .00973 L
s
.92857 .00598 m
.92857 .00973 L
s
.25 Mabswid
0 .00598 m
1 .00598 L
s
.02381 .09131 m
.03006 .09131 L
s
[(4)] .01131 .09131 1 0 Mshowa
.02381 .17665 m
.03006 .17665 L
s
[(5)] .01131 .17665 1 0 Mshowa
.02381 .26198 m
.03006 .26198 L
s
[(6)] .01131 .26198 1 0 Mshowa
.02381 .34731 m
.03006 .34731 L
s
[(7)] .01131 .34731 1 0 Mshowa
.02381 .43265 m
.03006 .43265 L
s
[(8)] .01131 .43265 1 0 Mshowa
.02381 .51798 m
.03006 .51798 L
s
[(9)] .01131 .51798 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(10)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .02304 m
.02756 .02304 L
s
.02381 .04011 m
.02756 .04011 L
s
.02381 .05718 m
.02756 .05718 L
s
.02381 .07424 m
.02756 .07424 L
s
.02381 .10838 m
.02756 .10838 L
s
.02381 .12544 m
.02756 .12544 L
s
.02381 .14251 m
.02756 .14251 L
s
.02381 .15958 m
.02756 .15958 L
s
.02381 .19371 m
.02756 .19371 L
s
.02381 .21078 m
.02756 .21078 L
s
.02381 .22785 m
.02756 .22785 L
s
.02381 .24491 m
.02756 .24491 L
s
.02381 .27905 m
.02756 .27905 L
s
.02381 .29611 m
.02756 .29611 L
s
.02381 .31318 m
.02756 .31318 L
s
.02381 .33025 m
.02756 .33025 L
s
.02381 .36438 m
.02756 .36438 L
s
.02381 .38145 m
.02756 .38145 L
s
.02381 .39852 m
.02756 .39852 L
s
.02381 .41558 m
.02756 .41558 L
s
.02381 .44972 m
.02756 .44972 L
s
.02381 .46678 m
.02756 .46678 L
s
.02381 .48385 m
.02756 .48385 L
s
.02381 .50092 m
.02756 .50092 L
s
.02381 .53505 m
.02756 .53505 L
s
.02381 .55212 m
.02756 .55212 L
s
.02381 .56919 m
.02756 .56919 L
s
.02381 .58625 m
.02756 .58625 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.07143 .39056 L
.11905 .15187 L
.16667 .04465 L
.21429 .01472 L
.2619 .03442 L
.30952 .10008 L
.35714 .21615 L
.40476 .37596 L
.45238 .53383 L
.5 .60332 L
.54762 .53383 L
.59524 .37596 L
.64286 .21615 L
.69048 .10008 L
.7381 .03442 L
.78571 .01472 L
.83333 .04465 L
.88095 .15187 L
.92857 .39056 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00Oogoo6Woo0010Ool0
0`00Oomoo`02Ool01000Oomoogoo0`009Woo00<007ooOol00Woo00<007ooOol00Woo0`0097oo00<0
07ooOol00Woo00@007ooOomoo`8002Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Qo
o`D000Yoo`00?goo00<007oo00001goo00<007ooOol09Goo00<007oo00002Goo00<007ooOol08Woo
00<007oo00001goo00<007oo00009Goo00<007oo00001goo00<007oo0000:goo00<007ooOol02Woo
000oOol00`00Ool00008Ool00`00Oomoo`0TOol00`00Ool00007Ool4000SOol00`00Ool00007Ool0
0`00Ool0000UOol00`00Ool00007Ool00`00Ool0000[Ool00`00Oomoo`0:Ool003moo`03001oo`00
00Qoo`03001oogoo02Aoo`03001oo`0000Moo`03001oo`0002Aoo`03001oo`0000Moo`8002Ioo`03
001oo`0000Qoo`03001oogoo02Yoo`03001oogoo00Yoo`00?goo00<007oo00001goo00<007oo0000
9Goo00<007oo000027oo0P0097oo00<007oo00001goo00<007ooOol09Goo00<007oo00001goo00<0
07oo0000:goo00<007ooOol02Woo0010Ool00`00Oomoo`07Ool00`00Oomoo`0UOol00`00Oomoo`08
Ool00`00Oomoo`0SOol00`00Oomoo`07Ool2000VOol00`00Oomoo`07Ool00`00Oomoo`0YOol2000<
Ool00?mooaYoo`00ogoo6Woo003oOolJOol00?mooaYoo`004goo00<007ooOol0ogoo17oo000COol0
0`00Oomoo`3oOol4Ool000eoool000P000Eoo`004goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo000COol00`00Oomoo`0_
Ool2002COol2000mOol001=oo`03001oogoo02eoo`80009oo`8008moo`80009oo`8003]oo`004goo
0P00;Goo00<007ooOol017oo0`00RGoo0`001Woo00<007ooOol0>7oo000COol00`00Oomoo`0ZOol2
000:Ool30023Ool3000:Ool2000hOol001=oo`03001oogoo02Uoo`03001oogoo00eoo`8007moo`80
00moo`03001oogoo03Eoo`004goo00<007ooOol09goo0P004Woo0P00Ngoo0P004Woo0P00=Goo000C
Ool00`00Oomoo`0VOol00`00Oomoo`0DOol00`00Oomoo`1gOol00`00Oomoo`0DOol00`00Oomoo`0b
Ool001=oo`8002Eoo`8001Moo`03001oogoo07Moo`03001oogoo01Eoo`80039oo`004goo00<007oo
Ool08goo00<007ooOol067oo00<007ooOol0MGoo00<007ooOol067oo00<007ooOol0;goo000COol0
0`00Oomoo`0SOol00`00Oomoo`0IOol00`00Oomoo`1cOol00`00Oomoo`0IOol00`00Oomoo`0_Ool0
01=oo`03001oogoo029oo`03001oogoo01]oo`03001oogoo075oo`03001oogoo01]oo`03001oogoo
02ioo`004goo0P008goo00<007ooOol06goo00<007ooOol0LGoo00<007ooOol06goo00<007ooOol0
;Woo000COol00`00Oomoo`0QOol00`00Oomoo`0MOol00`00Oomoo`1_Ool00`00Oomoo`0MOol00`00
Oomoo`0]Ool001=oo`03001oogoo025oo`03001oogoo01ioo`03001oogoo06eoo`03001oogoo01io
o`03001oogoo02eoo`004goo00<007ooOol087oo00<007ooOol07goo00<007ooOol0KGoo00<007oo
Ool07goo00<007ooOol0;7oo000COol00`00Oomoo`0POol00`00Oomoo`0POol00`00Oomoo`1[Ool0
0`00Oomoo`0POol00`00Oomoo`0/Ool001=oo`80021oo`03001oogoo029oo`03001oogoo06Uoo`03
001oogoo029oo`03001oogoo02]oo`004goo00<007ooOol07goo00<007ooOol08Woo00<007ooOol0
JGoo00<007ooOol08Woo00<007ooOol0:goo000=Ool30003Ool00`00Oomoo`0NOol00`00Oomoo`0T
Ool00`00Oomoo`1WOol00`00Oomoo`0TOol00`00Oomoo`0ZOol000ioo`03001oogoo009oo`03001o
ogoo01ioo`03001oogoo02Eoo`03001oogoo06Eoo`03001oogoo02Eoo`03001oogoo02Yoo`0037oo
10000goo0`007Goo00<007ooOol09goo00<007ooOol0Hgoo00<007ooOol09goo00<007ooOol0:Goo
000<Ool00`00Ool00004Ool00`00Oomoo`0MOol00`00Oomoo`0WOol00`00Oomoo`1SOol00`00Oomo
o`0WOol00`00Oomoo`0YOol000eoo`8000Aoo`03001oogoo01aoo`03001oogoo02Uoo`03001oogoo
065oo`03001oogoo02Qoo`03001oogoo02Uoo`003Woo00<007ooOol00Woo00<007ooOol077oo00<0
07ooOol0:Goo00<007ooOol0HGoo00<007ooOol0:Goo00<007ooOol0:7oo000COol00`00Oomoo`0L
Ool00`00Oomoo`0ZOol00`00Oomoo`1OOol00`00Oomoo`0ZOol00`00Oomoo`0XOol001=oo`8001ao
o`03001oogoo02]oo`03001oogoo05moo`03001oogoo02]oo`03001oogoo02Moo`004goo00<007oo
Ool06goo00<007ooOol0;7oo00<007ooOol0GGoo00<007ooOol0;7oo00<007ooOol09goo000COol0
0`00Oomoo`0JOol00`00Oomoo`0]Ool00`00Oomoo`1MOol00`00Oomoo`0]Ool00`00Oomoo`0VOol0
01=oo`03001oogoo01Yoo`03001oogoo02ioo`03001oogoo05]oo`03001oogoo02ioo`03001oogoo
02Ioo`004goo0P006Woo00<007ooOol0;goo00<007ooOol0Fgoo00<007ooOol0;goo00<007ooOol0
9Goo000COol00`00Oomoo`0IOol00`00Oomoo`0_Ool00`00Oomoo`1KOol00`00Oomoo`0_Ool00`00
Oomoo`0UOol001=oo`03001oogoo01Qoo`03001oogoo035oo`03001oogoo05Uoo`03001oogoo035o
o`03001oogoo02Aoo`004goo00<007ooOol067oo00<007ooOol0<Goo00<007ooOol0FGoo00<007oo
Ool0<Goo00<007ooOol097oo000COol2000HOol00`00Oomoo`0cOol00`00Oomoo`1GOol00`00Oomo
o`0cOol00`00Oomoo`0SOol001=oo`03001oogoo01Moo`03001oogoo03=oo`03001oogoo05Moo`03
001oogoo03=oo`03001oogoo02=oo`004goo00<007ooOol05Woo00<007ooOol0=7oo00<007ooOol0
Egoo00<007ooOol0=7oo00<007ooOol08Woo000COol00`00Oomoo`0FOol00`00Oomoo`0eOol00`00
Oomoo`1EOol00`00Oomoo`0eOol00`00Oomoo`0ROol001=oo`03001oogoo01Ioo`03001oogoo03Eo
o`03001oogoo05Eoo`03001oogoo03Eoo`03001oogoo029oo`004goo0P005goo00<007ooOol0=Woo
00<007ooOol0Dgoo00<007ooOol0=Woo00<007ooOol08Woo000COol00`00Oomoo`0EOol00`00Oomo
o`0gOol00`00Oomoo`1COol00`00Oomoo`0gOol00`00Oomoo`0QOol000eoo`03001oogoo00=oo`03
001oogoo01Eoo`03001oogoo03Qoo`03001oogoo055oo`03001oogoo03Qoo`03001oogoo025oo`00
37oo00<007oo000017oo00<007ooOol05Goo00<007ooOol0>7oo00<007ooOol0DGoo00<007ooOol0
>7oo00<007ooOol08Goo000>Ool00`00Oomoo`02Ool3000EOol00`00Oomoo`0hOol00`00Oomoo`1A
Ool00`00Oomoo`0hOol00`00Oomoo`0QOol000aoo`8000Eoo`03001oogoo01Eoo`03001oogoo03Uo
o`03001oogoo04moo`03001oogoo03Uoo`03001oogoo025oo`0037oo00<007ooOol017oo00<007oo
Ool057oo00<007ooOol0>Woo00<007ooOol0Cgoo00<007ooOol0>Woo00<007ooOol087oo000<Ool3
0004Ool00`00Oomoo`0DOol00`00Oomoo`0kOol00`00Oomoo`1=Ool00`00Oomoo`0kOol00`00Oomo
o`0POol001=oo`03001oogoo01Aoo`03001oogoo03]oo`03001oogoo04eoo`03001oogoo03]oo`03
001oogoo021oo`004goo0P005Goo00<007ooOol0>goo00<007ooOol0CGoo00<007ooOol0>goo00<0
07ooOol087oo000COol00`00Oomoo`0DOol00`00Oomoo`0lOol00`00Oomoo`1;Ool00`00Oomoo`0l
Ool00`00Oomoo`0POol001=oo`03001oogoo01=oo`03001oogoo03eoo`03001oogoo04]oo`03001o
ogoo03eoo`03001oogoo01moo`004goo00<007ooOol04goo00<007ooOol0?Woo00<007ooOol0BGoo
00<007ooOol0?Woo00<007ooOol07goo000COol2000DOol00`00Oomoo`0nOol00`00Oomoo`19Ool0
0`00Oomoo`0nOol00`00Oomoo`0OOol001=oo`03001oogoo01=oo`03001oogoo03moo`03001oogoo
04Moo`03001oogoo03moo`03001oogoo01moo`004goo00<007ooOol04goo00<007ooOol0?goo00<0
07ooOol0Agoo00<007ooOol0?goo00<007ooOol07goo000COol00`00Oomoo`0COol00`00Oomoo`0o
Ool00`00Oomoo`17Ool00`00Oomoo`0oOol00`00Oomoo`0OOol001=oo`03001oogoo019oo`03001o
ogoo045oo`03001oogoo04Eoo`03001oogoo045oo`03001oogoo01ioo`004goo0P004goo00<007oo
Ool0@Goo00<007ooOol0AGoo00<007ooOol0@Goo00<007ooOol07Woo000COol00`00Oomoo`0BOol0
0`00Oomoo`11Ool00`00Oomoo`15Ool00`00Oomoo`11Ool00`00Oomoo`0NOol001=oo`03001oogoo
019oo`03001oogoo045oo`03001oogoo04Eoo`03001oogoo045oo`03001oogoo01ioo`004goo00<0
07ooOol04Woo00<007ooOol0@Woo00<007ooOol0@goo00<007ooOol0@Woo00<007ooOol07Woo000C
Ool2000BOol00`00Oomoo`13Ool00`00Oomoo`13Ool00`00Oomoo`13Ool00`00Oomoo`0MOol001=o
o`03001oogoo015oo`03001oogoo04=oo`03001oogoo04=oo`03001oogoo04=oo`03001oogoo01eo
o`004goo00<007ooOol04Goo00<007ooOol0A7oo00<007ooOol0@Goo00<007ooOol0A7oo00<007oo
Ool07Goo000<Ool20005Ool00`00Oomoo`0AOol00`00Oomoo`14Ool00`00Oomoo`11Ool00`00Oomo
o`14Ool00`00Oomoo`0MOol000aoo`03001oo`0000Aoo`03001oogoo015oo`03001oogoo04Aoo`03
001oogoo045oo`03001oogoo04Aoo`03001oogoo01eoo`0037oo00<007oo000017oo0`0047oo00<0
07ooOol0AGoo00<007ooOol0@Goo00<007ooOol0AGoo00<007ooOol077oo000<Ool20005Ool00`00
Oomoo`0@Ool00`00Oomoo`16Ool00`00Oomoo`0oOol00`00Oomoo`16Ool00`00Oomoo`0LOol000ao
o`03001oogoo00Aoo`03001oogoo011oo`03001oogoo04Ioo`03001oogoo03moo`03001oogoo04Io
o`03001oogoo01aoo`003Goo0P0017oo00<007ooOol047oo00<007ooOol0AWoo00<007ooOol0?goo
00<007ooOol0AWoo00<007ooOol077oo000COol2000AOol00`00Oomoo`17Ool00`00Oomoo`0mOol0
0`00Oomoo`17Ool00`00Oomoo`0LOol001=oo`03001oogoo00moo`03001oogoo04Qoo`03001oogoo
03eoo`03001oogoo04Qoo`03001oogoo01]oo`004goo00<007ooOol03goo00<007ooOol0B7oo00<0
07ooOol0?Goo00<007ooOol0B7oo00<007ooOol06goo000COol00`00Oomoo`0?Ool00`00Oomoo`18
Ool00`00Oomoo`0mOol00`00Oomoo`18Ool00`00Oomoo`0KOol001=oo`03001oogoo00moo`03001o
ogoo04Uoo`03001oogoo03]oo`03001oogoo04Uoo`03001oogoo01]oo`004goo0P0047oo00<007oo
Ool0BGoo00<007ooOol0>goo00<007ooOol0BGoo00<007ooOol06goo000COol00`00Oomoo`0>Ool0
0`00Oomoo`1:Ool00`00Oomoo`0kOol00`00Oomoo`1:Ool00`00Oomoo`0JOol001=oo`03001oogoo
00ioo`03001oogoo04]oo`03001oogoo03Uoo`03001oogoo04]oo`03001oogoo01Yoo`004goo00<0
07ooOol03Woo00<007ooOol0Bgoo00<007ooOol0>Goo00<007ooOol0Bgoo00<007ooOol06Woo000C
Ool2000?Ool00`00Oomoo`1;Ool00`00Oomoo`0iOol00`00Oomoo`1;Ool00`00Oomoo`0JOol001=o
o`03001oogoo00ioo`03001oogoo04]oo`03001oogoo03Uoo`03001oogoo04]oo`03001oogoo01Yo
o`004goo00<007ooOol03Goo00<007ooOol0CGoo00<007ooOol0=goo00<007ooOol0CGoo00<007oo
Ool06Goo000COol00`00Oomoo`0=Ool00`00Oomoo`1=Ool00`00Oomoo`0gOol00`00Oomoo`1=Ool0
0`00Oomoo`0IOol001=oo`03001oogoo00eoo`03001oogoo04eoo`03001oogoo03Moo`03001oogoo
04eoo`03001oogoo01Uoo`004goo0P003Woo00<007ooOol0CWoo00<007ooOol0=Goo00<007ooOol0
CWoo00<007ooOol06Goo000COol00`00Oomoo`0=Ool00`00Oomoo`1>Ool00`00Oomoo`0eOol00`00
Oomoo`1>Ool00`00Oomoo`0IOol000eoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo04io
o`03001oogoo03Eoo`03001oogoo04ioo`03001oogoo01Uoo`003Goo00<007ooOol00goo00<007oo
Ool037oo00<007ooOol0Cgoo00<007ooOol0=Goo00<007ooOol0Cgoo00<007ooOol067oo000=Ool0
0`00Oomoo`03Ool3000<Ool00`00Oomoo`1@Ool00`00Oomoo`0cOol00`00Oomoo`1@Ool00`00Oomo
o`0HOol000ioo`03001oogoo009oo`03001oogoo00aoo`03001oogoo051oo`03001oogoo03=oo`03
001oogoo051oo`03001oogoo01Qoo`0037oo00<007oo000017oo00<007ooOol037oo00<007ooOol0
D7oo00<007ooOol0<goo00<007ooOol0D7oo00<007ooOol067oo000<Ool30004Ool00`00Oomoo`0<
Ool00`00Oomoo`1AOol00`00Oomoo`0aOol00`00Oomoo`1AOol00`00Oomoo`0HOol001=oo`03001o
ogoo00]oo`03001oogoo059oo`03001oogoo035oo`03001oogoo059oo`03001oogoo01Moo`004goo
0P0037oo00<007ooOol0DWoo00<007ooOol0<Goo00<007ooOol0DWoo00<007ooOol05goo000COol0
0`00Oomoo`0;Ool00`00Oomoo`1BOol00`00Oomoo`0aOol00`00Oomoo`1BOol00`00Oomoo`0GOol0
01=oo`03001oogoo00]oo`03001oogoo05=oo`03001oogoo02moo`03001oogoo05=oo`03001oogoo
01Moo`004goo00<007ooOol02goo00<007ooOol0Dgoo00<007ooOol0;goo00<007ooOol0Dgoo00<0
07ooOol05goo000COol2000;Ool00`00Oomoo`1DOol00`00Oomoo`0_Ool00`00Oomoo`1DOol00`00
Oomoo`0FOol001=oo`03001oogoo00Yoo`03001oogoo05Eoo`03001oogoo02eoo`03001oogoo05Eo
o`03001oogoo01Ioo`004goo00<007ooOol02Woo00<007ooOol0EGoo00<007ooOol0;Goo00<007oo
Ool0EGoo00<007ooOol05Woo000COol00`00Oomoo`0:Ool00`00Oomoo`1EOol00`00Oomoo`0]Ool0
0`00Oomoo`1EOol00`00Oomoo`0FOol001=oo`8000]oo`03001oogoo05Ioo`03001oogoo02]oo`03
001oogoo05Ioo`03001oogoo01Ioo`004goo00<007ooOol02Goo00<007ooOol0Egoo00<007ooOol0
:goo00<007ooOol0Egoo00<007ooOol05Goo000COol00`00Oomoo`09Ool00`00Oomoo`1GOol00`00
Oomoo`0[Ool00`00Oomoo`1GOol00`00Oomoo`0EOol001=oo`03001oogoo00Uoo`03001oogoo05Qo
o`03001oogoo02Uoo`03001oogoo05Qoo`03001oogoo01Eoo`004goo00<007ooOol02Goo00<007oo
Ool0F7oo00<007ooOol0:Goo00<007ooOol0F7oo00<007ooOol05Goo000COol20009Ool00`00Oomo
o`1IOol00`00Oomoo`0YOol00`00Oomoo`1IOol00`00Oomoo`0DOol001=oo`03001oogoo00Qoo`03
001oogoo05Uoo`03001oogoo02Uoo`03001oogoo05Uoo`03001oogoo01Aoo`003Goo00<007ooOol0
0goo00<007ooOol027oo00<007ooOol0FWoo00<007ooOol09goo00<007ooOol0FWoo00<007ooOol0
57oo000<Ool00`00Ool00004Ool00`00Oomoo`08Ool00`00Oomoo`1JOol00`00Oomoo`0WOol00`00
Oomoo`1JOol00`00Oomoo`0DOol000aoo`03001oo`0000Aoo`<000Moo`03001oogoo05]oo`03001o
ogoo02Moo`03001oogoo05]oo`03001oogoo01=oo`003Goo00<007ooOol00goo00<007ooOol01goo
00<007ooOol0G7oo00<007ooOol09Goo00<007ooOol0G7oo00<007ooOol04goo000<Ool00`00Ool0
0004Ool00`00Oomoo`07Ool00`00Oomoo`1LOol00`00Oomoo`0UOol00`00Oomoo`1LOol00`00Oomo
o`0COol000eoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo05aoo`03001oogoo02Eoo`03
001oogoo05aoo`03001oogoo01=oo`004goo00<007ooOol01goo00<007ooOol0GGoo00<007ooOol0
8goo00<007ooOol0GGoo00<007ooOol04goo000COol20007Ool00`00Oomoo`1NOol00`00Oomoo`0S
Ool00`00Oomoo`1NOol00`00Oomoo`0BOol001=oo`03001oogoo00Ioo`03001oogoo05ioo`03001o
ogoo02=oo`03001oogoo05ioo`03001oogoo019oo`004goo00<007ooOol01Woo00<007ooOol0Ggoo
00<007ooOol08Goo00<007ooOol0Ggoo00<007ooOol04Woo000COol00`00Oomoo`06Ool00`00Oomo
o`1OOol00`00Oomoo`0QOol00`00Oomoo`1OOol00`00Oomoo`0BOol001=oo`8000Ioo`03001oogoo
061oo`03001oogoo025oo`03001oogoo061oo`03001oogoo015oo`004goo00<007ooOol01Goo00<0
07ooOol0HGoo00<007ooOol07goo00<007ooOol0HGoo00<007ooOol04Goo000COol00`00Oomoo`05
Ool00`00Oomoo`1QOol00`00Oomoo`0OOol00`00Oomoo`1QOol00`00Oomoo`0AOol001=oo`03001o
ogoo00Eoo`03001oogoo065oo`03001oogoo01moo`03001oogoo065oo`03001oogoo015oo`004goo
00<007ooOol017oo00<007ooOol0Hgoo00<007ooOol07Goo00<007ooOol0Hgoo00<007ooOol047oo
000COol20005Ool00`00Oomoo`1SOol00`00Oomoo`0MOol00`00Oomoo`1SOol00`00Oomoo`0@Ool0
01=oo`03001oogoo00Aoo`03001oogoo06=oo`03001oogoo01eoo`03001oogoo06=oo`03001oogoo
011oo`004goo00<007ooOol017oo00<007ooOol0I7oo00<007ooOol06goo00<007ooOol0I7oo00<0
07ooOol047oo000COol00`00Oomoo`03Ool00`00Oomoo`1UOol00`00Oomoo`0KOol00`00Oomoo`1T
Ool00`00Oomoo`0@Ool001=oo`8000Aoo`03001oogoo06Eoo`03001oogoo01]oo`03001oogoo06Eo
o`03001oogoo00moo`004goo00<007ooOol00goo00<007ooOol0IGoo00<007ooOol06goo00<007oo
Ool0IGoo00<007ooOol03goo000COol00`00Oomoo`03Ool00`00Oomoo`1VOol00`00Oomoo`0IOol0
0`00Oomoo`1VOol00`00Oomoo`0?Ool000aoo`8000Eoo`03001oogoo00=oo`03001oogoo06Ioo`03
001oogoo01Uoo`03001oogoo06Ioo`03001oogoo00moo`003Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0Igoo00<007ooOol06Goo00<007ooOol0Igoo00<007ooOol03Woo000=Ool20004
Ool30002Ool00`00Oomoo`1XOol00`00Oomoo`0GOol00`00Oomoo`1XOol00`00Oomoo`0>Ool000ao
o`03001oo`0000Aoo`03001oogoo009oo`03001oogoo06Qoo`03001oogoo01Moo`03001oogoo06Qo
o`03001oogoo00ioo`0037oo00<007oo000017oo00<007ooOol00Woo00<007ooOol0J7oo00<007oo
Ool05goo00<007ooOol0J7oo00<007ooOol03Woo000=Ool20004Ool01@00Oomoogoo0000K7oo00<0
07ooOol05Goo00<007ooOol0JWoo00<007ooOol03Goo000COol20002Ool00`00Oomoo`1ZOol00`00
Oomoo`0EOol00`00Oomoo`1ZOol00`00Oomoo`0=Ool001=oo`05001oogooOol0001]Ool00`00Oomo
o`0COol00`00Oomoo`1[Ool00`00Oomoo`0=Ool001=oo`05001oogooOol0001]Ool00`00Oomoo`0C
Ool00`00Oomoo`1[Ool00`00Oomoo`0=Ool001=oo`04001oogoo001_Ool00`00Oomoo`0AOol00`00
Oomoo`1]Ool00`00Oomoo`0<Ool001=oo`04001oogoo001`Ool00`00Oomoo`0?Ool00`00Oomoo`1^
Ool00`00Oomoo`0<Ool001=oo`800003Ool007oo06moo`03001oogoo00moo`03001oogoo06ioo`03
001oogoo00aoo`004goo00@007ooOol0075oo`03001oogoo00eoo`03001oogoo06moo`03001oogoo
00aoo`004goo00@007ooOol0079oo`03001oogoo00]oo`03001oogoo071oo`03001oogoo00aoo`00
4goo00<007oo0000Lgoo00<007ooOol02goo00<007ooOol0LGoo00<007ooOol02goo000COol3001d
Ool00`00Oomoo`09Ool00`00Oomoo`1bOol00`00Oomoo`0;Ool001=oo`03001oo`0007Eoo`03001o
ogoo00Moo`03001oogoo07=oo`03001oogoo00]oo`004goo00<007oo0000MGoo00<007ooOol01goo
00<007ooOol0Lgoo00<007ooOol02goo000COol2001gOol00`00Oomoo`05Ool00`00Oomoo`1eOol0
0`00Oomoo`0:Ool001=oo`8007Qoo`03001oogoo00=oo`03001oogoo07Ioo`03001oogoo00Yoo`00
4goo0P00N7oo00<007ooOol00goo00<007ooOol0MWoo00<007ooOol02Woo000COol2001iOol01@00
Oomoogoo0000NGoo00<007ooOol02Woo0006Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`1iOol0
0`00Ool0001kOol00`00Oomoo`09Ool000Qoo`07001oogooOol007oo000017oo00<007ooOol0NGoo
00<007oo0000Ngoo00<007ooOol02Goo0008Ool01`00Oomoogoo001oo`0000Aoo`<007Yoo`03001o
ogoo07Yoo`03001oogoo00Uoo`0027oo00L007ooOomoo`00Ool00004Ool00`00Oomoo`3oOol4Ool0
00Qoo`07001oogooOol007oo000017oo00<007ooOol0ogoo17oo0007Ool20004Ool00`00Oomoo`03
Ool00`00Oomoo`3oOol4Ool001=oo`03001oogoo0?moo`Aoo`00\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-0.0802027, 2.45028, 0.00401466, 
  0.0448058}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " packages."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph:=Graphics[{\n  Thickness[.01],\n  \
Line[{{1,-2.2},{0,0},{-1,-2.2},{5.5,-2.2},{5.5,-.25},{1.5,-.25}}],\n  \
{Thickness[.02],RGBColor[1,0,0],\n   Disk[{0,0},.5],Edge[crank, {0,{1,0}}],\n \
  RGBColor[0,1,0],Edge[{Point[crank,{1,0}],Point[slider,0]}],\n   \
RGBColor[0,0,1],Box[slider,{{-0.5,-.25},{0.5,.25}}]},\n  \
PointSize[.02],Point[Location[slider,0]],Point[{0,0}],\n  \
Thickness[.002],LocalAxes[{crank,slider}, 1]},\n  AspectRatio \[Rule] \
Automatic,PlotRange \[Rule] {{-2.3,6.3},{-2.3,2.3}}]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["10.3  Free Acceleration"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the use of the ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to build the dynamic equations of motion of an underconstrained \
model, and the use of the ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to find the instantaneous free acceleration. To find the \
time-domain free response of an underconstrained model, the free acceleration \
is integrated with respect to time. Integration of the equations of motion is \
covered in Section 10.4. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A model of a two-link planar robot arm is developed to demonstrate the use \
of ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to find the instantaneous free acceleration of a mechanism. The robot arm \
has a force of unit magnitude, but varying direction, applied to the tip of \
the second link, while the two revolute joints in the arm are free to rotate. \
By finding the acceleration vector of the tip that results from a 1-unit \
applied force at a particular configuration of the arm, the \"ellipse of \
mobility\" can be plotted.\n\nOf the four constraints that make up the robot \
arm model, two are ",
  StyleBox["Revolute2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints that model the joints between the ground and link 1, and \
between link 1 and link 2. The other two ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints are present only to set up the initial position of the arm. \
They are dropped by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to provide two unconstrained degrees of freedom. The parameter ",
  StyleBox["loadangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to change the direction of the applied load at the tip of link 2. \
"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and defines names for each of the body numbers."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(link1 = 2; \)\), 
    \(\(link2 = 3; \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints, bodies, and loads for the robot arm model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SetParameters[loadangle \[Rule] 0]; \)\), 
    \(SetConstraints[\n\t
      Revolute2[1, Point[ground, 0], Point[link1, {\(-3\), 0}]], \n\t
      Revolute2[2, Point[link1, {3, 0}], Point[link2, {3, 0}]], \n\t
      RelativeAngle1[3, Vector[link1, {1, 0}], \[Pi]/6.0], \n\t
      RelativeAngle1[4, Vector[link2, {\(-1\), 0}], Vector[link1, {1, 0}], 
        2\ \[Pi]/3.0]]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[link1, Mass \[Rule] 1.0, Inertia \[Rule] 3.0, 
        InitialGuess \[Rule] {{3, 1}, 0.5}], \n\t
      Body[link2, Mass \[Rule] 1.0, Inertia \[Rule] 3.0, 
        InitialGuess \[Rule] {{3, 3}, \(-0.5\)}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[\n\t
      Force[link2, 
        Axis[link2, {\(-3\), 0}, ground, PolarToXY[{1, loadangle}]], 1, 
        Magnitude \[Rule] Relative]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run with the ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Kinematic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option so that initial conditions are available for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Here is the reaction torque applied by the locked joint between t",
  StyleBox["he ground and link 1.",
    FontFamily->"Times"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[3, link1] /. SolveMech[Solution \[Rule] Kinematic]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({{0, 0}, 6.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the robot arm at its initial configuration."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .72727 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.363636 0.0909091 0.0909091 0.0909091 [
[(-2)] .18182 0 0 2 Msboxa
[(0)] .36364 0 0 2 Msboxa
[(2)] .54545 0 0 2 Msboxa
[(4)] .72727 0 0 2 Msboxa
[(6)] .90909 0 0 2 Msboxa
[(-1)] -0.0125 0 1 0 Msboxa
[(0)] -0.0125 .09091 1 0 Msboxa
[(1)] -0.0125 .18182 1 0 Msboxa
[(2)] -0.0125 .27273 1 0 Msboxa
[(3)] -0.0125 .36364 1 0 Msboxa
[(4)] -0.0125 .45455 1 0 Msboxa
[(5)] -0.0125 .54545 1 0 Msboxa
[(6)] -0.0125 .63636 1 0 Msboxa
[(7)] -0.0125 .72727 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .72827 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(-2)] .18182 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(0)] .36364 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(2)] .54545 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(4)] .72727 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(6)] .90909 0 0 2 Mshowa
p
.001 w
.03636 0 m
.03636 .00375 L
s
P
p
.001 w
.07273 0 m
.07273 .00375 L
s
P
p
.001 w
.10909 0 m
.10909 .00375 L
s
P
p
.001 w
.14545 0 m
.14545 .00375 L
s
P
p
.001 w
.21818 0 m
.21818 .00375 L
s
P
p
.001 w
.25455 0 m
.25455 .00375 L
s
P
p
.001 w
.29091 0 m
.29091 .00375 L
s
P
p
.001 w
.32727 0 m
.32727 .00375 L
s
P
p
.001 w
.4 0 m
.4 .00375 L
s
P
p
.001 w
.43636 0 m
.43636 .00375 L
s
P
p
.001 w
.47273 0 m
.47273 .00375 L
s
P
p
.001 w
.50909 0 m
.50909 .00375 L
s
P
p
.001 w
.58182 0 m
.58182 .00375 L
s
P
p
.001 w
.61818 0 m
.61818 .00375 L
s
P
p
.001 w
.65455 0 m
.65455 .00375 L
s
P
p
.001 w
.69091 0 m
.69091 .00375 L
s
P
p
.001 w
.76364 0 m
.76364 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.83636 0 m
.83636 .00375 L
s
P
p
.001 w
.87273 0 m
.87273 .00375 L
s
P
p
.001 w
.94545 0 m
.94545 .00375 L
s
P
p
.001 w
.98182 0 m
.98182 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-1)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .09091 m
.00625 .09091 L
s
P
[(0)] -0.0125 .09091 1 0 Mshowa
p
.002 w
0 .18182 m
.00625 .18182 L
s
P
[(1)] -0.0125 .18182 1 0 Mshowa
p
.002 w
0 .27273 m
.00625 .27273 L
s
P
[(2)] -0.0125 .27273 1 0 Mshowa
p
.002 w
0 .36364 m
.00625 .36364 L
s
P
[(3)] -0.0125 .36364 1 0 Mshowa
p
.002 w
0 .45455 m
.00625 .45455 L
s
P
[(4)] -0.0125 .45455 1 0 Mshowa
p
.002 w
0 .54545 m
.00625 .54545 L
s
P
[(5)] -0.0125 .54545 1 0 Mshowa
p
.002 w
0 .63636 m
.00625 .63636 L
s
P
[(6)] -0.0125 .63636 1 0 Mshowa
p
.002 w
0 .72727 m
.00625 .72727 L
s
P
[(7)] -0.0125 .72727 1 0 Mshowa
p
.001 w
0 .01818 m
.00375 .01818 L
s
P
p
.001 w
0 .03636 m
.00375 .03636 L
s
P
p
.001 w
0 .05455 m
.00375 .05455 L
s
P
p
.001 w
0 .07273 m
.00375 .07273 L
s
P
p
.001 w
0 .10909 m
.00375 .10909 L
s
P
p
.001 w
0 .12727 m
.00375 .12727 L
s
P
p
.001 w
0 .14545 m
.00375 .14545 L
s
P
p
.001 w
0 .16364 m
.00375 .16364 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .21818 m
.00375 .21818 L
s
P
p
.001 w
0 .23636 m
.00375 .23636 L
s
P
p
.001 w
0 .25455 m
.00375 .25455 L
s
P
p
.001 w
0 .29091 m
.00375 .29091 L
s
P
p
.001 w
0 .30909 m
.00375 .30909 L
s
P
p
.001 w
0 .32727 m
.00375 .32727 L
s
P
p
.001 w
0 .34545 m
.00375 .34545 L
s
P
p
.001 w
0 .38182 m
.00375 .38182 L
s
P
p
.001 w
0 .4 m
.00375 .4 L
s
P
p
.001 w
0 .41818 m
.00375 .41818 L
s
P
p
.001 w
0 .43636 m
.00375 .43636 L
s
P
p
.001 w
0 .47273 m
.00375 .47273 L
s
P
p
.001 w
0 .49091 m
.00375 .49091 L
s
P
p
.001 w
0 .50909 m
.00375 .50909 L
s
P
p
.001 w
0 .52727 m
.00375 .52727 L
s
P
p
.001 w
0 .56364 m
.00375 .56364 L
s
P
p
.001 w
0 .58182 m
.00375 .58182 L
s
P
p
.001 w
0 .6 m
.00375 .6 L
s
P
p
.001 w
0 .61818 m
.00375 .61818 L
s
P
p
.001 w
0 .65455 m
.00375 .65455 L
s
P
p
.001 w
0 .67273 m
.00375 .67273 L
s
P
p
.001 w
0 .69091 m
.00375 .69091 L
s
P
p
.001 w
0 .70909 m
.00375 .70909 L
s
P
p
.002 w
0 0 m
0 .72727 L
s
P
P
p
p
.002 w
0 .72102 m
0 .72727 L
s
P
p
.002 w
.18182 .72102 m
.18182 .72727 L
s
P
p
.002 w
.36364 .72102 m
.36364 .72727 L
s
P
p
.002 w
.54545 .72102 m
.54545 .72727 L
s
P
p
.002 w
.72727 .72102 m
.72727 .72727 L
s
P
p
.002 w
.90909 .72102 m
.90909 .72727 L
s
P
p
.001 w
.03636 .72352 m
.03636 .72727 L
s
P
p
.001 w
.07273 .72352 m
.07273 .72727 L
s
P
p
.001 w
.10909 .72352 m
.10909 .72727 L
s
P
p
.001 w
.14545 .72352 m
.14545 .72727 L
s
P
p
.001 w
.21818 .72352 m
.21818 .72727 L
s
P
p
.001 w
.25455 .72352 m
.25455 .72727 L
s
P
p
.001 w
.29091 .72352 m
.29091 .72727 L
s
P
p
.001 w
.32727 .72352 m
.32727 .72727 L
s
P
p
.001 w
.4 .72352 m
.4 .72727 L
s
P
p
.001 w
.43636 .72352 m
.43636 .72727 L
s
P
p
.001 w
.47273 .72352 m
.47273 .72727 L
s
P
p
.001 w
.50909 .72352 m
.50909 .72727 L
s
P
p
.001 w
.58182 .72352 m
.58182 .72727 L
s
P
p
.001 w
.61818 .72352 m
.61818 .72727 L
s
P
p
.001 w
.65455 .72352 m
.65455 .72727 L
s
P
p
.001 w
.69091 .72352 m
.69091 .72727 L
s
P
p
.001 w
.76364 .72352 m
.76364 .72727 L
s
P
p
.001 w
.8 .72352 m
.8 .72727 L
s
P
p
.001 w
.83636 .72352 m
.83636 .72727 L
s
P
p
.001 w
.87273 .72352 m
.87273 .72727 L
s
P
p
.001 w
.94545 .72352 m
.94545 .72727 L
s
P
p
.001 w
.98182 .72352 m
.98182 .72727 L
s
P
p
.002 w
0 .72727 m
1 .72727 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .09091 m
1 .09091 L
s
P
p
.002 w
.99375 .18182 m
1 .18182 L
s
P
p
.002 w
.99375 .27273 m
1 .27273 L
s
P
p
.002 w
.99375 .36364 m
1 .36364 L
s
P
p
.002 w
.99375 .45455 m
1 .45455 L
s
P
p
.002 w
.99375 .54545 m
1 .54545 L
s
P
p
.002 w
.99375 .63636 m
1 .63636 L
s
P
p
.001 w
.99625 .01818 m
1 .01818 L
s
P
p
.001 w
.99625 .03636 m
1 .03636 L
s
P
p
.001 w
.99625 .05455 m
1 .05455 L
s
P
p
.001 w
.99625 .07273 m
1 .07273 L
s
P
p
.001 w
.99625 .10909 m
1 .10909 L
s
P
p
.001 w
.99625 .12727 m
1 .12727 L
s
P
p
.001 w
.99625 .14545 m
1 .14545 L
s
P
p
.001 w
.99625 .16364 m
1 .16364 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .21818 m
1 .21818 L
s
P
p
.001 w
.99625 .23636 m
1 .23636 L
s
P
p
.001 w
.99625 .25455 m
1 .25455 L
s
P
p
.001 w
.99625 .29091 m
1 .29091 L
s
P
p
.001 w
.99625 .30909 m
1 .30909 L
s
P
p
.001 w
.99625 .32727 m
1 .32727 L
s
P
p
.001 w
.99625 .34545 m
1 .34545 L
s
P
p
.001 w
.99625 .38182 m
1 .38182 L
s
P
p
.001 w
.99625 .4 m
1 .4 L
s
P
p
.001 w
.99625 .41818 m
1 .41818 L
s
P
p
.001 w
.99625 .43636 m
1 .43636 L
s
P
p
.001 w
.99625 .47273 m
1 .47273 L
s
P
p
.001 w
.99625 .49091 m
1 .49091 L
s
P
p
.001 w
.99625 .50909 m
1 .50909 L
s
P
p
.001 w
.99625 .52727 m
1 .52727 L
s
P
p
.001 w
.99625 .56364 m
1 .56364 L
s
P
p
.001 w
.99625 .58182 m
1 .58182 L
s
P
p
.001 w
.99625 .6 m
1 .6 L
s
P
p
.001 w
.99625 .61818 m
1 .61818 L
s
P
p
.001 w
.99625 .65455 m
1 .65455 L
s
P
p
.001 w
.99625 .67273 m
1 .67273 L
s
P
p
.001 w
.99625 .69091 m
1 .69091 L
s
P
p
.001 w
.99625 .70909 m
1 .70909 L
s
P
p
.002 w
1 0 m
1 .72727 L
s
P
P
p
P
0 0 m
1 0 L
1 .72727 L
0 .72727 L
closepath
clip
newpath
p
.36364 .09091 m
.45455 0 L
.27273 0 L
F
p
1 0 0 r
.34545 .1224 m
.38182 .05942 L
.8542 .33214 L
.81783 .39513 L
F
0 0 1 r
.81783 .33214 m
.8542 .39513 L
.38182 .66786 L
.34545 .60487 L
F
P
p
16 Mabswid
.36364 .63636 Mdot
.83601 .36364 Mdot
P
16 Mabswid
.36364 .09091 Mdot
p
p
.015 w
.13636 .63636 m
.31818 .63636 L
s
.29247 .61065 m
.31818 .63636 L
.29247 .66208 L
s
P
P
p
/Times-Bold findfont 16 scalefont setfont
[(F)] .22727 .54545 0 0 Mshowa
P
p
p
p
/Courier findfont 8 scalefont setfont
[(x)] .75728 .31818 -0.54904 -1.22942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .50892 .38473 -0.54904 -1.22942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(2)] .59983 .22727 -0.54904 -1.22942 Mshowa
P
.004 w
.75728 .31818 m
.59983 .22727 L
.50892 .38473 L
s
.73488 .28425 m
.75728 .31818 L
.7167 .31575 L
s
.51135 .34415 m
.50892 .38473 L
.54284 .36233 L
s
P
p
p
/Courier findfont 8 scalefont setfont
[(x)] .75728 .40909 -2.04904 -0.32942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(y)] .69073 .65746 -2.04904 -0.32942 Mshowa
P
p
/Courier findfont 8 scalefont setfont
[(3)] .59983 .5 -2.04904 -0.32942 Mshowa
P
.004 w
.75728 .40909 m
.59983 .5 L
.69073 .65746 L
s
.7167 .41153 m
.75728 .40909 L
.73488 .44302 L
s
.65681 .63506 m
.69073 .65746 L
.6883 .61688 L
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 205},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000cA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0015Ool3000XOol00`00Oomoo`0YOol3000[Ool3000YOol2000ROol0
04Eoo`03001oogoo02Moo`03001oo`0002Yoo`03001oogoo02aoo`03001oogoo02Qoo`03001oo`00
025oo`00@7oo0`000goo00<007ooOol09Woo00<007oo0000:goo00<007ooOol0:Goo1000:Goo00<0
07oo00008Goo0016Ool00`00Oomoo`0VOol00`00Ool0000[Ool00`00Oomoo`0YOol00`00Ool0000Z
Ool2000ROol004Eoo`03001oo`0002Moo`03001oo`0002Yoo`03001oo`0002]oo`8002Yoo`03001o
ogoo025oo`00AWoo00<007ooOol09goo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Goo
0P008Goo003oOolKOol00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000?Ool5
003oOol7Ool0015oo`03001oogoo0?moo`Moo`002goo0`000goo00<007ooOol00goon0002goo000A
Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06
Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`02Ool/0005Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo
000AOol00`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`0EOolZ000HOol00`00Oomoo`0ZOol0
0`00Oomoo`0ZOol00`00Oomoo`0COol00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo04=oobP0
08Uoo`03001oogoo00Uoo`005goo00<007ooOol0A7oo9P00RWoo00<007ooOol02Goo000GOol20016
OolT002:Ool2000;Ool001Moo`03001oogoo04Ioob8008aoo`03001oogoo00Uoo`005goo00<007oo
Ool0Agoo8000SGoo00<007ooOol02Goo000GOol00`00Oomoo`18OolN002>Ool00`00Oomoo`09Ool0
01Moo`8004Yooa`008ioo`8000]oo`005goo00<007ooOol0BWoo6P00T7oo00<007ooOol02Goo000G
Ool00`00Oomoo`1;OolH002AOol00`00Oomoo`09Ool001Moo`03001oogoo04aooaH0099oo`03001o
ogoo00Uoo`005goo00<007ooOol0CGoo5000Tgoo00<007ooOol02Goo000GOol2001?OolB002COol2
000;Ool001Moo`03001oogoo04mooa0009Eoo`03001oogoo00Uoo`005goo00<007ooOol0D7oo2`00
0W`000<007ooOol0U7oo00<007ooOol02Goo000GOol00`00Oomoo`1AOol90005O02EOol00`00Oomo
o`09Ool001Moo`80059oo`/000El099oo`8000]oo`005goo00<007ooOol0DGoo2`001W`0TWoo00<0
07ooOol02Goo000GOol00`00Oomoo`1@Ool=0007O02@Ool00`00Oomoo`09Ool0015oo`03001oogoo
00=oo`03001oogoo051oo`d000Ul08ioo`03001oogoo00Uoo`0047oo00<007oo000017oo00<007oo
Ool0Cgoo3`002W`0S7oo00<007ooOol02Goo000@Ool00`00Ool00004Ool2001@Ool?000;O02:Ool2
000;Ool0011oo`03001oo`0000Aoo`03001oogoo04moo`l000el08Uoo`03001oogoo00Uoo`0047oo
00<007oo000017oo00<007ooOol0D7oo3@0047`0Qgoo00<007ooOol02Goo000AOol00`00Oomoo`03
Ool00`00Oomoo`1@Ool=000AO026Ool00`00Oomoo`09Ool001Moo`80059oo`/001Al08=oo`8000]o
o`005goo00<007ooOol0DGoo2`005W`0PWoo00<007ooOol02Goo000GOol00`00Oomoo`1COol7000J
O020Ool00`00Oomoo`09Ool001Moo`03001oogoo05=oo`9l00<001el07moo`03001oogoo00Uoo`00
5goo00<007ooOol0DWoo9G`0OGoo00<007ooOol02Goo000GOol2001EOolUO01jOol2000;Ool001Mo
o`03001oogoo05IoobAl07Yoo`03001oogoo00Uoo`005goo00<007ooOol0F7oo97`0N7oo00<007oo
Ool02Goo000GOol00`00Oomoo`1IOolUO01fOol00`00Oomoo`09Ool001Moo`8005aoobEl07=oo`80
00]oo`005goo00<007ooOol0GGoo97`0Lgoo00<007ooOol02Goo000GOol00`00Oomoo`1OOolTO01a
Ool00`00Oomoo`09Ool001Moo`03001oogoo061oobEl06moo`03001oogoo00Uoo`005goo00<007oo
Ool0HWoo9G`0KGoo00<007ooOol02Goo000GOol2001UOolTO01[Ool2000;Ool001Moo`03001oogoo
06IoobAl06Yoo`03001oogoo00Uoo`003goo1@000goo00<007ooOol0Igoo9G`0J7oo00<007ooOol0
2Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1YOolTO01WOol00`00Oomoo`09Ool0015oo`03001o
ogoo00=oo`8006aoobAl06Aoo`8000]oo`004Goo00<007ooOol00goo00<007ooOol0KGoo97`0Hgoo
00<007ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1^OolUO01QOol00`00Oomoo`09Ool0
011oo`8000Eoo`03001oogoo071oobAl061oo`03001oogoo00Uoo`005goo00<007ooOol0LWoo97`0
GWoo00<007ooOol02Goo000GOol2001eOolTO01KOol2000;Ool001Moo`03001oogoo07EoobAl05]o
o`03001oogoo00Uoo`005goo00<007ooOol0Mgoo97`0FGoo00<007ooOol02Goo000GOol00`00Oomo
o`1iOolTO01GOol00`00Oomoo`09Ool001Moo`8007aoobAl05Aoo`8000]oo`005goo00<007ooOol0
O7oo97`0E7oo00<007ooOol02Goo000GOol00`00Oomoo`1nOolTO01BOol00`00Oomoo`09Ool001Mo
o`03001oogoo081ooa5l0003001l07`0011l051oo`03001oogoo00Uoo`005goo00<007ooOol0PWoo
3W`000@007`00000015l04moo`03001oogoo00Uoo`005goo0P00Q7oo3G`000@007`0O01l0080015l
04aoo`8000]oo`005goo00<007ooOol0QGoo2W`000<007`0O00017`00P004G`0Bgoo00<007ooOol0
2Goo000GOol00`00Oomoo`27Ool8O0000`00O00000020004O0000`00O01l000@O019Ool00`00Oomo
o`09Ool001Moo`03001oogoo08Uoo`El0003001l07`0008000Il0080015l04Qoo`03001oogoo00Uo
o`005goo0P00Rgoo17`000<007`0O0000W`000<007`0O0001G`00P004G`0AGoo0P002goo000GOol0
0`00Oomoo`2<Ool00g`0001l0004O0000`00O01l0007O002000AO014Ool00`00Oomoo`09Ool001Mo
o`03001oogoo08aoo`03001oog`0009l00<000]l0080015l049oo`03001oogoo00Uoo`0047oo0`00
17oo00<007ooOol0S7oo00@007ooOomooa5l0003001l07`000ml045oo`03001oogoo00Uoo`0047oo
00<007ooOol017oo00<007ooOol0Rgoo00<007ooOol00goo4G`00P004G`0?goo00<007ooOol02Goo
000AOol00`00Oomoo`03Ool2002<Ool00`00Oomoo`05OolAO002000AO00lOol2000;Ool0015oo`03
001oogoo00=oo`03001oogoo08Yoo`03001oogoo00Qooa5l0080011l03aoo`03001oogoo00Uoo`00
47oo00<007oo000017oo00<007ooOol0RWoo00<007ooOol02Woo4G`000<007`0O0003g`0>Woo00<0
07ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`29Ool00`00Oomoo`0<OolAO0020008O000
0`00O01l0006O00hOol00`00Oomoo`09Ool001Moo`8008Yoo`03001oogoo00iooa5l008000Ml0003
001l07`000Ml03Eoo`8000]oo`005goo00<007ooOol0R7oo00<007ooOol04Goo4G`00P001G`000<0
07`0O00027`0=Goo00<007ooOol02Goo000GOol00`00Oomoo`27Ool00`00Oomoo`0DOolAO0020004
O0000`00O01l0009O00cOol00`00Oomoo`09Ool001Moo`03001oogoo08Moo`03001oogoo01Eooa9l
0005001l07`0O000000=O00aOol00`00Oomoo`09Ool001Moo`03001oogoo08Ioo`03001oogoo01Qo
oa5l0080009l0003001l07`000]l031oo`03001oogoo00Uoo`005goo0P00Qgoo00<007ooOol06Woo
4G`00P0000=l0000O0003G`0;Goo0P002goo000GOol00`00Oomoo`25Ool00`00Oomoo`0MOolAO002
000@O00/Ool00`00Oomoo`09Ool001Moo`03001oogoo08Eoo`03001oogoo01ioo`Ql00/0015l02Yo
o`03001oogoo00Uoo`005goo00<007ooOol0Q7oo00<007ooOol08Goo8g`0:Goo00<007ooOol02Goo
000GOol20024Ool00`00Oomoo`0TOolSO00VOol2000;Ool001Moo`03001oogoo08=oo`03001oogoo
02Ioob=l02Eoo`03001oogoo00Uoo`005goo00<007ooOol0PWoo00<007ooOol0:7oo2W`00P0000=l
0000O00057`097oo00<007ooOol02Goo000GOol00`00Oomoo`22Ool00`00Oomoo`0ZOol:O0000`00
O01l000:O00201l2O0030003O00TOol00`00Oomoo`09Ool001Moo`03001oogoo085oo`03001oogoo
02eoo`Ml0003001l000000Ul00@07`L002Eoo`03001oogoo00Uoo`005goo0P00O7oo00<007ooOol0
0goo00<007ooOol0;goo3g`0100O2`008Woo0P002goo000GOol00`00Oomoo`1kOol00`00Oomoo`02
Ool00`00Oomoo`0aOol=O00501l;000SOol00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo07]o
o`03001oogoo009oo`03001oogoo03=oo`Ul00H07`d0029oo`03001oogoo00Uoo`004Woo00<007oo
Ool00Woo00<007ooOol0Ngoo00D007ooOomoo`0003Qoo`El00P07`d0029oo`03001oogoo00Uoo`00
4Goo00<007ooOol00goo0P00O7oo00@007ooOol000Aoo`03001oogoo03Aoo`03O0007`0O00L07`l0
021oo`8000]oo`004Woo00<007ooOol00Woo00<007ooOol0Ngoo00@007ooOol000=oo`03001oogoo
03Eoo`X07`l0025oo`03001oogoo00Uoo`0047oo00<007oo000017oo00<007ooOol0Ngoo00<007oo
00000Woo0P00=Woo300O3`008Goo00<007ooOol02Goo000AOol00`00Oomoo`03Ool00`00Oomoo`1k
Ool01@00Ool007oo0000=Woo3`0O3@008Woo00<007ooOol02Goo000GOol00`00Oomoo`1kOol20000
0goo001oo`0dOolA01l=000ROol00`00Oomoo`09Ool001Moo`8007aoo`<003Eooa<07`/0029oo`80
00]oo`005goo00<007ooOol0Ngoo00<007ooOol0<goo5@0O2`008goo00<007ooOol02Goo000GOol0
0`00Oomoo`2_OolI01l700000`0OOomoo`0ROol00`00Oomoo`09Ool001Moo`03001oogoo07Yoo`80
035ooad07`<000<07bAoo`03001oogoo00Uoo`005goo0P00O7oo00<007ooOol0;Woo8`0O97oo0P00
2goo000GOol00`00Oomoo`1kOol00`00Oomoo`0/OolS01lWOol00`00Oomoo`09Ool001Moo`03001o
ogoo07Yoo`03001oo`0002]oob<07bUoo`03001oogoo00Uoo`005goo00<007ooOol0NWoo00@007oo
000002Qoo`P07`/000807`80000301l0000O00X07bYoo`03001oogoo00Uoo`005goo00<007ooOol0
YGoo4@0O0P001@0O00<0000O01l0200O;7oo00<007ooOol02Goo000GOol2002TOolA01l200000`0O
00007`0301l00`0001l0000701l]Ool2000;Ool001Moo`03001oogoo0:5ooa407`8000807`030000
7`0O00/07c1oo`03001oogoo00Uoo`005goo00<007ooOol0Wgoo4P0O00D0000O01l07`0000d07c5o
o`03001oogoo00Uoo`005goo00<007ooOol0WWoo4@0O0P00100O00<0000O01l02@0O<goo00<007oo
Ool02Goo000GOol2002MOolA01l2000501l00`0001l07`0801ldOol2000;Ool001Moo`03001oogoo
09Yooa407`8000L07`0300007`0O00L07cIoo`03001oogoo00Uoo`005goo00<007ooOol0V7oo4@0O
0P00200O00<0000O01l01P0O>7oo00<007ooOol02Goo000AOol30003Ool00`00Oomoo`2GOolA01l0
0`0001l07`0?01ljOol00`00Oomoo`09Ool0019oo`03001oogoo009oo`03001oogoo09Eooa407`80
01007caoo`03001oogoo00Uoo`0047oo10000goo0P00U7oo4@0O0P004@0O?7oo0P002goo000@Ool0
0`00Ool00004Ool00`00Oomoo`2AOolA01l2000A01loOol00`00Oomoo`09Ool0015oo`8000Aoo`03
001oogoo091ooa407`0300007`0O00l07d5oo`03001oogoo00Uoo`004Woo00<007ooOol00Woo00<0
07ooOol0SWoo4@0O0P004@0O@Woo00<007ooOol02Goo000GOol2002=OolA01l2000A01m3Ool2000;
Ool001Moo`03001oogoo08Yooa407`8001407dIoo`03001oogoo00Uoo`005goo00<007ooOol0RGoo
400O0P004@0OB7oo00<007ooOol02Goo000GOol00`00Oomoo`27OolA01l00`0001l07`0@01m9Ool0
0`00Oomoo`09Ool001Moo`03001oogoo08Eooa407`8001407d]oo`03001oogoo00Uoo`005goo0P00
Q7oo4@0O0P004@0OC7oo0P002goo000GOol00`00Oomoo`22Ool@01l2000A01m?Ool00`00Oomoo`09
Ool001Moo`03001oogoo081ooa407`0300007`0O01007e1oo`03001oogoo00Uoo`005goo00<007oo
Ool0OWoo500O00<0000O01l00`002P0ODWoo00<007ooOol02Goo000GOol2001mOolF01l00`0001l0
7`0201l00`0001l07`0601mCOol2000;Ool001Moo`03001oogoo07]ooaP07`0400007`0O000801mE
Ool00`00Oomoo`09Ool001Moo`03001oogoo07UooaX07`0500007`0O01l0000501mGOol00`00Oomo
o`09Ool001Moo`03001oogoo07Mooad07`@000<07eUoo`03001oogoo00Uoo`005goo00<007ooOol0
MGoo800O00@0000O01l07e]oo`03001oogoo00Uoo`005goo0P00<Goo1P00?Woo8@0O00<0000O01l0
Fgoo0P002goo000GOol00`00Oomoo`0bOol2000nOolT01l00`00Oomoo`1KOol00`00Oomoo`09Ool0
015oo`03001oogoo00=oo`03001oogoo039oo`8003aoob@07`9oo`03001oogoo05]oo`03001oogoo
00Uoo`0047oo00<007oo000017oo00<007ooOol0<Woo0P000Woo00<007ooOol0=Goo9@0O17oo00<0
07ooOol0FWoo00<007ooOol02Goo000BOol00`00Oomoo`02Ool2000cOol20002Ool00`00Oomoo`0d
OolT01l6Ool00`00Oomoo`1IOol2000;Ool0011oo`8000Eoo`03001oogoo039oo`D003Aoob@07`Uo
o`03001oogoo05Uoo`03001oogoo00Uoo`0047oo00<007ooOol017oo00<007ooOol0<Woo0P000Woo
00<007ooOol0<7oo900O37oo00<007ooOol0F7oo00<007ooOol02Goo000@Ool30004Ool00`00Oomo
o`0bOol20002Ool00`00Oomoo`0^OolU01l=Ool00`00Oomoo`1HOol00`00Oomoo`09Ool001Moo`03
001oogoo039oo`8000Aoo`03001oogoo02]oob@07a1oo`03001oogoo05Moo`03001oogoo00Uoo`00
5goo0P00<goo0P0017oo00<007ooOol0:Goo900O4Woo00<007ooOol0EWoo0P002goo000GOol00`00
Oomoo`0`Ool9000YOolU01lDOol00`00Oomoo`1FOol00`00Oomoo`09Ool001Moo`03001oogoo061o
obD07aMoo`03001oogoo05Eoo`03001oogoo00Uoo`005goo00<007ooOol0Ggoo900O6Goo00<007oo
Ool0EGoo00<007ooOol02Goo000GOol2001NOolT01lLOol00`00Oomoo`1COol2000;Ool001Moo`03
001oogoo05]oobD07aeoo`03001oogoo05Aoo`03001oogoo00Uoo`005goo00<007ooOol0FGoo9@0O
87oo00<007ooOol0Dgoo00<007ooOol02Goo000GOol00`00Oomoo`1HOolT01lSOol00`00Oomoo`1B
Ool00`00Oomoo`09Ool001Moo`03001oogoo05Ioob@07bEoo`03001oogoo059oo`03001oogoo00Uo
o`005goo0P00EGoo9@0O9goo00<007ooOol0D7oo0P002goo000GOol00`00Oomoo`1BOolU01lYOol0
0`00Oomoo`1AOol00`00Oomoo`09Ool001Moo`03001oogoo04Aoo`8000eoo`807`<001d07baoo`03
001oogoo051oo`03001oogoo00Uoo`005goo00<007ooOol0@goo100037oo1`006P0O;Woo00<007oo
Ool0Cgoo00<007ooOol02Goo000GOol20015Ool40009Ool;000F01l`Ool00`00Oomoo`02Ool00`00
Oomoo`19Ool2000;Ool001Moo`03001oogoo04Eoo`@000Qoo`/001@07c=oo`05001oogooOol0001<
Ool00`00Oomoo`09Ool001Moo`03001oogoo04Ioo`@000Ioo`d001407cEoo`05001oogooOol0001<
Ool00`00Oomoo`09Ool0011oo`8000Eoo`03001oogoo04Moo`D000Aoo`d001007cMoo`04001oogoo
001<Ool00`00Oomoo`09Ool0011oo`03001oo`0000Aoo`03001oogoo01eooc00009oo`l000d07cUo
o`04001oogoo001<Ool00`00Oomoo`09Ool0011oo`03001oo`0000Aoo`8001iooc00009oo`l000/0
7cIoo`03001oogoo00=oo`03001oo`0004]oo`8000]oo`0047oo0P001Goo00<007ooOol07Goo<000
0Woo3`002P0O>7oo0P0017oo00<007oo0000Bgoo00<007ooOol02Goo000@Ool00`00Oomoo`04Ool0
0`00Oomoo`17Ool50004Ool=000901llOol20002Ool00`00Ool0001;Ool00`00Oomoo`09Ool0015o
o`8000Aoo`03001oogoo04Ioo`@000Ioo`d000L07d1oo`800003Ool0000004]oo`03001oogoo00Uo
o`005goo0P00AWoo100027oo2`001P0OA7oo0`000Woo0P00AWoo0P002goo000GOol00`00Oomoo`14
Ool40009Ool;000501m7Ool01@00Oomoogoo0000Agoo00<007ooOol02Goo000GOol00`00Oomoo`13
Ool4000<Ool7000501m=Ool00`00Oomoo`15Ool00`00Oomoo`09Ool001Moo`03001oogoo04Aoo`80
00moo`<000=oo`807dioo`03001oo`0004Ioo`03001oogoo00Uoo`005goo00<007ooOol0Zgoo00@0
07oo000004Eoo`03001oogoo00Uoo`005goo0P00m7oo0P002goo000GOol00`00Oomoo`3dOol00`00
Oomoo`09Ool001Moo`03001oogoo0?Aoo`03001oogoo00Uoo`005goo00<007ooOol0m7oo00<007oo
Ool02Goo000GOol2003dOol2000;Ool001Moo`03001oogoo0?Aoo`03001oogoo00Uoo`005goo00<0
07ooOol0m7oo00<007ooOol02Goo000GOol00`00Oomoo`3dOol00`00Oomoo`09Ool001Moo`03001o
ogoo0?Aoo`03001oogoo00Uoo`005goo0P00m7oo0P002goo000GOol00`00Oomoo`3dOol00`00Oomo
o`09Ool0015oo`03001oogoo00=oo`03001oogoo0?Aoo`03001oogoo00Uoo`004Goo00<007ooOol0
0goo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0
:Woo00<007ooOol04goo00<007ooOol02Goo000AOol00`00Oomoo`03Oooh000;Ool0019oo`03001o
ogoo0?moo`Ioo`0047oo00<007oo0000ogoo27oo000@Ool3003oOol8Ool00?mooa]oo`00ogoo6goo
003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {204, 0}} -> {-5.02995, -1.80004, 0.0444447, 
  0.0444447}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Instantaneous Free Acceleration"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the free acceleration of an underconstrained mechanism a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that contains a new set of equations of motion with one \
or more constraints dropped from the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["dropcon, ",
    FontSlant->"Italic"],
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Dynamic]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the equations of motion required to find the free acceleration of \
the current model and returns them in a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. The ",
  StyleBox["dropcon",
    FontSlant->"Italic"],
  " argument is used to specify the constraint numbers that are to be dropped \
to make the model underconstrained."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Instantaneous free acceleration."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The two ",
  StyleBox["RelativeAngle1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints are now dropped from the robot arm to give the model two \
degrees of freedom. If initial conditions are not specified, ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " takes them from the current default initial guesses ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This drops the constraints that lock the rotation of the joints."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fsys = SetFree[{3, 4}, Solution \[Rule] Dynamic]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = SolveFree[fsys]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the resultant acceleration vector at the tip of link 2."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Acceleration[link2, {\(-3\), 0}] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1.41818181818181887`, 1.13370598313599257`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To find the free acceleration corresponding to a sequence of different \
values of ",
  StyleBox["loadangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["SetParameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " could be used between each successive run of ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option can be used to pass ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the new parameter values. ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " reads all its initial conditions from the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, ",
  StyleBox["Parameters[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the initial conditions contained in the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object, in that order."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object at 21 different values of ",
  StyleBox["loadangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(freetab = 
      Table[SolveFree[fsys, 
          InitialCondition \[Rule] \(loadangle \[Rule] i\)], {i, 0, 
          2.0  \[Pi], \[Pi]/10.}]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a parametric plot of the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " and ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " components of the resulting acceleration at the tip o",
  StyleBox["f link 2. T",
    FontFamily->"Times"],
  "he diagonal line across the plot crosses the ellipse at ",
  StyleBox["loadangle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[acc = Acceleration[link2, {\(-3\), 0}] /. freetab, 
      PlotJoined \[Rule] True, 
      Epilog \[Rule] 
        Line[{{0, 0}, acc\[LeftDoubleBracket]1\[RightDoubleBracket]}]]; \)\)],
   "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.262551 0.309017 0.116365 [
[.10617 .29652 -12 -9 ]
[.10617 .29652 12 0 ]
[.23745 .29652 -6 -9 ]
[.23745 .29652 6 0 ]
[.36872 .29652 -12 -9 ]
[.36872 .29652 12 0 ]
[.63128 .29652 -9 -9 ]
[.63128 .29652 9 0 ]
[.76255 .29652 -3 -9 ]
[.76255 .29652 3 0 ]
[.89383 .29652 -9 -9 ]
[.89383 .29652 9 0 ]
[.4875 .07629 -12 -4.5 ]
[.4875 .07629 0 4.5 ]
[.4875 .19265 -12 -4.5 ]
[.4875 .19265 0 4.5 ]
[.4875 .42538 -6 -4.5 ]
[.4875 .42538 0 4.5 ]
[.4875 .54175 -6 -4.5 ]
[.4875 .54175 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.10617 .30902 m
.10617 .31527 L
s
[(-1.5)] .10617 .29652 0 1 Mshowa
.23745 .30902 m
.23745 .31527 L
s
[(-1)] .23745 .29652 0 1 Mshowa
.36872 .30902 m
.36872 .31527 L
s
[(-0.5)] .36872 .29652 0 1 Mshowa
.63128 .30902 m
.63128 .31527 L
s
[(0.5)] .63128 .29652 0 1 Mshowa
.76255 .30902 m
.76255 .31527 L
s
[(1)] .76255 .29652 0 1 Mshowa
.89383 .30902 m
.89383 .31527 L
s
[(1.5)] .89383 .29652 0 1 Mshowa
.125 Mabswid
.13243 .30902 m
.13243 .31277 L
s
.15868 .30902 m
.15868 .31277 L
s
.18494 .30902 m
.18494 .31277 L
s
.21119 .30902 m
.21119 .31277 L
s
.2637 .30902 m
.2637 .31277 L
s
.28996 .30902 m
.28996 .31277 L
s
.31621 .30902 m
.31621 .31277 L
s
.34247 .30902 m
.34247 .31277 L
s
.39498 .30902 m
.39498 .31277 L
s
.42123 .30902 m
.42123 .31277 L
s
.44749 .30902 m
.44749 .31277 L
s
.47374 .30902 m
.47374 .31277 L
s
.52626 .30902 m
.52626 .31277 L
s
.55251 .30902 m
.55251 .31277 L
s
.57877 .30902 m
.57877 .31277 L
s
.60502 .30902 m
.60502 .31277 L
s
.65753 .30902 m
.65753 .31277 L
s
.68379 .30902 m
.68379 .31277 L
s
.71004 .30902 m
.71004 .31277 L
s
.7363 .30902 m
.7363 .31277 L
s
.78881 .30902 m
.78881 .31277 L
s
.81506 .30902 m
.81506 .31277 L
s
.84132 .30902 m
.84132 .31277 L
s
.86757 .30902 m
.86757 .31277 L
s
.07992 .30902 m
.07992 .31277 L
s
.05366 .30902 m
.05366 .31277 L
s
.02741 .30902 m
.02741 .31277 L
s
.00115 .30902 m
.00115 .31277 L
s
.92008 .30902 m
.92008 .31277 L
s
.94634 .30902 m
.94634 .31277 L
s
.97259 .30902 m
.97259 .31277 L
s
.99885 .30902 m
.99885 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .07629 m
.50625 .07629 L
s
[(-2)] .4875 .07629 1 0 Mshowa
.5 .19265 m
.50625 .19265 L
s
[(-1)] .4875 .19265 1 0 Mshowa
.5 .42538 m
.50625 .42538 L
s
[(1)] .4875 .42538 1 0 Mshowa
.5 .54175 m
.50625 .54175 L
s
[(2)] .4875 .54175 1 0 Mshowa
.125 Mabswid
.5 .09956 m
.50375 .09956 L
s
.5 .12283 m
.50375 .12283 L
s
.5 .14611 m
.50375 .14611 L
s
.5 .16938 m
.50375 .16938 L
s
.5 .21592 m
.50375 .21592 L
s
.5 .2392 m
.50375 .2392 L
s
.5 .26247 m
.50375 .26247 L
s
.5 .28574 m
.50375 .28574 L
s
.5 .33229 m
.50375 .33229 L
s
.5 .35556 m
.50375 .35556 L
s
.5 .37884 m
.50375 .37884 L
s
.5 .40211 m
.50375 .40211 L
s
.5 .44866 m
.50375 .44866 L
s
.5 .47193 m
.50375 .47193 L
s
.5 .4952 m
.50375 .4952 L
s
.5 .51847 m
.50375 .51847 L
s
.5 .05301 m
.50375 .05301 L
s
.5 .02974 m
.50375 .02974 L
s
.5 .00647 m
.50375 .00647 L
s
.5 .56502 m
.50375 .56502 L
s
.5 .58829 m
.50375 .58829 L
s
.5 .61157 m
.50375 .61157 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.87234 .44094 m
.9461 .51686 L
.97619 .57244 L
.95967 .60223 L
.89815 .60332 L
.79766 .5756 L
.66803 .52179 L
.52195 .44714 L
.37372 .35898 L
.23786 .26593 L
.12766 .17709 L
.0539 .10117 L
.02381 .04559 L
.04033 .0158 L
.10185 .01472 L
.20234 .04243 L
.33197 .09625 L
.47805 .17089 L
.62628 .25905 L
.76214 .35211 L
.87234 .44094 L
s
.5 .30902 m
.87234 .44094 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{281, 174},
  ImageMargins->{{1, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004I0000[Q000`40O003h00OS7oo00<007ooOol0
RWoo002<Ool00`00Oomoo`2:Ool008aoo`8008]oo`00S7oo00<007ooOol0RWoo002<Ool00`00Oomo
o`2:Ool000]ooa<006ioo`03001oogoo08Yoo`002Woo00<007ooOol04Goo1000JWoo00<007ooOol0
RWoo000:Ool00`00Oomoo`0EOol4001VOol00`00Oomoo`2:Ool000Uoo`03001oogoo01Yoo`@0069o
o`03001oogoo08Yoo`0027oo00<007ooOol07goo1000GWoo0P00Rgoo0008Ool00`00Oomoo`0SOol4
001JOol00`00Oomoo`2:Ool000Moo`03001oogoo02Qoo`@005Ioo`03001oogoo08Yoo`001goo00<0
07ooOol0;7oo1000DWoo00<007ooOol0RWoo0006Ool00`00Oomoo`0aOol2001@Ool00`00Oomoo`2:
Ool000Moo`03001oogoo039oo`8004ioo`03001oogoo08Yoo`001goo00<007ooOol0=7oo0`00Bgoo
0P00Rgoo0008Ool00`00Oomoo`0fOol20019Ool00`00Oomoo`2:Ool000Qoo`03001oogoo03Qoo`<0
04Ioo`03001oogoo08Yoo`002Goo00<007ooOol0>Woo0P00A7oo00<007ooOol0RWoo0009Ool00`00
Oomoo`0lOol20012Ool00`00Oomoo`2:Ool000Yoo`03001oogoo03eoo`<003Moo`<000Eoo`03001o
ogoo08Yoo`002Woo00<007ooOol0@7oo0P00=Goo00<007ooOol01Goo00<007ooOol0RWoo000;Ool0
0`00Oomoo`11Ool3000]Ool30003Ool00`00Oomoo`04Ool2002;Ool000aoo`03001oogoo04=oo`80
035oo`03001oogoo00Aoo`03001oogoo08Yoo`0037oo00<007ooOol0AGoo0P00;Woo00<007oo0000
1Goo00<007ooOol0RWoo000=Ool00`00Oomoo`16Ool3000/Ool00`00Oomoo`04Ool00`00Oomoo`2:
Ool000eoo`03001oogoo04Uoo`80035oo`03001oogoo08Yoo`003Woo00<007ooOol0BWoo0P00;goo
00<007ooOol0RWoo000>Ool00`00Oomoo`1<Ool2000]Ool2002;Ool000moo`03001oogoo04eoo`80
02]oo`03001oogoo08Yoo`0047oo00<007ooOol0CWoo0P00:Goo00<007ooOol0RWoo000AOol00`00
Oomoo`1?Ool2000WOol00`00Oomoo`2:Ool0019oo`03001oogoo051oo`8002Eoo`03001oogoo08Yo
o`004goo00<007ooOol0DGoo0P008goo00<007ooOol0RWoo000DOol00`00Oomoo`1BOol2000QOol0
0`00Oomoo`2:Ool001Eoo`03001oogoo05=oo`8001moo`8008]oo`005Woo00<007ooOol0E7oo0P00
7Goo00<007ooOol0RWoo000GOol00`00Oomoo`1EOol2000KOol00`00Oomoo`2:Ool001Qoo`03001o
ogoo05Ioo`8001Uoo`03001oogoo08Yoo`006Goo00<007ooOol0Egoo0P005goo00<007ooOol0RWoo
000IOol00`00Oomoo`1IOol2000EOol00`00Oomoo`2:Ool001Yoo`03001oogoo05Yoo`8001=oo`80
08]oo`006goo00<007ooOol0Fgoo0P004Goo00<007ooOol0RWoo000LOol00`00Oomoo`1LOol2000?
Ool00`00Oomoo`2:Ool001eoo`03001oogoo05eoo`8000eoo`03001oogoo08Yoo`007Woo00<007oo
Ool0GWoo0P002goo00<007ooOol0RWoo000OOol00`00Oomoo`1OOol20009Ool00`00Oomoo`2:Ool0
021oo`03001oogoo061oo`8000Moo`03001oogoo08Yoo`008Goo00<007ooOol0HGoo00<007ooOol0
17oo0P00Rgoo000ROol00`00Oomoo`1QOol20004Ool00`00Oomoo`2:Ool002=oo`03001oogoo069o
o`80009oo`03001oogoo08Yoo`0097oo00<007ooOol0Hgoo00<007oo0000S7oo000UOol2001LOol5
0003Ool2002<Ool002Moo`03001oogoo05]oo`03001oogoo00Aoo`<008Yoo`00:7oo00<007ooOol0
E7oo0`000goo00<007ooOol017oo0P0000=oo`00Ool0R7oo000YOol00`00Oomoo`1IOol00`00Oomo
o`04Ool01000Oomoogoo0P00Qgoo000ZOol2001IOol00`00Oomoo`04Ool00`00Oomoo`03Ool20025
Ool002aoo`03001oogoo05Eoo`8000Ioo`03001oogoo00Eoo`03001oogoo089oo`00;Goo00<007oo
Ool0G7oo00<007ooOol01Woo0P00PWoo000^Ool00`00Oomoo`1KOol00`00Oomoo`08Ool20020Ool0
02moo`8005]oo`03001oogoo00Yoo`03001oogoo07eoo`00<Goo00<007ooOol0F7oo0P0037oo0P00
OGoo000bOol00`00Oomoo`1GOol00`00Oomoo`0=Ool2001kOol003=oo`03001oogoo05Ioo`03001o
ogoo00moo`8007Uoo`00=7oo00<007ooOol0EGoo00<007ooOol04Goo00<007ooOol0MWoo000eOol2
001EOol00`00Oomoo`0BOol2001fOol003Moo`03001oogoo059oo`03001oogoo01Aoo`8007Aoo`00
>7oo00<007ooOol0DGoo0P005goo00<007ooOol0LGoo000iOol00`00Oomoo`1@Ool00`00Oomoo`0G
Ool2001aOol003Yoo`80051oo`03001oogoo01Uoo`8006moo`00?7oo00<007ooOol0CGoo00<007oo
Ool06goo00<007ooOol0K7oo000mOol00`00Oomoo`1<Ool00`00Oomoo`0LOol2001/Ool003ioo`03
001oogoo04]oo`03001oogoo01ioo`8006Yoo`00?goo0P00Bgoo00<007ooOol087oo00<007ooOol0
Igoo0011Ool00`00Oomoo`18Ool2000ROol2001WOol0049oo`03001oogoo04Moo`03001oogoo02=o
o`03001oogoo06Aoo`0067oo1@000Woo00<007ooOol00Woo00<007ooOol06goo1@007Goo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol06goo00<007ooOol077oo00<007ooOol00Woo00<007oo
Ool00`0077oo1@006goo1@000Woo00<007ooOol00Woo00<007ooOol067oo000JOol00`00Oomoo`06
Ool00`00Ool0000NOol2000MOol00`00Ool00007Ool00`00Ool0000LOol00`00Oomoo`0KOol00`00
Ool00007Ool3000MOol00`00Oomoo`0MOol00`00Oomoo`06Ool00`00Ool0000IOol001Aoo`<000=o
o`03001oogoo00Qoo`03001oogoo01Ioo`<000=oo`04001oo`00000FOol30002Ool00`00Ool00009
Ool00`00Oomoo`0JOol00`00Oomoo`0KOol00`00Ool00009Ool2000LOol00`00Oomoo`0MOol00`00
Oomoo`08Ool00`00Oomoo`0GOol001Yoo`03001oogoo00Ioo`8001moo`05001oogooOol0000JOol0
0`00Ool00007Ool2000MOol00`00Oomoo`0KOol00`00Ool00007Ool20002Ool00`00Oomoo`0IOol0
0`00Oomoo`0MOol00`00Oomoo`06Ool2000JOol001Yoo`03001oogoo00Ioo`03001oogoo01ioo`03
001oogoo009oo`8001Qoo`03001oo`0000Moo`03001oogoo01aoo`8001aoo`03001oo`0000Moo`03
001oogoo009oo`03001oogoo01Qoo`03001oogoo01eoo`03001oogoo00Ioo`03001oogoo01Uoo`00
6Goo0P0027oo0`007Goo0P001Woo00<007ooOol05Woo00<007ooOol01Woo0`0077oo00<007ooOol0
77oo00<007ooOol01Woo0`000goo0P005goo0P007Woo0P0027oo0`006Goo001<Ool00`00Oomoo`0m
Ool00`00Oomoo`0]Ool00`00Oomoo`1JOol004eoo`8003eoo`03001oogoo02ioo`8005Yoo`00Cgoo
00<007ooOol0>Woo00<007ooOol0<7oo00<007ooOol0Egoo001@Ool2000jOol00`00Oomoo`0aOol2
001GOol0059oo`03001oogoo03Moo`03001oogoo03=oo`03001oogoo05Aoo`00o`006@000Goo0000
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007oo0000
0P000Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol00goo0P001goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo0@000Goo000MOol00`00Oomoo`0ROol0
0`00Oomoo`0AOol2000?Ool00`00Oomoo`0ROol00`00Oomoo`02Ool3000LOol00`00Oomoo`0COol2
000=Ool00`00Oomoo`0ROol00`00Oomoo`0LOol005Qoo`03001oogoo035oo`03001oogoo00Eoo`80
039oo`03001oogoo04ioo`00FGoo0P00<Goo00<007ooOol01goo0`00<7oo0P00CWoo001KOol00`00
Oomoo`0^Ool00`00Oomoo`0:Ool3000_Ool00`00Oomoo`1;Ool005aoo`8002ioo`03001oogoo00eo
o`<002eoo`03001oogoo04Yoo`00GWoo00<007ooOol0:goo0P004Goo0`00:goo0P00BWoo001OOol0
0`00Oomoo`0ZOol00`00Oomoo`0COol2000[Ool00`00Oomoo`17Ool0061oo`8002Yoo`03001oogoo
01Eoo`<002Uoo`8004Moo`00HWoo00<007ooOol09goo00<007ooOol067oo0`00:7oo00<007ooOol0
A7oo001SOol2000WOol00`00Oomoo`0KOol3000VOol20014Ool006Eoo`03001oogoo02Aoo`03001o
ogoo01ioo`<002Eoo`03001oogoo045oo`00IWoo0P0097oo0P008Woo0P0097oo00<007ooOol0@7oo
001XOol00`00Oomoo`0QOol00`00Oomoo`0SOol3000ROol20010Ool006Uoo`80025oo`03001oogoo
02Ioo`<0025oo`03001oogoo03eoo`00Jgoo0P007goo00<007ooOol0:Goo0`007goo00<007ooOol0
?7oo001]Ool00`00Oomoo`0LOol00`00Oomoo`0/Ool3000MOol00`00Oomoo`0kOol006ioo`8001ao
o`03001oogoo02moo`8001aoo`8003]oo`00L7oo0P006Woo00<007ooOol0<Goo0`006goo00<007oo
Ool0>7oo001bOol00`00Oomoo`0GOol2000eOol3000IOol00`00Oomoo`0gOol007=oo`8001Moo`03
001oogoo03Moo`<001Moo`03001oogoo03Ioo`00MGoo0P005Goo00<007ooOol0>Woo0`005Goo0P00
=Woo001gOol00`00Oomoo`0BOol00`00Oomoo`0mOol3000DOol00`00Oomoo`0cOol007Qoo`80019o
o`03001oogoo041oo`8001=oo`03001oogoo039oo`00NWoo0P0047oo00<007ooOol0@Woo0`004Goo
00<007ooOol0<Goo001lOol00`00Oomoo`0=Ool20016Ool3000?Ool00`00Oomoo`0`Ool007eoo`80
00eoo`03001oogoo04Qoo`<000eoo`80031oo`00Ogoo0P002goo00<007ooOol0Bgoo0`0037oo00<0
07ooOol0;Goo0021Ool20009Ool00`00Oomoo`1>Ool2000;Ool00`00Oomoo`0/Ool008=oo`03001o
ogoo00Ioo`03001oogoo051oo`<000Uoo`03001oogoo02]oo`00Pgoo1@0017oo00<007ooOol0Dgoo
0`001goo0P00:goo0025Ool30004Ool00`00Oomoo`1FOol30006Ool00`00Oomoo`0XOol008Eoo`04
001oogoo0003Ool2001JOol30004Ool00`00Oomoo`0WOol008Eoo`04001oogooOol200000goo001o
o`1MOol20003Ool00`00Oomoo`0VOol008Eoo`03001oogoo00=oo`80061oo`<00003Ool0000002Io
o`00Q7oo0P001Woo0P00HWoo10009Goo002<Ool01000Ool00000Hgoo0P0097oo002<Ool01000Oomo
ogoo0P00Hgoo00<007ooOol08Goo002<Ool20004Ool00`00Oomoo`1QOol00`00Oomoo`0POol008ao
o`03001oogoo00Aoo`80069oo`03001oogoo01moo`00S7oo00<007ooOol01Woo0P00HGoo00<007oo
Ool07Woo002<Ool00`00Oomoo`08Ool2001POol00`00Oomoo`0MOol008aoo`03001oogoo00Yoo`80
05moo`03001oogoo01aoo`00S7oo00<007ooOol037oo0P00GWoo00<007ooOol06goo002<Ool00`00
Oomoo`0>Ool2001MOol00`00Oomoo`0JOol008aoo`80015oo`8005aoo`03001oogoo01Uoo`00S7oo
00<007ooOol04Woo0P00Fgoo00<007ooOol067oo002<Ool00`00Oomoo`0DOol2001IOol00`00Oomo
o`0HOol008aoo`03001oogoo01Ioo`8005Qoo`03001oogoo01Moo`00S7oo00<007ooOol067oo0P00
Egoo00<007ooOol05Woo002<Ool00`00Oomoo`0JOol2001FOol00`00Oomoo`0EOol008aoo`8001eo
o`8005Eoo`03001oogoo01Aoo`00S7oo00<007ooOol07Woo0P00E7oo00<007ooOol04goo002<Ool0
0`00Oomoo`0POol2001COol00`00Oomoo`0BOol008aoo`03001oogoo029oo`80059oo`03001oogoo
015oo`00S7oo00<007ooOol097oo0P00DGoo00<007ooOol047oo002<Ool00`00Oomoo`0VOol2001@
Ool00`00Oomoo`0?Ool008aoo`03001oogoo02Qoo`8004moo`03001oogoo00ioo`00S7oo0P00:goo
0P00CWoo00<007ooOol03Goo002<Ool00`00Oomoo`0/Ool2001<Ool00`00Oomoo`0=Ool008aoo`03
001oogoo02ioo`8004]oo`03001oogoo00aoo`00S7oo00<007ooOol0<7oo0P00BGoo00<007ooOol0
37oo0024Ool30005Ool00`00Oomoo`0bOol30017Ool00`00Oomoo`0;Ool008Aoo`03001oogoo00Eo
o`03001oogoo03Eoo`8004Eoo`03001oogoo00]oo`00QGoo00<007ooOol017oo0P00>7oo0`00@goo
00<007ooOol02Woo0025Ool00`00Oomoo`04Ool00`00Oomoo`0jOol20011Ool00`00Oomoo`0:Ool0
08Aoo`03001oo`0000Eoo`03001oogoo03aoo`80041oo`03001oogoo00Uoo`00QGoo00<007ooOol0
17oo00<007ooOol0?Woo0`00?Woo00<007ooOol027oo002<Ool00`00Oomoo`11Ool2000lOol00`00
Oomoo`08Ool008aoo`03001oogoo04=oo`<003Yoo`03001oogoo00Moo`00S7oo00<007ooOol0AWoo
0P00>7oo00<007ooOol01goo002<Ool20019Ool2000gOol00`00Oomoo`06Ool008aoo`03001oogoo
04Yoo`<003Aoo`03001oogoo00Ioo`00S7oo00<007ooOol0CGoo0P00<goo00<007ooOol01Goo002<
Ool00`00Oomoo`1?Ool3000_Ool00`00Oomoo`06Ool008aoo`03001oogoo059oo`@002]oo`03001o
ogoo00Ioo`00S7oo00<007ooOol0EWoo10009Woo00<007ooOol01goo002<Ool2001KOol4000QOol0
0`00Oomoo`08Ool008aoo`03001oogoo05ioo`@001eoo`03001oogoo00Qoo`00S7oo00<007ooOol0
HWoo100067oo00<007ooOol02Goo002<Ool00`00Oomoo`1VOol4000DOol00`00Oomoo`09Ool008ao
o`03001oogoo06Yooa@000aoo`00S7oo00<007ooOol0RWoo002<Ool00`00Oomoo`2:Ool008aoo`80
08]oo`00S7oo00<007ooOol0RWoo0000\
\>"],
  ImageRangeCache->{{{0, 280}, {173, 0}} -> {-1.90494, -2.65561, 0.0136067, 
  0.0307005}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following mechanism is a simple gyroscope that, dynamically, is not a \
very simple mechanism. The gyroscope consists of three moving bodies: the \
base, the gimbal, and the rotor. The base is constrained to rotate about a \
vertical axis affixed to the ground, while the gimbal rotates about a \
horizontal axis affixed to the base, and the rotor is constrained to rotate \
about a fixed axis on the gimbal that is orthogonal to the gimbal's \
horizontal rotational axis on the base.\n\nThe model is defined so that the \
origins of each body are always coincident, and so that each body is \
initially aligned with the global coordinate system, therefore no initial \
guesses are required because the default initial guesses are exact. The two ",
  
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints 2 and 4, are present only so that the model can be assembled \
in a fixed state. They will be dropped to find the free response. A single \
parameter ",
  StyleBox["freq",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is included in the model to specify the angular speed of the rotor, \
relative to the gimbal. The gyroscope is modeled in local, angular \
coordinates so that the angular velocities of interest appear directly in the \
solution rules.\n\nAll of the bodies are massless except the rotor. This \
makes the results much easier to interpret. The moments of inertia of the \
rotor are representative of a thin disk.\n\nOnly one load is applied to the \
model, a moment applied to the base in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction. Initially this moment has no effect because the base is \
prevented from rotating by constraint 2. However, when the constraints that \
prevent the base and gimbal from rotating are dropped, the orthogonal \
reaction to the moment applied to the base can be observed at the rotor. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and defines names for each of the body numbers. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(base = 2; \)\), 
    \(\(gimbal = 3; \)\), 
    \(\(rotor = 4; \)\), 
    \(X = {1, 0, 0}; Y = {0, 1, 0}; Z = {0, 0, 1}; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints, bodies, and loads for the gyroscope model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(\(SetParameters[freq \[Rule] 20.0  \[Pi]]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\tRevolute5[1, Axis[ground, 0, Z], Axis[base, 0, Z]], 
      \n\tOrthogonal1[2, Vector[base, X], Vector[ground, Y]], \n\t
      Revolute5[3, Axis[base, 0, Y], Axis[gimbal, 0, Y]], \n\t
      Orthogonal1[4, Vector[gimbal, Z], Vector[base, X]], \n\t
      Revolute5[5, Axis[gimbal, 0, X], Axis[rotor, 0, X]], \n\t
      ProjectedAngle1[6, Vector[rotor, Z], Vector[gimbal, Z], 
        Vector[gimbal, X], freq\ T]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[Body[rotor, Inertia \[Rule] {2.0, 1.0, 1.0, 0, 0, 0}]]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[Moment[base, Z, 1]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the gyroscope with the gimbal rotated to make a better picture. "], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08079 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0260524 1.10184 0.0275459 1.10184 [
[ 0 0 0 0 ]
[ 1 1.08079 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.08079 L
0 1.08079 L
closepath
clip
newpath
p
.002 w
.11113 .25957 m
.02755 .78701 L
s
.02755 .78701 m
.40586 1.05324 L
s
.40586 1.05324 m
.42251 .57709 L
s
.42251 .57709 m
.11113 .25957 L
s
.66295 .02755 m
.90359 .41965 L
s
.90359 .41965 m
.97245 .92345 L
s
.97245 .92345 m
.69507 .58075 L
s
.69507 .58075 m
.66295 .02755 L
s
.11113 .25957 m
.02755 .78701 L
s
.02755 .78701 m
.69507 .58075 L
s
.69507 .58075 m
.66295 .02755 L
s
.66295 .02755 m
.11113 .25957 L
s
.42251 .57709 m
.90359 .41965 L
s
.90359 .41965 m
.97245 .92345 L
s
.97245 .92345 m
.40586 1.05324 L
s
.40586 1.05324 m
.42251 .57709 L
s
P
p
.002 w
.1936 .30342 m .44007 .56035 L .83331 .43077 L p
.671 .729 .893 r
F P
s
P
p
.002 w
.83331 .43077 m .63279 .12628 L .1936 .30342 L p
.671 .729 .893 r
F P
s
P
p
.002 w
.6148 .49028 m .63878 .55802 L .58757 .57426 L p
.635 .552 .743 r
F P
s
P
p
.002 w
.58757 .57426 m .56369 .50725 L .6148 .49028 L p
.635 .552 .743 r
F P
s
P
p
.002 w
.60351 .6427 m .58757 .57426 L .63878 .55802 L p
.615 .486 .682 r
F P
s
P
p
.002 w
.5849 .4286 m .6148 .49028 L .56369 .50725 L p
.652 .616 .801 r
F P
s
P
p
.002 w
.56369 .50725 m .53348 .44642 L .5849 .4286 L p
.652 .616 .801 r
F P
s
P
p
.002 w
.63878 .55802 m .65524 .62706 L .60351 .6427 L p
.615 .486 .682 r
F P
s
P
p
.002 w
.6102 .70771 m .60351 .6427 L .65524 .62706 L p
.588 .409 .606 r
F P
s
P
p
.002 w
.55108 .37773 m .5849 .4286 L .53348 .44642 L p
.665 .689 .862 r
F P
s
P
p
.002 w
.53348 .44642 m .49893 .39645 L .55108 .37773 L p
.665 .689 .862 r
F P
s
P
p
.002 w
.65524 .62706 m .66284 .6925 L .6102 .70771 L p
.588 .409 .606 r
F P
s
P
p
.002 w
.51881 .58144 m .4644 .53542 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.57619 .62425 m .51881 .58144 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.4644 .53542 m .51881 .58144 L .49031 .61747 L p
.756 .619 .707 r
F P
s
P
p
.002 w
.51881 .58144 m .57619 .62425 L .54771 .66064 L p
.697 .532 .66 r
F P
s
P
p
.002 w
.54771 .66064 m .49031 .61747 L .51881 .58144 L p
.697 .532 .66 r
F P
s
P
p
.002 w
.49031 .61747 m .43551 .57155 L .4644 .53542 L p
.756 .619 .707 r
F P
s
P
p
.002 w
.41941 .49152 m .4644 .53542 L .43551 .57155 L p
.814 .711 .752 r
F P
s
P
p
.002 w
.43551 .57155 m .3898 .52821 L .41941 .49152 L p
.814 .711 .752 r
F P
s
P
p
.002 w
.38999 .45536 m .41941 .49152 L .3898 .52821 L p
.877 .831 .798 r
F P
s
P
p
.002 w
.3898 .52821 m .3594 .493 L .38999 .45536 L p
.877 .831 .798 r
F P
s
P
p
.002 w
.38155 .43257 m .38999 .45536 L .3594 .493 L p
.897 .985 .791 r
F P
s
P
p
.002 w
.3594 .493 m .34982 .47148 L .38155 .43257 L p
.897 .985 .791 r
F P
s
P
p
.002 w
.49031 .61747 m .43551 .57155 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.54771 .66064 m .49031 .61747 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.6067 .76422 m .6102 .70771 L .66284 .6925 L p
.544 .301 .497 r
F P
s
P
p
.002 w
.70835 .57913 m .68408 .64424 L .65232 .62648 L p
.51 .394 .657 r
F P
s
P
p
.002 w
.65232 .62648 m .67603 .56225 L .70835 .57913 L p
.51 .394 .657 r
F P
s
P
p
.002 w
.61571 .68524 m .65232 .62648 L .68408 .64424 L p
.549 .371 .592 r
F P
s
P
p
.002 w
.62987 .65878 m .57619 .62425 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.57619 .62425 m .62987 .65878 L .60104 .69597 L p
.619 .426 .598 r
F P
s
P
p
.002 w
.60104 .69597 m .54771 .66064 L .57619 .62425 L p
.619 .426 .598 r
F P
s
P
p
.002 w
.68408 .64424 m .64696 .70392 L .61571 .68524 L p
.549 .371 .592 r
F P
s
P
p
.002 w
.56896 .734 m .61571 .68524 L .64696 .70392 L p
.586 .346 .519 r
F P
s
P
p
.002 w
.4644 .53542 m .41941 .49152 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.60104 .69597 m .54771 .66064 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.43551 .57155 m .3898 .52821 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.71765 .51357 m .70835 .57913 L .67603 .56225 L p
.461 .417 .722 r
F P
s
P
p
.002 w
.67603 .56225 m .68477 .49746 L .71765 .51357 L p
.461 .417 .722 r
F P
s
P
p
.002 w
.64696 .70392 m .59978 .75358 L .56896 .734 L p
.586 .346 .519 r
F P
s
P
p
.002 w
.51553 .76864 m .56896 .734 L .59978 .75358 L p
.622 .313 .426 r
F P
s
P
p
.002 w
.66284 .6925 m .66058 .74926 L .6067 .76422 L p
.544 .301 .497 r
F P
s
P
p
.02 w
.62077 .68311 m
.63122 .69451 L
s
P
p
.002 w
.51573 .34234 m .55108 .37773 L .49893 .39645 L p
.671 .78 .931 r
F P
s
P
p
.02 w
.52487 .38714 m
.52487 .41423 L
s
P
p
.002 w
.49893 .39645 m .46251 .36197 L .51573 .34234 L p
.671 .78 .931 r
F P
s
P
p
.002 w
.71065 .45285 m .71765 .51357 L .68477 .49746 L p
.39 .441 .794 r
F P
s
P
p
.002 w
.68477 .49746 m .67726 .43738 L .71065 .45285 L p
.39 .441 .794 r
F P
s
P
p
.002 w
.67298 .68029 m .62987 .65878 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.62987 .65878 m .67298 .68029 L .64347 .71863 L p
.486 .255 .489 r
F P
s
P
p
.002 w
.64347 .71863 m .60104 .69597 L .62987 .65878 L p
.486 .255 .489 r
F P
s
P
p
.002 w
.41941 .49152 m .38999 .45536 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.64347 .71863 m .60104 .69597 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.59256 .80699 m .6067 .76422 L .66058 .74926 L p
.453 .115 .301 r
F P
s
P
p
.002 w
.3898 .52821 m .3594 .493 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.59978 .75358 m .54599 .78906 L .51553 .76864 L p
.622 .313 .426 r
F P
s
P
p
.002 w
.45953 .78564 m .51553 .76864 L .54599 .78906 L p
.657 .263 .287 r
F P
s
P
p
.002 w
.66058 .74926 m .64794 .79204 L .59256 .80699 L p
.453 .115 .301 r
F P
s
P
p
.002 w
.68703 .40248 m .71065 .45285 L .67726 .43738 L p
.263 .462 .867 r
F P
s
P
p
.002 w
.67726 .43738 m .65325 .38745 L .68703 .40248 L p
.263 .462 .867 r
F P
s
P
p
.002 w
.48178 .32681 m .51573 .34234 L .46251 .36197 L p
.63 .891 .987 r
F P
s
P
p
.002 w
.46251 .36197 m .42719 .34726 L .48178 .32681 L p
.63 .891 .987 r
F P
s
P
p
.002 w
.54599 .78906 m .48974 .80676 L .45953 .78564 L p
.657 .263 .287 r
F P
s
P
p
.002 w
.40579 .78241 m .45953 .78564 L .48974 .80676 L p
.669 .164 .034 r
F P
s
P
p
.002 w
.69875 .68474 m .67298 .68029 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.67298 .68029 m .69875 .68474 L .66829 .72447 L p
.136 0 .193 r
F P
s
P
p
.002 w
.66829 .72447 m .64347 .71863 L .67298 .68029 L p
.136 0 .193 r
F P
s
P
p
.002 w
.38999 .45536 m .38155 .43257 L .39759 .42805 L p
0 .37 .834 r
F P
s
P
p
.002 w
.66829 .72447 m .64347 .71863 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.3594 .493 m .34982 .47148 L .36475 .46839 L p
0 .341 .811 r
F P
s
P
p
.002 w
.56808 .83091 m .59256 .80699 L .64794 .79204 L p
.2 0 0 r
F P
s
P
p
.002 w
.64782 .36787 m .68703 .40248 L .65325 .38745 L p
0 .429 .859 r
F P
s
P
p
.002 w
.65325 .38745 m .61382 .35302 L .64782 .36787 L p
0 .429 .859 r
F P
s
P
p
.002 w
.48974 .80676 m .43588 .804 L .40579 .78241 L p
.669 .164 .034 r
F P
s
P
p
.002 w
.64794 .79204 m .62509 .81572 L .56808 .83091 L p
.2 0 0 r
F P
s
P
p
.002 w
.35962 .7578 m .40579 .78241 L .43588 .804 L p
.524 0 0 r
F P
s
P
p
.002 w
.45263 .33461 m .48178 .32681 L .42719 .34726 L p
.317 .798 .74 r
F P
s
P
p
.002 w
.42719 .34726 m .39649 .35568 L .45263 .33461 L p
.317 .798 .74 r
F P
s
P
p
.002 w
.70147 .66968 m .69875 .68474 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.03 w
.54876 .54825 m
.67 .39491 L
s
P
p
.002 w
.69875 .68474 m .70147 .66968 L .66988 .71083 L p
.742 .937 .604 r
F P
s
P
p
.002 w
.66988 .71083 m .66829 .72447 L .69875 .68474 L p
.742 .937 .604 r
F P
s
P
p
.002 w
.39759 .42805 m .38155 .43257 L .34982 .47148 L p
0 0 0 r
F P
s
P
p
.002 w
.59575 .35369 m .64782 .36787 L .61382 .35302 L p
.4 0 0 r
F P
s
P
p
.002 w
.61382 .35302 m .56175 .3387 L .59575 .35369 L p
.4 0 0 r
F P
s
P
p
.002 w
.43588 .804 m .38972 .77954 L .35962 .7578 L p
.524 0 0 r
F P
s
P
p
.002 w
.66988 .71083 m .66829 .72447 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.03 w
.51654 .58899 m
.54038 .55884 L
s
P
p
.002 w
.53466 .83165 m .56808 .83091 L .62509 .81572 L p
.355 .829 .865 r
F P
s
P
p
.002 w
.34982 .47148 m .36475 .46839 L .39759 .42805 L p
0 0 0 r
F P
s
P
p
.002 w
.32633 .7127 m .35962 .7578 L .38972 .77954 L p
0 .277 .778 r
F P
s
P
p
.03 w
.37671 .76583 m
.50929 .59816 L
s
P
p
.002 w
.62509 .81572 m .59327 .81594 L .53466 .83165 L p
.355 .829 .865 r
F P
s
P
p
.002 w
.43187 .36738 m .45263 .33461 L .39649 .35568 L p
.232 0 .003 r
F P
s
P
p
.002 w
.39649 .35568 m .37412 .38876 L .43187 .36738 L p
.232 0 .003 r
F P
s
P
p
.002 w
.53545 .36304 m .59575 .35369 L .56175 .3387 L p
.559 .056 .017 r
F P
s
P
p
.002 w
.56175 .3387 m .50171 .34756 L .53545 .36304 L p
.559 .056 .017 r
F P
s
P
p
.002 w
.38972 .77954 m .35662 .73422 L .32633 .7127 L p
0 .277 .778 r
F P
s
P
p
.002 w
.67815 .6355 m .70147 .66968 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.70147 .66968 m .67815 .6355 L .64543 .67786 L p
.909 .894 .803 r
F P
s
P
p
.002 w
.64543 .67786 m .66988 .71083 L .70147 .66968 L p
.909 .894 .803 r
F P
s
P
p
.002 w
.31055 .65061 m .32633 .7127 L .35662 .73422 L p
.202 .342 .783 r
F P
s
P
p
.002 w
.49506 .80674 m .53466 .83165 L .59327 .81594 L p
.606 .834 .987 r
F P
s
P
p
.002 w
.63058 .58664 m .67815 .6355 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.56639 .53159 m .63058 .58664 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.49778 .48102 m .56639 .53159 L p
.39759 .42805 L 0 .37 .834 r
F P
s
P
p
.002 w
.39759 .42805 m .43806 .44456 L .49778 .48102 L p
0 .37 .834 r
F P
s
P
p
.002 w
.43806 .44456 m .39759 .42805 L .36475 .46839 L p
.394 .134 .398 r
F P
s
P
p
.002 w
.64543 .67786 m .66988 .71083 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.36475 .46839 m .40432 .48626 L .43806 .44456 L p
.394 .134 .398 r
F P
s
P
p
.002 w
.59693 .62977 m .64543 .67786 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.53219 .57486 m .59693 .62977 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.46355 .52377 m .53219 .57486 L p
.36475 .46839 L 0 .341 .811 r
F P
s
P
p
.002 w
.36475 .46839 m .40432 .48626 L .46355 .52377 L p
0 .341 .811 r
F P
s
P
p
.002 w
.47326 .39645 m .53545 .36304 L .50171 .34756 L p
.562 .187 .289 r
F P
s
P
p
.002 w
.50171 .34756 m .44002 .38011 L .47326 .39645 L p
.562 .187 .289 r
F P
s
P
p
.002 w
.59327 .81594 m .55504 .79023 L .49506 .80674 L p
.606 .834 .987 r
F P
s
P
p
.002 w
.35662 .73422 m .3412 .6715 L .31055 .65061 L p
.202 .342 .783 r
F P
s
P
p
.002 w
.44002 .38011 m .38396 .43368 L .41654 .45113 L p
.531 .254 .441 r
F P
s
P
p
.002 w
.42275 .42381 m .43187 .36738 L .37412 .38876 L p
.458 .173 .393 r
F P
s
P
p
.002 w
.37242 .52103 m .41654 .45113 L .38396 .43368 L p
.488 .295 .545 r
F P
s
P
p
.002 w
.38396 .43368 m .34056 .50233 L .37242 .52103 L p
.488 .295 .545 r
F P
s
P
p
.002 w
.37412 .38876 m .3635 .44508 L .42275 .42381 L p
.458 .173 .393 r
F P
s
P
p
.002 w
.31519 .5777 m .31055 .65061 L .3412 .6715 L p
.35 .341 .709 r
F P
s
P
p
.002 w
.41654 .45113 m .47326 .39645 L .44002 .38011 L p
.531 .254 .441 r
F P
s
P
p
.002 w
.67815 .6355 m .63058 .58664 L .59693 .62977 L p
.836 .741 .759 r
F P
s
P
p
.002 w
.59693 .62977 m .64543 .67786 L .67815 .6355 L p
.836 .741 .759 r
F P
s
P
p
.002 w
.45343 .75677 m .49506 .80674 L .55504 .79023 L p
.638 .719 .906 r
F P
s
P
p
.02 w
.52487 .76344 m
.52487 .78029 L
s
P
p
.02 w
.52487 .79854 m
.52487 .82237 L
s
P
p
.002 w
.49778 .48102 m .43806 .44456 L .40432 .48626 L p
.595 .386 .568 r
F P
s
P
p
.002 w
.3412 .6715 m .34638 .59761 L .31519 .5777 L p
.35 .341 .709 r
F P
s
P
p
.002 w
.34056 .50233 m .31519 .5777 L .34638 .59761 L p
.433 .323 .629 r
F P
s
P
p
.002 w
.40432 .48626 m .46355 .52377 L .49778 .48102 L p
.595 .386 .568 r
F P
s
P
p
.02 w
.41313 .45654 m
.41425 .45776 L
s
P
p
.002 w
.34638 .59761 m .37242 .52103 L .34056 .50233 L p
.433 .323 .629 r
F P
s
P
p
.002 w
.55504 .79023 m .51438 .73922 L .45343 .75677 L p
.638 .719 .906 r
F P
s
P
p
.002 w
.42738 .49884 m .42275 .42381 L .3635 .44508 L p
.543 .349 .568 r
F P
s
P
p
.02 w
.37841 .41865 m
.39294 .43451 L
s
P
p
.002 w
.3635 .44508 m .36692 .51959 L .42738 .49884 L p
.543 .349 .568 r
F P
s
P
p
.002 w
.63058 .58664 m .56639 .53159 L .53219 .57486 L p
.766 .628 .707 r
F P
s
P
p
.002 w
.53219 .57486 m .59693 .62977 L .63058 .58664 L p
.766 .628 .707 r
F P
s
P
p
.002 w
.56639 .53159 m .49778 .48102 L .46355 .52377 L p
.694 .522 .65 r
F P
s
P
p
.002 w
.41492 .68627 m .45343 .75677 L .51438 .73922 L p
.631 .625 .826 r
F P
s
P
p
.002 w
.46355 .52377 m .53219 .57486 L .56639 .53159 L p
.694 .522 .65 r
F P
s
P
p
.002 w
.44593 .58376 m .42738 .49884 L .36692 .51959 L p
.586 .458 .672 r
F P
s
P
p
.002 w
.36692 .51959 m .38473 .60361 L .44593 .58376 L p
.586 .458 .672 r
F P
s
P
p
.002 w
.51438 .73922 m .4763 .66755 L .41492 .68627 L p
.631 .625 .826 r
F P
s
P
p
.002 w
.38473 .60361 m .41492 .68627 L .4763 .66755 L p
.613 .543 .752 r
F P
s
P
p
.002 w
.4763 .66755 m .44593 .58376 L .38473 .60361 L p
.613 .543 .752 r
F P
s
P
p
.002 w
.66295 .02755 m
.90359 .41965 L
s
.90359 .41965 m
.97245 .92345 L
s
.97245 .92345 m
.69507 .58075 L
s
.69507 .58075 m
.66295 .02755 L
s
.11113 .25957 m
.02755 .78701 L
s
.02755 .78701 m
.69507 .58075 L
s
.69507 .58075 m
.66295 .02755 L
s
.66295 .02755 m
.11113 .25957 L
s
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{265, 287},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004900017a000`40O003h00Oogoo2Woo003oOol:
Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00:ioo`8005Uo
o`00[7oo0P0000=oo`000000F7oo002ZOol20003Ool2001HOol00:Moo`<000Eoo`03001oo`0005Mo
o`00YGoo0P0027oo00<007oo0000Egoo002ROol3000:Ool01000Oomoo`00EWoo002POol2000=Ool0
1@00Oomoogoo0000EGoo002NOol2000?Ool01@00Oomoogoo0000EGoo002KOol3000AOol00`00Oomo
o`02Ool00`00Oomoo`1BOol009Uoo`8001Aoo`03001oogoo009oo`03001oogoo059oo`00UWoo0`00
5goo00<007ooOol00Woo00<007ooOol0DGoo002DOol2000JOol00`00Oomoo`03Ool00`00Oomoo`1@
Ool0099oo`8001aoo`03001oogoo00=oo`03001oogoo051oo`00Sgoo0`007Woo00<007ooOol017oo
00<007ooOol0Cgoo002=Ool2000QOol00`00Oomoo`04Ool00`00Oomoo`1?Ool008Yoo`<002=oo`03
001oogoo00Eoo`03001oogoo04ioo`00R7oo0P009Woo00<007ooOol01Woo00<007ooOol0CGoo0026
Ool2000XOol00`00Oomoo`06Ool00`00Oomoo`1=Ool008=oo`<002Yoo`03001oogoo00Moo`03001o
ogoo04aoo`00PGoo0P00;Goo00<007ooOol027oo00<007ooOol0Bgoo001nOol3000_Ool00`00Oomo
o`08Ool00`00Oomoo`1;Ool007aoo`80039oo`03001oogoo00Uoo`03001oogoo04Yoo`00NWoo0P00
=7oo00<007ooOol02Goo00<007ooOol0BWoo001gOol3000fOol00`00Oomoo`0:Ool00`00Oomoo`19
Ool007Eoo`8003Uoo`03001oogoo00]oo`03001oogoo04Qoo`00LWoo0`00>goo00<007ooOol02goo
00<007ooOol0B7oo001`Ool2000dOol20008Ool00`00Oomoo`0<Ool00`00Oomoo`17Ool006ioo`80
03Aoo`80009Fo003001oogoo00Eoo`03001oogoo00aoo`03001oogoo04Moo`00Jgoo0`00<goo0`00
15Kl00<007ooOol01Woo00<007ooOol037oo00<007ooOol0AWoo001YOol2000dOol20008E_`00`00
Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`15Ool006Moo`8003=oo`<000]Fo003001oogoo00Ao
o`03001oogoo00eoo`03001oogoo04Eoo`00I7oo0`00<goo0P003UKl00<007ooOol017oo00<007oo
Ool03Woo00<007ooOol0A7oo001ROol2000cOol3000AE_`00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`14Ool005moo`<003=oo`8001AFo003001oogoo00=oo`03001oogoo00moo`03001oogoo
04=oo`00GGoo0P00=7oo0P005eKl00<007ooOol00Woo00<007ooOol047oo00<007ooOol0@Woo001K
Ool2000cOol3000JE_`01@00Oomoogoo00004Woo00<007ooOol0@Woo001HOol3000cOol2000ME_`0
1@00Oomoogoo00004goo00<007ooOol0@Goo001FOol2000cOol3000PE_`01000Oomoo`004goo00<0
07ooOol0@Goo001COol3000cOol2000TE_`00`00Ool0000DOol00`00Oomoo`10Ool0055oo`8003=o
o`<002IFo003001oo`0001Eoo`03001oogoo03moo`00Cgoo0P00<goo0P00:UKl0P005Goo00<007oo
Ool0?goo001<Ool3000bOol3000]E_`00`00Oomoo`0DOol00`00Oomoo`0nOol004Yoo`8003=oo`80
031Fo003001oogoo01Aoo`03001oogoo03ioo`00Agoo0`00<Woo0`00<UKl0P005Woo00<007ooOol0
?Goo0015Ool2000cOol2000eE_`00`00E_`0000FOol00`00Oomoo`0lOol004=oo`80039oo`<003MF
o003001Fo00001Ioo`03001oogoo03aoo`00@7oo0`00<Woo0P00>eKl00<005Kl00005Woo00<007oo
Ool0>goo000nOol2000bOol3000mE_`00`00E_`0000FOol00`00Oomoo`0kOol003]oo`<0039oo`80
041Fo004001Fo5Kl000FOol00`00Oomoo`0jOol003Uoo`8003=oo`80049Fo005001Fo5KlE_`0000F
Ool00`00Oomoo`0iOol003Moo`80039oo`<004AFo005001Fo5KlE_`0000FOol00`00Oomoo`0iOol0
03Aoo`<0039oo`8004MFo003001Fo5Kl009Fo003001oogoo01Aoo`03001oogoo03Qoo`00<Woo0P00
<Woo0`00BEKl00<005KlE_`00eKl00<007ooOol04goo00<007ooOol0>7oo000_Ool3000bOol2001<
E_`00`00E_aFo003E_`00`00Oomoo`0DOol00`00Oomoo`0gOol002eoo`80039oo`<004iFo003001F
o5Kl00AFo003001oogoo01Aoo`03001oogoo03Ioo`00:goo0P00<Woo0P00DEKl00<005KlE_`01EKl
00<007ooOol04goo00<007ooOol0=Woo000XOol3000aOol3001CE_`00`00E_aFo005E_`00`00Oomo
o`0DOol00`00Oomoo`0eOol002Ioo`80039oo`8005IFo003001Fo5Kl00IFo003001oogoo01Aoo`03
001oogoo03Aoo`008goo0`00<Goo0`00F5Kl00<005KlE_`01eKl00<007ooOol04goo00<007ooOol0
=7oo000QOol2000bOol2001KE_`00`00E_aFo007E_`00`00Oomoo`0DOol00`00Oomoo`0cOol001mo
o`80035oo`<005eFo003001Fo5Kl00QFo003001oogoo01=oo`03001oogoo03=oo`007Goo0P00<Goo
0P00H5Kl00<005KlE_`025Kl00<007ooOol057oo00<007ooOol0<Woo000MOol2000^Ool3001RE_`0
0`00E_aFo009E_`00`00Oomoo`0DOol00`00Oomoo`0aOol001eoo`03001oo`0002]oo`8006EFo003
001Fo5Kl00YFo003001oogoo01=oo`03001oogoo035oo`007Goo00@007ooOol002Moo`<006QFo003
001Fo5Kl00UFo003001oogoo01Aoo`03001oogoo031oo`0077oo00<007ooOol00Woo00<007ooOol0
8Woo0P00JeKl00<005KlE_`02UKl00<007ooOol04goo00<007ooOol0<7oo000LOol00`00Oomoo`03
Ool00`00Oomoo`0OOol2001]E_`00`00E_aFo00;E_`00`00Oomoo`0COol00`00Oomoo`0_Ool001ao
o`03001oogoo00Aoo`03001oogoo01]oo`<006mFo003001Fo5Kl00]Fo003001oogoo01Aoo`03001o
ogoo02ioo`0077oo00<007ooOol01Goo00<007ooOol067oo0P00LUKl00<005KlE_`035Kl00<007oo
Ool04goo00<007ooOol0;Woo000LOol00`00Oomoo`06Ool00`00Oomoo`0DOol3001dE_`00`00E_aF
o00=E_`00`00Oomoo`0COol00`00Oomoo`0]Ool001aoo`03001oogoo00Moo`03001oogoo015oo`80
07MFo003001Fo5Kl00eFo003001oogoo01=oo`03001oogoo02eoo`006goo00<007ooOol02Goo00<0
07ooOol03Goo0`00NEKl00<005KlE_`03UKl00<007ooOol04goo00<007ooOol0;7oo000KOol00`00
Oomoo`0:Ool00`00Oomoo`0:Ool2001lE_`00`00E_aFo00?E_`00`00Oomoo`0COol00`00Oomoo`0[
Ool001]oo`03001oogoo00]oo`03001oogoo00Moo`8007iFo003001Fo5Kl00mFo003001oogoo01=o
o`03001oogoo02]oo`006goo00<007ooOol037oo00<007ooOol01goo00<005KlE_`0O5Kl00<005Kl
E_`045Kl00<007ooOol04goo00<007ooOol0:Woo000KOol00`00Oomoo`0=Ool00`00Oomoo`07Ool0
0`00E_aFo01kE_`00`00E_aFo00@E_`00`00Oomoo`0COol00`00Oomoo`0ZOol001]oo`03001oogoo
00ioo`03001oogoo00Moo`03001Fo5Kl07YFo003001Fo5Kl015Fo003001oogoo01=oo`03001oogoo
02Uoo`006Woo00<007ooOol047oo00<007ooOol01goo00<005KlE_`0NEKl00<005KlE_`04UKl00<0
07ooOol04goo00<007ooOol0:7oo000JOol00`00Oomoo`0AOol00`00Oomoo`07Ool00`00E_aFo01h
E_`00`00E_aFo00BE_`00`00Oomoo`0COol00`00Oomoo`0XOol001Yoo`03001oogoo019oo`03001o
ogoo00Moo`03001Fo5Kl049Fo0<0039Fo003001Fo5Kl01=Fo003001oogoo01=oo`03001oogoo02Mo
o`006Woo00<007ooOol04goo00<007ooOol01goo00<005KlE_`0?EKl10000e>O0P00<5Kl00<005Kl
E_`055Kl00<007ooOol04Woo00<007ooOol09goo000JOol00`00Oomoo`0DOol00`00Oomoo`07Ool0
0`00E_aFo00hE_`60007Dil2000^E_`00`00E_aFo00DE_`00`00Oomoo`0COol00`00Oomoo`0VOol0
01Yoo`03001oogoo01Aoo`03001oogoo00Qoo`03001Fo5Kl03EFo0D000aCW`8000]Fo0@001eFo003
001Fo5Kl01EFo003001oogoo01=oo`03001oogoo02Eoo`006Woo00<007ooOol05Goo00<007ooOol0
27oo00<005KlE_`0<EKl0`000Q`000<005>ODil03U>O0P0015Kl1@0014@P10006UKl00<005KlE_`0
5EKl00<007ooOol04Woo00<007ooOol09Goo000IOol00`00Oomoo`0GOol00`00Oomoo`08Ool00`00
E_aFo00^E_`2000470000`00DimCW`0<Dil9000;A205000GE_`00`00E_aFo00EE_`00`00Oomoo`0C
Ool00`00Oomoo`0TOol001Uoo`03001oogoo01Qoo`03001oogoo00Moo`03001Fo5Kl02]Fo0<000HL
0003001CWe>O00YCW`D001=480800003<0000000008001=Fo003001Fo5Kl01IFo003001oogoo019o
o`03001oogoo02Aoo`006Goo00<007ooOol06Goo00<007ooOol01goo00<005KlE_`0:5Kl0P0021`0
00<005>ODil025>O1@000TBY0P004d@P0`000c000`0045Kl00<005KlE_`05eKl00<007ooOol04Woo
00<007ooOol08goo000IOol00`00Oomoo`0JOol00`00Oomoo`07Ool00`00E_aFo00UE_`2000:7005
0003Dil300000eLM00000006A:T2000<A2050004E_`400000c000000000>E_`00`00E_aFo00GE_`0
0`00Oomoo`0COol00`00Oomoo`0ROol001Uoo`03001oogoo01]oo`03001oogoo00Moo`03001Fo5Kl
02=Fo003000L01`000TL0003001Fo5Kl00=Fo0<0009G7@8000Y4Z@8000A480H000eFo0D000aFo003
001Fo5Kl01QFo003001oogoo019oo`03001oogoo029oo`006Goo00<007ooOol077oo00<007ooOol0
1goo00<005KlE_`08EKl00<001`070002Q`000<005KlE_`01EKl0`003TBY10005EKl1@002UKl00<0
05KlE_`065Kl00<007ooOol04goo00<007ooOol08Goo000HOol00`00Oomoo`0NOol00`00Oomoo`07
Ool00`00E_aFo00PE_`00`00700L000870020007E_`2000>A:T20002Ead00`00E_aFo00EE_`01000
0K/1^`6k0P0025Kl00<005KlE_`06EKl00<007ooOol04goo00<007ooOol087oo000HOol00`00Oomo
o`0OOol00`00Oomoo`07Ool00`00E_aFo00NE_`00`00700L0006700300000cR/001Fo004E_`2000>
A:T20005Ead00`00E_aFo00EE_`200030K/00`00E_aFo005E_`00`00E_aFo00JE_`00`00Oomoo`0B
Ool00`00Oomoo`0POol001Qoo`03001oogoo021oo`03001oogoo00Moo`03001Fo5Kl01aFo003000L
01`000@L00<000@h[004001Fo5KlE_`2000>A:T20008Ead00`00E_aFo00FE_`01@000K/1^`6k0000
1UKl00<005KlE_`06UKl00<007ooOol04goo00<007ooOol07goo000HOol00`00Oomoo`0QOol00`00
Oomoo`07Ool00`00E_aFo00JE_`01000700L01`010001SR/00<005KlE_`00P003TBY0P000ULM1@00
0eLM0P0065Kl00L0006k0K/1^`00E_`00003E_`00`00E_aFo00KE_`00`00Oomoo`0BOol00`00Oomo
o`0OOol001Qoo`03001oogoo029oo`03001oogoo00Moo`03001Fo5Kl01UFo0@000Xh[004001Fo000
@@h2000;A:T20004Ead80002E]/00`00E_aFo00FE_`010000K/1^`6k0`000UKl00<005KlE_`075Kl
00<007ooOol04Woo00<007ooOol07Woo000HOol00`00Oomoo`0SOol00`00Oomoo`07Ool00`00E_aF
o00GE_`2000=>:`20004@@h20007A:T20006Ead50005E]/00`00E_aFo00GE_`9000NE_`00`00Oomo
o`0COol00`00Oomoo`0MOol001Moo`03001oogoo02Eoo`03001oogoo00Moo`03001Fo5Kl01IFo003
000h[3R/00`h[00300113T4>00E13P8000=4Z@80009Fo003001G7ELM00P000IFf`03001Fo5Kl01IF
o0T001mFo003001oogoo019oo`03001oogoo01eoo`005goo00<007ooOol09Woo00<007ooOol01goo
00<005KlE_`05EKl00<003R/>:`033R/00<0044>@@h01d4>0`001EKl0P000eKK1@001eKK00<005Kl
E_`05EKl2@0085Kl00<007ooOol04Woo00<007ooOol077oo000GOol00`00Oomoo`0WOol00`00Oomo
o`07Ool00`00E_aFo00CE_`00`00>:`h[00<>:`00`00@@i13P08@@h00`00E_aFo006E_`01000E]]F
feKK1@001eKK00<005KlE_`05EKl2@0085Kl00<007ooOol04Woo00<007ooOol077oo000GOol00`00
Oomoo`0XOol00`00Oomoo`07Ool00`00E_aFo00BE_`00`00>:`h[00<>:`00`00@@i13P07@@h00`00
E_aFo007E_`01000E]]FfeKK1@0025KK00<005KlE_`04eKl200000<Qf`00000085Kl00<007ooOol0
4Woo00<007ooOol06goo000GOol00`00Oomoo`0YOol00`00Oomoo`07Ool00`00E_aFo00AE_`00`00
>:`0000<>:`00`00@@i13P06@@h00`00E_aFo009E_`00`00E]]Ff`050009E]/00`00E_aFo00AE_`8
00028M/2000QE_`00`00Oomoo`0BOol00`00Oomoo`0JOol001Moo`03001oogoo02Yoo`03001oogoo
00Moo`03001Fo5Kl011Fo0@000/h[00300113T4>00E13P03001Fo5Kl00]Fo003001Ff`0000@000YF
f`03001Fo5Kl00mFo0P000@Qf`80021Fo003001oogoo019oo`03001oogoo01Yoo`005goo00<007oo
Ool0:goo00<007ooOol01goo00<005KlE_`03eKl1@002SR/00<0044>@@h0144>00<005KlE_`035Kl
00<005KK000010002UKK00<005KlE_`03eKl2000127K0P008EKl00<007ooOol04Woo00<007ooOol0
6Goo000FOol00`00Oomoo`0]Ool00`00Oomoo`07Ool00`00E_aFo00=E_`70008>:`00`00@@i13P04
@@h00`00E_aFo00>E_`6000;E]/00`00E_aFo00=E_`900048M/00`008M/0000PE_`00`00Oomoo`0B
Ool00`00Oomoo`0IOol001Ioo`03001oogoo02ioo`03001oogoo00Moo`03001Fo5Kl00aFo0L000Ph
[00300113T4>00=13P03001Fo5Kl00mFo0H000aFf`03001Fo5Kl00]Fo0P00003E_`0027K00<Qf`03
000Qf`00025Fo003001oogoo015oo`8001Yoo`005Woo00<007ooOol0;goo00<007ooOol01goo00<0
05KlE_`02eKl00<003R/00001@001SR/0P00144>00<005KlE_`04EKl00<005KKE]/03UKK00<005Kl
E_`02UKl20000eKl00D0027K8M/Qf`00008Qf`03001Fo5Kl01mFo003001oogoo00eoo`<00003Ool0
07oo01Uoo`005Woo00<007ooOol0<7oo00<007ooOol01goo00<005KlE_`02UKl00<003R/>:`01P00
0SR/0`0000=5LP00@@h00T4>00<005KlE_`04eKl00<005KKE]/03EKK0P002UKl2@000eKl00D0027K
8M/Qf`00008Qf`03001Fo5Kl01mFo003001oogoo00Yoo`<000Aoo`03001oogoo01Qoo`005Woo00<0
07ooOol0<Goo00<007ooOol01Woo00<005KlE_`02UKl00<003R/>:`0200014Eb00@0044>@@h001IF
o003001FfeKK00YFf`<00003DWT005Kl00UFo0P000EFo004000Qfb7K00038M/00`00E_aFo00NE_`2
0008Ool30007Ool00`00Oomoo`0HOol001Ioo`03001oogoo039oo`03001oogoo00Ioo`03001Fo5Kl
00QFo003000h[3R/008h[0L000A5LP0300113P0001QFo003001FfeKK00MFf`8000EBN@03001Fo5Kl
00IFo0P000IFo08000038M/0027K008Qf`03001Fo5Kl01]Fo0<000Moo`<000]oo`03001oogoo01Mo
o`005Goo00<007ooOol0=7oo00<007ooOol01Woo00<005KlE_`01eKl00<003R/00000P0000=5LP00
00000`001DEb0`006EKl00<005KKE]/00eKK0`001e9i00<005KlE_`01EKl20001eKl00@0037I0000
00@Qf`03001Fo5Kl01MFo0<000Ioo`@000ioo`03001oogoo01Moo`005Goo00<007ooOol0=Goo00<0
07ooOol01Woo00<005KlE_`01UKl0P001DEb0`001TEb00<0032<<8`00P005eKl00<005KKE]/00`00
2e9i00<005KlE_`00eKl200025Kl00<0037I<MT00`000R7K00<005KlE_`055Kl0`001Woo0`004Woo
00<007ooOol05goo000EOol00`00Oomoo`0fOol00`00Oomoo`06Ool00`00E_aFo005E_`00`00AG95
LP05AG800`00AG95LP05AG801@00<8``S000CI800P005UKl0P003U9i00<005KlE_`00eKl200025Kl
00@0037I<MT0008af@8000038M/005Kl015Fo0<000Ioo`<001Eoo`03001oogoo01Moo`005Goo00<0
07ooOol0=goo00<007ooOol01Woo00<005KlE_`015Kl00<004EbAG803DEb00<0032<000014fB00<0
05KlE_`04eKl00<0059iDWT03U9i00@005KlE_aFo0P000UFo004000afC7I0004<MT2000?E_`30006
Ool3000HOol00`00Oomoo`0GOol001Eoo`03001oogoo03Qoo`03001oogoo00Ioo`03001Fo5Kl00=F
o0030015LTEb00e5LP03000`S00000E=TP8001AFo003001BNE9i00eBN@03001Fo5Kl00P000]Fo003
000af@0000Daf@03001Fo5Kl00YFo0<000Ioo`<001]oo`03001oogoo01Moo`005Goo00<007ooOol0
>Goo00<007ooOol01Woo00@005KlE_aFo08000m5LP8000Q=TP80019Fo003001BNE9i00iBN@T000aF
o003000af@0000Daf@03001Fo5Kl00MFo0<000Ioo`<001ioo`03001oogoo01Moo`005Goo00<007oo
Ool0>Woo00<007ooOol01Woo00<005KlE_`00P003dEb00<004fBCI802DfB00<005KlE_`045Kl00<0
059iDWT03E9i2@0035Kl00<0037I00001C7I00<005KlE_`015Kl0`001Woo0`008Goo00<007ooOol0
5goo000DOol00`00Oomoo`0lOol00`00Oomoo`06Ool4000@AG800`00CI9=TP09CI82000@E_`00`00
DWUBN@0=DWT8000=E_`00`00<MT00005<MT01000E_aFo5Kl0`001Woo0`009Goo00<007ooOol05Woo
000DOol00`00Oomoo`0mOol00`00Oomoo`05Ool4000@AG800`00CI9=TP0;CI800`00E_aFo00>E_`0
0`00DWUBN@0;DWT8000>E_`00`00<MT00006<MT30006Ool3000XOol00`00Oomoo`0FOol001Aoo`03
001oogoo03ioo`03001oogoo00Aoo`040001F@00000@AG800`00CI9=TP0<CI82000>E_`00`00DWUB
N@0:DWT8000?E_`00`00<MT00006<MT00`00Oomoo`03Ool3000[Ool00`00Oomoo`0FOol001Aoo`03
001oogoo03moo`03001oogoo00Aoo`03000m<@000115LP03001=TTfB00i=TP8000eFo003001BNE9i
00QBN@P0011Fo004000afC7I0005<MT00`00Ool00003000^Ool00`00Oomoo`0FOol001Aoo`03001o
ogoo041oo`03001oogoo009oo`04000m<Cda000@AG800`00CI9=TP0@CI800`00E_aFo00:E_`00`00
DWUBN@07DWT9000@E_`01000<MTaf@001C7I0P00<Woo00<007ooOol05Woo000DOol00`00Oomoo`11
Ool01@00Oomoogoo00000cda00<004EbAG803DEb00<004fBCI803dfB00@005XD000000]Fo003001B
NE9i00IBN@P000iFo0<00004Ool0037I0005<MT00`00Oomoo`0aOol00`00Oomoo`0FOol001=oo`03
001oogoo04=oo`03001oo`0000@m<@030015LTEb00e5LP03001=TTfB00i=TP03001J55XD009J5003
001Fo5Kl00QFo003001BNE9i00EBN@X000YFo0<000Aoo`03000af@0000Daf@03001oogoo035oo`03
001oogoo01Ioo`004goo00<007ooOol0A7oo00<003da?C400cda00<004EbAG803DEb00<004fBCI80
3TfB00<005XDFQ@00eXD00<005KlE_`025Kl00<0059iDWT00e9i2@0000=B=`00E_`01UKl0`001Goo
0`0000<af@00<MT0137I00<007ooOol0<Woo00<007ooOol05Goo000COol00`00Oomoo`14Ool00`00
?C4m<@03?C400`00AG95LP0=AG800`00CI9=TP0=CI800`00FQAJ5005FQ@20008E_`00`00DWUBN@02
DWT80004DSL00`00E_aFo0040005Ool30002Ool30005<MT00`00Oomoo`0bOol00`00Oomoo`0EOol0
01=oo`03001oogoo04=oo`03000m<Cda00@m<@030015LTEb00a5LP<000e=TP03001J55XD00QJ5003
001Fo5Kl00IFo004001BNE9iDWT80004DSL30006Ool30005Ool01000>KL000001C7I00<007ooOol0
<Goo00<007ooOol05Goo000COol00`00Oomoo`13Ool30004?C400`00AG95LP09AG83000014WE0001
F@002dfB00<005XDFQ@02UXD00<005KlE_`01EKl00<0059iDWT020001E8g00<007ooOol00goo0`00
27oo00@003Vg000i]`8000<af@03001oogoo035oo`03001oogoo01Eoo`004goo00<007ooOol0@Woo
00@003ED=E@eE080008m<@030015LTEb00I5LP<000A9e@030001F@5I008000Q=TP03001J55XD00aJ
508000IFo0T000MB=`03001oo`00008000]oo`03000i]`0000<i]`800003<MT007oo039oo`03001o
ogoo01Eoo`004Woo00<007ooOol0@goo00<003ED=E@00cED0`0014Eb100024WE00D0005I0ET1F@00
00I=TP03001J55XD00mJ5003001Fo5Kl00=Fo0P000QB=`8000ioo`03000i]`0000Di]`8003=oo`03
001oogoo01Eoo`004Woo00<007ooOol0@goo00<003ED=E@01CED00<004Eb00000P0034WE00<0005I
0ET00P5I0P0014fB00<005XDFQ@045XD0P000UKl2@00258g00<007ooOol037oo00@003Vg>KL000Hi
]`03001oogoo035oo`03001oogoo01Eoo`004Woo00<007ooOol0@Woo00<003ED=E@01SED0P003dWE
00<0005I0ET0105I0P0000==TP00FQ@055XD00<005Kl00001`002U8g00<007ooOol02goo00@003Vg
>KL000Hi]`03001oogoo039oo`03001oogoo01Aoo`004Woo00<007ooOol0@Woo00<003ED=E@01SED
00<004WEBMD03TWE00<0005I0ET01P5I00<005XDFQ@05EXD20002e8g00<007ooOol02goo00@003Vg
>KL000Hi]`03001oogoo039oo`03001oogoo01Aoo`004Woo00<007ooOol0@Woo00<003ED=E@01SED
00<004WEBMD03dWE00<0005I0ET01P5I00<005XDFQ@05EXD1P00358g00<007ooOol02goo00@003Vg
>KL000Hi]`03001oogoo039oo`03001oogoo01Aoo`004Woo00<007ooOol0@Woo00<003ED=E@01cED
00<004WEBMD03TWE00<0005I0ET01`5I0P005eXD0`003U8g00<007ooOol02Woo00@003Vg>KL000Di
]`03001oogoo03=oo`03001oogoo01Aoo`004Woo00<007ooOol0@Goo00<003ED=E@023ED00<004WE
BMD03TWE00<0005I0ET02@5I00<005XDFQ@04eXD00@006:F000000iB=`03001oogoo00Yoo`04000i
]cVg0005>KL00`00Oomoo`0cOol00`00Oomoo`0DOol0015oo`03001oogoo049oo`03000eE3ED00Le
E0800119e@030001F@5I00X1F@03001J55XD015J5005001RUV:FHYH0000>DSL00`00Oomoo`0:Ool0
1000>KLi]`001CVg00<007ooOol0<goo00<007ooOol057oo000AOol00`00Oomoo`12Ool00`00=E@e
E007=E@2000@BMD00`000ET1F@0;0ET2000AFQ@00`00HYIRUP02HYH00`00DSMB=`0<DSL00`00Oomo
o`09Ool01000>KLi]`001CVg00<007ooOol0<goo00<007ooOol057oo000AOol00`00Oomoo`11Ool0
0`00=E@eE008=E@00`00Ool0000@BMD00`000ET1F@0<0ET00`00FQAJ500=FQ@00`00HYIRUP04HYH2
000<DSL00`00Oomoo`08Ool00`00>KLi]`02>KL00`00>KLi]`02>KL00`00Oomoo`0cOol00`00Oomo
o`0DOol0015oo`03001oogoo045oo`03000eE3ED00LeE004001oogoo000@BMD00`000ET1F@0=0ET0
0`00FQAJ500;FQ@00`00HYIRUP07HYH00`00DSMB=`09DSL00`00Oomoo`08Ool00`00>KLi]`02>KL0
0`00>KLi]`02>KL00`00Oomoo`0dOol00`00Oomoo`0COol0015oo`03001oogoo045oo`03000eE3ED
00LeE004001oogoo000@BMD00`000ET1F@0>0ET00`00FQAJ5009FQ@00`00HYIRUP09HYH00`00DSMB
=`09DSL00`00Oomoo`07Ool00`00>KLi]`02>KL00`00>KLi]`02>KL00`00Oomoo`0dOol00`00Oomo
o`0COol0015oo`03001oogoo041oo`03000eE3ED00PeE004001oogoo000@BMD00`000ET1F@0?0ET2
0009FQ@00`00HYIRUP0:HYH00`00DSMB=`07DSL20009Ool00`00>KLi]`02>KL00`00>KLi]`02>KL0
0`00Oomoo`0dOol00`00Oomoo`0COol0011oo`03001oogoo045oo`03000eE3ED00LeE005001oogoo
Ool0000ABMD00`000ET1F@0@0ET00`00FQAJ5005FQ@00`00HYIRUP0<HYH00`00DSMB=`03DSL30000
0dge001oo`08Ool00`00>KLi]`02>KL00`00>KLi]`02>KL00`00Oomoo`0dOol00`00Oomoo`0COol0
011oo`03001oogoo045oo`03000eE3ED00LeE003001oogoo009oo`030019eDWE00i9e@030001F@5I
0141F@03001J55XD00=J5003001RUV:F00iRUPD000A=m@03001oogoo00Moo`<0008i]`05000i]cVg
>KL0000gOol00`00Oomoo`0COol0011oo`03001oogoo045oo`03000eE3ED00LeE003001oogoo009o
o`030019eDWE00i9e@030001F@5I0181F@80009J5003001RUV:F011RUP03001=mDge00I=m@03001o
ogoo00Eoo`040011UD6E@ID30003>KL00`00Oomoo`0eOol00`00Oomoo`0COol0011oo`03001oogoo
041oo`03000eE3ED00LeE003001oogoo00=oo`030019eDWE00i9e@030001F@5I01@1F@03001J5000
01=RUP8000I=m@03001oogoo00Eoo`030011UD6E00=1U@80008i]`03001oogoo03Eoo`03001oogoo
01=oo`0047oo00<007ooOol0@7oo00<003ED=E@01cED00<007ooOol00goo00<004WEBMD03dWE00<0
005I0ET0505I00<006:FHYH056:F00<004geCOD00dge00<007ooOol01Goo00<0046E@ID00d6E00<0
046E00000P00>7oo00<007ooOol04Woo000@Ool00`00Oomoo`10Ool20008=E@00`00Oomoo`04Ool0
0`00BME9e@0>BMD00`000ET1F@0E0ET00`00HYIRUP0DHYH00`00COE=m@02COD00`00Oomoo`04Ool0
0`00@IE1U@03@ID20003@ID00`00Oomoo`0fOol00`00Oomoo`0BOol000moo`03001oogoo045oo`04
000]EP000005=E@00`00Oomoo`05Ool00`00BME9e@0=BMD3000>0ET200070ET2000EHYH00`00COE=
m@02COD00`00Oomoo`03Ool00`00@IE1U@030002@ID01000@IE1U@00>7oo00<007ooOol04Woo000?
Ool00`00Oomoo`11Ool01@00;EH]EReF000013ED00<007ooOol01Goo00<004WEBMD02TWE0`0000A>
>000Ool000`1F@@000P1F@03001RUV:F01=RUP05001=mDgeCOD00005Ool30006@ID2000iOol00`00
Oomoo`0BOol000moo`03001oogoo045oo`03000]EReF008]EP05000eE3ED=E@00007Ool00`00BME9
e@07BMD30005CSP00`00Ool0000;0ET600070ET00`00HYIRUP0AHYH00`00J_P00002COD00`00Ool0
00030009@ID2000iOol00`00Oomoo`0BOol000moo`03001oogoo041oo`03000]EReF00@]EP<000Uo
o`030019eDWE0099e@@000Q>>003001oogoo008000P1F@P000L1F@03001RUV:F00mRUP04001Zn6[h
J_P40003Ool00`00@IE1U@07@ID2000iOol00`00Oomoo`0BOol000moo`03001oogoo041oo`03000]
EReF00H]EP03001oogoo00Moo`030019e@00008000a>>003001oogoo009oo`030001F@5I00@1F@T0
00P1F@03001RUV:F00iRUP03001Zn00000@000=oo`030011UD6E00Q1U@03001oo`0003Qoo`03001o
ogoo019oo`003goo00<007ooOol0@7oo00<002eF;EH01ReF00<007ooOol01goo0P0044hh00<007oo
Ool00Woo00<0005I0ET00`5I20002P5I0P003F:F0`0016[h0P000Woo00<0046E@ID0246E00@007oo
Ool003Moo`03001oogoo019oo`003goo00<007ooOol0@7oo00<002eF;EH01ReF00<007ooOol01goo
00<004hhCSP03dhh00<007ooOol00goo00@0005I0ET1F@P000d1F@03001RUV:F00MRUP<000QZn004
001oogoo0009@ID00`00Oomoo`02Ool00`00Oomoo`0eOol00`00Oomoo`0AOol000ioo`03001oogoo
045oo`03000]EReF00H]EP03001oogoo00Qoo`03001>>4hh00m>>003001oogoo00=oo`X000l1F@03
001RUV:F009RUP@00003HYH006[h00UZn08000Y1U@03001oogoo009oo`03001oogoo03Eoo`03001o
ogoo015oo`003Woo00<007ooOol0@Goo00<002eF;EH01ReF00<007ooOol027oo00<004hhCSP03dhh
00<007ooOol017oo20004@5I100016:F00<006[hJ_P02V[h00<0046E@ID01d6E00<007ooOol017oo
00<007ooOol0=7oo00<007ooOol04Goo000>Ool00`00Oomoo`11Ool00`00;EH]EP06;EH00`00Oomo
o`08Ool00`00CSQ>>00?CSP00`00Oomoo`03Ool9000?0ET40005HYH00`00J_QZn00<J_P00`00@IE1
U@06@ID00`00Oomoo`05Ool00`00Oomoo`0cOol00`00Oomoo`0AOol000ioo`03001oogoo045oo`03
000]EReF00H]EP03001oogoo00Uoo`03001>>4hh00m>>003001oogoo009oo`P000d1F@<000@1F@80
00=RUP03001Zn6[h00eZn0030011UD6E00A1U@03001oogoo00Moo`03001oogoo039oo`03001oogoo
015oo`003Woo00<007ooOol0@Goo00<002eF;EH01ReF00<007ooOol02Goo00<004hhCSP03dhh00@0
07ooOomoo`P000/1F@<000T1F@03001RUP00015Zn0030011UD6E00=1U@03001oogoo00Qoo`03001o
ogoo035oo`03001oogoo015oo`003Woo00<007ooOol0@Goo00<002eF;EH01ReF00<007ooOol02Woo
00<004hhCSP03Thh00<007ooOol0200000=oo`000ET01@5I10003@5I00<006[hJ_P04F[h00<0046E
@ID00T6E00<007ooOol027oo00<007ooOol0<Goo00<007ooOol04Goo000=Ool00`00Oomoo`11Ool0
0`00;EH]EP07;EH00`00Oomoo`0:Ool00`00CSQ>>00?CSP90003Ool20000105I000000004P5I00<0
06[hJ_P04F[h00@0046E@ID000aoo`03001oogoo035oo`03001oogoo011oo`003Goo00<007ooOol0
@Goo00<002eF;EH01ReF00<007ooOol02goo00<004hhCSP03dhh2@000goo0`005P5I00<006[hJ_P0
4F[h00<0046E00003Goo00<007ooOol0<7oo00<007ooOol047oo000=Ool00`00Oomoo`11Ool00`00
;EH]EP06;EH00`00Oomoo`0<Ool00`00CSQ>>00>CSP8000017oo000000000goo00<0005I0ET0505I
00<006[hJ_P03f[h00<007NI00003goo00<007ooOol0;goo00<007ooOol047oo000=Ool00`00Oomo
o`11Ool00`00;EH]EP06;EH00`00Oomoo`0<Ool00`00CSQ>>00?CSP80007Ool2000E0ET00`00J_QZ
n00=J_P01000MiUgV@0047oo00<007ooOol0;Woo00<007ooOol047oo000=Ool00`00Oomoo`11Ool0
0`00;EH]EP06;EH00`00Oomoo`0<Ool00`00CSQ>>00?CSP5000<Ool00`000ET1F@0C0ET00`00J_QZ
n00<J_P01@00MiUgVGNI00003goo00<007ooOol0;Woo00<007ooOol047oo000=Ool00`00Oomoo`11
Ool00`00;EH]EP06;EH00`00Oomoo`0=Ool00`00CSQ>>00<CSP6000>Ool00`000ET1F@0C0ET00`00
J_QZn00:J_P00`00MiUgV@03MiT00`00Oomoo`0=Ool00`00Oomoo`0]Ool00`00Oomoo`0@Ool000ao
o`03001oogoo049oo`<000H]EP03001oogoo00eoo`03001>>4hh00U>>0<000=>>0<000moo`8001@1
F@03001Zn6[h00QZn003001gVGNI00AgV@03001oogoo00ioo`03001oogoo02aoo`03001oogoo011o
o`0037oo00<007ooOol0@goo00@001UI000000@]EP03001oogoo00eoo`03001>>4hh00I>>0<000I>
>080019oo`030001F@5I0181F@03001Zn6[h00IZn003001gVGNI00IgV@03001oogoo00ioo`03001o
ogoo02aoo`03001oogoo00moo`0037oo00<007ooOol0@goo00@001UI6ETIF@80008]EP03001oogoo
00ioo`03001>>4hh009>>0<000Y>>003001oogoo015oo`8001<1F@03001Zn6[h00AZn003001gVGNI
00QgV@03001oogoo00ioo`03001oogoo02]oo`03001oogoo00moo`0037oo00<007ooOol0@goo00<0
01UI6ET00aUI0`0047oo1@0034hh0P005Goo00<0005I0ET04@5I00<006[hJ_P00V[h00<007NIMiT0
2GNI00<007ooOol03Woo00<007ooOol0:goo00<007ooOol03goo000<Ool00`00Oomoo`14Ool00`00
6ETIF@046ET00`00Oomoo`0<Ool4000<CSP30002DWX00`00Oomoo`0COol00`000ET1F@0A0ET01@00
J_QZn6[h000037NI00<007ooOol03Woo00<007ooOol0:Woo00<007ooOol03goo000<Ool00`00Oomo
o`14Ool00`006ETIF@046ET00`00Oomoo`09Ool30003Ool00`00CSQ>>007CSP30005DWX00`00Oomo
o`0DOol2000B0ET00`00J_P0000<MiT2000AOol00`00Oomoo`0YOol00`00Oomoo`0?Ool000aoo`03
001oogoo04Aoo`03000IFAUI00@IF@03001oogoo00Ioo`<000Ioo`03001>>4hh00=>>0@000UBNP03
001oogoo01Eoo`030001F@5I0101F@03001gVGNI00YgV@8001=oo`03001oogoo02Qoo`03001oogoo
00moo`002goo00<007ooOol0AGoo00<001UI6ET01AUI00<007ooOol00Woo0`002Woo00<004hh0000
0P003E9j00<007ooOol05Woo0P004@5I00<007NIMiT027NI00<005nc000057oo00<007ooOol09goo
00<007ooOol03goo000;Ool00`00Oomoo`16Ool00`006ETIF@046ET5000=Ool2000ADWX00`00Oomo
o`0GOol00`000ET1F@0>0ET00`00MiUgV@07MiT01000Gk=O/`0057oo00<007ooOol09goo00<007oo
Ool03goo000;Ool00`00Oomoo`16Ool00`006ETIF@026ET3000BOol00`00DWYBNP0?DWX00`00Oomo
o`0HOol00`000ET1F@0>0ET00`00MiUgV@05MiT01000Gk=O/`005Woo00<007ooOol09goo00<007oo
Ool03Woo000;Ool00`00Oomoo`16Ool00`006ET0000200026ET00`00Oomoo`0@Ool00`00DWYBNP0@
DWX00`00Oomoo`0HOol00`000ET1F@0>0ET00`00MiUgV@04MiT00`00Gk<0000HOol00`00Oomoo`0V
Ool00`00Oomoo`0>Ool000]oo`03001oogoo04Eoo`<000HIF@03001oogoo00moo`80015BNP03001o
ogoo01Yoo`030001F@5I00d1F@03001gVGNI009gV@04001O/enc000IOol00`00Oomoo`0UOol00`00
Oomoo`0>Ool000]oo`03001oogoo049oo`<0009oo`03000IFAUI00@IF@03001oogoo00ioo`<0019B
NP03001oogoo01Uoo`<000d1F@05001gVGNIMiT00002Gk<00`00Oomoo`0IOol00`00Oomoo`0TOol0
0`00Oomoo`0>Ool000Yoo`03001oogoo03moo`@000Eoo`03000IFAUI00@IF@03001oogoo00eoo`D0
015BNP03001oogoo01Qoo`040019L4U`BG02000<0ET00`00MiT00002Gk<00`00Oomoo`0JOol00`00
Oomoo`0TOol00`00Oomoo`0>Ool000Yoo`03001oogoo03aoo`<000Yoo`03000IFAUI00<IF@03001o
ogoo00aoo`H0019BNP03001oogoo01Ioo`030019L4U`00A9L08000/1F@04001O/enc000NOol00`00
Oomoo`0SOol00`00Oomoo`0>Ool000Yoo`03001oogoo03Uoo`<000eoo`03000IFAUI00@IF@03001o
ogoo00]oo`L0015BNP03001oogoo01Ioo`030019L4U`00I9L08000T1F@03001O/`00021oo`03001o
ogoo029oo`03001oogoo00ioo`002Woo00<007ooOol0=Woo0`004Goo00<001UI6ET00aUI00<007oo
Ool02Woo20004U9j00<007ooOol057oo00<004U`BG002DU`00<0005I0ET01P5I00<005nc00008Goo
00<007ooOol08Woo00<007ooOol03Goo000:Ool00`00Oomoo`0cOol3000DOol300036ET00`00Oomo
o`09Ool800000goo001BNP0@DWX00`00Oomoo`0COol00`00BG19L009BG000`00ABm5;`0400030ET2
000SOol00`00Oomoo`0QOol00`00Oomoo`0=Ool000Yoo`03001oogoo02moo`@001Qoo`0300016000
008IF@03001oogoo00Qoo`P0009oo`03001BNU9j011BNP03001oogoo015oo`030019L4U`00U9L003
0015;dD_00E5;`@002Aoo`03001oogoo025oo`03001oogoo00eoo`002Woo00<007ooOol0;7oo0`00
7Goo00<0004H00000QUI00<007ooOol01Woo2@000goo00<0059jDWX03e9j00<007ooOol047oo00<0
04U`BG002DU`00<004D_ABl01dD_00<007ooOol09Goo00<007ooOol087oo00<007ooOol03Goo0009
Ool00`00Oomoo`0ZOol3000POol00`000AP160030008Ool80004Ool00`00DWYBNP0@DWX00`00Oomo
o`0>Ool00`00BG19L00:BG000`00ABm5;`07ABl00`00Oomoo`0VOol00`00Oomoo`0OOol00`00Oomo
o`0=Ool000Uoo`03001oogoo02Moo`<002Aoo`050001604H0AP00007Ool90005Ool00`00DWYBNP0?
DWX00`00Oomoo`0=Ool00`00BG19L00:BG000`00ABm5;`08ABl00`00Oomoo`0WOol00`00Oomoo`0N
Ool00`00Oomoo`0=Ool000Uoo`03001oogoo02Aoo`<002Qoo`050001604H0AP00005Ool800000goo
001oo`04Ool00`00DWYBNP0?DWX2000<Ool200000de=00000009BG000`00ABm5;`09ABl00`00Oomo
o`0XOol00`00Oomoo`0MOol00`00Oomoo`0=Ool000Uoo`03001oogoo021oo`@002]oo`050001604H
0AP00004Ool80002Ool00`00Oomoo`04Ool00`00DWYBNP0;DWX30002D_`00`00Oomoo`08Ool00`00
CDe=C@03CDd00`00BG19L005BG000`00ABm5;`0:ABl00`00Oomoo`0XOol00`00Oomoo`0NOol00`00
Oomoo`0<Ool000Uoo`03001oogoo01eoo`<0031oo`050001604H0AP00002Ool90002Ool00`00Oomo
o`04Ool00`00DWYBNP08DWX30006D_`00`00Oomoo`05Ool20007CDd20004BG000`00ABm5;`0;ABl0
0`00Oomoo`0YOol00`00Oomoo`0MOol00`00Oomoo`0<Ool000Uoo`03001oogoo01Yoo`<003Aoo`06
0001604H0AP007oo20000goo00<007ooOol01Goo00<0059jDWX00e9j10002U;l00<007ooOol00goo
00<004e=CDd02De=0P0000=9L000000034D_0P00;7oo00<007ooOol077oo00<007ooOol037oo0008
Ool00`00Oomoo`0HOol3000gOol010000AP1604H2@0017oo00<007ooOol01Goo00<0059jDWX00`00
3U;l0`0000=oo`0000003Te=00<007oo000024D_100000<hJ@00Ool0;7oo00<007ooOol06goo00<0
07ooOol037oo0008Ool00`00Oomoo`0EOol3000kOol010000AP1604H1`0017oo00<007ooOol01goo
0P004U;l0`003Te=0P000Woo00<004D_ABl00dD_0`0013QY00<007ooOol0;Goo00<007ooOol06Woo
00<007ooOol037oo0008Ool00`00Oomoo`0AOol4000oOol300000`4H000000030005Ool00`00Oomo
o`08Ool00`00D_aBo00AD_`00`00CDe=C@0<CDd00`00Oomoo`02Ool00`00ABl000030007>6T00`00
Oomoo`0^Ool00`00Oomoo`0IOol00`00Oomoo`0<Ool000Qoo`03001oogoo00ioo`<004=oo`T000Eo
o`03001oogoo00Uoo`03001Bo5;l015Bo003001=CDe=00U=C@8000Eoo`8000/hJ@03001oogoo02io
o`03001oogoo01Uoo`03001oogoo00aoo`0027oo00<007ooOol02goo0`00AWoo20001Woo00<007oo
Ool02Woo00<005;lD_`04E;l00<004e=CDd01de=00<007ooOol01Goo00<003QY>6T02SQY00<007oo
Ool0;goo00<007ooOol067oo00<007ooOol037oo0008Ool00`00Oomoo`08Ool3001:Ool80005Ool0
0`00Oomoo`0:Ool00`00D_aBo00BD_`00`00CDe=C@04CDd20007Ool00`00>6ThJ@0:>6T00`00Oomo
o`0aOol00`00Oomoo`0HOol00`00Oomoo`0;Ool000Moo`03001oogoo00Ioo`<004moo`@000900080
00=oo`03001oogoo00]oo`03001Bo5;l015Bo003001=CDe=009=C@8000Uoo`03000hJCQY00XhJ@03
001oogoo039oo`03001oogoo01Moo`03001oogoo00]oo`001goo00<007ooOol00Woo1000Dgoo00<0
07ooOol00P000T0020002Goo0P002e;l100015;l00@004e=CDd000]oo`03000hJCQY00XhJ@03001o
ogoo03=oo`03001oogoo01Ioo`03001oogoo00]oo`001goo00<007oo00000P00G7oo0P000T0000<0
05BQE:400eBQ2@000UD900<005;lD_`025;l1@0015;l0P002goo00<003QY>6T02cQY00<007ooOol0
<goo00<007ooOol05Woo00<007ooOol02goo0007Ool2001QOol200000d000000000;E:401@00E@UE
2ED900002E;l1@0015;l0P002goo00<003QY>6T02SQY00<007ooOol0=Goo00<007ooOol05Goo00<0
07ooOol02goo0008Ool2001ROol200000d00001DX@0:E:420002E@T00`00D_aBo006D_`5000015;l
000000000TmO0P0027oo00<003QY>6T02SQY0P00>7oo00<007ooOol057oo00<007ooOol02goo000:
Ool00`00Oomoo`1POol4000<E:400`00E@T00008D_`60007Cel00`00Oomoo`05Ool00`00>6ThJ@06
>6T300000aP0001oo`0iOol00`00Oomoo`0COol00`00Oomoo`0;Ool000]oo`03001oogoo05moo`03
001oogoo00<000]DX@03001E2@0000IBo0H000U?G`03001oogoo00Aoo`03000hJCQY008hJ@@000<H
0003001oogoo03Yoo`03001oogoo01=oo`03001oogoo00Yoo`0037oo0P00Ggoo00<007ooOol00Woo
20001EBQ0`000U;l0`0000=?G`0000000`002TmO0P000goo00<003QY00000`001QP000<007ooOol0
>goo00<007ooOol04goo00<007ooOol02Woo000>Ool00`00Oomoo`1LOol00`00Oomoo`0:Ool:0004
Cel5000<Cel00`00Oomoo`02000960000`00Oomoo`0mOol00`00Oomoo`0BOol00`00Oomoo`0:Ool0
00moo`8005aoo`03001oogoo01=oo`8000=?G`D000e?G`8000XH0003001oogoo03moo`03001oogoo
015oo`03001oogoo00Yoo`004Goo00<007ooOol0FGoo00<007ooOol05Goo0P0000=?G`0000000`00
3TmO2`00@goo00<007ooOol047oo00<007ooOol02Woo000BOol2001IOol00`00Oomoo`0GOol6000:
Cel40005;e/40016Ool00`00Oomoo`0?Ool00`00Oomoo`0:Ool001Aoo`03001oogoo05Ioo`03001o
ogoo01Qoo`D000I?G`@000D_F`@004Yoo`03001oogoo00moo`03001oogoo00Yoo`005Goo00<007oo
Ool0EGoo00<007ooOol067oo1@000TmO10001BmK1000Cgoo00<007ooOol03Woo00<007ooOol02Woo
000FOol2001EOol00`00Oomoo`0HOol@001DOol00`00Oomoo`0>Ool00`00Oomoo`09Ool001Qoo`03
001oogoo059oo`03001oogoo07eoo`03001oogoo00eoo`03001oogoo00Uoo`006Goo0P00DWoo00<0
07ooOol0OWoo00<007ooOol037oo00<007ooOol02Goo000KOol00`00Oomoo`1?Ool00`00Oomoo`1n
Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool001aoo`8004moo`03001oogoo07moo`03001oogoo00]o
o`03001oogoo00Uoo`007Woo00<007ooOol0C7oo00<007ooOol0P7oo00<007ooOol02Woo00<007oo
Ool02Goo000OOol00`00Oomoo`1;Ool00`00Oomoo`21Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0
021oo`8004]oo`03001oogoo089oo`03001oogoo00Uoo`03001oogoo00Qoo`008Woo00<007ooOol0
B7oo00<007ooOol0PWoo00<007ooOol02Goo00<007ooOol027oo000SOol20018Ool00`00Oomoo`23
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool002Eoo`03001oogoo04Eoo`03001oogoo08Aoo`03001o
ogoo00Moo`03001oogoo00Qoo`009Woo0P00AGoo00<007ooOol0QGoo00<007ooOol01Woo00<007oo
Ool027oo000XOol00`00Oomoo`11Ool00`00Oomoo`27Ool00`00Oomoo`05Ool00`00Oomoo`08Ool0
02Uoo`03001oogoo041oo`03001oogoo08Moo`03001oogoo00Eoo`03001oogoo00Qoo`00:Woo0P00
@7oo00<007ooOol0R7oo00<007ooOol01Goo00<007ooOol01goo000/Ool00`00Oomoo`0mOol00`00
Oomoo`29Ool00`00Oomoo`04Ool00`00Oomoo`07Ool002eoo`8003eoo`03001oogoo08Yoo`03001o
ogoo00=oo`03001oogoo00Moo`00;goo00<007ooOol0>Woo00<007ooOol0Rgoo00<007ooOol00Woo
00<007ooOol01goo000`Ool2000jOol00`00Oomoo`2;Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
039oo`03001oogoo03Moo`03001oogoo08aoo`05001oogooOol00009Ool003=oo`03001oogoo03Io
o`03001oogoo08eoo`04001oogoo0009Ool003Aoo`8003Ioo`03001oogoo08ioo`03001oo`0000Uo
o`00=Woo00<007ooOol0<goo00<007ooOol0Sgoo00<007oo000027oo000gOol2000cOol00`00Oomo
o`2?Ool00`00Ool00008Ool003Uoo`03001oogoo031oo`03001oogoo091oo`8000Qoo`00>Woo0P00
<7oo00<007ooOol0Sgoo0`0027oo000lOol00`00Oomoo`0]Ool00`00Oomoo`2;Ool4000;Ool003eo
o`03001oogoo02aoo`03001oogoo08Moo`@000moo`00?Woo0P00;7oo00<007ooOol0PWoo1@004goo
0010Ool00`00Oomoo`0YOol00`00Oomoo`1nOol4000HOol0045oo`8002Uoo`03001oogoo07Uoo`D0
01aoo`00@goo00<007ooOol09Woo00<007ooOol0MGoo10008Goo0014Ool2000VOol00`00Oomoo`1a
Ool4000UOol004Ioo`03001oogoo02=oo`03001oogoo06aoo`D002Uoo`00Agoo00<007ooOol08Woo
00<007ooOol0J7oo1000;Woo0018Ool2000ROol00`00Oomoo`1SOol5000bOol004Yoo`03001oogoo
01moo`03001oogoo05moo`@003Moo`00Bgoo0P007goo00<007ooOol0Fgoo1000>goo001=Ool00`00
Oomoo`0LOol00`00Oomoo`1FOol5000oOol004ioo`8001aoo`03001oogoo059oo`@004Aoo`00D7oo
00<007ooOol06Goo00<007ooOol0CWoo1000B7oo001AOol00`00Oomoo`0HOol00`00Oomoo`19Ool5
001<Ool0059oo`8001Qoo`03001oogoo04Eoo`@0055oo`00E7oo00<007ooOol05Goo00<007ooOol0
@7oo1@00EGoo001EOol2000DOol00`00Oomoo`0mOol4001JOol005Moo`03001oogoo015oo`03001o
ogoo03Uoo`@005ioo`00F7oo0P004Goo00<007ooOol0=7oo1@00HWoo001JOol00`00Oomoo`0>Ool0
0`00Oomoo`0`Ool4001WOol005]oo`03001oogoo00eoo`03001oogoo02aoo`@006]oo`00G7oo0P00
3Goo00<007ooOol09goo1@00Kgoo001NOol00`00Oomoo`0:Ool00`00Oomoo`0SOol4001dOol005mo
o`8000Yoo`03001oogoo01ioo`D007Qoo`00HGoo00<007ooOol01goo00<007ooOol06Woo1000OGoo
001ROol20007Ool00`00Oomoo`0FOol40021Ool006Aoo`03001oogoo00Aoo`03001oogoo015oo`D0
08Eoo`00IGoo00<007ooOol00goo00<007ooOol03Goo1000RWoo001VOol20003Ool00`00Oomoo`08
Ool5002>Ool006Qoo`04001oogoo0006Ool4002COol006Uoo`<0009oo`@009Moo`00Jgoo0`00Vgoo
003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00?moo`Yoo`00ogoo2Woo003oOol:Ool00001
\
\>"],
  ImageRangeCache->{{{0, 264}, {286, 0}} -> {0.0236399, -0.026159, 0.00343781,
   0.00343781}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1 so that initial conditions are available for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Omega[rotor] /. SolveMech[0, Solution \[Rule] Acceleration]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({62.8318530717958623`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Instantaneous Free Acceleration"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the free acceleration of the gyroscope, one or more constraints \
must be dropped. The constraint that prevents rotation of the base, \
constraint 2, is dropped first. The rotor cannot precess in this state \
because the gimbal is still locked to the base, but the reaction torques \
applied to the base that accelerate the rotor can be measured.\n\nNo initial \
conditions are explicitly given. Initial guesses are taken from the default \
initial guesses that were set by the last run of ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This drops the constraint that locks the base relative to the ground."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fsys = SetFree[2, Solution \[Rule] Dynamic]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = SolveFree[fsys]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The angular acceleration of the rotor is 1-unit in the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction. This corresponds to the 1-unit applied moment divided by the \
1-unit moment of inertia about the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " axis."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[rotor], Alpha[rotor], Alpha[gimbal]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{62.8318530717958623`, 0.`, 0.`}, {0.`, 0.`, 1.`}, {0.`, 0.`, 1.`}}\)],
   "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "There is no gyroscopic torque applied to the base by the ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint because the base has zero angular velocity at this instant."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, base] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {0.`, 0.`, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "To make this model a little more interesting, the base is given a nonzero \
angular velocity with the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This induces gyroscopic torques in the base constraint. To be consistent \
with the constraints the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " components of the initial angular velocity of each body must be \
identical. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with a new partial initial condition. The rest of the initial \
conditions are taken from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = 
      SolveFree[fsys, 
        InitialCondition 
          \[Rule] {Wz2 \[Rule] 1, Wz3 \[Rule] 1, Wz4 \[Rule] 1}]; \)\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The angular acceleration of the rotor now has a component in the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " direction corresponding to the changing direction of the angular velocity \
vector."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[rotor], Alpha[rotor], Alpha[gimbal]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{62.8318530717958623`, 0.`, 1}, {0.`, 62.8318530717958623`, 1.`}, {
        0.`, 0.`, 1.`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now there is a gyroscopic torque applied to the base by the ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, base] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {0.`, 125.663706143591724`, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Now the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is rebuilt with both the base and the gimbal unlocked. The same initial \
velocity for the base, gimbal, and rotor is used so that the gyroscope \
precesses."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds and solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with constraints 2 and 4 dropped."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(fsys = SetFree[{2, 4}, Solution \[Rule] Dynamic]; \)\), 
    \(\(sol = 
      SolveFree[fsys, 
        InitialCondition 
          \[Rule] {Wz2 \[Rule] 1, Wz3 \[Rule] 1, Wz4 \[Rule] 1}]; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Without the constraint forces applied by constraint 4, the gimbal has an \
angular acceleration about its ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " axis induced by the gyroscopic forces."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[rotor], Alpha[rotor], Alpha[gimbal]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{62.8318530717958623`, 0.`, 1}, {0.`, \(-62.8318530717958623`\), 
        1.`}, {0.`, \(-125.663706143591724`\), 1.`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Again, there is no gyroscopic torque applied to the base by the ",
  StyleBox["Revolute5",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint because the gimbal is free to rotate. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, base] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {0.`, 0.`, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Gyroscopic Moments"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Gyroscopic forces and moments modeled as per the example in the previous \
subsection work well for single point analyses. However, if the time-domain \
free response is desired, such a modeling technique has a serious \
computational problem. While the rotor is spinning rapidly, the Euler \
parameters that represent the angular orientation of the rotor are changing, \
sinusoidally, very rapidly. To numerically integrate such a system, the \
integrator must faithfully track very many periods of the sinusoidal Euler \
parameters to cover only a few periods of the motion of the more interesting \
parts of the gyroscope. If the period of the rotor's local rotation is much, \
much shorter than the period of interest, the integration becomes \
computationally infeasible.\n\nThe way around this problem is to introduce a \
special forcing function that mimics the gyroscopic torque of a spinning \
axially symmetric body and apply it to the rotor. This allows the rotor to be \
rotationally static."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GyroMoment[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ", ",
  StyleBox["omega",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " applies a moment to body ",
  StyleBox["bnum ",
    FontSlant->"Italic"],
  "to simulate the gyroscopic effects of the body spinning with angular speed \
",
  StyleBox["omega",
    FontSlant->"Italic"],
  ", about an axis originating at the centroid of the body, parallel to ",
  StyleBox["vec",
    FontSlant->"Italic"],
  ". The constant angular velocity is relative to the local reference frame \
of body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Inertia",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that is used to specify the inertia tensor of the gyroscoping body. The \
default setting ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the inertia tensor from body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A function to simulate gyroscopic moments."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has two important caveats attached to its use: the gyroscopic motion that \
it models is that of a body rotating about a principal axis of inertia ",
  StyleBox["and",
    FontSlant->"Italic"],
  " the two principle moments not associated with the axis of rotation must \
be equal. For most practical purposes, this means that the body is axially \
symmetric, and it is rotating about its axis of symmetry.\n\nTo demonstrate \
the use of ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the gyroscope model that was presented in the previous subsection is \
modified to remove the large angular velocity of the rotor and replace it \
with a ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here the gyroscopic moment simulation is added to the applied loads, the \
angular speed of the rotor body is reduced to zero, and the model is run at ",
  
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 so initial conditions are available to ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetLoads[Moment[base, Z, 1], GyroMoment[rotor, X, 20\ N[\[Pi]]]]\), 
    \(\(SetParameters[freq \[Rule] 0]; \)\), 
    \(Omega[rotor] /. SolveMech[0, Solution \[Rule] Kinematic]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "First, the constraint that locks the base to the ground is dropped and ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run with the ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " direction angular velocity set to 1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(fsys = SetFree[2, Solution \[Rule] Dynamic]; \)\), 
    \(\(sol = 
      SolveFree[fsys, 
        InitialCondition 
          \[Rule] {Wz2 \[Rule] 1, Wz3 \[Rule] 1, Wz4 \[Rule] 1}]; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The resulting angular velocities and accelerations are missing the large \
components that were due to the rotation of the rotor."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[rotor], Alpha[rotor], Alpha[gimbal]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 1}, {0.`, 0.`, 1.`}, {0.`, 0.`, 1.`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"But the reaction at the base still reflects the gyroscopic torques."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, base] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {0.`, 125.663706143591724`, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds and solves the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object with constraints 2 and 4 dropped."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(fsys = SetFree[{2, 4}, Solution \[Rule] Dynamic]; \)\), 
    \(\(sol = 
      SolveFree[fsys, 
        InitialCondition 
          \[Rule] {Wz2 \[Rule] 1, Wz3 \[Rule] 1, Wz4 \[Rule] 1}]; \)\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Without the rotation of the rotor, the angular accelerations of the rotor \
and gimbal are equal."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \({Omega[rotor], Alpha[rotor], Alpha[gimbal]} /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 1}, {0.`, \(-125.663706143591724`\), 1.`}, {0.`, 
        \(-125.663706143591724`\), 1.`}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"There is still no gyroscopic torque applied to the base when the gimbal is \
free to rotate. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Reaction[1, base] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{0.`, 0.`, 0.`}, {0.`, 0.`, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The constraint reaction forces that result from using this method are \
identical to the reaction forces that result from the normal procedure, \
without the use of ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The true values of alpha and omega for the simulated rotor are \
reproduced by the following calculation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["omegalocal",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the local angular velocity vector that was passed to ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that ",
  StyleBox["omegatrue",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["alphatrue",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " match the angular velocity and acceleration components of the rotor in \
the previous analysis."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(omegalocal = {20\ N[\[Pi]], 0, 0}; \)\), 
    \(omegatrue = omegalocal + Omega[rotor] /. sol\), 
    \(alphatrue = Omega[rotor]\[Cross]omegalocal + Alpha[rotor] /. sol\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({62.8318530717958623`, 0.`, 1}\)], "Output"],

Cell[BoxData[
    \({0.`, \(-62.8318530717958623`\), 1.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"The equations of motion that are produced by this method are essentially \
equivalent to the equations of motion without the spinning rotor simulation, \
with one important difference, these equations of motion can be easily \
integrated to obtain the time-domain motion of the entire gyroscope assembly \
without an overwhelming computational burden. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph:=Graphics[{\n   Polygon[{{0,0},{1,-1},{-1,-1}}],\n  \
{RGBColor[1,0,0],Bar[Line[link1, {-3,0}, { 3,0}], 0.4],\n   \
RGBColor[0,0,1],Bar[Line[link2, { 3,0}, {-3,0}], 0.4]},\n   \
AbsolutePointSize[16],\n   Vertex[link2, {{-3,0}, {3,0}}], Point[{0,0}],\n   \
{Thickness[0.015],\n    Arrow[Axis[Location[link2,{-3,0}]-{2.5,0},{1,0}],2]},\
\n   Text[FontForm[\"F\", {\"Times-Bold\", 16}],{-1.5,5}],\n   \
LocalAxes[{link1, link2},2]},\n   AspectRatio \[Rule] Automatic,\n   \
PlotRange \[Rule] {{-4,7},{-1,7}},\n   Frame \[Rule] True]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph:=Graphics3D[{\n  \
Polygon[{{2,2,-2.2},{2,-2,-2.2},{-2,-2,-2.2},{-2,2,-2.2}}],\n  Bar[Axis[base, \
{-.25,0,0}, .5 X], 2, 20, Ends \[Rule] False],\n  Bar[Axis[gimbal, {0,0,-.2}, \
.4 Z], 1.9, 20, Ends \[Rule] False],\n  Thickness[0.02],\n  \
Line[{{0,0,-2.2},{0,0,-1.7}}],Line[{{0,0,1.7},{0,0,2.2}}],\n  Edge[base, \
{{0,-2.2,0},{0,-1.7,0}},{{0,1.7,0},{0,2.2,0}}],\n  Thickness[0.007],\n  \
(*LocalAxes[rotor, 2.5],*)\n  Thickness[0.03],\n  Bar[Axis[rotor, {-.2,0,0}, \
.4 X], 1.6, 16],\n  Edge[gimbal,{{-1.9,0,0},{1.9,0,0}}]},\n  PlotRange \
\[Rule] {{-2.5,2.5},{-2.5,2.5},{-2.5,2.5}}]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["10.4  Dynamic Motion Synthesis"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers the use of the ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to numerically integrate the equations of motion built by ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is done to find the time-domain dynamic motion of underconstrained \
systems. The ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that contain the equations of motion to be integrated are built \
using the same procedure that would be used if only the instantaneous free \
response was desired. Building such ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects is covered in Sections 10.2 and 10.3."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Numerical Integration"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveFree[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["freesys, endtime, options",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the time-domain solution to a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object built with ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrates the equations of motion in ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " from the initial time (that is contained in ",
  StyleBox["freesys",
    FontSlant->"Italic"],
  " or set with the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option) to ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of rules representing the solution in the form of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Numerical integration with ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "There are several issues that are specifically associated with the \
numerical solution of the constrained equations of motion generated by ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  ". The equations of motion are a nonminimal differential-algebraic system \
of equations, that may or may not be linear in the highest-order terms.\n\n\
One important issue is constraint violation. The equations of motion do not \
include the actual kinematic constraints, they only include the second time \
derivatives of the constraint equations. Because of this, small errors in the \
numerical integration of the equations of motion can accumulate into large \
violations of the kinematic constraints and their first derivatives. To deal \
with this problem, the equations can be algebraically reduced to a minimal \
set, but this is not generally possible with the type of constraints allowed \
by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  ". Alternatively, the numerical values of the dependent variables can be \
corrected as the integration progresses so as to continuously satisfy the \
constraints. This method is implemented in ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nAnother issue is the transformation of angular velocity and \
acceleration in 3D models. If a model is built with angular coordinates (the \
",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option in ",
  StyleBox["SetSymbols",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") the first and second derivatives of angular orientation are represented \
by the angular velocity, omega, and the angular acceleration, alpha. \
Unfortunately, omega is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " the first derivative of the Euler parameters used to represent angular \
orientation. Thus, a coordinate transformation must occur at each time step \
to allow the Euler parameters to be integrated. ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " handles this transformation automatically, so models built in any \
coordinate system can be integrated.\n\nThe equations of motion are not \
necessarily linear in their highest-order terms, depending on the form of the \
applied loads. ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " automatically switches to an iterative solution method for nonlinear \
systems that allows them to be solved, albeit slowly."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Initialization Options"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The only option that is concerned with the initialization of the \
integrator is the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. All other information needed to integrate the equations of motion \
is contained in the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. This option is most useful for repeatedly integrating the same ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with different sets of initial conditions without having to rerun ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " is used to set the initial conditions for numerical integration. The ",
  StyleBox["rules",
    FontSlant->"Italic"],
  " should be a list of rules specifying the location, or location and \
velocity, of each body in the model. The initial value of time should be \
included. Any dependent variables not specified in ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are taken from the rules contained in the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object passed into ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These initial conditions are taken from ",
  StyleBox["LastSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " when the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built with ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". ",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An initialization option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The list of rules required by ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is of the form returned by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Using ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to generate the initial conditions (which is essentially what is done by \
the default setting) guarantees that the initial conditions constitute a \
valid solution to the constraint equations. If initial conditions that do not \
satisfy the constraints are passed to ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the integration will proceed without difficulty, producing results that \
satisfy the differential equations of motion, but do not satisfy the \
kinematic constraints.\n\nNote that a sufficient set of initial conditions \
for integrating a free acceleration system is returned by ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time",
    FontSlant->"Italic"],
  ", ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Velocity]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", while a sufficient set of initial conditions for integrating an \
equilibrium velocity system is returned by ",
  StyleBox["SolveMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["time",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Integration Options"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following options are used to control the actual integration algorithm \
used by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default settings for these options are intended to produce \
reasonable results in the shortest possible time with a well-behaved system. \
Some tweaking may be required to get the best result from models with large \
accelerations or force discontinuities."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["ConstraintCorrection",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " enables an algorithm that corrects the location and velocity of each body \
at each time step so as to be consistent with the kinematic constraints. ",
  StyleBox["ConstraintCorrection",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be used if the solution returned by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " appears to drift away from satisfying the constraints. Using constraint \
correction approximately doubles the time required to run the integration. \
The default setting is ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["sym",
    FontSlant->"Italic"],
  " specifies the degree of polynomial that is used to approximate each \
segment of the integrand at each time step. Valid settings for ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Linear",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Settings of lower degree work well on models that exhibit acceleration \
discontinuities. The default setting is ",
  StyleBox["Cubic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["num",
    FontSlant->"Italic"],
  " is used to specify the maximum estimated error allowed in any dependent \
variable in a single time step. If the maximum error in the current step goes \
above ",
  StyleBox["num",
    FontSlant->"Italic"],
  ", the time step size is halved. Setting ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to a smaller number than the default, 0.0001, effectively tightens the \
error tolerance, producing a more accurate result.\n \n",
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " specifies the maximum number of time steps that will be taken by the \
numerical integrator. If ",
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is exceeded before reaching the final time, ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " stops and returns as much of the result as was completed. The default \
setting is ",
  StyleBox["MaxSteps",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["500",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["MaxStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["number",
    FontSlant->"Italic"],
  " specifies the maximum step size that is used by the integrator. ",
  StyleBox["MaxStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no effect if ",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not set to ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["Infinity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for controlling the ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrator."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Predictor",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to use an Adams-Bashforth predictive integration algorithm that requires \
one evaluation of the integrand at each time step. ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Corrector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses an Adams-Moulton predictor-corrector algorithm that requires two \
integrand evaluations per time step. ",
  StyleBox["Method",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the default, enables automatic switching between predictive and \
corrective steps, depending on the current error estimate, as the integration \
proceeds.\n\n",
  StyleBox["StartingStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["num",
    FontSlant->"Italic"],
  " specifies the starting step size that is used by the integrator. ",
  StyleBox["StartingStepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no effect if ",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is not set to the default setting, ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["num",
    FontSlant->"Italic"],
  " specifies a constant time step size ",
  StyleBox["num",
    FontSlant->"Italic"],
  " that is used throughout the integration. The default setting, ",
  StyleBox["Automatic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", allows the time step size to be automatically increased or decreased by \
a factor of 2 as required by the current error estimate."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["More options for controlling the integrator."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The error estimation used by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " makes an assumption that the approximate magnitude of each of the \
dependent variables is near to 1. While this assumption is certainly valid \
for Euler parameters that are between -1 and 1, and the 2D angular coordinate \
that has units of radians, it is up to the user to choose a system of units \
such that the linear dimensions of the model are not extremely large or \
small. While the error estimation routine does not look at the Lagrange \
multipliers (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ...",
    FontFamily->"Times"],
  ") it is best to keep the units of force and mass such that the Lagrange \
multipliers are not extremely large or small, because other parts of the \
numerical solution method begin to produce significant errors when dealing \
with a wide range of numerical magnitudes. \n\nWhen step size switching is \
enabled, ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " basically limits the maximum error in any dependent variable at a single \
time step to be less than the ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting. If this is exceeded at a time step, the integrator backs up, \
halves the step size, and proceeds forward again. This error limit seems \
rather loose. If the same variable exhibited the maximum signed error at each \
time step, the cumulative error in that variable after 1000 time steps would \
be 0.1! In reality, the large errors occur at discrete points in the motion \
of a model, so the cumulative error is n",
  StyleBox["ormally smaller. \n\nThe ",
    FontFamily->"Times"],
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  " option can also be used to explicitly specify the error magnitude limits \
at which the time step size is halved, doubled, or when a corrective versus \
predictive step is taken. ",
    FontFamily->"Times"],
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox["a, b, c",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Times",
    FontWeight->"Bold"],
  StyleBox[
  " specifies that the time step size will be doubled if the sum of the \
maximum errors in the last four steps drops below ",
    FontFamily->"Times"],
  StyleBox["c",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  ", it will be halved if the error in the current step goes above ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[
  ", and an Adams-Moulton corrective step will be taken if the error is \
between ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontFamily->"Times"],
  StyleBox["b",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[". Thus, ",
    FontFamily->"Times"],
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{0.0001, 0.00001, 0.000001}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" is equivalent to the default setting of ",
    FontFamily->"Times"],
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["0.0001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Iterative Solution Options"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following options are used only to control the iterative solution block \
used for nonlinear models. These options have no effect on linear models."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " sets the maximum number of iterations that are used by the Newton-Rhapson \
solution block. The default setting is 15.\n\n",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["func",
    FontSlant->"Italic"],
  " specifies a function to be applied to the values of the constraint \
expressions to determine if they are sufficiently close to zero. The default \
setting is ",
  StyleBox["ZeroTest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["( Abs[#] < 10^(-9)& )",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options for the Newton-Rhapson solution block in ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Free acceleration models are always linear in the acceleration variables \
(",
  StyleBox["X2dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) but they may be nonlinear in the Lagrange multipliers (",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ... ) if there are loads applied that are algebraically dependent on \
reaction forces, such as friction. Equilibrium velocity models can be \
nonlinear in the Lagrange multipliers, and they can also be nonlinear in \
velocity variables (",
  StyleBox["X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) if the applied loads are nonlinear functions of velocity. The \
second element in a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object tells whether the model is linear or not. ",
  StyleBox["FreeSystem[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "...",
  StyleBox["][[2]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for nonlinear models."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Output Control Options"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following options are used to specify what data are returned by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and what format is used to returned it."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["FunctionOfTime",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return pure functions that must have a single numeric argument to be \
evaluated, instead of ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects that are explicitly functions of time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Interpolation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return the results in raw form, as lists of real numbers representing \
the value of each variable at each time step. The default setting is ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["InterpolationOrder",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["integer",
    FontSlant->"Italic"],
  " specifies the order of the interpolating polynomials that are used to \
interpolate the results. A lower setting than the default, 3, may cause the \
interpolating functions to evaluate more quickly.\n\n",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["syms",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to specify which dependent variables to include in the results. ",
  
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["syms",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be any subset of the list: ",
  StyleBox[
  "{Parameters, Location, Velocity, Acceleration, Generalized, Diagnostics}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting, {",
  StyleBox["Parameters",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", ",
    FontFamily->"Times"],
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "}, includes ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects for the location solution and any parameters. Constants are not \
interpolated.\n\n",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an optional element of the setting for ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Including ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " causes ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to return two extra ",
  StyleBox["InterpolatingFunction",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects, ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["intfunc",
    FontSlant->"Italic"],
  " and ",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["intfunc",
    FontSlant->"Italic"],
  ", that represent the maximum error in any dependent variable and the \
current time step size as functions of time."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Output options for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["StepSize",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data that are returned by the ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting can be useful to help determine what should be chosen for a \
constant step size, if one is desired. The ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " data included by ",
  StyleBox["Diagnostics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are the measure of error used by the adaptive time step adjustment \
algorithm to decide when to change the step size."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Planar Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"The following example uses the pendulum-on-a-rope model that was developed \
in Section 10.1. The pendulum is released from a constrained zero velocity \
position, that is not in static equilibrium, and the free response is found.\n\
\nThe spring force that was used to pull the pendulum off to one side is \
removed from the model, but gravity is retained. Also, nonzero moments of \
inertia are defined for each body, since the moments of inertia are relevant \
to the dynamics of the system, while they were not relevant to the \
equilibrium analysis. "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the three body objects, including the new inertia properties."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetBodies[\n\t
      Body[ground = 1, PointList \[Rule] {{4, 0}, {5, \(-3\)}}], 
      Body[slider = 2, PointList \[Rule] {{\(-0.5\), 0.3}, {0.5, 0.3}}, 
        InitialGuess \[Rule] {{2.0, \(-1.5\)}, 0}, Mass \[Rule] 1.0, 
        Inertia \[Rule] 0.5, Centroid \[Rule] {0, 0.2}], \n\t
      Body[pendulum = 3, PointList \[Rule] {{0, 1.8}}, 
        InitialGuess \[Rule] {{2.0, \(-3.0\)}, 0}, Mass \[Rule] 2.0, 
        Inertia \[Rule] 0.4]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"The pendulum-on-a-rope model uses seven constraint objects. The constraints \
that fix the initial position of the model have been altered so that the \
pendulum may be released from an offset position."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Here are the constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[\n\t
      RelativeDistance1[1, \n\t\tPoint[ground, 0], Point[slider, 1], s], \n\t
      RelativeDistance1[2, \n\t\tPoint[ground, 1], Point[slider, 2], 4 - s], 
      \n\tConstraint[3, {}, {s, 2.5}], \n\t
      Revolute2[4, Point[slider, 0], Point[pendulum, 1]], \n\t
      RelativeX1[5, Point[slider, 0], 2.5], \n\tRotationLock1[6, slider, 0], 
      \n\tRotationLock1[7, pendulum, 0.5]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the gravitational load applied to the pendulum and slider."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[Gravity[{0, \(-1\)}, 9.81]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the model is run with ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({T \[Rule] 0, X2 \[Rule] 2.5`, Y2 \[Rule] \(-1.58086884575541937`\), 
      Th2 \[Rule] 0.`, X3 \[Rule] 3.36296596948756532`, 
      Y3 \[Rule] \(-3.16051745715809051`\), Th3 \[Rule] 0.5`, 
      s \[Rule] 2.375`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the pendulum-on-a-rope model in its initial configuration."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[(1)] .2 0 0 2 Msboxa
[(2)] .4 0 0 2 Msboxa
[(3)] .6 0 0 2 Msboxa
[(4)] .8 0 0 2 Msboxa
[(5)] 1 0 0 2 Msboxa
[(-4)] -0.0125 0 1 0 Msboxa
[(-3.5)] -0.0125 .1 1 0 Msboxa
[(-3)] -0.0125 .2 1 0 Msboxa
[(-2.5)] -0.0125 .3 1 0 Msboxa
[(-2)] -0.0125 .4 1 0 Msboxa
[(-1.5)] -0.0125 .5 1 0 Msboxa
[(-1)] -0.0125 .6 1 0 Msboxa
[(-0.5)] -0.0125 .7 1 0 Msboxa
[(0)] -0.0125 .8 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.2 0 m
.2 .00625 L
s
P
[(1)] .2 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(2)] .4 0 0 2 Mshowa
p
.002 w
.6 0 m
.6 .00625 L
s
P
[(3)] .6 0 0 2 Mshowa
p
.002 w
.8 0 m
.8 .00625 L
s
P
[(4)] .8 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(5)] 1 0 0 2 Mshowa
p
.001 w
.04 0 m
.04 .00375 L
s
P
p
.001 w
.08 0 m
.08 .00375 L
s
P
p
.001 w
.12 0 m
.12 .00375 L
s
P
p
.001 w
.16 0 m
.16 .00375 L
s
P
p
.001 w
.24 0 m
.24 .00375 L
s
P
p
.001 w
.28 0 m
.28 .00375 L
s
P
p
.001 w
.32 0 m
.32 .00375 L
s
P
p
.001 w
.36 0 m
.36 .00375 L
s
P
p
.001 w
.44 0 m
.44 .00375 L
s
P
p
.001 w
.48 0 m
.48 .00375 L
s
P
p
.001 w
.52 0 m
.52 .00375 L
s
P
p
.001 w
.56 0 m
.56 .00375 L
s
P
p
.001 w
.64 0 m
.64 .00375 L
s
P
p
.001 w
.68 0 m
.68 .00375 L
s
P
p
.001 w
.72 0 m
.72 .00375 L
s
P
p
.001 w
.76 0 m
.76 .00375 L
s
P
p
.001 w
.84 0 m
.84 .00375 L
s
P
p
.001 w
.88 0 m
.88 .00375 L
s
P
p
.001 w
.92 0 m
.92 .00375 L
s
P
p
.001 w
.96 0 m
.96 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(-4)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .1 m
.00625 .1 L
s
P
[(-3.5)] -0.0125 .1 1 0 Mshowa
p
.002 w
0 .2 m
.00625 .2 L
s
P
[(-3)] -0.0125 .2 1 0 Mshowa
p
.002 w
0 .3 m
.00625 .3 L
s
P
[(-2.5)] -0.0125 .3 1 0 Mshowa
p
.002 w
0 .4 m
.00625 .4 L
s
P
[(-2)] -0.0125 .4 1 0 Mshowa
p
.002 w
0 .5 m
.00625 .5 L
s
P
[(-1.5)] -0.0125 .5 1 0 Mshowa
p
.002 w
0 .6 m
.00625 .6 L
s
P
[(-1)] -0.0125 .6 1 0 Mshowa
p
.002 w
0 .7 m
.00625 .7 L
s
P
[(-0.5)] -0.0125 .7 1 0 Mshowa
p
.002 w
0 .8 m
.00625 .8 L
s
P
[(0)] -0.0125 .8 1 0 Mshowa
p
.001 w
0 .02 m
.00375 .02 L
s
P
p
.001 w
0 .04 m
.00375 .04 L
s
P
p
.001 w
0 .06 m
.00375 .06 L
s
P
p
.001 w
0 .08 m
.00375 .08 L
s
P
p
.001 w
0 .12 m
.00375 .12 L
s
P
p
.001 w
0 .14 m
.00375 .14 L
s
P
p
.001 w
0 .16 m
.00375 .16 L
s
P
p
.001 w
0 .18 m
.00375 .18 L
s
P
p
.001 w
0 .22 m
.00375 .22 L
s
P
p
.001 w
0 .24 m
.00375 .24 L
s
P
p
.001 w
0 .26 m
.00375 .26 L
s
P
p
.001 w
0 .28 m
.00375 .28 L
s
P
p
.001 w
0 .32 m
.00375 .32 L
s
P
p
.001 w
0 .34 m
.00375 .34 L
s
P
p
.001 w
0 .36 m
.00375 .36 L
s
P
p
.001 w
0 .38 m
.00375 .38 L
s
P
p
.001 w
0 .42 m
.00375 .42 L
s
P
p
.001 w
0 .44 m
.00375 .44 L
s
P
p
.001 w
0 .46 m
.00375 .46 L
s
P
p
.001 w
0 .48 m
.00375 .48 L
s
P
p
.001 w
0 .52 m
.00375 .52 L
s
P
p
.001 w
0 .54 m
.00375 .54 L
s
P
p
.001 w
0 .56 m
.00375 .56 L
s
P
p
.001 w
0 .58 m
.00375 .58 L
s
P
p
.001 w
0 .62 m
.00375 .62 L
s
P
p
.001 w
0 .64 m
.00375 .64 L
s
P
p
.001 w
0 .66 m
.00375 .66 L
s
P
p
.001 w
0 .68 m
.00375 .68 L
s
P
p
.001 w
0 .72 m
.00375 .72 L
s
P
p
.001 w
0 .74 m
.00375 .74 L
s
P
p
.001 w
0 .76 m
.00375 .76 L
s
P
p
.001 w
0 .78 m
.00375 .78 L
s
P
p
.002 w
0 0 m
0 .8 L
s
P
P
p
p
.002 w
0 .79375 m
0 .8 L
s
P
p
.002 w
.2 .79375 m
.2 .8 L
s
P
p
.002 w
.4 .79375 m
.4 .8 L
s
P
p
.002 w
.6 .79375 m
.6 .8 L
s
P
p
.002 w
.8 .79375 m
.8 .8 L
s
P
p
.001 w
.04 .79625 m
.04 .8 L
s
P
p
.001 w
.08 .79625 m
.08 .8 L
s
P
p
.001 w
.12 .79625 m
.12 .8 L
s
P
p
.001 w
.16 .79625 m
.16 .8 L
s
P
p
.001 w
.24 .79625 m
.24 .8 L
s
P
p
.001 w
.28 .79625 m
.28 .8 L
s
P
p
.001 w
.32 .79625 m
.32 .8 L
s
P
p
.001 w
.36 .79625 m
.36 .8 L
s
P
p
.001 w
.44 .79625 m
.44 .8 L
s
P
p
.001 w
.48 .79625 m
.48 .8 L
s
P
p
.001 w
.52 .79625 m
.52 .8 L
s
P
p
.001 w
.56 .79625 m
.56 .8 L
s
P
p
.001 w
.64 .79625 m
.64 .8 L
s
P
p
.001 w
.68 .79625 m
.68 .8 L
s
P
p
.001 w
.72 .79625 m
.72 .8 L
s
P
p
.001 w
.76 .79625 m
.76 .8 L
s
P
p
.001 w
.84 .79625 m
.84 .8 L
s
P
p
.001 w
.88 .79625 m
.88 .8 L
s
P
p
.001 w
.92 .79625 m
.92 .8 L
s
P
p
.001 w
.96 .79625 m
.96 .8 L
s
P
p
.002 w
0 .8 m
1 .8 L
s
P
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .1 m
1 .1 L
s
P
p
.002 w
.99375 .2 m
1 .2 L
s
P
p
.002 w
.99375 .3 m
1 .3 L
s
P
p
.002 w
.99375 .4 m
1 .4 L
s
P
p
.002 w
.99375 .5 m
1 .5 L
s
P
p
.002 w
.99375 .6 m
1 .6 L
s
P
p
.002 w
.99375 .7 m
1 .7 L
s
P
p
.001 w
.99625 .02 m
1 .02 L
s
P
p
.001 w
.99625 .04 m
1 .04 L
s
P
p
.001 w
.99625 .06 m
1 .06 L
s
P
p
.001 w
.99625 .08 m
1 .08 L
s
P
p
.001 w
.99625 .12 m
1 .12 L
s
P
p
.001 w
.99625 .14 m
1 .14 L
s
P
p
.001 w
.99625 .16 m
1 .16 L
s
P
p
.001 w
.99625 .18 m
1 .18 L
s
P
p
.001 w
.99625 .22 m
1 .22 L
s
P
p
.001 w
.99625 .24 m
1 .24 L
s
P
p
.001 w
.99625 .26 m
1 .26 L
s
P
p
.001 w
.99625 .28 m
1 .28 L
s
P
p
.001 w
.99625 .32 m
1 .32 L
s
P
p
.001 w
.99625 .34 m
1 .34 L
s
P
p
.001 w
.99625 .36 m
1 .36 L
s
P
p
.001 w
.99625 .38 m
1 .38 L
s
P
p
.001 w
.99625 .42 m
1 .42 L
s
P
p
.001 w
.99625 .44 m
1 .44 L
s
P
p
.001 w
.99625 .46 m
1 .46 L
s
P
p
.001 w
.99625 .48 m
1 .48 L
s
P
p
.001 w
.99625 .52 m
1 .52 L
s
P
p
.001 w
.99625 .54 m
1 .54 L
s
P
p
.001 w
.99625 .56 m
1 .56 L
s
P
p
.001 w
.99625 .58 m
1 .58 L
s
P
p
.001 w
.99625 .62 m
1 .62 L
s
P
p
.001 w
.99625 .64 m
1 .64 L
s
P
p
.001 w
.99625 .66 m
1 .66 L
s
P
p
.001 w
.99625 .68 m
1 .68 L
s
P
p
.001 w
.99625 .72 m
1 .72 L
s
P
p
.001 w
.99625 .74 m
1 .74 L
s
P
p
.001 w
.99625 .76 m
1 .76 L
s
P
p
.001 w
.99625 .78 m
1 .78 L
s
P
p
.002 w
1 0 m
1 .8 L
s
P
P
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.4 .54383 L
.6 .54383 L
.8 .8 L
s
P
p
0 .7 0 r
p
.5 .48383 m
.4 .52383 L
.4 .56383 L
.6 .56383 L
.6 .52383 L
F
P
P
p
0 0 .7 r
p
.03 w
.67259 .1679 m
.5 .48383 L
s
P
.03 w
.67259 .1679 m
.67259 .1679 .06 28.6479 388.648 arc
F
P
p
.04 w
.5 .48383 Mdot
0 .8 Mdot
.8 .8 Mdot
P
p
.012 w
.2 .4 m
.2 .2 L
s
.17172 .22828 m
.2 .2 L
.22828 .22828 L
s
P
p
/Times-Bold findfont 14 scalefont setfont
[(G)] .24 .3 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{282, 225},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004J0000hA000`40O003h00Oogoo6goo003oOolK
Ool00?mooa]oo`00ogoo6goo0019Ool5000^Ool3000_Ool2000aOol3000_Ool00`00Oomoo`04Ool0
04]oo`03001oogoo02ioo`03001oogoo035oo`03001oogoo02moo`03001oogoo02eoo`03001oo`00
00Eoo`00Bgoo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0;Woo1000<7oo00<007ooOol0
0goo001;Ool00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Ool0000_Ool20006
Ool004]oo`03001oogoo02ioo`03001oo`0002moo`03001oo`00031oo`8002moo`03001oogoo00Eo
o`00BWoo0P00<Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0;Goo0`001Goo003oOolK
Ool00?mooa]oo`00ogoo6goo003oOolKOol00?mooa]oo`00ogoo6goo000COol3003oOol5Ool001Ao
o`03001oogoo0?moo`Aoo`003Goo0`000Woo10000goon`001Woo000BOol00`00Ool00004Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool001=oo`8000Aoo`03001oogoo02moo`03001oogoo02moo`03001oogoo02moo`03001o
ogoo02moo`03001oogoo02moo`03001oogoo00Aoo`0057oo00<007ooOol00Woo00<007ooOol0mgoo
00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`00
6Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uo
o`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol2
003gOol20006Ool001Uoo`03001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<0
07ooOol017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03001oogoo0?Moo`03001o
ogoo00Aoo`006Goo0P00mgoo0P001Woo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03
001oogoo0?Moo`03001oogoo00Aoo`006Goo00<007ooOol0mgoo00<007ooOol017oo000IOol00`00
Oomoo`3gOol00`00Oomoo`04Ool001Uoo`800?Moo`8000Ioo`006Goo00<007ooOol0mgoo00<007oo
Ool017oo000IOol00`00Oomoo`3gOol00`00Oomoo`04Ool000Qoo`8000Aoo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo0?Moo`03001oogoo00Aoo`002Woo00<007ooOol01Goo00<007oo0000
17oo00<007ooOol0mgoo00<007ooOol017oo0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool3003fOol20006Ool000Yoo`03001oogoo00Eoo`8000Eoo`03001oogoo0?Moo`03001oogoo00Ao
o`0027oo00<007oo00001goo00<007ooOol017oo00<007ooOol0mgoo00<007ooOol017oo0009Ool0
0`00Oomoo`06Ool30004Ool00`00Oomoo`3gOol00`00Oomoo`04Ool001Uoo`03001oogoo09moo`h0
5TYoo`03001oogoo00Aoo`006Goo0P00Wgoo400FB7oo0P001Woo000IOol00`00Oomoo`2LOolC01I8
Ool00`00Oomoo`04Ool001Uoo`03001oogoo09]ooaD05TMoo`03001oogoo00Aoo`006Goo00<007oo
Ool0VWoo5`0FAWoo00<007ooOol017oo000IOol00`00Oomoo`2IOolI01I5Ool00`00Oomoo`04Ool0
01Uoo`8009Uooa/05T=oo`8000Ioo`006Goo00<007ooOol0V7oo6`0FA7oo00<007ooOol017oo000I
Ool00`00Oomoo`2HOolL01I3Ool00`00Oomoo`04Ool001Uoo`03001oogoo09Mooad05T=oo`03001o
ogoo00Aoo`006Goo00<007ooOol0Ugoo7@0F@goo00<007ooOol017oo000IOol2002HOolM01I2Ool2
0006Ool001Uoo`03001oogoo09Mooad05T=oo`03001oogoo00Aoo`006Goo00<007ooOol0Ugoo7@0F
@goo00<007ooOol017oo000IOol00`00Oomoo`2GOolM01I3Ool00`00Oomoo`04Ool001Uoo`03001o
ogoo09Mooad05T=oo`03001oogoo00Aoo`006Goo0P00V7oo7@0F@Woo0P001Woo000IOol00`00Oomo
o`2GOolM01I3Ool00`00Oomoo`04Ool001Uoo`03001oogoo09Mooad05T=oo`03001oogoo00Aoo`00
4Woo0P001Goo00<007ooOol0;goo00<007ooOol0IWoo700F@goo00<007ooOol017oo000DOol00`00
Oomoo`02Ool00`00Oomoo`0^Ool3001WOolL01I3Ool00`00Oomoo`04Ool000eoo`<000=oo`03001o
ogoo00=oo`<002ioo`<006QooaX05T=oo`8000Ioo`0057oo00<007ooOol00Woo00<007ooOol0;Goo
1@00J7oo600FAGoo00<007ooOol017oo000BOol00`00Ool00004Ool00`00Oomoo`0/Ool7001WOolG
01I6Ool00`00Oomoo`04Ool001=oo`03001oogoo00=oo`03001oogoo02]oo`T006MooaD05TMoo`03
001oogoo00Aoo`006Goo00<007ooOol0:Woo2`00IWoo500FB7oo00<007ooOol017oo000IOol2000Z
Ool400001Goo00000000Ool01000IGoo4`0FB7oo0P001Woo000IOol00`00Oomoo`0XOol40002Ool3
0002Ool4001SOolB01I;Ool00`00Oomoo`04Ool001Uoo`03001oogoo02Moo`@000=oo`<000=oo`@0
069ooa005Teoo`03001oogoo00Aoo`006Goo00<007ooOol09goo0`0017oo0`0017oo0`00HGoo200F
EWoo00<007ooOol017oo000IOol00`00Oomoo`0WOol20005Ool30005Ool2001POol801IGOol00`00
Oomoo`04Ool001Uoo`8002Uoo`03001oogoo00=oo`<000Eoo`03001oogoo05moo`P05UIoo`8000Io
o`006Goo00<007ooOol0;Woo0`00IWoo200FF7oo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3
001VOol701IIOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<006Eoo`P05UUoo`03001oogoo
00Aoo`006Goo00<007ooOol0;Woo0`00IGoo1`0FFWoo00<007ooOol017oo000IOol2000_Ool3001T
Ool801IIOol20006Ool001Uoo`03001oogoo02ioo`<006Aoo`L05U]oo`03001oogoo00Aoo`006Goo
00<007ooOol0;Woo0`00Hgoo200FFgoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001SOol7
01ILOol00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<0069oo`P05Uaoo`03001oogoo00Aoo`00
6Goo0P00;goo0`00HGoo200FG7oo0P001Woo000IOol00`00Oomoo`0^Ool30006Ool5001FOol801IM
Ool00`00Oomoo`04Ool001Uoo`03001oogoo02ioo`<000Eoo`8000=oo`8005Aoo`P05Uioo`03001o
ogoo00Aoo`0027oo0`000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;Woo0`0017oo
0P0017oo0P00E7oo1`0FGgoo00<007ooOol017oo0008Ool00`00Oomoo`07Ool00`00Ool00004Ool0
0`00Oomoo`0^Ool30004Ool20003Ool4001BOol801IOOol00`00Oomoo`04Ool000=oo`<000=oo`03
001oogoo00Qoo`03001oogoo009oo`<002ioo`<000Aoo`8005Uoo`L05Umoo`8000Ioo`002Goo00<0
07ooOol01Woo0P001Goo00<007ooOol0;Woo0`0017oo0P00F7oo200FH7oo00<007ooOol017oo0008
Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0^Ool30004Ool2001HOol701IQOol00`00
Oomoo`04Ool000Uoo`03001oogoo00Ioo`<000Aoo`03001oogoo02ioo`<000Aoo`8000Eoo`03001o
ogoo04moo`P05V5oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`001Goo0P000goo0P00DGoo
1`0FHWoo00<007ooOol017oo000IOol2000_Ool30006Ool400000goo001oo`1?Ool801IQOol20006
Ool001Uoo`03001oogoo02ioo`<005]oo`P05V=oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo
0`00Fgoo200FHgoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001JOol801ITOol00`00Oomo
o`04Ool001Uoo`03001oogoo02ioo`<005Yoo`L05VEoo`03001oogoo00Aoo`006Goo0P00;goo0`00
FGoo200FI7oo0P001Woo000IOol00`00Oomoo`0^Ool3001IOol701IVOol00`00Oomoo`04Ool001Uo
o`03001oogoo02ioo`<005Qoo`P05VIoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00F7oo
1`0FIgoo00<007ooOol017oo000IOol00`00Oomoo`0^Ool3001GOol801IWOol00`00Oomoo`04Ool0
01Uoo`8002moo`<005Moo`L05VMoo`8000Ioo`006Goo00<007ooOol0;Woo0`00EWoo200FJ7oo00<0
07ooOol017oo000IOol00`00Oomoo`0^Ool3001EOol801IYOol00`00Oomoo`04Ool001Uoo`03001o
ogoo02ioo`<005Eoo`P05VUoo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00E7oo200FJWoo
00<007ooOol017oo000IOol2000_Ool3001DOol701IZOol20006Ool001Uoo`03001oogoo02ioo`<0
05=oo`P05V]oo`03001oogoo00Aoo`006Goo00<007ooOol0;Woo0`00Dgoo1`0FK7oo00<007ooOol0
17oo000BOol30004Ool00`00Oomoo`0^Ool3001BOol801I/Ool00`00Oomoo`04Ool0019oo`03001o
ogoo00Aoo`03001oogoo02ioo`<0059oo`L05Veoo`03001oogoo00Aoo`003Goo0`000goo00<007oo
Ool00goo0`00;Woo0`00DGoo200FK7oo0P001Woo000COol00`00Oomoo`03Ool00`00Oomoo`0^Ool3
001AOol701I^Ool00`00Oomoo`04Ool0019oo`03001oo`0000Aoo`03001oogoo085oo`P05Vioo`03
001oogoo00Aoo`004goo00<007ooOol00goo00<007ooOol0P7oo200FKgoo00<007ooOol017oo000I
Ool00`00Oomoo`20Ool801I_Ool00`00Oomoo`04Ool001Uoo`80081oo`P05Vmoo`8000Ioo`006Goo
00<007ooOol0Ogoo1`0FLGoo00<007ooOol017oo000IOol00`00Oomoo`1nOol801IaOol00`00Oomo
o`04Ool001Uoo`03001oogoo07ioo`L05W9oo`03001oogoo00Aoo`006Goo00<007ooOol0OGoo200F
LWoo00<007ooOol017oo000IOol2001nOol701IbOol20006Ool001Uoo`03001oogoo07aoo`P05W=o
o`03001oogoo00Aoo`006Goo00<007ooOol0O7oo1`0FM7oo00<007ooOol017oo000IOol00`00Oomo
o`1kOol801IdOol00`00Oomoo`04Ool001Uoo`03001oogoo07Yoo`P05WEoo`03001oogoo00Aoo`00
6Goo0P00Ngoo200FM7oo0P001Woo000IOol00`00Oomoo`1iOol801IfOol00`00Oomoo`04Ool001Uo
o`03001oogoo07Uoo`L05WMoo`03001oogoo00Aoo`006Goo00<007ooOol0N7oo0P0F00<0000F01H0
0`0FMgoo00<007ooOol017oo000IOol00`00Oomoo`1gOol6000201IhOol00`00Oomoo`04Ool001Uo
o`8007Qoo`L0000301Ioogoo07Eoo`8000Ioo`006Goo00<007ooOol0Mgoo1`00NGoo00<007ooOol0
17oo000IOol00`00Oomoo`1fOol9001hOol00`00Oomoo`04Ool000Moo`D0009oo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo07Eoo`82`0L000030/1oogoo07Ioo`03001oogoo00Aoo`002Goo
00<007ooOol01Woo00<007oo000017oo00<007ooOol0Lgoo10;01`0010;0MGoo00<007ooOol017oo
0003Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool3001`Ool70/0600070/1bOol20006Ool0
00Uoo`03001oogoo00Ioo`8000Eoo`03001oogoo06ioo``2`0030002`0;000X2`71oo`03001oogoo
00Aoo`002Goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0Jgoo7P;0KWoo00<007ooOol0
17oo0008Ool20008Ool30004Ool00`00Oomoo`1YOolS0/1[Ool00`00Oomoo`04Ool001Uoo`03001o
ogoo06IoobP2`6Uoo`03001oogoo00Aoo`006Goo0P00IGoo;@;0IGoo0P001Woo000IOol00`00Oomo
o`1QOolb0/1TOol00`00Oomoo`04Ool001Uoo`03001oogoo065ooc82`6Aoo`03001oogoo00Aoo`00
6Goo00<007ooOol0HGoo<P;0I7oo00<007ooOol017oo000IOol00`00Oomoo`1QOolb0/1TOol00`00
Oomoo`04Ool001Uoo`80069ooc82`003F01oogoo061oo`8000Ioo`006Goo00<007ooOol0Ggoo0UP0
<P;00UP0HWoo00<007ooOol017oo000IOol00`00Oomoo`1NOol3F00b0/03F01QOol00`00Oomoo`04
Ool001Uoo`03001oogoo05aoo`AH0003Ool2`0;00302`003OomH05P0065oo`03001oogoo00Aoo`00
6Goo00<007ooOol0Fgoo15P00Woo<P;00Woo0UP0H7oo00<007ooOol017oo000IOol2001JOol4F004
Oolb0/02Ool3F01NOol20006Ool001Uoo`03001oogoo05Qoo`AH00Eooc82`0=oo`=H05ioo`03001o
ogoo00Aoo`006Goo00<007ooOol0EWoo15P0?Goo0UP0GWoo00<007ooOol017oo000IOol00`00Oomo
o`1DOol5F00oOol2F01MOol00`00Oomoo`04Ool001Uoo`03001oogoo05=oo`AH045oo`=H05aoo`03
001oogoo00Aoo`006Goo0P00DWoo15P0A7oo0eP0FWoo0P001Woo000IOol00`00Oomoo`1@Ool4F016
Ool3F01JOol00`00Oomoo`04Ool001Uoo`03001oogoo04ioo`AH04Uoo`9H05Yoo`03001oogoo00Ao
o`004Goo1@000goo00<007ooOol0CGoo15P0Bgoo0UP0FGoo00<007ooOol017oo000COol00`00Oomo
o`03Ool00`00Oomoo`1;Ool4F01=Ool3F01HOol00`00Oomoo`04Ool000eoo`<000=oo`03001oogoo
00=oo`<004Yoo`AH04moo`=H05Ioo`8000Ioo`004goo00<007ooOol00goo00<007ooOol0B7oo15P0
DWoo0eP0EWoo00<007ooOol017oo000COol00`00Oomoo`03Ool00`00Oomoo`16Ool5F01DOol2F01F
Ool00`00Oomoo`04Ool0019oo`8000Eoo`03001oogoo04Eoo`AH05Moo`9H05Eoo`03001oogoo00Ao
o`006Goo00<007ooOol0@goo15P0FGoo0eP0E7oo00<007ooOol017oo000IOol20013Ool4F01KOol3
F01BOol20006Ool001Uoo`03001oogoo041oo`AH05ioo`9H05=oo`03001oogoo00Aoo`006Goo00<0
07ooOol0?goo15P0H7oo0UP0DWoo00<007ooOol017oo000IOol00`00Oomoo`0mOol4F01ROol3F01A
Ool00`00Oomoo`04Ool001Uoo`03001oogoo03]oo`EH06Aoo`=H051oo`03001oogoo00Aoo`006Goo
0P00>goo15P0Igoo0eP0CWoo0P001Woo000IOol00`00Oomoo`0hOol4F01ZOol2F01?Ool00`00Oomo
o`04Ool001Uoo`03001oogoo03Moo`AH06aoo`9H04ioo`03001oogoo00Aoo`006Goo00<007ooOol0
=Goo15P0KWoo0eP0CGoo00<007ooOol017oo000IOol00`00Oomoo`0dOol4F01`Ool3F01<Ool00`00
Oomoo`04Ool001Uoo`8003=oo`AH07=oo`9H04]oo`8000Ioo`006Goo00<007ooOol0<Goo15P0MGoo
0UP0Bgoo00<007ooOol017oo000IOol00`00Oomoo`0_Ool4F01gOol3F01:Ool00`00Oomoo`04Ool0
01Uoo`03001oogoo02eoo`EH07Uoo`=H04Uoo`03001oogoo00Aoo`006Goo00<007ooOol0;7oo15P0
O7oo0eP0B7oo00<007ooOol017oo000IOol2000[Ool4F01oOol2F017Ool20006Ool001Uoo`03001o
ogoo02Uoo`AH085oo`9H04Moo`03001oogoo00Aoo`006Goo00<007ooOol09goo15P0Pgoo0eP0AWoo
00<007ooOol017oo0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0VOol4F025Ool3F015Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oo`0000Aoo`03
001oogoo02Aoo`AH08Qoo`9H04Eoo`03001oogoo00Aoo`000goo0`000Woo00<007oo00002Goo00<0
07ooOol00Woo0`008goo15P0RWoo0UP0@goo0P001Woo0008Ool00`00Ool00007Ool20005Ool00`00
Oomoo`0QOol4F02<Ool3F013Ool00`00Oomoo`04Ool000Qoo`03001oo`0000Moo`03001oogoo00Ao
o`03001oogoo01moo`EH08ioo`=H049oo`03001oogoo00Aoo`002Goo00<007ooOol01Woo0`0017oo
00<007ooOol07Woo15P0TGoo0eP0@Goo00<007ooOol017oo000IOol00`00Oomoo`0LOol4F02DOol2
F011Ool00`00Oomoo`04Ool001Uoo`8001aoo`AH09Ioo`9H03moo`8000Ioo`006Goo00<007ooOol0
6Goo15P0V7oo0eP0?goo00<007ooOol017oo000IOol00`00Oomoo`0HOol4F02JOol3F00nOol00`00
Oomoo`04Ool001Uoo`03001oogoo01Ioo`AH09eoo`9H03ioo`03001oogoo00Aoo`006Goo00<007oo
Ool057oo1EP0Wgoo0UP0?Goo00<007ooOol017oo000IOol2000DOol4F02QOol3F00kOol20006Ool0
01Uoo`03001oogoo015oo`AH0:Aoo`=H03]oo`03001oogoo00Aoo`006Goo00<007ooOol047oo15P0
YWoo0eP0>Woo00<007ooOol017oo000IOol00`00Oomoo`0>Ool4F02YOol2F00jOol00`00Oomoo`04
Ool001Uoo`03001oogoo00eoo`AH0:]oo`9H03Uoo`03001oogoo00Aoo`006Goo0P0037oo15P0[Goo
0eP0=goo0P001Woo000IOol00`00Oomoo`0:Ool4F02_Ool3F00gOol00`00Oomoo`04Ool001Uoo`03
001oogoo00Qoo`AH0;9oo`=H03Ioo`03001oogoo00Aoo`006Goo00<007ooOol01Woo1EP0]7oo0UP0
=Woo00<007ooOol017oo000IOol00`00Oomoo`05Ool4F02gOol2F00eOol00`00Oomoo`04Ool001Uo
o`8000Aoo`AH0;Uoo`=H03=oo`8000Ioo`006Goo00<007ooOol00Woo15P0^goo0eP0<goo00<007oo
Ool017oo000IOol00`00Oomoo`04F02nOol2F0000goo001oo`0`Ool00`00Oomoo`04Ool001=oo`03
001oogoo00H000=H0;moo`H002moo`03001oogoo00Aoo`004Woo00@007oo001oo`L002ioo`03001o
ogoo02moo`03001oogoo02moo`03001oogoo02aoo`L002ioo`03001oogoo00Aoo`004Woo00@007oo
001oooh000Ioo`004Woo00<007oo00002@00_goo2@00=7oo000BOol01000Ool007oo1`00`Goo1`00
=Goo000COol00`00Oomoo`070031Ool7000eOol001Ioo`H00<9oo`H003Ioo`006Goo00<007ooOol0
aGoo00<007ooOol0=Woo003oOolKOol00001\
\>"],
  ImageRangeCache->{{{0, 281}, {224, 0}} -> {-0.51628, -4.36002, 0.0200002, 
  0.0200002}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Free Response"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the free acceleration of the pendulum, a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that contains a new set of equations of motion with \
constraints 5, 6, and 7 dropped from the model. Note that no initial \
conditions are yet available for the velocity of the bodies in the model. ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sets all of the initial velocities to zero if ",
  StyleBox["none are specified with the ",
    FontFamily->"Times"],
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" option.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This drops the constraints that lock the position of the pendulum. ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " needs initial conditions for the velocity of each body. Since none are \
available zero is assumed."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(fsys = SetFree[{5, 6, 7}, Solution \[Rule] Dynamic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetFree::"zcond" \( : \ \) 
      "Warning: Initial conditions for velocity are not available. Zero \
initial velocity assumed."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This integrates the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 4.5, which is approximately a full period of the pendulum. The ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option includes the velocity solution in the result."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = SolveFree[fsys, 4.5, MakeRules \[Rule] {Location, Velocity}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a plot of the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinates of the slider and the pendulum."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[{X2, X3} /. sol], {T, 0, 4.5}]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.21164 -0.120461 0.214471 [
[.23545 .08151 -3 -9 ]
[.23545 .08151 3 0 ]
[.44709 .08151 -3 -9 ]
[.44709 .08151 3 0 ]
[.65873 .08151 -3 -9 ]
[.65873 .08151 3 0 ]
[.87037 .08151 -3 -9 ]
[.87037 .08151 3 0 ]
[.01131 .20124 -18 -4.5 ]
[.01131 .20124 0 4.5 ]
[.01131 .30848 -6 -4.5 ]
[.01131 .30848 0 4.5 ]
[.01131 .41572 -18 -4.5 ]
[.01131 .41572 0 4.5 ]
[.01131 .52295 -6 -4.5 ]
[.01131 .52295 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.23545 .09401 m
.23545 .10026 L
s
[(1)] .23545 .08151 0 1 Mshowa
.44709 .09401 m
.44709 .10026 L
s
[(2)] .44709 .08151 0 1 Mshowa
.65873 .09401 m
.65873 .10026 L
s
[(3)] .65873 .08151 0 1 Mshowa
.87037 .09401 m
.87037 .10026 L
s
[(4)] .87037 .08151 0 1 Mshowa
.125 Mabswid
.06614 .09401 m
.06614 .09776 L
s
.10847 .09401 m
.10847 .09776 L
s
.15079 .09401 m
.15079 .09776 L
s
.19312 .09401 m
.19312 .09776 L
s
.27778 .09401 m
.27778 .09776 L
s
.32011 .09401 m
.32011 .09776 L
s
.36243 .09401 m
.36243 .09776 L
s
.40476 .09401 m
.40476 .09776 L
s
.48942 .09401 m
.48942 .09776 L
s
.53175 .09401 m
.53175 .09776 L
s
.57407 .09401 m
.57407 .09776 L
s
.6164 .09401 m
.6164 .09776 L
s
.70106 .09401 m
.70106 .09776 L
s
.74339 .09401 m
.74339 .09776 L
s
.78571 .09401 m
.78571 .09776 L
s
.82804 .09401 m
.82804 .09776 L
s
.9127 .09401 m
.9127 .09776 L
s
.95503 .09401 m
.95503 .09776 L
s
.99735 .09401 m
.99735 .09776 L
s
.25 Mabswid
0 .09401 m
1 .09401 L
s
.02381 .20124 m
.03006 .20124 L
s
[(1.5)] .01131 .20124 1 0 Mshowa
.02381 .30848 m
.03006 .30848 L
s
[(2)] .01131 .30848 1 0 Mshowa
.02381 .41572 m
.03006 .41572 L
s
[(2.5)] .01131 .41572 1 0 Mshowa
.02381 .52295 m
.03006 .52295 L
s
[(3)] .01131 .52295 1 0 Mshowa
.125 Mabswid
.02381 .11546 m
.02756 .11546 L
s
.02381 .1369 m
.02756 .1369 L
s
.02381 .15835 m
.02756 .15835 L
s
.02381 .1798 m
.02756 .1798 L
s
.02381 .22269 m
.02756 .22269 L
s
.02381 .24414 m
.02756 .24414 L
s
.02381 .26559 m
.02756 .26559 L
s
.02381 .28703 m
.02756 .28703 L
s
.02381 .32993 m
.02756 .32993 L
s
.02381 .35137 m
.02756 .35137 L
s
.02381 .37282 m
.02756 .37282 L
s
.02381 .39427 m
.02756 .39427 L
s
.02381 .43716 m
.02756 .43716 L
s
.02381 .45861 m
.02756 .45861 L
s
.02381 .48006 m
.02756 .48006 L
s
.02381 .5015 m
.02756 .5015 L
s
.02381 .07256 m
.02756 .07256 L
s
.02381 .05112 m
.02756 .05112 L
s
.02381 .02967 m
.02756 .02967 L
s
.02381 .00822 m
.02756 .00822 L
s
.02381 .5444 m
.02756 .5444 L
s
.02381 .56584 m
.02756 .56584 L
s
.02381 .58729 m
.02756 .58729 L
s
.02381 .60874 m
.02756 .60874 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41572 m
.02499 .41573 L
.02605 .41576 L
.02729 .41581 L
.02846 .41589 L
.03053 .41608 L
.03279 .41636 L
.03527 .41677 L
.0379 .41731 L
.04262 .41856 L
.04749 .42025 L
.05205 .4222 L
.06244 .42796 L
.07305 .4357 L
.08274 .44416 L
.10458 .46524 L
.11377 .47356 L
.12357 .48115 L
.1292 .48467 L
.13431 .4872 L
.13678 .48818 L
.13945 .48904 L
.14067 .48936 L
.14197 .48965 L
.14317 .48988 L
.14429 .49005 L
.14551 .49019 L
.14615 .49024 L
.14683 .49029 L
.14798 .49032 L
.14925 .49032 L
.15037 .49026 L
.15158 .49016 L
.15272 .49002 L
.15377 .48985 L
.15613 .48933 L
.15872 .48854 L
.16141 .48748 L
.16393 .48627 L
.17279 .48031 L
.17775 .47587 L
.18226 .47118 L
.20145 .44482 L
.22224 .40584 L
.26316 .306 L
.28352 .25441 L
.30256 .21152 L
.32083 .17809 L
.33108 .16348 L
.34045 .15308 L
Mistroke
.34523 .1489 L
.35032 .14531 L
.35513 .14271 L
.35947 .14102 L
.36215 .14028 L
.36461 .13979 L
.3659 .13961 L
.36663 .13954 L
.36731 .13948 L
.36803 .13943 L
.36869 .1394 L
.36944 .13938 L
.37016 .13938 L
.37137 .13941 L
.37266 .13949 L
.37376 .13959 L
.37498 .13975 L
.37768 .14023 L
.38021 .14087 L
.38492 .14247 L
.39007 .14482 L
.40043 .15121 L
.41895 .16635 L
.44024 .18404 L
.4503 .19068 L
.45956 .19542 L
.46426 .19729 L
.46923 .1989 L
.47421 .2001 L
.47704 .20061 L
.47831 .20079 L
.47969 .20097 L
.48096 .2011 L
.48215 .20119 L
.48327 .20127 L
.48447 .20132 L
.48554 .20135 L
.48655 .20136 L
.48765 .20135 L
.48884 .20131 L
.49003 .20126 L
.49134 .20117 L
.4927 .20104 L
.49396 .2009 L
.49623 .20058 L
.49866 .20013 L
.50398 .1988 L
.50889 .19712 L
.51998 .19175 L
.52976 .18523 L
Mistroke
.54013 .17669 L
.57798 .1387 L
.58794 .12972 L
.59741 .1229 L
.60262 .12009 L
.60538 .11891 L
.60831 .11791 L
.60971 .11752 L
.61103 .11721 L
.61231 .11696 L
.61349 .11678 L
.61461 .11665 L
.6158 .11655 L
.61699 .11649 L
.61829 .11649 L
.6196 .11653 L
.6208 .11662 L
.62143 .11669 L
.62213 .11677 L
.62354 .11699 L
.6261 .11755 L
.62851 .11826 L
.63299 .12003 L
.63781 .12261 L
.64873 .13085 L
.65873 .14123 L
.67767 .16806 L
.69838 .20812 L
.73896 .30999 L
.75771 .35739 L
.77802 .40168 L
.78914 .42126 L
.79939 .43594 L
.80918 .44687 L
.8146 .45164 L
.81954 .45523 L
.82406 .45787 L
.82899 .46008 L
.83169 .461 L
.83419 .46167 L
.83659 .46215 L
.83792 .46235 L
.83913 .46248 L
.84028 .46258 L
.8415 .46264 L
.84253 .46266 L
.84367 .46265 L
.8449 .4626 L
.84621 .46251 L
.84745 .46238 L
Mistroke
.84857 .46223 L
.85076 .46184 L
.85314 .46128 L
.85745 .45991 L
.86232 .45785 L
.86688 .45547 L
.87728 .44877 L
.8983 .43321 L
.90868 .4264 L
.91854 .42117 L
.9274 .41769 L
.93241 .41627 L
.93467 .41577 L
.93706 .41533 L
.93832 .41513 L
.9397 .41495 L
.94098 .41482 L
.94214 .41472 L
.94351 .41463 L
.94426 .41459 L
.94497 .41457 L
.94624 .41455 L
.94696 .41455 L
.94762 .41456 L
.94881 .41459 L
.94992 .41465 L
.95114 .41473 L
.95245 .41485 L
.95512 .4152 L
.95758 .41563 L
.9619 .41665 L
.96664 .41815 L
.97618 .42237 L
.97619 .42237 L
Mfstroke
.02381 .6008 m
.02499 .60079 L
.02605 .60076 L
.02729 .60071 L
.02846 .60065 L
.03053 .60049 L
.03279 .60025 L
.03527 .59991 L
.0379 .59946 L
.04262 .59839 L
.04749 .59695 L
.05205 .59527 L
.06244 .59019 L
.07305 .58304 L
.08274 .57467 L
.10458 .54998 L
.14429 .49223 L
.18248 .43267 L
.22313 .37204 L
.26226 .31693 L
.30384 .25659 L
.34391 .19283 L
.38246 .12807 L
.402 .09641 L
.42346 .06574 L
.43332 .05398 L
.44388 .04325 L
.46295 .02855 L
.47312 .02293 L
.47849 .02054 L
.48419 .01845 L
.48915 .01699 L
.49179 .01636 L
.49464 .01579 L
.49724 .01537 L
.49963 .01508 L
.50081 .01496 L
.50191 .01488 L
.50305 .01481 L
.50431 .01475 L
.50558 .01472 L
.50623 .01472 L
.50693 .01472 L
.50819 .01474 L
.50936 .01478 L
.51006 .01482 L
.51074 .01486 L
.512 .01496 L
.51335 .0151 L
.51483 .01528 L
Mistroke
.51733 .01568 L
.51999 .01622 L
.52476 .0175 L
.52979 .01929 L
.53452 .02139 L
.54335 .02638 L
.55314 .03348 L
.56347 .04263 L
.58196 .06267 L
.61998 .11393 L
.66046 .17275 L
.69942 .22795 L
.74083 .28576 L
.78073 .34653 L
.81911 .41215 L
.85994 .48536 L
.88024 .51951 L
.89926 .54711 L
.91769 .56871 L
.93707 .58597 L
.94673 .59249 L
.95184 .59536 L
.95729 .59798 L
.96232 .59997 L
.96689 .60142 L
.96909 .602 L
.97148 .60254 L
.9758 .60327 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol001Eoo`03001oogoo0?moo`5oo`005Goo00<007ooOol0
ogoo0Goo000EOol2003oOol2Ool001Eoo`03001oogoo0?moo`5oo`005Goo00<007ooOol0N7oo2@00
Ogoo000EOol00`00Oomoo`1eOol30009Ool2001mOol001Eoo`03001oogoo07=oo`8000ioo`8007]o
o`005Goo00<007ooOol0LGoo0P004Woo0P00NGoo000EOol2001aOol00`00Oomoo`0DOol2001gOol0
01Eoo`03001oogoo06ioo`8001Uoo`03001oogoo07Aoo`005Goo00<007ooOol0KGoo00<007ooOol0
6Woo00<007ooOol0Lgoo000EOol00`00Oomoo`1/Ool00`00Oomoo`0LOol00`00Oomoo`1bOol001Eo
o`03001oogoo06]oo`03001oogoo01ioo`03001oogoo075oo`005Goo0P00<goo1@00<goo10007goo
00<007ooOol04goo0P00=goo0`008Goo000EOol00`00Oomoo`0dOol00`00Oomoo`0bOol00`00Ool0
000ROol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`0POol001Eoo`03001oogoo03Aoo`03
001oogoo035oo`05001oogooOol0000ROol00`00Oomoo`0BOol00`00Oomoo`0dOol4000QOol001Eo
o`03001oogoo03Aoo`03001oogoo031oo`03001oogoo009oo`03001oogoo025oo`03001oogoo019o
o`03001oogoo03=oo`03001oo`00029oo`005Goo00<007ooOol0=7oo00<007ooOol0;goo00<007oo
Ool00Woo00<007oo00008goo00<007ooOol03goo00<007oo0000=Woo0P008Woo000EOol00`00Oomo
o`0cOol2000`Ool00`00Oomoo`04Ool00`00Oomoo`0ROol00`00Oomoo`0@Ool00`00Oomoo`0fOol0
0`00Oomoo`0POol001Eoo`8006Ioo`03001oogoo02Yoo`03001oogoo06]oo`005Goo00<007ooOol0
I7oo00<007ooOol0;7oo00<007ooOol0JWoo000EOol00`00Oomoo`1SOol00`00Oomoo`0^Ool00`00
Oomoo`1YOol001Eoo`03001oogoo06=oo`03001oogoo02ioo`03001oogoo06Uoo`005Goo00<007oo
Ool0HWoo00<007ooOol0<7oo00<007ooOol0J7oo000EOol00`00Oomoo`1ROol00`00Oomoo`0aOol0
0`00Oomoo`1WOol000moool000X000005Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<007ooOol0
27oo00<007ooOol01goo0P002goo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol01Woo00<007oo00002Woo00<007ooOol02Goo00<007ooOol027oo00<007ooOol027oo00<0
07ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo0@00
0Goo000EOol00`00Oomoo`1POol00`00Oomoo`0eOol00`00Oomoo`1UOol001Eoo`03001oogoo05mo
o`03001oogoo03Moo`03001oogoo06Aoo`005Goo00<007ooOol0GWoo00<007ooOol0>7oo00<007oo
Ool0I7oo000EOol2001OOol00`00Oomoo`0iOol00`00Oomoo`1SOol001Eoo`03001oogoo05eoo`03
001oogoo03Ioo`L006=oo`005Goo00<007ooOol0G7oo00<007ooOol0=Goo0`0017oo00<007oo0000
0P00H7oo000EOol00`00Oomoo`1LOol00`00Oomoo`0dOol00`00Oomoo`06Ool01000Oomoogoo0P00
GWoo000EOol00`00Oomoo`1KOol00`00Oomoo`0dOol00`00Oomoo`08Ool00`00Oomoo`02Ool00`00
Oomoo`1KOol001Eoo`03001oogoo05Yoo`03001oogoo03Aoo`03001oogoo00Uoo`03001oogoo00=o
o`03001oogoo05Yoo`005Goo0P00Fgoo00<007ooOol0<goo00<007ooOol02goo00<007ooOol00Woo
00<007ooOol0FWoo000EOol00`00Oomoo`1EOol7000cOol00`00Oomoo`0=Ool00`00Oomoo`02Ool0
0`00Oomoo`1IOol001Eoo`03001oogoo05=oo`8000Aoo`03001oogoo0080031oo`03001oogoo00io
o`03001oogoo00=oo`03001oogoo05Qoo`005Goo00<007ooOol0DWoo00<007ooOol00goo00<007oo
Ool00goo0P00;Goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0F7oo000EOol00`00Oomo
o`1@Ool20005Ool00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`0BOol00`00Oomoo`02Ool0
0`00Oomoo`1GOol001Eoo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo
02Moo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo05Ioo`005Goo0P00D7oo00<007ooOol0
17oo00<007ooOol02Goo0P009Woo00<007ooOol05Goo00<007ooOol00goo00<007ooOol0EGoo000E
Ool00`00Oomoo`1>Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0ROol00`00Oomoo`0G
Ool00`00Oomoo`02Ool00`00Oomoo`1EOol001Eoo`03001oogoo04eoo`03001oogoo00Eoo`03001o
ogoo00eoo`03001oogoo021oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo05Aoo`005Goo
00<007ooOol0C7oo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol07Woo00<007ooOol06Woo
00<007ooOol00goo00<007ooOol0Dgoo000EOol00`00Oomoo`1<Ool00`00Oomoo`05Ool00`00Oomo
o`0@Ool00`00Oomoo`0LOol00`00Oomoo`0LOol00`00Oomoo`02Ool00`00Oomoo`1COol001Eoo`80
04aoo`03001oogoo00Eoo`03001oogoo019oo`8001]oo`03001oogoo01ioo`03001oogoo009oo`03
001oogoo059oo`005Goo00<007ooOol0BWoo00<007ooOol01Woo00<007ooOol057oo00<007ooOol0
5Woo0P008Goo00<007ooOol00Woo00<007ooOol0DWoo000EOol00`00Oomoo`1:Ool00`00Oomoo`05
Ool00`00Oomoo`0FOol00`00Oomoo`0DOol00`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`1A
Ool001Eoo`03001oogoo04Uoo`03001oogoo00Ioo`03001oogoo01Moo`8001=oo`03001oogoo02Ao
o`05001oogooOol0001COol000=oo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
04Uoo`03001oogoo00Eoo`03001oogoo01Yoo`8000moo`8002Qoo`05001oogooOol0001BOol000Eo
o`03001oogoo00Ioo`03001oo`0000Aoo`03001oogoo04Qoo`03001oogoo00Eoo`03001oogoo01eo
o`<000Uoo`<002Yoo`05001oogooOol0001BOol000Eoo`03001oogoo00Qoo`03001oogoo009oo`80
04Uoo`03001oogoo00Eoo`03001oogoo021oo`T002ioo`05001oogooOol0001AOol000Eoo`03001o
ogoo00Ioo`8000Eoo`03001oogoo04Moo`03001oogoo00Eoo`03001oogoo05Uoo`04001oogoo001A
Ool000Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo04Moo`03001oogoo00Eoo`03001o
ogoo05Uoo`05001oogooOol0001@Ool000Aoo`8000Qoo`<000Aoo`03001oogoo04Ioo`03001oogoo
00Eoo`03001oogoo05]oo`04001oogoo001@Ool001Eoo`03001oogoo04Ioo`03001oogoo00Aoo`03
001oogoo05eoo`04001oogoo001?Ool001Eoo`03001oogoo04Eoo`03001oogoo00Eoo`03001oogoo
05ioo`03001oo`0004moo`005Goo0P00AWoo00<007ooOol017oo00<007ooOol0Ggoo00@007ooOol0
04ioo`005Goo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0H7oo00<007oo0000CWoo000E
Ool00`00Oomoo`14Ool00`00Oomoo`04Ool00`00Oomoo`1ROol2001>Ool001Eoo`03001oogoo04=o
o`03001oogoo00Eoo`03001oogoo069oo`03001oo`0004eoo`005Goo00<007ooOol0@goo00<007oo
Ool017oo00<007ooOol0I7oo0P00CGoo000EOol20013Ool00`00Oomoo`04Ool00`00Oomoo`1VOol2
001<Ool001Eoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo06Moo`03001oogoo04Yoo`00
5Goo00<007ooOol0@Goo00<007ooOol017oo00<007ooOol0J7oo00<007ooOol0BWoo000EOol00`00
Oomoo`11Ool00`00Oomoo`04Ool00`00Oomoo`1YOol00`00Oomoo`19Ool001Eoo`03001oogoo045o
o`03001oogoo00=oo`03001oogoo06Yoo`8004Yoo`005Goo00<007ooOol0@7oo00<007ooOol00goo
00<007ooOol0K7oo0P00BGoo000EOol20011Ool00`00Oomoo`03Ool00`00Oomoo`1/Ool20019Ool0
01Eoo`03001oogoo041oo`03001oogoo009oo`03001oogoo06ioo`8004Qoo`005Goo00<007ooOol0
?goo00<007ooOol00Woo00<007ooOol0Kgoo00<007oo0000Agoo000EOol00`00Oomoo`0oOol00`00
Oomoo`02Ool00`00Oomoo`1_Ool01000Oomoo`00AWoo000EOol00`00Oomoo`0nOol00`00Oomoo`02
Ool00`00Oomoo`1aOol00`00Ool00016Ool001Eoo`03001oogoo03ioo`05001oogooOol0001dOol0
1000Oomoo`00AGoo000EOol2000oOol01000Oomoo`00MWoo00@007ooOol004Aoo`005Goo00<007oo
Ool0?Goo00D007ooOomoo`0007Ioo`04001oogoo0014Ool001Eoo`03001oogoo03eoo`04001oogoo
001gOol01@00Oomoogoo0000@goo000>Ool30004Ool00`00Oomoo`0mOol00`00Ool0001iOol01@00
Oomoogoo0000@Woo000>Ool00`00Oomoo`04Ool00`00Oomoo`0lOol01000Oomoo`00NGoo00D007oo
Oomoo`00049oo`003goo00<007ooOol00goo0P00?Goo00<007oo0000Ngoo00D007ooOomoo`00045o
o`003goo00<007ooOol00goo00<007ooOol0?7oo0P00O7oo00<007ooOol00Woo00<007ooOol0?Woo
000>Ool00`00Ool00004Ool00`00Oomoo`0kOol00`00Ool0001lOol00`00Oomoo`02Ool00`00Oomo
o`0nOol000moo`03001oogoo00=oo`03001oogoo03]oo`8007ioo`03001oogoo009oo`03001oogoo
03eoo`005Goo00<007ooOol0>Woo0P00Ogoo00<007ooOol00goo00<007ooOol0?7oo000EOol00`00
Oomoo`0jOol00`00Oomoo`1oOol00`00Oomoo`03Ool00`00Oomoo`0kOol001Eoo`8003Yoo`80085o
o`03001oogoo00=oo`03001oogoo03]oo`005Goo00<007ooOol0>Goo00<007ooOol0P7oo00<007oo
Ool017oo00<007ooOol0>Woo000EOol00`00Oomoo`0hOol20023Ool00`00Oomoo`04Ool00`00Oomo
o`0iOol001Eoo`03001oogoo03Moo`8008Aoo`03001oogoo00Aoo`03001oogoo03Uoo`005Goo00<0
07ooOol0=Woo00<007oo0000QGoo00<007ooOol017oo00<007ooOol0>7oo000EOol00`00Oomoo`0f
Ool20026Ool00`00Oomoo`05Ool00`00Oomoo`0gOol001Eoo`8003Ioo`03001oo`0008Moo`03001o
ogoo00Aoo`03001oogoo03Moo`005Goo00<007ooOol0=7oo00<007oo0000R7oo00<007ooOol01Goo
00<007ooOol0=Woo000EOol00`00Oomoo`0cOol01000Oomoo`00R7oo00<007ooOol01Goo00<007oo
Ool0=Woo000EOol00`00Oomoo`0cOol01000Oomoo`00RGoo00<007ooOol01Goo00<007ooOol0=Goo
000EOol00`00Oomoo`0bOol01000Oomoo`00RWoo00<007ooOol01Goo00<007ooOol0=Goo000EOol2
000bOol01@00Oomoogoo0000Rgoo00<007ooOol01Goo00<007ooOol0=7oo000EOol00`00Oomoo`0`
Ool01@00Oomoogoo0000S7oo00<007ooOol01Goo00<007ooOol0=7oo000EOol00`00Oomoo`0`Ool0
1@00Oomoogoo0000S7oo00<007ooOol01Woo00<007ooOol0<goo000EOol00`00Oomoo`0_Ool00`00
Oomoo`02Ool00`00Oomoo`2;Ool00`00Oomoo`06Ool00`00Oomoo`0bOol001Eoo`03001oogoo02io
o`03001oogoo009oo`03001oogoo08aoo`03001oogoo00Ioo`03001oogoo039oo`005Goo00<007oo
Ool0;Woo00<007ooOol00Woo00<007ooOol0SGoo00<007ooOol01Woo00<007ooOol0<Goo000EOol2
000^Ool00`00Oomoo`02Ool00`00Oomoo`2>Ool00`00Oomoo`06Ool00`00Oomoo`0aOol001Eoo`03
001oogoo02eoo`03001oogoo009oo`03001oogoo08moo`03001oogoo00Ioo`03001oogoo031oo`00
5Goo00<007ooOol0;7oo00<007ooOol00Woo00<007ooOol0T7oo00<007ooOol01Woo00<007ooOol0
<7oo000EOol00`00Oomoo`0[Ool00`00Oomoo`03Ool00`00Oomoo`2AOol00`00Oomoo`06Ool00`00
Oomoo`0_Ool000Aoo`<000=oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02]oo`03001o
ogoo009oo`03001oogoo099oo`03001oogoo00Ioo`03001oogoo02moo`0017oo00<007ooOol01goo
00<007oo000017oo00<007ooOol0:Woo00<007ooOol00goo00<007ooOol0Tgoo00<007ooOol01Woo
00<007ooOol07Goo10003Goo0005Ool00`00Oomoo`08Ool00`00Oomoo`02Ool6000VOol00`00Oomo
o`03Ool00`00Oomoo`2DOol00`00Oomoo`07Ool00`00Oomoo`0HOol40004Ool40009Ool000Eoo`03
001oogoo00Ioo`8000Eoo`03001oogoo00=oo`8002Aoo`03001oogoo00=oo`03001oogoo09Eoo`03
001oogoo00Ioo`03001oogoo01Eoo`<000aoo`8000Moo`0017oo00<007oo00001goo00<007ooOol0
17oo00<007ooOol01Goo0P008Goo00<007ooOol00goo00<007ooOol0Ugoo00<007ooOol01Woo00<0
07ooOol04Woo0P0067oo0005Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`07Ool00`00Oomoo`0N
Ool00`00Oomoo`03Ool00`00Oomoo`2GOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0H
Ool001Eoo`03001oogoo00Qoo`8001eoo`03001oogoo00=oo`03001oogoo09Uoo`03001oogoo00Io
o`03001oogoo00moo`03001oogoo01Uoo`005Goo0P002goo00<007ooOol06Goo00<007ooOol017oo
00<007ooOol0VWoo00<007ooOol01Goo00<007ooOol03Goo0P0077oo000EOol00`00Oomoo`0;Ool0
0`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`2LOol00`00Oomoo`05Ool00`00Oomoo`0;Ool0
0`00Oomoo`0LOol001Eoo`03001oogoo00aoo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo
09aoo`03001oogoo00Ioo`03001oogoo00Qoo`8001moo`005Goo00<007ooOol03Goo00<007ooOol0
57oo00<007ooOol017oo00<007ooOol0WWoo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
7goo000EOol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`2OOol20006
Ool00`00Oomoo`04Ool2000ROol001Eoo`03001oogoo00moo`03001oogoo015oo`03001oogoo00Ao
o`03001oogoo0:9oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo029oo`005Goo0P004Goo
00<007ooOol047oo00<007ooOol00goo00<007ooOol0Y7oo0P0017oo00<007ooOol00P009Goo000E
Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`2WOol7000WOol001Eo
o`03001oogoo019oo`03001oogoo00aoo`03001oogoo00Aoo`03001oogoo0:aoo`03001oogoo02Io
o`005Goo00<007ooOol04goo0P0037oo00<007ooOol00goo00<007ooOol0[Woo00<007ooOol09Goo
000EOol00`00Oomoo`0EOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`2_Ool00`00Oomo
o`0UOol001Eoo`03001oogoo01Ioo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo0;5oo`03
001oogoo02Aoo`005Goo0P0067oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0/Woo00<0
07ooOol097oo000EOol00`00Oomoo`0HOol20004Ool01000Oomoogoo0P00]Woo00<007ooOol08goo
000EOol00`00Oomoo`0JOol8002iOol00`00Oomoo`0ROol001Eoo`03001oogoo01eoo`03001oogoo
0;]oo`03001oogoo029oo`005Goo00<007ooOol077oo00<007ooOol0_Goo00<007ooOol08Goo000E
Ool2000MOol00`00Oomoo`2mOol00`00Oomoo`0QOol001Eoo`03001oogoo01]oo`03001oogoo0;mo
o`03001oogoo021oo`005Goo00<007ooOol06Woo00<007ooOol0`7oo00<007ooOol087oo000EOol0
0`00Oomoo`0IOol00`00Oomoo`32Ool00`00Oomoo`0OOol000ioo`8000Eoo`03001oogoo01Uoo`03
001oogoo0<9oo`03001oogoo01moo`0047oo00<007ooOol00Woo00<007ooOol067oo00<007ooOol0
a7oo00<007ooOol07Woo000?Ool00`00Oomoo`03Ool2000HOol00`00Oomoo`36Ool00`00Oomoo`0M
Ool0011oo`03001oogoo009oo`03001oogoo01Ioo`03001oogoo0<Moo`03001oogoo01eoo`003Woo
00<007oo000017oo00<007ooOol05Woo00<007ooOol0b7oo00<007ooOol077oo000?Ool00`00Oomo
o`03Ool00`00Oomoo`0EOol00`00Oomoo`3:Ool00`00Oomoo`0KOol001Eoo`03001oogoo01Aoo`03
001oogoo0<aoo`03001oogoo01Yoo`005Goo00<007ooOol04goo00<007ooOol0cGoo00<007ooOol0
6Woo000EOol2000DOol00`00Oomoo`3>Ool00`00Oomoo`0IOol001Eoo`03001oogoo019oo`03001o
ogoo0=1oo`03001oogoo01Qoo`005Goo00<007ooOol04Goo00<007ooOol0dWoo00<007ooOol05goo
000EOol00`00Oomoo`0@Ool00`00Oomoo`3COol00`00Oomoo`0GOol001Eoo`03001oogoo00moo`03
001oogoo0=Eoo`03001oogoo01Ioo`005Goo0P0047oo00<007ooOol0eWoo00<007ooOol05Goo000E
Ool00`00Oomoo`0>Ool00`00Oomoo`3HOol00`00Oomoo`0DOol001Eoo`03001oogoo00eoo`03001o
ogoo0=Yoo`03001oogoo01=oo`005Goo00<007ooOol037oo00<007ooOol0g7oo00<007ooOol04Woo
000EOol00`00Oomoo`0;Ool00`00Oomoo`3NOol00`00Oomoo`0AOol001Eoo`03001oogoo00Yoo`03
001oogoo0>1oo`03001oogoo011oo`005Goo0P002Goo0P00i7oo00<007ooOol03goo000EOol00`00
Oomoo`06Ool2003WOol2000?Ool001Eoo`03001oogoo00Aoo`800>]oo`8000eoo`005Goo1`00kgoo
0`002Woo000EOol2003gOol30007Ool001Eoo`03001oogoo0?moo`5oo`005Goo0P00ogoo0Woo000E
Ool00`00Oomoo`3oOol1Ool001Eoo`03001oogoo0?moo`5oo`00ogoo6Goo003oOolIOol00?mooaUo
o`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.381264, 0.483504, 0.0178989, 
  0.0176626}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Since the pendulum model is a conservative system, the sum of the kinetic \
and potential energy in the system should remain constant. This fact can be \
used to measure of the accuracy of the numerical integrator."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["BodyEnergy[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total kinetic energy possesed by body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A special output function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The kinetic energy of each body is given by the ",
  StyleBox["BodyEnergy",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, and the potential energy is simply the gravitational potential \
energy ",
  StyleBox["mass G altitude",
    FontSlant->"Italic"],
  ". The following plot shows that the numerical error in the integration has \
allowed the total energy of the model to increase by about 0.04% over 4.5 \
seconds."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the total energy in the pendulum model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[9.81\ Mass[slider]\ 
              \(Location[Centroid[slider]]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] + \n\t\t\t
            9.81\ Mass[pendulum]\ 
              \(Location[Centroid[pendulum]]\)\[LeftDoubleBracket]2
                \[RightDoubleBracket] + \n\t\t\tBodyEnergy[slider] + \n\t\t\t
            BodyEnergy[pendulum] /. sol], {T, 0, 4.5}, 
      PlotRange \[Rule] All]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.21164 1355.27 17.9367 [
[.23545 .13991 -3 -9 ]
[.23545 .13991 3 0 ]
[.44709 .13991 -3 -9 ]
[.44709 .13991 3 0 ]
[.65873 .13991 -3 -9 ]
[.65873 .13991 3 0 ]
[.87037 .13991 -3 -9 ]
[.87037 .13991 3 0 ]
[.01131 .06273 -42 -4.5 ]
[.01131 .06273 0 4.5 ]
[.01131 .24209 -42 -4.5 ]
[.01131 .24209 0 4.5 ]
[.01131 .33178 -36 -4.5 ]
[.01131 .33178 0 4.5 ]
[.01131 .42146 -42 -4.5 ]
[.01131 .42146 0 4.5 ]
[.01131 .51114 -36 -4.5 ]
[.01131 .51114 0 4.5 ]
[.01131 .60083 -42 -4.5 ]
[.01131 .60083 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.23545 .15241 m
.23545 .15866 L
s
[(1)] .23545 .13991 0 1 Mshowa
.44709 .15241 m
.44709 .15866 L
s
[(2)] .44709 .13991 0 1 Mshowa
.65873 .15241 m
.65873 .15866 L
s
[(3)] .65873 .13991 0 1 Mshowa
.87037 .15241 m
.87037 .15866 L
s
[(4)] .87037 .13991 0 1 Mshowa
.125 Mabswid
.06614 .15241 m
.06614 .15616 L
s
.10847 .15241 m
.10847 .15616 L
s
.15079 .15241 m
.15079 .15616 L
s
.19312 .15241 m
.19312 .15616 L
s
.27778 .15241 m
.27778 .15616 L
s
.32011 .15241 m
.32011 .15616 L
s
.36243 .15241 m
.36243 .15616 L
s
.40476 .15241 m
.40476 .15616 L
s
.48942 .15241 m
.48942 .15616 L
s
.53175 .15241 m
.53175 .15616 L
s
.57407 .15241 m
.57407 .15616 L
s
.6164 .15241 m
.6164 .15616 L
s
.70106 .15241 m
.70106 .15616 L
s
.74339 .15241 m
.74339 .15616 L
s
.78571 .15241 m
.78571 .15616 L
s
.82804 .15241 m
.82804 .15616 L
s
.9127 .15241 m
.9127 .15616 L
s
.95503 .15241 m
.95503 .15616 L
s
.99735 .15241 m
.99735 .15616 L
s
.25 Mabswid
0 .15241 m
1 .15241 L
s
.02381 .06273 m
.03006 .06273 L
s
[(-75.555)] .01131 .06273 1 0 Mshowa
.02381 .24209 m
.03006 .24209 L
s
[(-75.545)] .01131 .24209 1 0 Mshowa
.02381 .33178 m
.03006 .33178 L
s
[(-75.54)] .01131 .33178 1 0 Mshowa
.02381 .42146 m
.03006 .42146 L
s
[(-75.535)] .01131 .42146 1 0 Mshowa
.02381 .51114 m
.03006 .51114 L
s
[(-75.53)] .01131 .51114 1 0 Mshowa
.02381 .60083 m
.03006 .60083 L
s
[(-75.525)] .01131 .60083 1 0 Mshowa
.125 Mabswid
.02381 .08066 m
.02756 .08066 L
s
.02381 .0986 m
.02756 .0986 L
s
.02381 .11654 m
.02756 .11654 L
s
.02381 .13447 m
.02756 .13447 L
s
.02381 .17035 m
.02756 .17035 L
s
.02381 .18828 m
.02756 .18828 L
s
.02381 .20622 m
.02756 .20622 L
s
.02381 .22416 m
.02756 .22416 L
s
.02381 .26003 m
.02756 .26003 L
s
.02381 .27797 m
.02756 .27797 L
s
.02381 .2959 m
.02756 .2959 L
s
.02381 .31384 m
.02756 .31384 L
s
.02381 .34971 m
.02756 .34971 L
s
.02381 .36765 m
.02756 .36765 L
s
.02381 .38559 m
.02756 .38559 L
s
.02381 .40352 m
.02756 .40352 L
s
.02381 .4394 m
.02756 .4394 L
s
.02381 .45733 m
.02756 .45733 L
s
.02381 .47527 m
.02756 .47527 L
s
.02381 .49321 m
.02756 .49321 L
s
.02381 .52908 m
.02756 .52908 L
s
.02381 .54702 m
.02756 .54702 L
s
.02381 .56495 m
.02756 .56495 L
s
.02381 .58289 m
.02756 .58289 L
s
.02381 .04479 m
.02756 .04479 L
s
.02381 .02685 m
.02756 .02685 L
s
.02381 .00892 m
.02756 .00892 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.5 Mabswid
.02381 .0506 m
.02499 .05063 L
.02605 .05059 L
.02729 .05061 L
.02846 .0506 L
.02954 .05053 L
.03053 .05033 L
.03279 .04997 L
.03525 .04964 L
.03646 .04941 L
.03756 .04929 L
.03872 .04928 L
.03997 .04909 L
.04062 .04899 L
.04132 .04893 L
.04262 .04894 L
.04326 .04887 L
.04396 .04875 L
.04523 .04864 L
.04646 .04865 L
.04759 .04852 L
.04882 .04843 L
.04952 .04841 L
.05017 .04842 L
.05149 .04833 L
.0529 .04825 L
.0553 .04817 L
.05786 .04806 L
.059 .04801 L
.06022 .04796 L
.06138 .04786 L
.06244 .04778 L
.06502 .04755 L
.06649 .04736 L
.06787 .04719 L
.06853 .04707 L
.06924 .04691 L
.07074 .04663 L
.07376 .04587 L
.08448 .04263 L
.10458 .0367 L
.12449 .02754 L
.12995 .0256 L
.13572 .0239 L
.1381 .02308 L
.13941 .0227 L
.14065 .02245 L
.14135 .02237 L
.14212 .02232 L
.14281 .02233 L
Mistroke
.14346 .02236 L
.14473 .02249 L
.14537 .02258 L
.14608 .02259 L
.1474 .02245 L
.14879 .02227 L
.15127 .02191 L
.15399 .02154 L
.1547 .0215 L
.15548 .02141 L
.15621 .0213 L
.15689 .02117 L
.15964 .02048 L
.16215 .01998 L
.16706 .01921 L
.16825 .01915 L
.16936 .01886 L
.17052 .01847 L
.17178 .01817 L
.17307 .01804 L
.17378 .01807 L
.17444 .01816 L
.17569 .01852 L
.17687 .01824 L
.18606 .01647 L
.18715 .01601 L
.18832 .01598 L
.18942 .01641 L
.19042 .01716 L
.19155 .01801 L
.19262 .01669 L
.19378 .01567 L
.19504 .01515 L
.19631 .01533 L
.19696 .01569 L
.19767 .01627 L
.19892 .01768 L
.2001 .01641 L
.20127 .01526 L
.20234 .01472 L
.20352 .01474 L
.20476 .01543 L
.20603 .01673 L
.20722 .0168 L
.20789 .01602 L
.2086 .01536 L
.20986 .01472 L
.21106 .01474 L
.21233 .01541 L
.21341 .01638 L
Mistroke
.2146 .01765 L
.21532 .01801 L
.216 .0181 L
.21728 .01787 L
.21801 .01765 L
.21878 .01742 L
.21951 .01726 L
.22017 .01719 L
.22145 .01727 L
.22266 .01796 L
.22397 .01867 L
.22471 .01895 L
.22538 .01917 L
.22779 .01981 L
.23004 .02033 L
.23515 .02178 L
.23769 .02242 L
.23903 .02269 L
.23976 .02283 L
.24045 .02296 L
.24169 .02305 L
.24235 .02307 L
.24306 .02311 L
.24432 .02323 L
.24547 .02317 L
.24655 .02307 L
.2477 .02311 L
.24879 .02318 L
.24977 .02301 L
.25093 .02301 L
.25219 .02327 L
.25338 .02327 L
.25447 .02341 L
.25561 .0238 L
.25667 .02418 L
.25908 .02514 L
.26143 .02646 L
.26395 .02814 L
.2665 .02964 L
.26921 .03107 L
.27053 .03161 L
.27177 .03204 L
.27289 .0323 L
.27409 .03251 L
.27478 .0326 L
.27543 .03267 L
.27614 .03268 L
.27689 .03267 L
.27769 .03264 L
.27844 .03261 L
Mistroke
.27912 .03257 L
.27985 .03247 L
.28514 .03159 L
.29021 .0309 L
.29144 .03071 L
.29214 .03062 L
.29277 .03057 L
.29352 .03057 L
.29423 .0306 L
.29488 .03052 L
.29559 .03044 L
.29686 .03043 L
.29801 .03054 L
.29865 .0305 L
.29934 .03047 L
.3006 .03052 L
.30177 .03069 L
.30302 .0307 L
.30408 .03077 L
.30525 .03095 L
.30654 .03106 L
.30776 .03117 L
.30904 .03139 L
.30971 .0315 L
.31044 .03151 L
.31119 .03156 L
.31197 .03167 L
.31265 .03183 L
.31338 .03203 L
.31406 .03196 L
.31479 .03191 L
.3161 .03193 L
.31679 .03202 L
.31743 .03216 L
.31813 .03238 L
.31887 .03268 L
.31952 .03301 L
.32022 .0334 L
.32148 .03381 L
.3227 .03378 L
.32382 .0339 L
.32513 .03422 L
.32638 .03469 L
.33638 .03774 L
.34125 .03885 L
.34566 .03978 L
.35467 .04114 L
.3571 .0417 L
.35774 .04194 L
.35843 .04224 L
Mistroke
.35967 .04231 L
.36082 .042 L
.36186 .04188 L
.3631 .04197 L
.36426 .04232 L
.36551 .04299 L
.36667 .0438 L
.36794 .04277 L
.36858 .04238 L
.36929 .04207 L
.36999 .04192 L
.37064 .04194 L
.37134 .04214 L
.37209 .04255 L
.37334 .04373 L
.37472 .04503 L
.37944 .05032 L
.38072 .05303 L
.38192 .05576 L
.38318 .05701 L
.38384 .05728 L
.38455 .05739 L
.38529 .05739 L
.386 .05734 L
.38731 .05731 L
.38853 .05751 L
.38921 .05775 L
.38985 .05807 L
.391 .05883 L
.39227 .05991 L
.39485 .06167 L
.40419 .06762 L
.42515 .08072 L
.46531 .10645 L
.50396 .12671 L
.52357 .1418 L
.54505 .15388 L
.56578 .16362 L
.57482 .167 L
.57728 .16774 L
.57958 .16854 L
.58074 .16906 L
.58198 .16978 L
.58463 .17158 L
.58986 .17516 L
.5947 .17865 L
.60421 .1866 L
.60946 .19167 L
.61507 .1966 L
.61779 .19851 L
Mistroke
.62035 .19997 L
.62266 .201 L
.62515 .20188 L
.62771 .20254 L
.63041 .20315 L
.63526 .20407 L
.64629 .207 L
.65127 .20887 L
.65246 .20955 L
.65372 .21035 L
.6548 .21092 L
.65598 .21116 L
.65663 .21095 L
.65733 .21066 L
.65859 .21033 L
.65931 .21033 L
.66007 .21053 L
.66071 .21086 L
.66142 .21142 L
.66266 .21285 L
.66335 .21385 L
.66399 .21441 L
.66524 .21342 L
.66638 .21308 L
.66751 .21335 L
.66876 .21434 L
.67006 .21606 L
.67128 .21813 L
.67242 .21972 L
.67346 .2205 L
.67467 .22098 L
.67581 .22131 L
.67703 .22172 L
.67834 .22238 L
.67958 .22348 L
.68069 .22461 L
.68602 .22883 L
.70436 .24537 L
.74448 .28555 L
.7831 .32782 L
.82416 .37653 L
.86371 .4346 L
.88361 .46901 L
.8923 .48792 L
.89688 .49687 L
.90174 .50449 L
.90696 .5108 L
.91179 .51569 L
.92129 .52492 L
.94222 .54786 L
Mistroke
.95975 .57268 L
.97619 .60332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00;7oo00<007ooOol0jGoo000/Ool00`00Oomoo`3YOol002ao
o`800>Yoo`00;7oo00<007ooOol0jGoo000/Ool00`00Oomoo`0TOol:002kOol002aoo`03001oogoo
01aoo`P0009oo`03001oogoo009oo`H00;Qoo`00;7oo00<007ooOol05goo1@005Goo1P00/Woo000/
Ool2000FOol2000OOol3002`Ool002aoo`03001oogoo01=oo`8002=oo`l00:9oo`00;7oo00<007oo
Ool03goo1000<goo0`00X7oo000/Ool00`00Oomoo`0;Ool4000jOol9002GOol002aoo`8000Uoo`<0
04Aoo`@009Ioo`00;7oo3000BWoo00<007ooOol0Tgoo000>Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1C
Ool00`00Oomoo`2COol000ioo`07001oogooOol007oo00001goo00<007oo00000Woo00<007oo0000
0Woo00<007oo00000goo00<007ooOol0Dgoo1000TWoo0008Ool30003Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0`00EWoo0P00TGoo000?Ool0
0`00Oomoo`020008Ool20003Ool20003Ool20004Ool00`00Oomoo`1HOol2002?Ool000eoo`03001o
o`00009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo05Yoo`03001oogoo08aoo`003Goo0`000Woo0`001goo0`000Woo0`000Woo0`000goo00<007oo
Ool0Fgoo0P00S7oo000/Ool00`00Oomoo`1MOol00`00Oomoo`29Ool002aoo`8005moo`03001oogoo
08Qoo`00;7oo00<007ooOol0Ggoo0P00R7oo000/Ool00`00Oomoo`1QOol00`00Oomoo`25Ool002ao
o`03001oogoo069oo`8008Eoo`00;7oo0P00IGoo00<007ooOol0PWoo000/Ool00`00Oomoo`1UOol2
0022Ool002aoo`03001oogoo02ioo`D002ioo`<000=oo`03001oogoo02Yoo`80039oo`<001ioo`00
;7oo00<007ooOol0<7oo00<007ooOol0;Woo00<007ooOol017oo0P00;7oo00<007ooOol0<7oo00<0
07ooOol07Goo000/Ool2000aOol00`00Oomoo`0_Ool00`00Oomoo`05Ool2000YOol00`00Oomoo`0_
Ool4000NOol002aoo`03001oogoo031oo`03001oogoo02moo`03001oogoo00Moo`8002Qoo`03001o
ogoo02ioo`03001oo`0001moo`00;7oo00<007ooOol0<7oo00<007ooOol0;Woo00<007oo00002Woo
0P0097oo00<007oo0000<Goo0P007goo000/Ool00`00Oomoo`0_Ool2000aOol00`00Oomoo`0;Ool2
000SOol00`00Oomoo`0aOol00`00Oomoo`0MOol002aoo`8007=oo`03001oogoo07Aoo`00;7oo00<0
07ooOol0Lgoo0P00M7oo000/Ool00`00Oomoo`1eOol00`00Oomoo`1aOol002aoo`03001oogoo07Io
o`80075oo`00;7oo00<007ooOol0N7oo0P00Kgoo000WOooa000002aoo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo009oo`8000=oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Moo`40005oo`00;7oo00<007ooOol0OWoo0`00J7oo000/Ool0
0`00Oomoo`21Ool2001VOol002aoo`8008Aoo`8006Aoo`00;7oo00<007ooOol0QGoo00<007ooOol0
HGoo000/Ool00`00Oomoo`26Ool00`00Oomoo`1POol002aoo`03001oogoo08Moo`80061oo`00;7oo
0P00RWoo00<007ooOol0GGoo000/Ool00`00Oomoo`2:Ool00`00Oomoo`1LOol002aoo`03001oogoo
08]oo`03001oogoo05]oo`00;7oo00<007ooOol0S7oo0P00Fgoo000/Ool00`00Oomoo`2>Ool4001G
Ool002aoo`8009=oo`<005Aoo`00;7oo00<007ooOol0U7oo1@00D7oo000/Ool00`00Oomoo`2GOol2
001@Ool002aoo`03001oogoo09Uoo`8004ioo`00;7oo0P00Vgoo0P00CGoo000/Ool00`00Oomoo`2L
Ool00`00Oomoo`1:Ool000ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`<0009oo`03001oogoo009oo`03001oogoo09eoo`03001oogoo04Uoo`003Woo00L007oo
Oomoo`00Ool00007Ool00`00Ool00004Ool01P00Oomoo`00Ool000=oo`03001oogoo09ioo`8004Uo
o`0027oo0`000goo00<007ooOol00goo00<007ooOol01goo00<007ooOol010000goo00@007ooOomo
o`<00:1oo`03001oogoo04Ioo`003goo00<007ooOol00P0027oo0P000goo00<007oo00000Woo0P00
17oo00<007ooOol0XGoo00<007ooOol0AGoo000=Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`2ROol00`00Oomoo`14Ool000eoo`<0009o
o`<000Moo`<000Aoo`03001oogoo00<000=oo`03001oogoo0:=oo`03001oogoo04=oo`00;7oo00<0
07ooOol0Y7oo00<007ooOol0@Woo000/Ool2002VOol00`00Oomoo`11Ool002aoo`03001oogoo0:Eo
o`03001oogoo045oo`00;7oo00<007ooOol0YWoo00<007ooOol0@7oo000/Ool00`00Oomoo`2WOol0
0`00Oomoo`0oOol002aoo`800:Uoo`03001oogoo03ioo`00;7oo00<007ooOol0ZGoo00<007ooOol0
?Goo000/Ool00`00Oomoo`2ZOol00`00Oomoo`0lOol002aoo`03001oogoo0:]oo`03001oogoo03]o
o`00;7oo0P00[Goo00<007ooOol0>Woo000/Ool00`00Oomoo`2]Ool00`00Oomoo`0iOol002aoo`03
001oogoo0:ioo`03001oogoo03Qoo`00;7oo00<007ooOol0[goo00<007ooOol0=goo000/Ool2002a
Ool00`00Oomoo`0fOol002aoo`03001oogoo0;5oo`03001oogoo03Eoo`00;7oo00<007ooOol0/Woo
00<007ooOol0=7oo000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool30002Ool00`00Oomoo`2cOol00`00Oomoo`0cOol001=oo`07001oogooOol007oo00001goo
00<007oo000017oo00D007ooOomoo`000;Ioo`03001oogoo039oo`003Goo0`000goo00<007ooOol0
0goo00<007ooOol01goo00<007ooOol010000Woo0`00]Goo00<007ooOol0<Goo000DOol00`00Oomo
o`020008Ool20003Ool00`00Ool00003Ool00`00Oomoo`2fOol00`00Oomoo`0`Ool0019oo`03001o
o`00009oo`03001oogoo00Moo`03001oogoo00=oo`8000=oo`03001oogoo0;Ioo`03001oogoo031o
o`004Woo0`000Woo0`001goo0`0017oo00D007ooOomoo`000;Uoo`03001oogoo02moo`00;7oo0P00
^Goo00<007ooOol0;Woo000/Ool00`00Oomoo`2iOol00`00Oomoo`0]Ool002aoo`03001oogoo0;Yo
o`03001oogoo02aoo`00;7oo00<007ooOol0^goo00<007ooOol0:goo000/Ool2002lOol00`00Oomo
o`0[Ool002aoo`03001oogoo0;aoo`03001oogoo02Yoo`00;7oo00<007ooOol0_Goo00<007ooOol0
:Goo000/Ool00`00Oomoo`2nOol00`00Oomoo`0XOol002aoo`03001oogoo0;ioo`03001oogoo02Qo
o`00;7oo0P00`7oo00<007ooOol09goo000/Ool00`00Oomoo`30Ool00`00Oomoo`0VOol002aoo`03
001oogoo0<5oo`03001oogoo02Eoo`00;7oo00<007ooOol0`Goo00<007ooOol09Goo000/Ool20033
Ool00`00Oomoo`0TOol002aoo`03001oogoo0<=oo`03001oogoo02=oo`003Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`8000Aoo`03001oogoo009oo`03001oogoo
0<=oo`03001oogoo02=oo`003Woo00L007ooOomoo`00Ool00007Ool00`00Ool00004Ool01P00Oomo
o`00Ool000=oo`03001oogoo0<Aoo`03001oogoo029oo`0027oo0`000goo00<007ooOol00goo00<0
07ooOol01goo00D007ooOomoo`0000Eoo`04001oogooOol30035Ool00`00Oomoo`0QOol000moo`03
001oogoo008000Qoo`8000Eoo`03001oogoo008000Aoo`03001oogoo0<Ioo`03001oogoo021oo`00
3Goo00<007oo00000Woo00<007ooOol01goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol0
0goo00<007ooOol0aWoo00<007ooOol087oo000=Ool30002Ool30007Ool30003Ool01000Oomoogoo
0`000goo00<007ooOol0agoo00<007ooOol07goo000/Ool00`00Oomoo`38Ool00`00Oomoo`0NOol0
02aoo`800<Uoo`03001oogoo01ioo`00;7oo00<007ooOol0bGoo00<007ooOol07Goo000/Ool00`00
Oomoo`39Ool00`00Oomoo`0MOol002aoo`03001oogoo0<Yoo`03001oogoo01aoo`00;7oo0P00bgoo
00<007ooOol077oo000/Ool00`00Oomoo`3;Ool00`00Oomoo`0KOol002aoo`03001oogoo0<]oo`03
001oogoo01]oo`00;7oo00<007ooOol0c7oo00<007ooOol06Woo000/Ool2003=Ool00`00Oomoo`0J
Ool002aoo`03001oogoo0<eoo`03001oogoo01Uoo`00;7oo00<007ooOol0cGoo00<007ooOol06Goo
000/Ool00`00Oomoo`3>Ool00`00Oomoo`0HOol002aoo`800<moo`03001oogoo01Qoo`00;7oo00<0
07ooOol0cgoo00<007ooOol05goo000/Ool00`00Oomoo`3?Ool00`00Oomoo`0GOol001=oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20004Ool00`00Oomoo`3@Ool0
0`00Oomoo`0FOol001=oo`07001oogooOol007oo00001goo00<007oo000017oo00D007ooOomoo`00
0=9oo`03001oogoo01Ioo`003Goo0`000goo00<007ooOol00goo00<007ooOol01goo00D007ooOomo
o`0000Aoo`<00=5oo`03001oogoo01Eoo`0057oo00<007ooOol00P0027oo0P001Goo00D007ooOomo
o`000=Aoo`03001oogoo01Aoo`004Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol00Woo
00<007oo00000goo00<007ooOol0dgoo0P0057oo000BOol30002Ool30007Ool30003Ool00`00Oomo
o`02Ool00`00Oomoo`3EOol00`00Oomoo`0AOol002aoo`800=Moo`03001oogoo011oo`00;7oo00<0
07ooOol0egoo00<007ooOol03goo000/Ool00`00Oomoo`3GOol00`00Oomoo`0?Ool002aoo`03001o
ogoo0=Qoo`03001oogoo00ioo`00;7oo0P00fWoo00<007ooOol03Goo000/Ool00`00Oomoo`3JOol0
0`00Oomoo`0<Ool002aoo`03001oogoo0=]oo`03001oogoo00]oo`00;7oo00<007ooOol0fgoo00<0
07ooOol02goo000/Ool00`00Oomoo`3LOol00`00Oomoo`0:Ool002aoo`800=ioo`03001oogoo00Uo
o`00;7oo00<007ooOol0gGoo00<007ooOol02Goo000/Ool00`00Oomoo`3NOol00`00Oomoo`08Ool0
02aoo`03001oogoo0=moo`03001oogoo00Moo`00;7oo0P00h7oo00<007ooOol01goo000/Ool00`00
Oomoo`3POol00`00Oomoo`06Ool000ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`04001oogooOol30003Ool00`00Oomoo`02Ool00`00Oomoo`3POol00`00Oomoo`06Ool000ioo`07
001oogooOol007oo00001goo00<007oo00000Woo00<007ooOol00Woo00<007oo00000goo00<007oo
Ool0hGoo00<007ooOol01Goo0008Ool30003Ool00`00Oomoo`03Ool00`00Oomoo`07Ool01@00Oomo
ogoo00001Goo00@007ooOomoo`<00>5oo`03001oogoo00Eoo`003goo00<007ooOol00P0027oo0P00
17oo00@007ooOomoo`8000Aoo`03001oogoo0>9oo`03001oogoo00Aoo`003Goo00<007oo00000Woo
00<007ooOol01goo00<007ooOol00Woo00<007oo00000Woo00<007ooOol00goo00<007ooOol0jGoo
000=Ool30002Ool30007Ool30003Ool01000Oomoogoo0`000goo00<007ooOol0jGoo000/Ool00`00
Oomoo`3YOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mo
oaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.886964, -75.5612, 0.0197114, 
  0.000232581}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Tightening the error budget by a factor of 100 by specifying the ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["0.000001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will reduce the total energy rise to only 0.0007%, over the same time \
period, with an associated doubling of run time. Using the ",
  StyleBox["ConstraintCorrection",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, with the default error budget, will reduce the total energy rise \
to 0.002% with a slightly smaller increase in run time. In this case, either \
constraint correction or reducing step size, which is the result of \
decreasing the error budget, give similar returns on computer time \
investment.\n\nChanging the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting can also affect the integration error. Setting ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to ",
  StyleBox["Quadratic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for this example will increase the net energy rise to 0.08%, while \
setting ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will reverse the sign of the error, changing the net energy rise to \
-0.04%. Specifying a higher ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " setting often produces unexpected results because the automatic time step \
size adjustment works to counteract the higher degree setting. The integrator \
measures a smaller error in each step so it chooses a larger step size, \
resulting in the same net error.\n\nThe free response of dynamic machines \
makes for very interesting animation that, unfortunately, cannot be displayed \
in this text. The on-line version of this manual contains the commands \
required to animate the motion of the pendulum model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the pendulum-on-a-rope model at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1, 2, and 3 seconds."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .25 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.00595238 0.31746 [
[ 0 0 0 0 ]
[ 1 .25 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .25 L
0 .25 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.00595238 0.321429 0.244048 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.36277 .53777 L
.56276 .53923 L
.8 .8 L
s
P
p
0 .7 0 r
p
.4632 .4785 m
.36291 .51777 L
.36262 .55777 L
.56262 .55923 L
.56291 .51923 L
F
P
P
p
0 0 .7 r
p
.03 w
.44287 .11908 m
.46319 .47851 L
s
P
.03 w
.44287 .11908 m
.44287 .11908 .06 -3.23589 356.764 arc
F
P
p
.04 w
.4632 .4785 Mdot
0 .8 Mdot
.8 .8 Mdot
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.00595238 0.64881 0.244048 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.19273 .55167 L
.39229 .53846 L
.8 .8 L
s
P
p
0 .7 0 r
p
.28855 .48519 m
.19141 .53171 L
.19405 .57162 L
.39361 .55841 L
.39097 .5185 L
F
P
P
p
0 0 .7 r
p
.03 w
.14997 .1532 m
.28854 .48547 L
s
P
.03 w
.14997 .1532 m
.14997 .1532 .06 -22.6378 337.362 arc
F
P
p
.04 w
.28855 .48519 Mdot
0 .8 Mdot
.8 .8 Mdot
P
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.00595238 0.97619 0.244048 MathSubStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.2 0.8 0.2 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
p
P
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
p
p
.7 0 0 r
.01 w
0 .8 m
.14943 .56293 L
.34905 .55069 L
.8 .8 L
s
P
p
0 .7 0 r
p
.24557 .49692 m
.1482 .54297 L
.15065 .58289 L
.35028 .57065 L
.34783 .53073 L
F
P
P
p
0 0 .7 r
p
.03 w
.27225 .13899 m
.24577 .49801 L
s
P
.03 w
.27225 .13899 m
.27225 .13899 .06 4.21781 364.218 arc
F
P
p
.04 w
.24557 .49692 Mdot
0 .8 Mdot
.8 .8 Mdot
P
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{430, 107},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006^0000Ja000`40O003h00Oogoo[goo003oOon_
Ool00?moojmoo`00ogoo[goo003oOon_Ool00?moojmoo`00ogoo[goo003oOon_Ool00?moojmoo`00
ogoo[goo003oOon_Ool00?moojmoo`00@7oo2@0FogooIWoo000nOol<01KoOomUOol003ioo`d05_Io
o`H05VMoo`00?Woo3@0Fm7oo2P0FIGoo000mOol?01IJOol801J@Ool<01ITOol003eoo`l05UQoo`/0
5Xioo`h05V=oo`00?Goo3`0FF7oo300FSGoo3P0FHgoo000lOol@01IHOol=01J<Ool?01IROol003eo
o`l05UMoo`h05X]ooa005V9oo`00?Goo3P0FF7oo3P0FS7oo3`0FHWoo000nOol=01IGOol?01J<Ool?
01IROol003moo`/05UUoo`h05Xaoo`l05V9oo`00?goo2P0FFWoo3P0FSGoo3@0FHgoo0011Ool601IL
Ool>01J=Ool<01ITOol004Aoo`<05Ueoo`d05Xeoo`/05VEoo`00A7oo0`0FGGoo300FTGoo1`0FIWoo
0014Ool301IMOol;01JDOol301IXOol004Aoo`<05V1oo`P05Y=oo`<05VUoo`00A7oo0`0FIGoo0`0F
Tgoo0`0FJGoo0014Ool301IUOol401JBOol301IYOol004Aoo`<05VIoo`<05Y9oo`<05VUoo`00A7oo
0`0FIWoo100FTGoo0`0FJGoo0014Ool301IWOol301JAOol301IYOol004Aoo`<05VMoo`<05Y5oo`<0
5VUoo`00A7oo0`0FIgoo100FT7oo0`0FJGoo0014Ool301IXOol301J@Ool301IYOol004Aoo`<05VQo
o`@05Xmoo`<05VUoo`00A7oo0`0FJGoo0`0FSgoo0`0FJGoo0014Ool301IYOol301J?Ool301IYOol0
04Eoo`<05VQoo`@05Xioo`<05VUoo`00AGoo0`0FJGoo0`0FSWoo0`0FJGoo0015Ool301IYOol401J=
Ool301IYOol004Eoo`<05VYoo`<05Xaoo`<05VYoo`00AGoo0`0FJWoo100FRgoo0`0FJWoo0015Ool3
01I[Ool301J;Ool301IZOol004Eoo`<05V]oo`<05X]oo`<05VYoo`00AGoo0`0FJgoo100FRWoo0`0F
JWoo0015Ool301I/Ool301J:Ool301IZOol004Eoo`<05Vaoo`@05XUoo`<05VYoo`00AGoo0`0FKGoo
0`0FRGoo0`0FJWoo0015Ool301I]Ool301J9Ool301IZOol004Eoo`<05Veoo`@05XQoo`<05VYoo`00
AGoo0`0FKWoo0`0FR7oo0`0FJWoo0015Ool301I^Ool401J7Ool301IZOol004Ioo`<05Vioo`<05XMo
o`<05VYoo`00AWoo0`0FKWoo0`0FQgoo0`0FJWoo0016Ool301I^Ool401J6Ool301IZOol004Ioo`<0
5Vmoo`<05XEoo`<05V]oo`00AWoo0`0FKgoo100FQ7oo0`0FJgoo0016Ool301I`Ool301J4Ool301I[
Ool004Ioo`80000301Ioogoo06ioo`<05XAoo`<05V]oo`00AGoo1000L7oo00@05P0000005X=oo`<0
5V]oo`00AGoo1000L7oo1000Pgoo0`0FJgoo0012Ool40/0200030/1^Ool400020/21Ool200000`0F
Oomoo`1YOol0041oo`d2`6Yoo`<2`08000H2`7eoo`@006]oo`00?Goo4P;0IWoo40;0NWoo10000P;0
JGoo000jOolG0/1ROolE0/1eOol30/0200060/1VOol003YooaT2`5iooaP2`79ooa02`6=oo`00>Woo
6@;0G7oo6P;0L7oo5@;0H7oo000jOolI0/000eP0Oomoo`1IOolJ0/1^OolG0/1POol003Qoo`9H01T2
`003OomH07oo05UooaX2`09H06UooaX2`61oo`00=goo00=H07ooOol06@;00Woo00=H07ooOol0Egoo
6P;00Woo00=H07ooOol0Igoo6@;000=H07ooOol0GGoo000fOol00eP0Oomoo`0MOol00eP0Oomoo`1E
Ool00eP00/02`00H0/03Ool2F01WOolI0/000gooF01H001MOol003Aoo`9H025oo`03F01oogoo05=o
o`03F01oogoo01ioo`9H06Aoo`03F002`0;001L2`0=oo`9H05]oo`00<goo00=H07ooOol08Woo00=H
07ooOol0DWoo00=H07ooOol087oo00=H07ooOol0HGoo00=H00;00/002`;04Goo0UP0FGoo000aOol2
F00UOol00eP0Oomoo`1AOol00eP0Oomoo`0ROol2F01POol00eP0Oomoo`0OOol2F01GOol0031oo`03
F01oogoo02Ioo`03F01oogoo04moo`03F01oogoo02Eoo`03F01oogoo05aoo`03F01oogoo029oo`9H
05Eoo`00;goo00=H07ooOol0:7oo00=H07ooOol0CGoo00=H07ooOol09goo0UP0G7oo00=H07ooOol0
97oo00=H07ooOol0DWoo000]Ool2F00/Ool00eP0Oomoo`1<Ool00eP0Oomoo`0YOol00eP0Oomoo`1H
Ool00eP0Oomoo`0VOol2F01BOol002aoo`03F01oogoo02eoo`03F01oogoo04Yoo`03F01oogoo02]o
o`9H05Qoo`03F01oogoo02Qoo`9H051oo`00:Woo0UP0<Goo00=H07ooOol0B7oo00=H07ooOol0;Woo
0UP0EGoo00=H07ooOol0:goo0UP0CWoo000YOol00eP0Oomoo`0bOol00eP0Oomoo`16Ool00eP0Oomo
o`0aOol00eP0Oomoo`1AOol00eP0Oomoo`0^Ool2F01<Ool002Qoo`03F01oogoo03Aoo`03F01oogoo
04Aoo`03F01oogoo03=oo`9H055oo`03F01oogoo031oo`9H04Yoo`009Woo0UP0>7oo00=H07ooOol0
@goo00=H07ooOol0=Goo00=H07ooOol0CGoo00=H07ooOol0<goo00=H07ooOol0Agoo000UOol00eP0
Oomoo`0iOol00eP0Oomoo`11Ool00eP0Oomoo`0gOol2F01<Ool00eP0Oomoo`0eOol2F017Ool002Ao
o`03F01oogoo03]oo`03F01oogoo03moo`03F01oogoo03Yoo`03F01oogoo04Uoo`03F01oogoo03Mo
o`9H04Eoo`008Woo0UP0?Woo00=H07ooOol0?Woo00=H07ooOol0?7oo0UP0B7oo00=H07ooOol0>Woo
0UP0@goo000QOol00eP0Oomoo`0oOol00eP0Oomoo`0mOol00eP0Oomoo`0nOol2F015Ool00eP0Oomo
o`0mOol2F011Ool001moo`9H04=oo`03F01oogoo03]oo`03F01oogoo045oo`03F01oogoo049oo`03
F01oogoo03moo`9H03moo`007Woo00=H07ooOol0A7oo00=H07ooOol0>Goo00=H07ooOol0@goo0UP0
@Goo00=H07ooOol0@Woo0UP0?Goo000MOol00eP0Oomoo`16Ool00eP0Oomoo`0gOol00eP0Oomoo`16
Ool00eP0Oomoo`0nOol00eP0Oomoo`14Ool00eP0Oomoo`0jOol001]oo`9H04Yoo`03F01oogoo03Io
o`03F01oogoo04Moo`9H03eoo`03F01oogoo04Ioo`9H03Yoo`006Woo00=H07ooOol0Bgoo00=H07oo
Ool0=7oo00=H07ooOol0BWoo0UP0>Woo00=H07ooOol0BGoo0UP0>7oo000HOol2F01?Ool00eP0Oomo
o`0bOol00eP0Oomoo`1=Ool00eP0Oomoo`0gOol00eP0Oomoo`1;Ool2F00fOol001Moo`03F01oogoo
051oo`03F01oogoo031oo`03F01oogoo04moo`9H03Ioo`03F01oogoo04ioo`9H03Aoo`005Woo00=H
07ooOol0DWoo00=H07ooOol0;Woo00=H07ooOol0DWoo00=H07ooOol0<Woo00=H07ooOol0DGoo0UP0
<Woo000DOol2F01FOol00eP0Oomoo`0]Ool00eP0Oomoo`1COol2F00bOol00eP0Oomoo`1COol00eP0
Oomoo`0_Ool001=oo`03F01oogoo05Ioo`03F01oogoo02aoo`03F01oogoo05Ioo`03F01oogoo02io
o`03F01oogoo05Eoo`9H02moo`004Goo0UP0FWoo00=H07ooOol0:Woo00=H07ooOol0F7oo0UP0;Woo
00=H07ooOol0Egoo0UP0;Goo000@Ool00eP0Oomoo`1KOol00eP0Oomoo`0XOol00eP0Oomoo`1KOol2
F00[Ool00eP0Oomoo`1JOol2F00[Ool000moo`03F01oogoo05eoo`03F01oogoo02Moo`03F01oogoo
05eoo`03F01oogoo02Moo`03F01oogoo05eoo`9H02Uoo`003Goo0UP0HGoo00=H07ooOol09Goo00=H
07ooOol0Ggoo0UP09goo00=H07ooOol0Ggoo0UP09goo000;Ool2001SOol2000TOol2001SOol2000T
Ool2001SOol2000VOol000Yoo`@0065oo`@0029oo`@0065oo`@0029oo`@0065oo`@002Eoo`002Woo
1000HGoo10008Woo1000HGoo10008Woo1000HGoo10009Goo0000\
\>"],
  ImageRangeCache->{{{0, 429}, {106, 0}} -> {-0.0935891, -0.018754, 
  0.00742933, 0.00742933}, {{12.5625, 138.75}, {103.438, 2.5}} -> {-0.498172,
   -4.10157, 0.0396289, 0.0396289}, {{151.375, 277.563}, {103.438, 2.5}} ->
   {-5.99916, -4.10157, 0.0396289, 0.0396289}, {{290.188, 416.375}, {103.438, 
  2.5}} -> {-11.5001, -4.10157, 0.0396289, 0.0396289}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Gyroscopic Example"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following example integrates the motion of the gyroscope model that \
was presented in Section 10.3. The model uses the ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, which was also presented in Section 10.3, to reduce the \
numerical burden of integrating the motion of the rotor. The angular local \
coordinate system is used, which requires ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to use a coordinate transformation during the integration."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package and defines names for each of the body numbers. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(base = 2; \)\), 
    \(\(gimbal = 3; \)\), 
    \(\(rotor = 4; \)\), 
    \(X = {1, 0, 0}; Y = {0, 1, 0}; Z = {0, 0, 1}; \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the constraints, bodies, and loads for the gyroscope model."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(SetConstraints[\n\tRevolute5[1, Axis[ground, 0, Z], Axis[base, 0, Z]], 
      \n\tOrthogonal1[2, Vector[base, X], Vector[ground, Y]], \n\t
      Revolute5[3, Axis[base, 0, Y], Axis[gimbal, 0, Y]], \n\t
      Orthogonal1[4, Vector[gimbal, Z], Vector[base, X]], \n\t
      Revolute5[5, Axis[gimbal, 0, X], Axis[rotor, 0, X]], \n\t
      ProjectedAngle1[6, Vector[rotor, Z], Vector[gimbal, Z], 
        Vector[gimbal, X], 0]]\), 
    \(SetBodies[Body[rotor, Inertia \[Rule] {2.0, 1.0, 1.0, 0, 0, 0}]]\), 
    \(SetLoads[Moment[base, Z, 1], GyroMoment[rotor, X, 2\ N[\[Pi]]]]\)}], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run to prepare the initial conditions for ",
  StyleBox["SetFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Note that the rotor has no angular velocity because it is modeled in the \
",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " load."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Omega[rotor] /. SolveMech[0, Solution \[Rule] Acceleration]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Free Response"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "To find the unconstrained motion of the gyroscope, a ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is built that contains a new set of equations of motion with \
constraints 2, 4, and 6 dropped from the model. Constraint 6, the constraint \
that locks the rotation of the rotor to that of the gimbal, is dropped in \
this simulation because the gross motion of the rotor results in some \
relative angular acceleration between these two bodies. If constraint 6 was \
not dropped, the model would represent an enforced constant angular velocity \
between the rotor and the gimbal, as if the rotor had a constant velocity \
motor attaching it to the gimbal.\n\nThe constant moment that was applied to \
the base is retained, so the model is expected to gain energy with the \
passage of time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This drops the constraints that lock the three rotational axes of the \
gyroscope."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(fsys = SetFree[{2, 4, 6}, Solution \[Rule] Dynamic]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This integrates the ",
  StyleBox["FreeSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = ",
  StyleBox["endt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The ",
  StyleBox["MakeRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option includes the velocity solution in the result."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = 
      SolveFree[fsys, endt = 1.0, MakeRules \[Rule] {Location, Velocity}]; 
    \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a plot of the three components of the angular velocity of the \
gimbal. The ",
  StyleBox["Z",
    FontSlant->"Italic"],
  " component is simply oscillating about zero, so the applied torque is \
producing no net motion of the gimbal. The ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " component, however, is consistently negative, so the gimbal is precessing \
in an oscillatory manner."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[Omega[gimbal] /. sol], {T, 0, endt}, \n\t
      PlotStyle \[Rule] {{}, {Dashing[{.03, .03}]}, {Dashing[{.04, .02}]}}]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.406898 2.46776 [
[.21429 .3944 -9 -9 ]
[.21429 .3944 9 0 ]
[.40476 .3944 -9 -9 ]
[.40476 .3944 9 0 ]
[.59524 .3944 -9 -9 ]
[.59524 .3944 9 0 ]
[.78571 .3944 -9 -9 ]
[.78571 .3944 9 0 ]
[.97619 .3944 -3 -9 ]
[.97619 .3944 3 0 ]
[.01131 .03673 -30 -4.5 ]
[.01131 .03673 0 4.5 ]
[.01131 .16012 -24 -4.5 ]
[.01131 .16012 0 4.5 ]
[.01131 .28351 -30 -4.5 ]
[.01131 .28351 0 4.5 ]
[.01131 .53029 -24 -4.5 ]
[.01131 .53029 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .4069 m
.21429 .41315 L
s
[(0.2)] .21429 .3944 0 1 Mshowa
.40476 .4069 m
.40476 .41315 L
s
[(0.4)] .40476 .3944 0 1 Mshowa
.59524 .4069 m
.59524 .41315 L
s
[(0.6)] .59524 .3944 0 1 Mshowa
.78571 .4069 m
.78571 .41315 L
s
[(0.8)] .78571 .3944 0 1 Mshowa
.97619 .4069 m
.97619 .41315 L
s
[(1)] .97619 .3944 0 1 Mshowa
.125 Mabswid
.07143 .4069 m
.07143 .41065 L
s
.11905 .4069 m
.11905 .41065 L
s
.16667 .4069 m
.16667 .41065 L
s
.2619 .4069 m
.2619 .41065 L
s
.30952 .4069 m
.30952 .41065 L
s
.35714 .4069 m
.35714 .41065 L
s
.45238 .4069 m
.45238 .41065 L
s
.5 .4069 m
.5 .41065 L
s
.54762 .4069 m
.54762 .41065 L
s
.64286 .4069 m
.64286 .41065 L
s
.69048 .4069 m
.69048 .41065 L
s
.7381 .4069 m
.7381 .41065 L
s
.83333 .4069 m
.83333 .41065 L
s
.88095 .4069 m
.88095 .41065 L
s
.92857 .4069 m
.92857 .41065 L
s
.25 Mabswid
0 .4069 m
1 .4069 L
s
.02381 .03673 m
.03006 .03673 L
s
[(-0.15)] .01131 .03673 1 0 Mshowa
.02381 .16012 m
.03006 .16012 L
s
[(-0.1)] .01131 .16012 1 0 Mshowa
.02381 .28351 m
.03006 .28351 L
s
[(-0.05)] .01131 .28351 1 0 Mshowa
.02381 .53029 m
.03006 .53029 L
s
[(0.05)] .01131 .53029 1 0 Mshowa
.125 Mabswid
.02381 .06141 m
.02756 .06141 L
s
.02381 .08609 m
.02756 .08609 L
s
.02381 .11077 m
.02756 .11077 L
s
.02381 .13545 m
.02756 .13545 L
s
.02381 .1848 m
.02756 .1848 L
s
.02381 .20948 m
.02756 .20948 L
s
.02381 .23416 m
.02756 .23416 L
s
.02381 .25883 m
.02756 .25883 L
s
.02381 .30819 m
.02756 .30819 L
s
.02381 .33287 m
.02756 .33287 L
s
.02381 .35754 m
.02756 .35754 L
s
.02381 .38222 m
.02756 .38222 L
s
.02381 .43158 m
.02756 .43158 L
s
.02381 .45625 m
.02756 .45625 L
s
.02381 .48093 m
.02756 .48093 L
s
.02381 .50561 m
.02756 .50561 L
s
.02381 .01206 m
.02756 .01206 L
s
.02381 .55496 m
.02756 .55496 L
s
.02381 .57964 m
.02756 .57964 L
s
.02381 .60432 m
.02756 .60432 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4069 m
.02499 .4069 L
.02605 .4069 L
.02729 .4069 L
.02846 .4069 L
.02954 .4069 L
.03053 .4069 L
.03163 .4069 L
.03279 .4069 L
.03395 .4069 L
.0352 .4069 L
.03638 .4069 L
.03746 .4069 L
.03873 .4069 L
.04011 .4069 L
.04141 .4069 L
.04262 .4069 L
.04521 .4069 L
.04765 .4069 L
.04984 .4069 L
.05221 .4069 L
.05481 .40691 L
.05754 .40691 L
.06244 .40692 L
.06507 .40692 L
.06746 .40693 L
.07283 .40695 L
.07781 .40697 L
.08253 .407 L
.09309 .40709 L
.09906 .40715 L
.10458 .40723 L
.12324 .40759 L
.13387 .40787 L
.14385 .40818 L
.18253 .4097 L
.20218 .41051 L
.21257 .41091 L
.22367 .41124 L
.23443 .41149 L
.23951 .41158 L
.2442 .41165 L
.24891 .41171 L
.25135 .41173 L
.25402 .41175 L
.25635 .41176 L
.25747 .41177 L
.25853 .41177 L
.25973 .41177 L
.26083 .41178 L
Mistroke
.26201 .41178 L
.2633 .41178 L
.26395 .41178 L
.26463 .41178 L
.26586 .41177 L
.26718 .41177 L
.26863 .41176 L
.27122 .41175 L
.27247 .41174 L
.27364 .41173 L
.27601 .41171 L
.27817 .41168 L
.28301 .41159 L
.29307 .41136 L
.304 .41104 L
.34483 .40946 L
.36512 .40867 L
.38415 .40805 L
.40235 .4076 L
.41258 .40741 L
.42195 .40727 L
.43178 .40715 L
.44091 .40708 L
.45093 .40702 L
.45654 .40699 L
.46163 .40698 L
.47164 .40695 L
.48085 .40693 L
.49161 .40691 L
.50166 .40689 L
.51073 .40688 L
.51582 .40688 L
.52046 .40687 L
.52292 .40687 L
.52417 .40687 L
.52554 .40687 L
.52625 .40687 L
.52702 .40687 L
.52774 .40687 L
.52841 .40687 L
.5297 .40687 L
.53035 .40687 L
.53106 .40687 L
.53238 .40687 L
.53358 .40687 L
.53496 .40687 L
.53627 .40687 L
.53859 .40688 L
.54112 .40688 L
.54347 .40689 L
Mistroke
.546 .40689 L
.55057 .40691 L
.556 .40694 L
.56097 .40697 L
.56613 .40701 L
.57175 .40707 L
.582 .4072 L
.59233 .40739 L
.60169 .4076 L
.62267 .40822 L
.66276 .40977 L
.68115 .41049 L
.69159 .41085 L
.70133 .41115 L
.71096 .41137 L
.7159 .41146 L
.72128 .41155 L
.72422 .41158 L
.72694 .41161 L
.72949 .41164 L
.73084 .41165 L
.73156 .41165 L
.7323 .41166 L
.73361 .41166 L
.73482 .41166 L
.73594 .41166 L
.73718 .41166 L
.73847 .41166 L
.7392 .41166 L
.73986 .41166 L
.74114 .41166 L
.74235 .41165 L
.74474 .41164 L
.74698 .41163 L
.75208 .41158 L
.75705 .41152 L
.76238 .41144 L
.76733 .41133 L
.77202 .41122 L
.78084 .41098 L
.8191 .4096 L
.84047 .40879 L
.85982 .40814 L
.86953 .40787 L
.88002 .40762 L
.89902 .40729 L
.90856 .40717 L
.91901 .40707 L
.92428 .40703 L
.92993 .407 L
Mistroke
.94009 .40696 L
.94899 .40693 L
.95865 .40691 L
.97619 .40688 L
Mfstroke
[ .03 .03 ] 0 setdash
.02381 .4069 m
.02499 .40692 L
.02605 .40688 L
.02729 .40675 L
.02846 .40659 L
.03053 .40619 L
.03279 .40558 L
.03527 .40472 L
.0379 .40358 L
.04262 .40094 L
.05205 .39348 L
.06244 .38198 L
.0842 .34783 L
.10458 .30557 L
.14335 .2093 L
.18458 .10789 L
.20517 .06675 L
.21519 .05039 L
.22428 .03816 L
.2338 .02801 L
.24277 .021 L
.2477 .01824 L
.25224 .01641 L
.25461 .01571 L
.25597 .0154 L
.25722 .01516 L
.25853 .01496 L
.25925 .01488 L
.25994 .01482 L
.26115 .01474 L
.26184 .01472 L
.26248 .01472 L
.26365 .01474 L
.26489 .01481 L
.26595 .01492 L
.26711 .01507 L
.26836 .01529 L
.2697 .01558 L
.2721 .01626 L
.27454 .01713 L
.27684 .0182 L
.28114 .02072 L
.29103 .02875 L
.30174 .04082 L
.32162 .07189 L
.34266 .11485 L
.38055 .20774 L
.42089 .30603 L
.43946 .34392 L
.45971 .37626 L
Mistroke
.4707 .38882 L
.47605 .39364 L
.48089 .39725 L
.48591 .40021 L
.4882 .40129 L
.49062 .4022 L
.49322 .40295 L
.49561 .40345 L
.49694 .40364 L
.49818 .40378 L
.49889 .40383 L
.49954 .40387 L
.50028 .40389 L
.50099 .4039 L
.50213 .40387 L
.50337 .4038 L
.50453 .40369 L
.50559 .40354 L
.50678 .40334 L
.50807 .40308 L
.51067 .40237 L
.51325 .40146 L
.51599 .40026 L
.52094 .39746 L
.5306 .38969 L
.53937 .38024 L
.5586 .35189 L
.57941 .31121 L
.62038 .21299 L
.65983 .11806 L
.67967 .07811 L
.69777 .04936 L
.70777 .03736 L
.71726 .02879 L
.72246 .02524 L
.72727 .0227 L
.72978 .02166 L
.73255 .02075 L
.73394 .02041 L
.73544 .02012 L
.73686 .01991 L
.73816 .01977 L
.73944 .01969 L
.74064 .01966 L
.74172 .01967 L
.74289 .01973 L
.74417 .01984 L
.74482 .01991 L
.74552 .02001 L
.74795 .02046 L
Mistroke
.75022 .02105 L
.75266 .02186 L
.75706 .0238 L
.76261 .02709 L
.76787 .03121 L
.77776 .04117 L
.79758 .06928 L
.81597 .10399 L
.85512 .19483 L
.89672 .29447 L
.9176 .33683 L
.92676 .35247 L
.93681 .3673 L
.94586 .37839 L
.95557 .38764 L
.96093 .3915 L
.96582 .3942 L
.96817 .39522 L
.97073 .39611 L
.9719 .39644 L
.97314 .39674 L
.9743 .39696 L
.97538 .39713 L
.97619 .39723 L
Mfstroke
[ .04 .02 ] 0 setdash
.02381 .4069 m
.06244 .50276 L
.08255 .54437 L
.0932 .56265 L
.10458 .57881 L
.11009 .58526 L
.11531 .59049 L
.12038 .59475 L
.12507 .59793 L
.12951 .60028 L
.13178 .60122 L
.13422 .60204 L
.13549 .60239 L
.13666 .60266 L
.13784 .60289 L
.13895 .60306 L
.14022 .6032 L
.1409 .60325 L
.14161 .60329 L
.1423 .60331 L
.14295 .60332 L
.14415 .60329 L
.14531 .60322 L
.14656 .60309 L
.14773 .60291 L
.14881 .60272 L
.15143 .60207 L
.15392 .60124 L
.15886 .59897 L
.16423 .59558 L
.17383 .58718 L
.1827 .57685 L
.20137 .54773 L
.22197 .50586 L
.26217 .40692 L
.30086 .31147 L
.32051 .27093 L
.3309 .25294 L
.342 .23703 L
.35275 .22517 L
.35784 .22078 L
.36253 .21747 L
.36724 .21486 L
.36972 .21384 L
.37235 .21299 L
.37463 .21243 L
.37573 .21222 L
.37677 .21206 L
.37799 .21191 L
.37911 .21182 L
Mistroke
.38031 .21177 L
.38162 .21177 L
.38227 .21178 L
.38296 .21182 L
.38419 .21192 L
.38551 .21208 L
.38695 .21233 L
.38955 .21293 L
.39197 .21369 L
.39649 .21561 L
.40134 .21847 L
.41232 .22768 L
.42232 .23917 L
.44144 .26909 L
.46222 .3112 L
.50305 .41085 L
.54237 .50538 L
.5621 .54449 L
.58017 .5724 L
.58962 .58317 L
.59956 .59165 L
.60473 .59486 L
.60953 .59709 L
.6123 .598 L
.61481 .59858 L
.6162 .59882 L
.61693 .59892 L
.6177 .59901 L
.61838 .59907 L
.61912 .59912 L
.62043 .59917 L
.62173 .59916 L
.62293 .59911 L
.62425 .59899 L
.62492 .59892 L
.62566 .59881 L
.62822 .59832 L
.63062 .59767 L
.63509 .59598 L
.63992 .59345 L
.64522 .58974 L
.65082 .58488 L
.66082 .5739 L
.68054 .54412 L
.6989 .50814 L
.73791 .41567 L
.77938 .31609 L
.80015 .27449 L
.80928 .2592 L
.81933 .24477 L
Mistroke
.82832 .23433 L
.83799 .22585 L
.84332 .22238 L
.8482 .21997 L
.85054 .21908 L
.85178 .21868 L
.8531 .2183 L
.85437 .21799 L
.85552 .21779 L
.85667 .21762 L
.85776 .2175 L
.85892 .21741 L
.86017 .21737 L
.86135 .21737 L
.86242 .21741 L
.86368 .21751 L
.86439 .21758 L
.86505 .21766 L
.86633 .21787 L
.86753 .2181 L
.86991 .2187 L
.87254 .21957 L
.87785 .22198 L
.88249 .2248 L
.88675 .22801 L
.89633 .23734 L
.91527 .26321 L
.93597 .30168 L
.97619 .39477 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
8Goo00<007ooOol0m7oo000QOol00`00Oomoo`3dOol0025oo`03001oogoo0?Aoo`008Goo0P00mGoo
000QOol00`00Oomoo`0kOol2002gOol0025oo`03001oogoo03Aoo`03001oogoo00Ioo`03001oogoo
06ioo`H0041oo`008Goo00<007ooOol0<goo00<007ooOol027oo0P00KGoo00<007ooOol0A7oo000<
Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomo
o`0;Ool00`00Oomoo`1YOol00`00Oomoo`08Ool00`00Oomoo`0jOol000]oo`03001oo`0000Qoo`07
001oogooOol007oo000017oo00<007ooOol0<7oo0P003goo00<007ooOol0M7oo00<007ooOol0>Goo
0006Ool30002Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2000`Ool00`00Oomo
o`27Ool2000iOol000]oo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`0_Ool00`00
Oomoo`29Ool00`00Oomoo`0fOol000]oo`03001oo`0000Qoo`05001oogooOol00006Ool00`00Oomo
o`2kOol00`00Oomoo`0fOol000aoo`03001oogoo00Ioo`8000=oo`<000Aoo`03001oogoo0:Ioo`80
01Aoo`03001oogoo03Eoo`008Goo00<007ooOol0YGoo00<007ooOol0C7oo000QOol00`00Oomoo`15
Ool00`00Oomoo`1MOol00`00Oomoo`1<Ool0025oo`8004Moo`03001oogoo05]oo`03001oogoo04eo
o`008Goo00<007ooOol0:Woo00<007ooOol06Goo00<007ooOol0Fgoo00<007ooOol0CGoo000QOol0
0`00Oomoo`0ZOol00`00Oomoo`0JOol00`00Oomoo`1IOol00`00Oomoo`1>Ool0025oo`03001oogoo
02Uoo`03001oogoo01aoo`03001oogoo05Qoo`03001oogoo01Yoo`03001oogoo035oo`008Goo00<0
07ooOol0:Goo00<007ooOol077oo00<007ooOol0MWoo00<007ooOol0<7oo000QOol00`00Oomoo`0X
Ool00`00Oomoo`0NOol00`00Oomoo`1eOol00`00Oomoo`0`Ool0025oo`8002Uoo`03001oogoo01io
o`03001oogoo07Ioo`03001oogoo02moo`008Goo00<007ooOol09goo00<007ooOol0V7oo00<007oo
Ool0;goo000QOol00`00Oomoo`0WOol00`00Oomoo`2IOol00`00Oomoo`0^Ool0025oo`03001oogoo
0<=oo`03001oogoo02ioo`008Goo00<007ooOol0Wgoo00<007ooOol08Woo00<007ooOol0;Goo000Q
Ool00`00Oomoo`2NOol00`00Oomoo`1COol0025oo`03001oogoo09ioo`03001oogoo05=oo`008Goo
0P00CWoo00<007ooOol0CGoo00<007ooOol0E7oo000QOol00`00Oomoo`1=Ool00`00Oomoo`1=Ool0
0`00Oomoo`1DOol0025oo`03001oogoo02Aoo`03001oogoo02Ioo`03001oogoo04eoo`03001oogoo
05Aoo`008Goo00<007ooOol097oo00<007ooOol09goo00<007ooOol0Bgoo00<007ooOol0EGoo000Q
Ool00`00Oomoo`0SOol00`00Oomoo`0XOol00`00Oomoo`1;Ool00`00Oomoo`0XOol00`00Oomoo`0Z
Ool0025oo`03001oogoo02=oo`03001oogoo02Qoo`03001oogoo07Ioo`03001oogoo02Yoo`008Goo
0P008goo00<007ooOol0:Woo00<007ooOol0MWoo00<007ooOol0:Goo000QOol00`00Oomoo`0ROol0
0`00Oomoo`0ZOol00`00Oomoo`1fOol00`00Oomoo`0YOol0025oo`03001oogoo025oo`03001oogoo
0:Eoo`03001oogoo02Qoo`008Goo00<007ooOol08Goo00<007ooOol0YGoo00<007ooOol0:7oo000A
Ool00`00Oomoo`02Ool00`00Oomoo`050003Ool00`00Oomoo`3:Ool00`00Oomoo`0WOol0011oo`03
001oo`0000Qoo`03001oogoo00=oo`03001oogoo09Uoo`03001oogoo02ioo`03001oogoo02Moo`00
2goo0`000Woo00<007oo000027oo00<007ooOol00goo0P00VWoo00<007ooOol0F7oo000@Ool00`00
Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`2HOol00`00Oomoo`1IOol0011oo`03001oo`0000Qo
o`03001oogoo00=oo`03001oogoo059oo`03001oogoo04=oo`03001oogoo05Uoo`004Goo00<007oo
Ool01Woo0P001Goo00<007ooOol0DWoo00<007ooOol0@Woo00<007ooOol0FWoo000QOol00`00Oomo
o`0NOol00`00Oomoo`0bOol00`00Oomoo`11Ool00`00Oomoo`1JOol0025oo`03001oogoo01ioo`03
001oogoo039oo`03001oogoo041oo`03001oogoo05]oo`008Goo0P007Woo00<007ooOol0=7oo00<0
07ooOol0?goo00<007ooOol0=7oo00<007ooOol097oo000QOol00`00Oomoo`0MOol00`00Oomoo`0d
Ool00`00Oomoo`1fOol00`00Oomoo`0TOol0025oo`03001oogoo01aoo`03001oogoo03Ioo`03001o
ogoo07Ioo`03001oogoo02=oo`008Goo00<007ooOol077oo00<007ooOol0=Woo00<007ooOol0MWoo
00<007ooOol08goo000QOol00`00Oomoo`0KOol00`00Oomoo`2`Ool00`00Oomoo`0SOol0025oo`03
001oogoo01]oo`03001oogoo0;5oo`03001oogoo029oo`008Goo0P00d7oo00<007ooOol08Woo000Q
Ool00`00Oomoo`1DOol4000kOol00`00Oomoo`0jOol00`00Oomoo`0QOol0025oo`03001oogoo059o
o`<003ioo`03001oogoo03Qoo`@0029oo`008Goo00<007ooOol0DGoo00<007ooOol01goo0P00=Goo
00<007ooOol0=goo0`000Woo0P008Goo000QOol00`00Oomoo`1?Ool20007Ool00`00Oomoo`02Ool0
0`00Oomoo`0bOol00`00Oomoo`0fOol00`00Oomoo`0VOol0025oo`03001oogoo04ioo`03001oogoo
00Moo`03001oogoo00=oo`03001oogoo031oo`03001oogoo03Eoo`8002Uoo`008Goo00<007ooOol0
67oo00<007ooOol0<goo00<007ooOol027oo00<007ooOol00goo00<007ooOol0;goo00<007ooOol0
@Woo00<007ooOol06goo000QOol2000IOol00`00Oomoo`0nOol00`00Oomoo`04Ool00`00Oomoo`0]
Ool00`00Oomoo`14Ool2000KOol0025oo`03001oogoo01Moo`03001oogoo041oo`03001oogoo00Ao
o`03001oogoo02aoo`03001oogoo041oo`03001oogoo00=oo`03001oogoo01Qoo`008Goo00<007oo
Ool05goo00<007ooOol0@7oo00<007ooOol017oo00<007ooOol0HGoo00<007ooOol02goo00<007oo
Ool017oo00<007ooOol05goo000QOol00`00Oomoo`0GOol00`00Oomoo`0aOol00`00Oomoo`0=Ool0
0`00Oomoo`04Ool00`00Oomoo`1OOol00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0GOol0
025oo`03001oogoo01Moo`03001oogoo031oo`03001oogoo00ioo`03001oogoo06Eoo`03001oogoo
00ioo`03001oogoo00Aoo`03001oogoo01Ioo`008Goo00<007ooOol05Woo00<007ooOol0<7oo00<0
07ooOol0Mgoo00<007ooOol03goo00<007ooOol017oo00<007ooOol05Goo000QOol2000GOol00`00
Oomoo`0`Ool00`00Oomoo`1fOol00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`0DOol0025o
o`03001oogoo04Qoo`03001oogoo01Yoo`03001oogoo05Uoo`03001oogoo019oo`03001oogoo01]o
o`008Goo00<007ooOol0B7oo00<007ooOol06goo00<007ooOol097oo00<007ooOol0<Goo00<007oo
Ool04Woo00<007ooOol06goo000QOol00`00Oomoo`17Ool00`00Oomoo`0LOol00`00Oomoo`0TOol0
0`00Oomoo`1TOol000aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo04Moo`03001oogoo01eoo`03001oogoo029oo`03001oogoo06Eoo`002goo00<0
07oo00001goo00<007oo00000Woo00<007oo000017oo00<007ooOol0AWoo00<007ooOol05Goo00<0
07ooOol01Woo00<007ooOol08Woo00<007ooOol0D7oo00<007ooOol04Woo0006Ool30002Ool00`00
Ool00007Ool00`00Ool00004Ool00`00Oomoo`02Ool20017Ool00`00Oomoo`0EOol00`00Oomoo`07
Ool00`00Oomoo`0POol00`00Oomoo`0aOol00`00Oomoo`0MOol00`00Oomoo`0BOol000]oo`03001o
o`0000Moo`03001oo`00009oo`8000Eoo`03001oogoo01=oo`03001oogoo04Uoo`03001oogoo00Io
o`03001oogoo021oo`03001oogoo031oo`03001oogoo01moo`03001oogoo015oo`002goo00<007oo
00001goo00<007oo00000Woo00<007ooOol017oo00<007ooOol04goo00<007ooOol0BGoo00<007oo
Ool01goo00<007ooOol07Woo00<007ooOol0<Goo00<007ooOol07goo00<007ooOol04Goo000<Ool0
0`00Oomoo`07Ool01000Oomoogoo0`0017oo00<007ooOol04Woo00<007ooOol0Bgoo00<007ooOol0
1Woo00<007ooOol07Woo00<007ooOol0<7oo00<007ooOol067oo00<007ooOol01Woo00<007ooOol0
47oo000QOol00`00Oomoo`0BOol00`00Oomoo`0_Ool00`00Oomoo`0IOol00`00Oomoo`07Ool00`00
Oomoo`1@Ool00`00Oomoo`0IOol00`00Oomoo`05Ool00`00Oomoo`0@Ool0025oo`03001oogoo015o
o`03001oogoo02moo`03001oogoo01]oo`03001oogoo05Qoo`03001oogoo01Yoo`03001oogoo00Io
o`03001oogoo00moo`008Goo0P004Woo00<007ooOol0;goo00<007ooOol06goo00<007ooOol0F7oo
00<007ooOol06goo00<007ooOol01Woo00<007ooOol03Woo000QOol00`00Oomoo`0@Ool00`00Oomo
o`0_Ool00`00Oomoo`1fOol00`00Oomoo`0LOol00`00Oomoo`06Ool00`00Oomoo`0>Ool0025oo`03
001oogoo011oo`03001oogoo02moo`03001oogoo07Ioo`03001oogoo01eoo`03001oogoo00Ioo`03
001oogoo00eoo`008Goo00<007ooOol0@Goo00<007ooOol0:7oo00<007ooOol0C7oo00<007ooOol0
7Goo00<007ooOol05Woo000QOol00`00Oomoo`11Ool00`00Oomoo`0XOol00`00Oomoo`0HOol00`00
Oomoo`1BOol00`00Oomoo`0EOol0025oo`03001oogoo045oo`03001oogoo02Uoo`03001oogoo01Io
o`03001oogoo06]oo`008Goo00<007ooOol0@Goo00<007ooOol087oo00<007ooOol01Woo00<007oo
Ool05Woo00<007ooOol0GGoo00<007ooOol02goo000QOol20011Ool00`00Oomoo`0QOol00`00Oomo
o`07Ool00`00Oomoo`0DOol00`00Oomoo`1NOol00`00Oomoo`0;Ool0025oo`03001oogoo041oo`03
001oogoo029oo`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo035oo`03001oogoo02]oo`03
001oogoo00Yoo`008Goo00<007ooOol03Goo00<007ooOol0EGoo00<007ooOol01goo00<007ooOol0
4Woo00<007ooOol0<Woo00<007ooOol0:goo00<007ooOol02Woo000QOol00`00Oomoo`0<Ool00`00
Oomoo`1GOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0aOol00`00Oomoo`0TOol00`00
Oomoo`06Ool00`00Oomoo`09Ool0025oo`03001oogoo00]oo`03001oogoo05Qoo`03001oogoo00Mo
o`03001oogoo04Eoo`03001oogoo02Eoo`03001oogoo00Eoo`03001oogoo00Uoo`008Goo00<007oo
Ool02goo00<007ooOol0<7oo00<007ooOol09Woo00<007ooOol01Woo00<007ooOol0A7oo00<007oo
Ool09goo00<007ooOol017oo00<007ooOol02Goo000QOol2000;Ool00`00Oomoo`0aOol00`00Oomo
o`0WOol00`00Oomoo`1<Ool00`00Oomoo`0WOol00`00Oomoo`05Ool00`00Oomoo`08Ool0025oo`03
001oogoo00Yoo`03001oogoo01Yoo`03001oogoo009oo`04001oogooOol3000:Ool00`00Oomoo`0G
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool3000SOol00`00Oomoo`02Ool01000Oomoogoo0P0097oo
0P0017oo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol017oo1P001Goo000QOol00`00Oomo
o`09Ool00`00Oomoo`0JOol00`00Ool00007Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol00`00Ool0
0009Ool00`00Oomoo`0QOol00`00Ool00007Ool00`00Ool0000SOol00`00Ool00007Ool00`00Ool0
000POol00`00Oomoo`04Ool00`00Ool00007Ool0025oo`03001oogoo02Ioo`03001oo`0000Qoo`03
001oogoo00Qoo`03001oogoo01Moo`03001oo`0000Moo`@0029oo`03001oo`0000Moo`03001oo`00
029oo`800003Ool007oo00Ioo`03001oo`00025oo`03001oogoo00=oo`03001oo`0000Moo`008Goo
00<007ooOol09Woo00<007oo000027oo00<007ooOol027oo00<007ooOol05goo00<007oo00001goo
00<007oo00003Woo00<007ooOol037oo00<007ooOol00goo00<007oo00001goo0P008goo0P0000=o
o`00Ool01goo00<007ooOol0:7oo00<007ooOol01Goo000QOol00`00Oomoo`0VOol00`00Ool00007
Ool00`00Ool00009Ool00`00Oomoo`0GOol00`00Ool00008Ool2000>Ool00`00Oomoo`0:Ool20006
Ool00`00Ool00007Ool00`00Oomoo`0SOol00`00Ool00007Ool00`00Ool0000YOol00`00Oomoo`05
Ool0025oo`8002Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo00Qo
o`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`8002Aoo`03001o
ogoo00Moo`03001oogoo02Moo`8000Moo`008Goo00<007ooOol0>goo00<007ooOol0=7oo00<007oo
Ool027oo00<007ooOol0K7oo00<007ooOol01Goo000QOol00`00Oomoo`04Ool00`00Oomoo`0cOol0
0`00Oomoo`0`Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1]Ool00`00Oomoo`05Ool0
025oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo035oo`8000=oo`03001oogoo00Eoo`03
001oogoo03Eoo`03001oogoo03=oo`<00003Ool007oo00Eoo`008Goo00<007ooOol00Woo0P00K7oo
0P000Woo00<007ooOol0>goo00<007ooOol0=Woo0`001Woo000QOol00`00Oomoo`02001`Ool3000m
Ool00`00Oomoo`0oOol001]oood000008Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol0
27oo=P001goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo=00027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol017oo000QOol00`00
Oomoo`0]Ool00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`0]Ool00`00Oomoo`0POol00`00
Oomoo`0:Ool00`00Oomoo`0]Ool00`00Oomoo`04Ool0025oo`8003Qoo`03001oogoo07Ioo`03001o
ogoo045oo`008Goo0P00>7oo00<007ooOol0MGoo00<007ooOol0@Woo000QOol00`00Ool0000fOol0
0`00Oomoo`1fOol00`00Oomoo`12Ool0025oo`<003Ioo`03001oogoo03ioo`03001oogoo03Eoo`03
001oogoo049oo`008Goo00<007oo0000=Woo00<007ooOol0?Woo00<007ooOol0NWoo000QOol01000
Oomoo`00=7oo00<007ooOol0@7oo00<007ooOol0NGoo000QOol01000Oomoo`00=7oo00<007ooOol0
@7oo00<007ooOol0NGoo000QOol01000Oomoo`00<goo00<007ooOol0@Woo00<007ooOol0N7oo000Q
Ool01@00Oomoogoo0000<Woo00<007ooOol0@Woo00<007ooOol0<Goo00<007ooOol0A7oo000QOol0
1@00Oomoogoo0000N7oo00<007ooOol0<7oo00<007ooOol0A7oo000QOol2001kOol00`00Oomoo`0_
Ool00`00Oomoo`15Ool0025oo`03001oogoo07]oo`03001oogoo02ioo`03001oogoo04Eoo`008Goo
00<007ooOol0<goo00<007ooOol0AGoo00<007ooOol0;Goo00<007ooOol0AWoo000QOol00`00Oomo
o`0cOol00`00Oomoo`1eOol00`00Oomoo`16Ool0025oo`03001oogoo00=oo`03001oogoo02aoo`03
001oogoo07Eoo`03001oogoo04Moo`008Goo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol0
MGoo00<007ooOol0Agoo000QOol20005Ool00`00Oomoo`0ZOol00`00Oomoo`1eOol00`00Oomoo`18
Ool0025oo`03001oogoo00Aoo`03001oogoo02Yoo`03001oogoo04Uoo`03001oogoo02Uoo`03001o
ogoo04Qoo`008Goo00<007ooOol01Goo00<007ooOol0:Goo00<007ooOol0BGoo00<007ooOol0M7oo
000QOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`1;Ool00`00Oomoo`1cOol0025oo`03
001oogoo00Ioo`03001oogoo02Moo`03001oogoo04]oo`03001oogoo07=oo`008Goo00<007ooOol0
1Woo00<007ooOol09Woo00<007ooOol0CGoo00<007ooOol0LWoo000QOol20007Ool00`00Oomoo`0V
Ool00`00Oomoo`1=Ool00`00Oomoo`0UOol00`00Oomoo`1:Ool0025oo`03001oogoo00Moo`03001o
ogoo07Eoo`03001oogoo02Eoo`03001oogoo04Yoo`008Goo00<007ooOol0P7oo00<007ooOol08goo
00<007ooOol0Bgoo000QOol00`00Oomoo`20Ool00`00Oomoo`0SOol00`00Oomoo`1;Ool000aoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02eoo`03
001oogoo055oo`03001oogoo025oo`03001oogoo04aoo`002goo00<007oo00001goo00<007oo0000
0Woo00<007oo000017oo00<007ooOol02Goo00<007ooOol087oo00<007ooOol0MWoo00<007ooOol0
C7oo000;Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`02Ool2000:Ool00`00Oomoo`0P
Ool00`00Oomoo`1eOol00`00Oomoo`1=Ool000]oo`03001oo`0000Moo`03001oo`00009oo`8000Eo
o`03001oogoo00Yoo`03001oogoo01ioo`03001oogoo07Ioo`03001oogoo04eoo`002goo00<007oo
00001goo00<007oo00000Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol07Woo00<007oo
Ool0EGoo00<007ooOol07Goo00<007ooOol0CWoo000<Ool00`00Oomoo`07Ool01000Oomoogoo0`00
17oo00<007ooOol02goo00<007ooOol077oo00<007ooOol0EWoo00<007ooOol07Goo00<007ooOol0
CWoo000QOol00`00Oomoo`0;Ool00`00Oomoo`0LOol00`00Oomoo`1GOol00`00Oomoo`1]Ool0025o
o`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo05Uoo`03001oogoo06aoo`008Goo0P003Goo
00<007ooOol06Goo00<007ooOol0FWoo00<007ooOol0K7oo000QOol00`00Oomoo`0=Ool00`00Oomo
o`0HOol00`00Oomoo`1KOol00`00Oomoo`0GOol00`00Oomoo`1AOol0025oo`03001oogoo00ioo`03
001oogoo07Ioo`03001oogoo01Eoo`03001oogoo059oo`008Goo00<007ooOol0R7oo00<007ooOol0
4goo00<007ooOol0Dgoo000QOol00`00Oomoo`28Ool00`00Oomoo`0COol00`00Oomoo`1COol0025o
o`03001oogoo02Eoo`03001oogoo065oo`03001oogoo015oo`03001oogoo05Aoo`008Goo00<007oo
Ool09Goo00<007ooOol0M7oo00<007ooOol0EGoo000QOol2000BOol00`00Oomoo`0@Ool00`00Oomo
o`1eOol00`00Oomoo`1EOol0025oo`03001oogoo019oo`03001oogoo00ioo`03001oogoo06Ioo`03
001oogoo00aoo`03001oogoo05Ioo`008Goo00<007ooOol04goo0P003Goo00<007ooOol0J7oo00<0
07ooOol02Woo00<007ooOol0Egoo000QOol00`00Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`1Z
Ool2001TOol0025oo`03001oogoo01Ioo`03001oogoo00Moo`03001oogoo06eoo`<00003Ool00000
05ioo`008Goo00<007ooOol05goo0`0017oo0P00LWoo0`00Ggoo000QOol2003eOol0025oo`03001o
ogoo0?Aoo`008Goo00<007ooOol0m7oo000QOol00`00Oomoo`3dOol00?mooaUoo`00ogoo6Goo003o
OolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.138206, -0.178041, 0.00416922,
   0.00160902}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the rotation angle of the base."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[ProjectedAngle[Vector[base, X], X, Z] /. sol], {T, 0, endt}]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 46.4459 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .10761 -30 -4.5 ]
[.01131 .10761 0 4.5 ]
[.01131 .2005 -30 -4.5 ]
[.01131 .2005 0 4.5 ]
[.01131 .29339 -30 -4.5 ]
[.01131 .29339 0 4.5 ]
[.01131 .38628 -30 -4.5 ]
[.01131 .38628 0 4.5 ]
[.01131 .47917 -24 -4.5 ]
[.01131 .47917 0 4.5 ]
[.01131 .57207 -30 -4.5 ]
[.01131 .57207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10761 m
.03006 .10761 L
s
[(0.002)] .01131 .10761 1 0 Mshowa
.02381 .2005 m
.03006 .2005 L
s
[(0.004)] .01131 .2005 1 0 Mshowa
.02381 .29339 m
.03006 .29339 L
s
[(0.006)] .01131 .29339 1 0 Mshowa
.02381 .38628 m
.03006 .38628 L
s
[(0.008)] .01131 .38628 1 0 Mshowa
.02381 .47917 m
.03006 .47917 L
s
[(0.01)] .01131 .47917 1 0 Mshowa
.02381 .57207 m
.03006 .57207 L
s
[(0.012)] .01131 .57207 1 0 Mshowa
.125 Mabswid
.02381 .03794 m
.02756 .03794 L
s
.02381 .06116 m
.02756 .06116 L
s
.02381 .08438 m
.02756 .08438 L
s
.02381 .13083 m
.02756 .13083 L
s
.02381 .15405 m
.02756 .15405 L
s
.02381 .17728 m
.02756 .17728 L
s
.02381 .22372 m
.02756 .22372 L
s
.02381 .24694 m
.02756 .24694 L
s
.02381 .27017 m
.02756 .27017 L
s
.02381 .31661 m
.02756 .31661 L
s
.02381 .33984 m
.02756 .33984 L
s
.02381 .36306 m
.02756 .36306 L
s
.02381 .4095 m
.02756 .4095 L
s
.02381 .43273 m
.02756 .43273 L
s
.02381 .45595 m
.02756 .45595 L
s
.02381 .5024 m
.02756 .5024 L
s
.02381 .52562 m
.02756 .52562 L
s
.02381 .54884 m
.02756 .54884 L
s
.02381 .59529 m
.02756 .59529 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01475 L
.02605 .01484 L
.02729 .01503 L
.02846 .01527 L
.03053 .01587 L
.03279 .01678 L
.03527 .01807 L
.0379 .01978 L
.04262 .02373 L
.05205 .03491 L
.06244 .05212 L
.0842 .10328 L
.10458 .16657 L
.14335 .31085 L
.18458 .46284 L
.20517 .5245 L
.21519 .54906 L
.22428 .56762 L
.2338 .58315 L
.24277 .59395 L
.2477 .59813 L
.25224 .60086 L
.25461 .60189 L
.25597 .60236 L
.25722 .6027 L
.25853 .60298 L
.25925 .6031 L
.25994 .60319 L
.26115 .60329 L
.26184 .60332 L
.26248 .60332 L
.26365 .60327 L
.26489 .60314 L
.26595 .60298 L
.26711 .60273 L
.26836 .60239 L
.2697 .60194 L
.2721 .60091 L
.27454 .59957 L
.27684 .59798 L
.28114 .59424 L
.29103 .58231 L
.30174 .56433 L
.32162 .51771 L
.34266 .45314 L
.38055 .31299 L
.42089 .16362 L
.43946 .10631 L
.45971 .05751 L
Mistroke
.4707 .03837 L
.47605 .031 L
.48089 .02547 L
.48591 .0209 L
.4882 .01921 L
.49062 .01779 L
.49322 .01661 L
.49561 .01581 L
.49694 .01549 L
.49818 .01527 L
.49889 .01517 L
.49954 .01511 L
.50028 .01506 L
.50099 .01504 L
.50213 .01506 L
.50337 .01515 L
.50453 .0153 L
.50559 .0155 L
.50678 .01578 L
.50807 .01617 L
.51067 .0172 L
.51325 .01854 L
.51599 .02033 L
.52094 .02455 L
.52591 .03009 L
.5306 .03638 L
.53937 .05076 L
.55943 .09591 L
.57789 .15024 L
.61735 .29216 L
.65529 .43253 L
.67641 .49933 L
.69568 .54757 L
.70523 .56604 L
.71027 .5741 L
.71563 .58144 L
.7203 .58677 L
.72546 .59147 L
.72771 .59314 L
.73015 .59466 L
.73245 .59584 L
.73455 .5966 L
.73583 .59696 L
.73703 .59723 L
.73811 .59741 L
.73928 .59754 L
.74056 .5976 L
.7412 .59761 L
.74191 .59759 L
.74317 .59749 L
Mistroke
.74434 .59734 L
.74552 .59712 L
.74663 .59684 L
.74873 .59617 L
.75099 .59521 L
.75345 .59388 L
.75865 .59014 L
.76419 .58471 L
.77415 .57109 L
.78444 .55248 L
.79557 .5275 L
.81575 .47075 L
.85677 .32618 L
.89628 .18244 L
.91616 .12074 L
.93427 .07573 L
.9443 .05617 L
.95379 .04161 L
.959 .03539 L
.96382 .0308 L
.9691 .02711 L
.97177 .0258 L
.97329 .02522 L
.97471 .02479 L
.97619 .02447 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol004]oo`03001oogoo009oo`04001oogooOol3000TOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool3000SOol00`00Oomoo`02Ool01000Oomoogoo0P009Goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol09Woo1@001Goo001:Ool00`00Ool00007Ool00`00
Oomoo`0SOol00`00Ool00009Ool00`00Oomoo`0QOol00`00Ool00007Ool00`00Ool0000SOol00`00
Ool00007Ool00`00Ool0000YOol00`00Oomoo`05Ool004Yoo`03001oo`0000Qoo`03001oogoo029o
o`03001oo`0000Moo`@0029oo`03001oo`0000Moo`03001oo`0002=oo`03001oo`0000Moo`03001o
o`0002Uoo`03001oogoo00Eoo`00BWoo00<007oo000027oo00<007ooOol08Woo00<007oo00001goo
00<007oo00008goo00<007oo00001goo0P0097oo00<007oo000027oo00<007ooOol0:7oo00<007oo
Ool01Goo001:Ool00`00Ool00007Ool00`00Ool0000SOol00`00Ool00008Ool2000SOol00`00Ool0
0007Ool00`00Oomoo`0SOol00`00Ool00007Ool00`00Ool0000YOol00`00Oomoo`05Ool004]oo`03
001oogoo00Moo`03001oogoo02=oo`03001oogoo00Qoo`03001oogoo029oo`03001oogoo00Moo`80
02Aoo`03001oogoo00Moo`03001oogoo02Moo`8000Moo`00ogoo6Goo003oOolIOol0025oo`03001o
ogoo0?Aoo`008Goo00<007ooOol0m7oo000QOol00`00Oomoo`3dOol0025oo`03001oogoo0?Aoo`00
6gooo@00000QOol01000Oomoo`0027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo
00<007ooOol01Goo0P000Woo00<007ooOol00P001goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol017oo000QOol01@00Oomoogoo0000KWoo00<007oo
Ool01goo00<007ooOol0KWoo0`001Woo000QOol00`00Oomoo`02Ool00`00Oomoo`1ZOol00`00Oomo
o`09Ool00`00Oomoo`1]Ool00`00Oomoo`06Ool0025oo`03001oogoo00=oo`03001oogoo06Uoo`03
001oogoo00Uoo`03001oogoo06]oo`8000Uoo`008Goo0P001Goo00<007ooOol0Igoo00<007ooOol0
2goo00<007ooOol0JGoo00<007ooOol02Goo000QOol00`00Oomoo`04Ool00`00Oomoo`1VOol00`00
Oomoo`0<Ool00`00Oomoo`1XOol00`00Oomoo`0:Ool0025oo`03001oogoo00Eoo`03001oogoo06Ao
o`03001oogoo00ioo`03001oogoo06Ioo`03001oogoo00]oo`008Goo00<007ooOol01Goo00<007oo
Ool0Hgoo00<007ooOol03goo00<007ooOol0IGoo00<007ooOol037oo000QOol00`00Oomoo`06Ool0
0`00Oomoo`1ROol00`00Oomoo`0@Ool00`00Oomoo`1TOol00`00Oomoo`0<Ool0025oo`03001oogoo
00Ioo`03001oogoo065oo`03001oogoo019oo`03001oogoo069oo`03001oogoo00eoo`008Goo0P00
27oo00<007ooOol0H7oo00<007ooOol04Woo00<007ooOol0HWoo00<007ooOol03Goo000QOol00`00
Oomoo`07Ool00`00Oomoo`1OOol00`00Oomoo`0DOol00`00Oomoo`1POol00`00Oomoo`0>Ool0025o
o`03001oogoo00Qoo`03001oogoo05ioo`03001oogoo01Aoo`03001oogoo061oo`03001oogoo00io
o`008Goo00<007ooOol027oo00<007ooOol0GGoo00<007ooOol05Woo00<007ooOol0GWoo00<007oo
Ool03goo000QOol00`00Oomoo`09Ool00`00Oomoo`1LOol00`00Oomoo`0FOol00`00Oomoo`1NOol0
0`00Oomoo`0?Ool0025oo`03001oogoo00Uoo`03001oogoo05aoo`03001oogoo01Moo`03001oogoo
05eoo`03001oogoo00moo`008Goo0P002goo00<007ooOol0FWoo00<007ooOol067oo00<007ooOol0
G7oo00<007ooOol047oo000QOol00`00Oomoo`0:Ool00`00Oomoo`1JOol00`00Oomoo`0IOol00`00
Oomoo`1KOol00`00Oomoo`0@Ool0025oo`03001oogoo00]oo`03001oogoo05Uoo`03001oogoo01Uo
o`03001oogoo05Yoo`03001oogoo015oo`008Goo00<007ooOol02goo00<007ooOol0F7oo00<007oo
Ool06goo00<007ooOol0FGoo00<007ooOol04Goo0007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool01000Oomoogoo0`0017oo00<007ooOol037oo00<007ooOol0Egoo00<007ooOol0
6goo00<007ooOol0F7oo00<007ooOol04Woo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`1FOol00`00Oomoo`0MOol00`00
Oomoo`1GOol00`00Oomoo`0BOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000=o
o`03001oogoo00=oo`8000eoo`03001oogoo05Ioo`03001oogoo01eoo`03001oogoo05Ioo`03001o
ogoo01=oo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00goo
00<007ooOol03Goo00<007ooOol0EGoo00<007ooOol07Goo00<007ooOol0EWoo00<007ooOol04goo
0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomo
o`0=Ool00`00Oomoo`1DOol00`00Oomoo`0NOol00`00Oomoo`1EOol00`00Oomoo`0DOol000Moo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00eoo`03
001oogoo05Aoo`03001oogoo01moo`03001oogoo05Aoo`03001oogoo01Aoo`008Goo00<007ooOol0
3Woo00<007ooOol0Dgoo00<007ooOol07goo00<007ooOol0E7oo00<007ooOol057oo000QOol00`00
Oomoo`0>Ool00`00Oomoo`1COol00`00Oomoo`0OOol00`00Oomoo`1COol00`00Oomoo`0EOol0025o
o`8000moo`03001oogoo059oo`03001oogoo025oo`03001oogoo059oo`03001oogoo01Eoo`008Goo
00<007ooOol03Woo00<007ooOol0DWoo00<007ooOol08Goo00<007ooOol0DWoo00<007ooOol05Goo
000QOol00`00Oomoo`0?Ool00`00Oomoo`1AOol00`00Oomoo`0QOol00`00Oomoo`1AOol00`00Oomo
o`0FOol0025oo`03001oogoo00moo`03001oogoo051oo`03001oogoo029oo`03001oogoo055oo`03
001oogoo01Ioo`008Goo00<007ooOol03goo00<007ooOol0D7oo00<007ooOol08goo00<007ooOol0
D7oo00<007ooOol05Woo000QOol00`00Oomoo`0@Ool00`00Oomoo`1?Ool00`00Oomoo`0SOol00`00
Oomoo`1?Ool00`00Oomoo`0GOol0025oo`80015oo`03001oogoo04moo`03001oogoo02=oo`03001o
ogoo04moo`03001oogoo01Moo`008Goo00<007ooOol047oo00<007ooOol0CWoo00<007ooOol09Goo
00<007ooOol0CWoo00<007ooOol05goo000QOol00`00Oomoo`0AOol00`00Oomoo`1=Ool00`00Oomo
o`0UOol00`00Oomoo`1>Ool00`00Oomoo`0GOol0025oo`03001oogoo015oo`03001oogoo04eoo`03
001oogoo02Eoo`03001oogoo04eoo`03001oogoo01Qoo`008Goo00<007ooOol04Goo00<007ooOol0
C7oo00<007ooOol09Woo00<007ooOol0CGoo00<007ooOol067oo000QOol00`00Oomoo`0BOol00`00
Oomoo`1;Ool00`00Oomoo`0WOol00`00Oomoo`1<Ool00`00Oomoo`0HOol0025oo`8001=oo`03001o
ogoo04]oo`03001oogoo02Moo`03001oogoo04]oo`03001oogoo01Uoo`008Goo00<007ooOol04Woo
00<007ooOol0Bgoo00<007ooOol09goo00<007ooOol0Bgoo00<007ooOol06Goo000QOol00`00Oomo
o`0BOol00`00Oomoo`1:Ool00`00Oomoo`0YOol00`00Oomoo`1:Ool00`00Oomoo`0IOol000Moo`03
001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`<000=oo`03001oogoo
01=oo`03001oogoo04Uoo`03001oogoo02Uoo`03001oogoo04Uoo`03001oogoo01Yoo`001Woo00<0
07oo00001goo00<007oo00000Woo00<007oo000017oo00<007ooOol00Woo00<007ooOol04goo00<0
07ooOol0BGoo00<007ooOol0:Goo00<007ooOol0BGoo00<007ooOol06Woo0006Ool00`00Ool00007
Ool00`00Ool00002Ool00`00Ool00002Ool40003Ool2000DOol00`00Oomoo`18Ool00`00Oomoo`0Z
Ool00`00Oomoo`19Ool00`00Oomoo`0JOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001o
o`00009oo`03001oo`0000Aoo`03001oogoo01=oo`03001oogoo04Qoo`03001oogoo02]oo`03001o
ogoo04Qoo`03001oogoo01Yoo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo
0P0017oo00<007ooOol057oo00<007ooOol0Agoo00<007ooOol0:goo00<007ooOol0Agoo00<007oo
Ool06goo0007Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`0DOol00`00Oomoo`17Ool00`00Oomoo`0[Ool00`00Oomoo`17Ool00`00Oomoo`0KOol0
025oo`03001oogoo01Aoo`03001oogoo04Ioo`03001oogoo02eoo`03001oogoo04Ioo`03001oogoo
01]oo`008Goo00<007ooOol05Goo00<007ooOol0AGoo00<007ooOol0;Goo00<007ooOol0AGoo00<0
07ooOol077oo000QOol2000FOol00`00Oomoo`15Ool00`00Oomoo`0]Ool00`00Oomoo`15Ool00`00
Oomoo`0LOol0025oo`03001oogoo01Eoo`03001oogoo04Aoo`03001oogoo02ioo`03001oogoo04Eo
o`03001oogoo01aoo`008Goo00<007ooOol05Goo00<007ooOol0A7oo00<007ooOol0;goo00<007oo
Ool0A7oo00<007ooOol077oo000QOol00`00Oomoo`0FOol00`00Oomoo`13Ool00`00Oomoo`0_Ool0
0`00Oomoo`13Ool00`00Oomoo`0MOol0025oo`03001oogoo01Ioo`03001oogoo049oo`03001oogoo
031oo`03001oogoo04=oo`03001oogoo01eoo`008Goo00<007ooOol05Woo00<007ooOol0@Woo00<0
07ooOol0<Goo00<007ooOol0@Woo00<007ooOol07Goo000QOol2000HOol00`00Oomoo`11Ool00`00
Oomoo`0aOol00`00Oomoo`12Ool00`00Oomoo`0MOol0025oo`03001oogoo01Moo`03001oogoo045o
o`03001oogoo035oo`03001oogoo045oo`03001oogoo01ioo`008Goo00<007ooOol05goo00<007oo
Ool0@7oo00<007ooOol0<Woo00<007ooOol0@Goo00<007ooOol07Woo000QOol00`00Oomoo`0GOol0
0`00Oomoo`10Ool00`00Oomoo`0cOol00`00Oomoo`10Ool00`00Oomoo`0NOol0025oo`03001oogoo
01Qoo`03001oogoo03moo`03001oogoo03=oo`03001oogoo03moo`03001oogoo01moo`008Goo00<0
07ooOol067oo00<007ooOol0?Woo00<007ooOol0=7oo00<007ooOol0?goo00<007ooOol07goo000Q
Ool2000IOol00`00Oomoo`0nOol00`00Oomoo`0eOol00`00Oomoo`0nOol00`00Oomoo`0OOol0025o
o`03001oogoo01Qoo`03001oogoo03ioo`03001oogoo03Eoo`03001oogoo03ioo`03001oogoo01mo
o`008Goo00<007ooOol06Goo00<007ooOol0?Goo00<007ooOol0=Goo00<007ooOol0?Goo00<007oo
Ool087oo000QOol00`00Oomoo`0IOol00`00Oomoo`0lOol00`00Oomoo`0fOol00`00Oomoo`0mOol0
0`00Oomoo`0POol000Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogoo
Ool20005Ool00`00Oomoo`0IOol00`00Oomoo`0lOol00`00Oomoo`0gOol00`00Oomoo`0lOol00`00
Oomoo`0POol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Ao
o`03001oogoo01Yoo`03001oogoo03]oo`03001oogoo03Moo`03001oogoo03]oo`03001oogoo025o
o`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<007oo000017oo0P006goo
00<007ooOol0>Woo00<007ooOol0>7oo00<007ooOol0>goo00<007ooOol08Goo0006Ool00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00002Ool20005Ool00`00Oomoo`0JOol00`00Oomoo`0jOol0
0`00Oomoo`0iOol00`00Oomoo`0jOol00`00Oomoo`0QOol000Ioo`03001oo`0000Moo`03001oo`00
009oo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo01Yoo`03001oogoo03Yoo`03001oogoo
03Uoo`03001oogoo03Yoo`03001oogoo025oo`001goo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol00Woo0P0017oo00<007ooOol06goo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0
>Goo00<007ooOol08Woo000QOol00`00Oomoo`0KOol00`00Oomoo`0hOol00`00Oomoo`0jOol00`00
Oomoo`0iOol00`00Oomoo`0ROol0025oo`03001oogoo01]oo`03001oogoo03Qoo`03001oogoo03]o
o`03001oogoo03Qoo`03001oogoo029oo`008Goo0P007Goo00<007ooOol0=goo00<007ooOol0>goo
00<007ooOol0>7oo00<007ooOol08Woo000QOol00`00Oomoo`0LOol00`00Oomoo`0fOol00`00Oomo
o`0lOol00`00Oomoo`0gOol00`00Oomoo`0SOol0025oo`03001oogoo01aoo`03001oogoo03Ioo`03
001oogoo03aoo`03001oogoo03Moo`03001oogoo02=oo`008Goo00<007ooOol077oo00<007ooOol0
=Woo00<007ooOol0?Goo00<007ooOol0=Woo00<007ooOol08goo000QOol00`00Oomoo`0MOol00`00
Oomoo`0eOol00`00Oomoo`0mOol00`00Oomoo`0eOol00`00Oomoo`0TOol0025oo`8001ioo`03001o
ogoo03Aoo`03001oogoo03ioo`03001oogoo03Eoo`03001oogoo02Aoo`008Goo00<007ooOol07Goo
00<007ooOol0=7oo00<007ooOol0?goo00<007ooOol0=7oo00<007ooOol097oo000QOol00`00Oomo
o`0MOol00`00Oomoo`0dOol00`00Oomoo`0oOol00`00Oomoo`0dOol00`00Oomoo`0TOol0025oo`03
001oogoo01ioo`03001oogoo03=oo`03001oogoo03moo`03001oogoo03=oo`03001oogoo02Eoo`00
8Goo00<007ooOol07Woo00<007ooOol0<Woo00<007ooOol0@7oo00<007ooOol0<goo00<007ooOol0
9Goo000QOol00`00Oomoo`0NOol00`00Oomoo`0bOol00`00Oomoo`11Ool00`00Oomoo`0bOol00`00
Oomoo`0UOol0025oo`8001moo`03001oogoo039oo`03001oogoo045oo`03001oogoo035oo`03001o
ogoo02Ioo`008Goo00<007ooOol07goo00<007ooOol0<Goo00<007ooOol0@Goo00<007ooOol0<Goo
00<007ooOol09Woo000QOol00`00Oomoo`0OOol00`00Oomoo`0`Ool00`00Oomoo`13Ool00`00Oomo
o`0`Ool00`00Oomoo`0VOol0025oo`03001oogoo01moo`03001oogoo031oo`03001oogoo04=oo`03
001oogoo031oo`03001oogoo02Ioo`001goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol07goo00<007ooOol0<7oo00<007ooOol0
@goo00<007ooOol0;goo00<007ooOol09goo0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00
Ool00002Ool00`00Ool00004Ool00`00Oomoo`0POol00`00Oomoo`0_Ool00`00Oomoo`13Ool00`00
Oomoo`0_Ool00`00Oomoo`0WOol000Ioo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009o
o`03001oo`0000Aoo`80025oo`03001oogoo02ioo`03001oogoo04Eoo`03001oogoo02ioo`03001o
ogoo02Moo`001Woo00<007oo00001goo00<007oo00000Woo00<007oo00000goo00<007ooOol00goo
00<007ooOol087oo00<007ooOol0;Woo00<007ooOol0AGoo00<007ooOol0;Woo00<007ooOol09goo
0006Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomo
o`0QOol00`00Oomoo`0]Ool00`00Oomoo`15Ool00`00Oomoo`0]Ool00`00Oomoo`0XOol000Moo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo025oo`03
001oogoo02eoo`03001oogoo04Eoo`03001oogoo02eoo`03001oogoo02Qoo`008Goo00<007ooOol0
8Goo00<007ooOol0;7oo00<007ooOol0Agoo00<007ooOol0;7oo00<007ooOol0:7oo000QOol00`00
Oomoo`0QOol00`00Oomoo`0/Ool00`00Oomoo`17Ool00`00Oomoo`0[Ool00`00Oomoo`0YOol0025o
o`8002=oo`03001oogoo02]oo`03001oogoo04Moo`03001oogoo02]oo`03001oogoo02Uoo`008Goo
00<007ooOol08Woo00<007ooOol0:goo00<007ooOol0B7oo00<007ooOol0:Woo00<007ooOol0:Goo
000QOol00`00Oomoo`0ROol00`00Oomoo`0ZOol00`00Oomoo`19Ool00`00Oomoo`0ZOol00`00Oomo
o`0YOol0025oo`03001oogoo029oo`03001oogoo02Yoo`03001oogoo04Uoo`03001oogoo02Uoo`03
001oogoo02Yoo`008Goo00<007ooOol08goo00<007ooOol0:Goo00<007ooOol0BGoo00<007ooOol0
:Goo00<007ooOol0:Woo000QOol00`00Oomoo`0SOol00`00Oomoo`0YOol00`00Oomoo`1:Ool00`00
Oomoo`0XOol00`00Oomoo`0ZOol0025oo`8002Aoo`03001oogoo02Qoo`03001oogoo04]oo`03001o
ogoo02Moo`03001oogoo02]oo`008Goo00<007ooOol08goo00<007ooOol0:7oo00<007ooOol0Bgoo
00<007ooOol09goo00<007ooOol0:goo000QOol00`00Oomoo`0TOol00`00Oomoo`0WOol00`00Oomo
o`1<Ool00`00Oomoo`0VOol00`00Oomoo`0[Ool0025oo`03001oogoo02Aoo`03001oogoo02Moo`03
001oogoo04aoo`03001oogoo02Ioo`03001oogoo02]oo`008Goo00<007ooOol097oo00<007ooOol0
9Woo00<007ooOol0CGoo00<007ooOol09Goo00<007ooOol0;7oo000QOol00`00Oomoo`0TOol00`00
Oomoo`0VOol00`00Oomoo`1=Ool00`00Oomoo`0UOol00`00Oomoo`0/Ool0025oo`8002Ioo`03001o
ogoo02Eoo`03001oogoo04ioo`03001oogoo02Aoo`03001oogoo02aoo`008Goo00<007ooOol09Goo
00<007ooOol097oo00<007ooOol0Cgoo00<007ooOol097oo00<007ooOol0;7oo000QOol00`00Oomo
o`0UOol00`00Oomoo`0TOol00`00Oomoo`1?Ool00`00Oomoo`0SOol00`00Oomoo`0]Ool0025oo`03
001oogoo02Ioo`03001oogoo02=oo`03001oogoo051oo`03001oogoo029oo`03001oogoo02eoo`00
37oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01@000goo00<007ooOol09Woo00<007oo
Ool08Woo00<007ooOol0DGoo00<007ooOol08Woo00<007ooOol0;Goo000;Ool00`00Ool00007Ool0
0`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0VOol00`00Oomoo`0ROol00`00Oomoo`1AOol0
0`00Oomoo`0QOol00`00Oomoo`0^Ool000]oo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo
00=oo`8002Qoo`03001oogoo025oo`03001oogoo059oo`03001oogoo021oo`03001oogoo02ioo`00
2goo00<007oo00001goo00<007oo00000goo00<007ooOol00goo00<007ooOol09goo00<007ooOol0
87oo00<007ooOol0Dgoo00<007ooOol087oo00<007ooOol0;Woo000;Ool00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`1COol00`00
Oomoo`0OOol00`00Oomoo`0_Ool000aoo`03001oogoo00Moo`04001oogooOol20005Ool00`00Oomo
o`0WOol00`00Oomoo`0POol00`00Oomoo`1COol00`00Oomoo`0OOol00`00Oomoo`0_Ool0025oo`03
001oogoo02Qoo`03001oogoo01moo`03001oogoo05Aoo`03001oogoo01ioo`03001oogoo02moo`00
8Goo0P00:Goo00<007ooOol07Woo00<007ooOol0EGoo00<007ooOol07Goo00<007ooOol0<7oo000Q
Ool00`00Oomoo`0XOol00`00Oomoo`0NOol00`00Oomoo`1EOol00`00Oomoo`0MOol00`00Oomoo`0`
Ool0025oo`03001oogoo02Uoo`03001oogoo01eoo`03001oogoo05Ioo`03001oogoo01aoo`03001o
ogoo031oo`008Goo00<007ooOol0:Goo00<007ooOol077oo00<007ooOol0Egoo00<007ooOol06goo
00<007ooOol0<Goo000QOol00`00Oomoo`0YOol00`00Oomoo`0LOol00`00Oomoo`1HOol00`00Oomo
o`0JOol00`00Oomoo`0aOol0025oo`03001oogoo02Yoo`03001oogoo01]oo`03001oogoo05Qoo`03
001oogoo01Yoo`03001oogoo035oo`008Goo0P00:goo00<007ooOol06Woo00<007ooOol0FGoo00<0
07ooOol06Goo00<007ooOol0<Woo000QOol00`00Oomoo`0ZOol00`00Oomoo`0JOol00`00Oomoo`1J
Ool00`00Oomoo`0HOol00`00Oomoo`0bOol0025oo`03001oogoo02]oo`03001oogoo01Qoo`03001o
ogoo05]oo`03001oogoo01Moo`03001oogoo03=oo`008Goo00<007ooOol0:goo00<007ooOol067oo
00<007ooOol0G7oo00<007ooOol05Woo00<007ooOol0<goo000QOol00`00Oomoo`0/Ool00`00Oomo
o`0FOol00`00Oomoo`1MOol00`00Oomoo`0EOol00`00Oomoo`0dOol0025oo`03001oogoo02aoo`03
001oogoo01Ioo`03001oogoo05ioo`03001oogoo01Aoo`03001oogoo03Aoo`008Goo0P00;Woo00<0
07ooOol05Goo00<007ooOol0GWoo00<007ooOol04goo00<007ooOol0=Goo000QOol00`00Oomoo`0]
Ool00`00Oomoo`0DOol00`00Oomoo`1OOol00`00Oomoo`0COol00`00Oomoo`0eOol0025oo`03001o
ogoo02ioo`03001oogoo01=oo`03001oogoo061oo`03001oogoo019oo`03001oogoo03Eoo`008Goo
00<007ooOol0;Woo00<007ooOol04Woo00<007ooOol0HGoo00<007ooOol04Goo00<007ooOol0=Woo
0007Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000017oo0000000017oo00<007oo
Ool0;goo00<007ooOol04Goo00<007ooOol0HWoo00<007ooOol047oo00<007ooOol0=Woo0006Ool0
0`00Ool00007Ool00`00Ool00003Ool01@00Oomoogoo00001Woo00<007ooOol0;goo00<007ooOol0
47oo00<007ooOol0I7oo00<007ooOol03Woo00<007ooOol0=goo0006Ool00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`03Ool2000aOol00`00Oomoo`0?Ool00`00Oomoo`1U
Ool00`00Oomoo`0=Ool00`00Oomoo`0gOol000Ioo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo031oo`03001oogoo00ioo`03001oogoo06Ioo`03001o
ogoo00aoo`03001oogoo03Qoo`001Woo00<007oo00001goo00<007oo00000goo00L007ooOomoo`00
Ool00004Ool00`00Oomoo`0aOol00`00Oomoo`0=Ool00`00Oomoo`1WOol00`00Oomoo`0:Ool00`00
Oomoo`0iOol000Moo`03001oogoo00Moo`04001oogooOol20004Ool00`00Oomoo`03Ool00`00Oomo
o`0bOol00`00Oomoo`0;Ool00`00Oomoo`1XOol00`00Oomoo`09Ool00`00Oomoo`0jOol0025oo`03
001oogoo03=oo`03001oogoo00Uoo`03001oogoo06Yoo`03001oogoo00Moo`03001oogoo03]oo`00
8Goo00<007ooOol0=7oo00<007ooOol01goo00<007ooOol0K7oo0P001Goo0`00?Goo000QOol2000e
Ool00`00Oomoo`05Ool2001aOol6000oOol0025oo`03001oogoo03Eoo`<000=oo`800;Moo`008Goo
00<007ooOol0=goo1000^Goo000QOol00`00Oomoo`3dOol0025oo`03001oogoo0?Aoo`008Goo00<0
07ooOol0m7oo000QOol00`00Oomoo`3dOol00?mooaUoo`00ogoo6Goo003oOolIOol00001\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.138206, -0.00137659, 
  0.00416922, 8.54905*^-05}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Note that the ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function was ",
  StyleBox["not",
    FontSlant->"Italic"],
  " used in the preceding example to resolve the rotation angle of the base \
from the Euler parameters, but ",
  StyleBox["ProjectedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " was used instead. This was done because the small numerical errors in the \
integration caused one of the Euler parameters to drift slightly above 1.0. \
The Euler parameters are not meaningful for absolute values greater than 1, \
so the ",
  StyleBox["Rotation",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function would return an error. The ",
  StyleBox["ProjectedAngle",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function uses vector algebra, instead of a mathematical identity, and it \
does not care if the values of the Euler parameters stray above 1.\n\nSince \
the gyroscope model is a conservative system (if the applied moment is \
recognized as a conservative force) the sum of the kinetic and potential \
energy in the model should be constant. The potential energy stored by the \
constant applied moment is the work done by the gyroscope on the applied \
moment, which is the negative of the magnitude of the applied moment times \
the is rotation of the base. The following plot shows that the numerical \
error in the integration has allowed the total energy of the model to \
decrease by about 2% of the maximum kinetic energy over the integration \
period. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the total energy in the gyroscope, including the energy stored in \
the constant applied moment."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[
      Evaluate[BodyEnergy[rotor] - 
            1\ ProjectedAngle[Vector[base, X], X, Z] /. sol], {T, 0, endt}]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.603287 2407.43 [
[.21429 .59079 -9 -9 ]
[.21429 .59079 9 0 ]
[.40476 .59079 -9 -9 ]
[.40476 .59079 9 0 ]
[.59524 .59079 -9 -9 ]
[.59524 .59079 9 0 ]
[.78571 .59079 -9 -9 ]
[.78571 .59079 9 0 ]
[.97619 .59079 -3 -9 ]
[.97619 .59079 3 0 ]
[.01131 .00143 -48 -4.5 ]
[.01131 .00143 0 4.5 ]
[.01131 .1218 -42 -4.5 ]
[.01131 .1218 0 4.5 ]
[.01131 .24217 -48 -4.5 ]
[.01131 .24217 0 4.5 ]
[.01131 .36254 -42 -4.5 ]
[.01131 .36254 0 4.5 ]
[.01131 .48292 -48 -4.5 ]
[.01131 .48292 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .60329 m
.21429 .60954 L
s
[(0.2)] .21429 .59079 0 1 Mshowa
.40476 .60329 m
.40476 .60954 L
s
[(0.4)] .40476 .59079 0 1 Mshowa
.59524 .60329 m
.59524 .60954 L
s
[(0.6)] .59524 .59079 0 1 Mshowa
.78571 .60329 m
.78571 .60954 L
s
[(0.8)] .78571 .59079 0 1 Mshowa
.97619 .60329 m
.97619 .60954 L
s
[(1)] .97619 .59079 0 1 Mshowa
.125 Mabswid
.07143 .60329 m
.07143 .60704 L
s
.11905 .60329 m
.11905 .60704 L
s
.16667 .60329 m
.16667 .60704 L
s
.2619 .60329 m
.2619 .60704 L
s
.30952 .60329 m
.30952 .60704 L
s
.35714 .60329 m
.35714 .60704 L
s
.45238 .60329 m
.45238 .60704 L
s
.5 .60329 m
.5 .60704 L
s
.54762 .60329 m
.54762 .60704 L
s
.64286 .60329 m
.64286 .60704 L
s
.69048 .60329 m
.69048 .60704 L
s
.7381 .60329 m
.7381 .60704 L
s
.83333 .60329 m
.83333 .60704 L
s
.88095 .60329 m
.88095 .60704 L
s
.92857 .60329 m
.92857 .60704 L
s
.25 Mabswid
0 .60329 m
1 .60329 L
s
.02381 .00143 m
.03006 .00143 L
s
[(-0.00025)] .01131 .00143 1 0 Mshowa
.02381 .1218 m
.03006 .1218 L
s
[(-0.0002)] .01131 .1218 1 0 Mshowa
.02381 .24217 m
.03006 .24217 L
s
[(-0.00015)] .01131 .24217 1 0 Mshowa
.02381 .36254 m
.03006 .36254 L
s
[(-0.0001)] .01131 .36254 1 0 Mshowa
.02381 .48292 m
.03006 .48292 L
s
[(-0.00005)] .01131 .48292 1 0 Mshowa
.125 Mabswid
.02381 .0255 m
.02756 .0255 L
s
.02381 .04958 m
.02756 .04958 L
s
.02381 .07365 m
.02756 .07365 L
s
.02381 .09773 m
.02756 .09773 L
s
.02381 .14588 m
.02756 .14588 L
s
.02381 .16995 m
.02756 .16995 L
s
.02381 .19402 m
.02756 .19402 L
s
.02381 .2181 m
.02756 .2181 L
s
.02381 .26625 m
.02756 .26625 L
s
.02381 .29032 m
.02756 .29032 L
s
.02381 .3144 m
.02756 .3144 L
s
.02381 .33847 m
.02756 .33847 L
s
.02381 .38662 m
.02756 .38662 L
s
.02381 .41069 m
.02756 .41069 L
s
.02381 .43477 m
.02756 .43477 L
s
.02381 .45884 m
.02756 .45884 L
s
.02381 .50699 m
.02756 .50699 L
s
.02381 .53106 m
.02756 .53106 L
s
.02381 .55514 m
.02756 .55514 L
s
.02381 .57921 m
.02756 .57921 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60329 m
.02499 .60329 L
.02605 .60329 L
.02729 .60329 L
.02846 .60329 L
.02954 .60329 L
.03053 .60329 L
.03163 .60329 L
.03279 .6033 L
.03394 .6033 L
.03504 .6033 L
.03631 .6033 L
.03746 .6033 L
.03874 .60331 L
.03946 .60331 L
.04012 .60332 L
.04133 .60332 L
.04262 .60332 L
.04327 .60332 L
.04396 .60332 L
.04519 .60332 L
.04588 .60332 L
.04652 .60332 L
.04722 .60332 L
.04797 .60331 L
.04862 .60331 L
.04933 .60331 L
.05061 .60332 L
.05186 .60331 L
.05302 .60331 L
.05414 .60332 L
.05519 .60331 L
.05634 .60331 L
.05759 .60331 L
.05882 .60331 L
.06012 .60331 L
.06124 .60331 L
.06244 .60331 L
.06315 .6033 L
.0638 .60329 L
.06509 .60328 L
.06625 .60328 L
.06748 .60327 L
.06872 .60328 L
.06941 .60328 L
.07005 .60327 L
.0708 .60326 L
.07151 .60324 L
.07216 .60324 L
.07287 .60323 L
Mistroke
.07415 .60322 L
.07531 .60322 L
.07595 .60323 L
.07664 .60323 L
.0779 .60322 L
.08257 .60318 L
.08382 .60319 L
.08452 .60319 L
.08517 .60319 L
.08637 .60316 L
.08764 .60314 L
.08834 .60314 L
.08899 .60313 L
.08971 .60313 L
.09048 .60313 L
.09114 .60314 L
.09183 .60314 L
.09307 .60313 L
.09445 .6031 L
.09522 .60309 L
.09592 .60309 L
.09675 .60308 L
.09753 .60308 L
.09825 .60308 L
.09903 .60309 L
.0997 .60309 L
.10043 .60308 L
.1012 .60307 L
.10192 .60305 L
.1032 .60303 L
.10392 .60303 L
.10458 .60303 L
.10582 .60303 L
.10713 .60303 L
.10825 .60296 L
.10949 .60278 L
.11483 .60194 L
.12456 .60053 L
.14564 .59689 L
.16658 .59402 L
.18581 .59115 L
.20463 .58893 L
.2092 .5885 L
.21052 .58837 L
.21177 .58822 L
.2129 .58804 L
.2141 .58782 L
.21473 .58684 L
.21544 .5853 L
.21667 .58241 L
Mistroke
.21946 .57506 L
.22446 .55993 L
.23442 .52772 L
.23933 .51348 L
.24172 .50741 L
.24388 .50251 L
.24519 .50013 L
.24641 .49865 L
.24772 .49733 L
.2491 .49623 L
.24978 .4958 L
.25053 .49541 L
.25184 .49495 L
.25258 .4948 L
.25337 .49474 L
.25411 .49478 L
.25479 .49488 L
.25607 .49525 L
.25725 .49581 L
.25854 .49664 L
.25992 .49776 L
.26222 .50015 L
.26477 .50344 L
.26969 .51123 L
.27238 .5159 L
.27368 .5182 L
.27487 .52026 L
.27597 .51943 L
.27701 .51733 L
.27929 .51266 L
.28413 .503 L
.289 .49436 L
.29414 .48725 L
.29683 .48455 L
.29836 .48336 L
.29979 .48246 L
.3011 .48184 L
.3023 .48143 L
.30296 .48126 L
.30368 .48114 L
.30499 .48105 L
.30564 .48107 L
.30633 .48044 L
.30756 .4793 L
.30899 .47818 L
.31033 .47734 L
.31149 .47678 L
.31272 .47636 L
.31343 .4762 L
.3141 .47611 L
Mistroke
.31535 .47608 L
.31648 .47623 L
.31768 .47655 L
.31871 .47697 L
.31984 .47757 L
.32236 .47944 L
.32472 .48183 L
.33 .489 L
.3325 .49308 L
.33483 .4971 L
.33612 .49938 L
.33684 .49871 L
.3375 .49791 L
.34041 .49448 L
.34293 .4918 L
.34571 .48933 L
.34692 .48844 L
.34823 .48762 L
.34935 .48705 L
.35058 .48656 L
.3513 .48635 L
.35196 .4862 L
.35327 .48604 L
.35446 .48605 L
.35573 .48624 L
.35681 .48654 L
.35799 .48701 L
.35909 .48759 L
.36011 .48824 L
.36247 .49016 L
.36495 .49277 L
.36623 .49433 L
.36744 .49475 L
.3681 .49465 L
.36883 .49459 L
.3701 .49457 L
.37131 .49468 L
.37259 .49494 L
.37368 .49528 L
.37489 .49579 L
.3763 .49658 L
.3776 .49748 L
.38051 .50015 L
.3832 .50343 L
.38576 .50727 L
.40583 .54159 L
.41456 .55648 L
.41915 .56604 L
.424 .57689 L
.42652 .58263 L
Mistroke
.42721 .5842 L
.42795 .58501 L
.42865 .58479 L
.42929 .58458 L
.43181 .58379 L
.43415 .58319 L
.43529 .58297 L
.4365 .58279 L
.43771 .58269 L
.43841 .58266 L
.43905 .58267 L
.44022 .58274 L
.44129 .58288 L
.44246 .58312 L
.4437 .58348 L
.45385 .59029 L
.45525 .59171 L
.45677 .59333 L
.45747 .59411 L
.45821 .59473 L
.45953 .5937 L
.46201 .59195 L
.46468 .5904 L
.46599 .5898 L
.46723 .58934 L
.46834 .58902 L
.46955 .58878 L
.4707 .58865 L
.47191 .58863 L
.47295 .5887 L
.4741 .58889 L
.47475 .58904 L
.47544 .58924 L
.47667 .58968 L
.47944 .59109 L
.48183 .59273 L
.48445 .59491 L
.48559 .59595 L
.48682 .59713 L
.48798 .59828 L
.48905 .59843 L
.4903 .59725 L
.49163 .59602 L
.49397 .59393 L
.50283 .58759 L
.50514 .58646 L
.50766 .58547 L
.51004 .58475 L
.51224 .58424 L
.5148 .58377 L
Mistroke
.51621 .58355 L
.51753 .58335 L
.51875 .58316 L
.52007 .58074 L
.52237 .57541 L
.54067 .53935 L
.56023 .50133 L
.57058 .48357 L
.57331 .48016 L
.57628 .47689 L
.57764 .47549 L
.57839 .47475 L
.57909 .47406 L
.58032 .47212 L
.58098 .46999 L
.58168 .4677 L
.59237 .43474 L
.60211 .40959 L
.62118 .34473 L
.64083 .27817 L
.66233 .21553 L
.68286 .16937 L
.69202 .15098 L
.69719 .14348 L
.69966 .1404 L
.70086 .13897 L
.70196 .13754 L
.70313 .1331 L
.70439 .12836 L
.70707 .11844 L
.71248 .0996 L
.72242 .07159 L
.73143 .05502 L
.73636 .04348 L
.74101 .03354 L
.7435 .02921 L
.74619 .02538 L
.74864 .02268 L
.7498 .02165 L
.75089 .02084 L
.752 .02016 L
.75301 .01966 L
.75414 .01925 L
.75534 .01898 L
.7565 .01886 L
.75776 .01889 L
.75894 .01906 L
.76004 .01934 L
.76123 .01977 L
.76251 .02036 L
Mistroke
.76372 .01968 L
.76483 .01867 L
.76612 .01762 L
.76753 .01664 L
.76886 .01591 L
.7701 .01537 L
.77078 .01515 L
.77151 .01495 L
.77278 .01475 L
.7735 .01472 L
.77427 .01473 L
.77492 .0148 L
.77564 .01492 L
.77692 .01526 L
.77764 .01553 L
.7783 .01582 L
.78078 .0173 L
.78554 .02165 L
.79002 .02718 L
.79227 .0303 L
.79353 .03161 L
.79469 .03036 L
.79985 .02543 L
.80235 .02359 L
.80379 .02275 L
.80509 .02213 L
.80648 .02163 L
.80724 .02143 L
.80796 .02128 L
.80924 .02115 L
.80996 .02114 L
.81062 .02118 L
.81181 .02136 L
.81293 .02164 L
.81415 .02209 L
.81547 .02273 L
.81815 .0245 L
.8206 .02665 L
.8218 .02787 L
.82307 .02926 L
.82373 .03002 L
.82446 .0297 L
.82574 .02896 L
.82695 .02835 L
.82824 .0278 L
.82947 .02741 L
.83058 .02715 L
.83129 .02704 L
.83195 .02698 L
.83268 .02696 L
Mistroke
.83345 .02699 L
.83474 .02717 L
.83547 .02735 L
.83616 .02756 L
.83743 .02809 L
.83859 .02872 L
.84121 .03065 L
.84352 .03296 L
.84566 .03559 L
.85053 .0432 L
.86034 .05486 L
.89856 .10586 L
.90909 .1179 L
.91161 .12166 L
.91298 .12381 L
.91427 .12587 L
.91536 .12739 L
.91654 .12698 L
.91773 .1266 L
.91904 .12623 L
.92028 .12594 L
.92143 .12573 L
.92253 .1256 L
.9237 .12553 L
.92485 .12554 L
.92594 .12563 L
.92691 .12578 L
.92796 .12601 L
.92913 .12636 L
.93041 .12686 L
.933 .12823 L
.9354 .12993 L
.93763 .13187 L
.94801 .14417 L
.95311 .1508 L
.95535 .15345 L
.95782 .15598 L
.95888 .15691 L
.96003 .15778 L
.96102 .15841 L
.96209 .15896 L
.96331 .15937 L
.96446 .15956 L
.96558 .15952 L
.96663 .15927 L
.96788 .1587 L
.96905 .15785 L
.97011 .15682 L
.97126 .15541 L
.97383 .15098 L
Mistroke
.97619 .14523 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`003goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001o
ogoo0>Qoo`003Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo
00<007ooOol00Woo00<007oo00000goo00<007ooOol0hgoo0009Ool30002Ool00`00Ool00007Ool0
0`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool01000Oomoogoo0`00
hgoo000>Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool01000
Oomoogoo0P0017oo00<007ooOol0hgoo000>Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`3SOol000moo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol30003
Ool00`00Oomoo`2[Ool4000dOol0039oo`03001oogoo0:Moo`D000=oo`03001oogoo009oo`<002ao
o`00<Woo0P00Ygoo0P001goo00@007ooOomoo`800003Ool0000002]oo`00<Woo00<007ooOol0YWoo
00<007ooOol01goo0`001Goo1@009Woo000bOol00`00Oomoo`2UOol00`00Oomoo`09Ool00`00Oomo
o`08Ool2000UOol0039oo`03001oogoo0:Eoo`03001oogoo01Eoo`03001oogoo02=oo`00<Woo00<0
07ooOol0Y7oo00<007ooOol05goo0P008goo000bOol00`00Oomoo`2TOol00`00Oomoo`0IOol00`00
Oomoo`0POol0039oo`800:Aoo`03001oogoo01Yoo`03001oogoo021oo`00<Woo00<007ooOol0Xgoo
00<007ooOol06goo00<007ooOol07goo000bOol00`00Oomoo`2ROol00`00Oomoo`0MOol00`00Oomo
o`0NOol0039oo`03001oogoo0:9oo`03001oogoo01eoo`03001oogoo01ioo`00<Woo00<007ooOol0
XGoo00<007ooOol07goo00<007ooOol07Goo000bOol00`00Oomoo`2QOol00`00Oomoo`0POol00`00
Oomoo`0LOol0039oo`800:9oo`03001oogoo025oo`03001oogoo01]oo`00<Woo00<007ooOol0X7oo
00<007ooOol08Woo00<007ooOol06goo000bOol00`00Oomoo`2POol00`00Oomoo`0SOol00`00Oomo
o`0JOol0039oo`03001oogoo09moo`03001oogoo02Eoo`03001oogoo01Uoo`00<Woo00<007ooOol0
Wgoo00<007ooOol09Woo00<007ooOol067oo000bOol2002OOol00`00Oomoo`0WOol00`00Oomoo`0H
Ool0039oo`03001oogoo09ioo`03001oogoo02Qoo`03001oogoo01Moo`00<Woo00<007ooOol0WWoo
00<007ooOol0:Goo00<007ooOol05Woo000bOol00`00Oomoo`2MOol00`00Oomoo`0[Ool00`00Oomo
o`0EOol001Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`04
001oogooOol30003Ool00`00Oomoo`2MOol00`00Oomoo`0[Ool00`00Oomoo`0EOol001=oo`03001o
o`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00=oo`03001o
ogoo09eoo`03001oogoo02aoo`03001oogoo01Aoo`003Woo0`000Woo00<007oo00001goo00<007oo
00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol00Woo0`00W7oo00<007ooOol0;Woo
00<007ooOol04goo000COol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0003Ool00`00Oomoo`02Ool00`00Oomoo`2LOol00`00Oomoo`0^Ool6000@Ool001=oo`03001oo`00
00Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo
09aoo`03001oogoo03=oo`8000moo`0057oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0W7oo00<007ooOol0=Goo00<007ooOol0
37oo000bOol00`00Oomoo`2KOol2000gOol00`00Oomoo`0<Ool0039oo`8009aoo`03001oogoo03Mo
o`03001oogoo00Aoo`03001oogoo00Aoo`00<Woo00<007ooOol0VWoo00<007ooOol0>Goo00<007oo
Ool00Woo00<007ooOol01Goo000bOol00`00Oomoo`2JOol00`00Oomoo`0jOol01@00Oomoogoo0000
1goo000bOol00`00Oomoo`2IOol00`00Oomoo`0lOol01000Ool000001goo000bOol00`00Oomoo`2H
Ool00`00Oomoo`0nOol20008Ool0039oo`03001oogoo09Qoo`03001oogoo04Qoo`00<Woo0P00V7oo
00<007ooOol0BGoo000bOol00`00Oomoo`2GOol00`00Oomoo`19Ool0039oo`03001oogoo09Ioo`03
001oogoo04Yoo`00<Woo00<007ooOol0UWoo00<007ooOol0BWoo000bOol00`00Oomoo`2FOol00`00
Oomoo`1:Ool0039oo`03001oogoo09Eoo`03001oogoo04]oo`00<Woo0P00UWoo00<007ooOol0Bgoo
000bOol00`00Oomoo`2DOol00`00Oomoo`1<Ool0039oo`03001oogoo09Aoo`03001oogoo04aoo`00
<Woo00<007ooOol0U7oo00<007ooOol0C7oo000bOol00`00Oomoo`2COol00`00Oomoo`1=Ool0039o
o`8009Aoo`03001oogoo04eoo`00<Woo00<007ooOol0Tgoo00<007ooOol0CGoo000bOol00`00Oomo
o`2BOol00`00Oomoo`1>Ool0039oo`03001oogoo099oo`03001oogoo04ioo`003goo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01@000Woo00<007oo
Ool00Woo00<007ooOol0TWoo00<007ooOol0CWoo000>Ool00`00Ool00007Ool00`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000=oo`03001oogoo095oo`03001o
ogoo04moo`002Goo0`000Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<007oo
00000goo00<007ooOol00goo00@007ooOomoo`<0095oo`03001oogoo04moo`003Woo00<007oo0000
1goo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00@007ooOomoo`8000Aoo`03001o
ogoo091oo`03001oogoo051oo`003Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo
00<007oo00000goo00D007ooOomoo`0000Eoo`03001oogoo091oo`03001oogoo051oo`003goo00<0
07ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`8000=oo`<000=oo`03001o
ogoo091oo`03001oogoo051oo`00<Woo00<007ooOol0Sgoo00<007ooOol0DGoo000bOol00`00Oomo
o`2?Ool00`00Oomoo`1AOol0039oo`80091oo`03001oogoo055oo`00<Woo00<007ooOol0SWoo00<0
07ooOol0DWoo000bOol00`00Oomoo`2>Ool00`00Oomoo`1BOol0039oo`03001oogoo08ioo`03001o
ogoo059oo`00<Woo00<007ooOol0SGoo00<007ooOol0Dgoo000bOol2002>Ool00`00Oomoo`1COol0
039oo`03001oogoo08eoo`03001oogoo05=oo`00<Woo00<007ooOol0S7oo00<007ooOol0E7oo000b
Ool00`00Oomoo`2<Ool00`00Oomoo`1DOol0039oo`03001oogoo08aoo`03001oogoo05Aoo`00<Woo
00<007ooOol0Rgoo00<007ooOol0EGoo000bOol2002<Ool00`00Oomoo`1EOol0039oo`03001oogoo
08]oo`03001oogoo05Eoo`00<Woo00<007ooOol0Rgoo00<007ooOol0EGoo000bOol00`00Oomoo`2:
Ool00`00Oomoo`1FOol0039oo`03001oogoo08Yoo`03001oogoo05Ioo`00<Woo0P00Rgoo00<007oo
Ool0EWoo000bOol00`00Oomoo`29Ool00`00Oomoo`1GOol0039oo`03001oogoo08Uoo`03001oogoo
05Moo`00<Woo00<007ooOol0RGoo00<007ooOol0Egoo000DOol00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`28Ool00`00Oomo
o`1HOol001=oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03
001oogoo009oo`03001oogoo08Qoo`03001oogoo05Qoo`003Woo0`000Woo00<007oo00001goo00<0
07oo00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol00Woo0`00R7oo00<007ooOol0
F7oo000COol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`28Ool00`00Oomoo`1HOol001=oo`03001oo`0000Moo`03001oo`00009o
o`03001oo`00009oo`03001oo`0000=oo`03001oogoo009oo`03001oogoo08Moo`03001oogoo05Uo
o`0057oo00<007ooOol01goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`8000Aoo`03
001oogoo08Moo`03001oogoo05Uoo`00<Woo00<007ooOol0Qgoo00<007ooOol0FGoo000bOol00`00
Oomoo`27Ool00`00Oomoo`1IOol0039oo`8008Moo`03001oogoo05Yoo`00<Woo00<007ooOol0QWoo
00<007ooOol0FWoo000bOol00`00Oomoo`26Ool00`00Oomoo`1JOol0039oo`03001oogoo08Ioo`03
001oogoo05Yoo`00<Woo00<007ooOol0QGoo00<007ooOol0Fgoo000bOol20026Ool00`00Oomoo`1K
Ool0039oo`03001oogoo08Aoo`03001oogoo05aoo`00<Woo00<007ooOol0Q7oo00<007ooOol0G7oo
000bOol00`00Oomoo`23Ool00`00Oomoo`1MOol0039oo`03001oogoo08=oo`03001oogoo05eoo`00
<Woo00<007ooOol0PWoo00<007ooOol0GWoo000bOol20023Ool00`00Oomoo`1NOol0039oo`03001o
ogoo089oo`03001oogoo05ioo`00<Woo00<007ooOol0PGoo00<007ooOol0Ggoo000bOol00`00Oomo
o`21Ool00`00Oomoo`1OOol0039oo`03001oogoo085oo`03001oogoo05moo`00<Woo00<007ooOol0
PGoo00<007ooOol0Ggoo000bOol20021Ool00`00Oomoo`1POol0039oo`03001oogoo081oo`03001o
ogoo061oo`00<Woo00<007ooOol0P7oo00<007ooOol0H7oo000?Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`1oOol00`00Oomoo`1QOol000ioo`03001oo`0000Moo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo041oo`@0
03]oo`03001oogoo065oo`002Goo0`000Woo00<007oo00001goo00<007oo00000Woo00<007oo0000
0Woo00<007oo00000Woo00<007oo000017oo00@007ooOomoo`<003ioo`8000Aoo`03001oogoo03Io
o`8006Aoo`003Woo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo
00<007oo00000Woo0P0017oo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol00Woo1000<7oo
00<007ooOol0Hgoo000>Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0002Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`0lOol00`00Oomoo`06Ool00`00Oomo
o`020003Ool00`00Oomoo`0/Ool00`00Oomoo`1TOol000moo`03001oogoo00Moo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`0bOol30006Ool0
0`00Oomoo`08Ool20005Ool4000[Ool00`00Oomoo`1TOol0039oo`03001oogoo035oo`80009oo`03
001oogoo009oo`03001oogoo00Uoo`8000Qoo`8002Uoo`03001oogoo06Eoo`00<Woo00<007ooOol0
<Goo00<007ooOol00Woo00D007ooOomoo`0001Ioo`03001oogoo02Moo`03001oogoo06Eoo`00<Woo
0P00<Goo00<007ooOol00goo00@007ooOol001Qoo`03001oogoo02Eoo`03001oogoo06Ioo`00<Woo
00<007ooOol0<7oo00<007ooOol017oo00<007oo00006Goo00<007ooOol097oo00<007ooOol0IWoo
000bOol00`00Oomoo`0`Ool00`00Oomoo`04Ool3000IOol00`00Oomoo`0SOol00`00Oomoo`1WOol0
039oo`03001oogoo02moo`03001oogoo00Ioo`03001oogoo01Uoo`03001oogoo025oo`03001oogoo
06Qoo`00<Woo00<007ooOol0;goo00<007ooOol08Woo00<007ooOol08Goo00<007ooOol0J7oo000b
Ool2000`Ool00`00Oomoo`0SOol00`00Oomoo`0OOol00`00Oomoo`1YOol0039oo`03001oogoo02mo
o`03001oogoo02Aoo`03001oogoo01ioo`03001oogoo06Uoo`00<Woo00<007ooOol0;Woo00<007oo
Ool09Goo00<007ooOol07Goo00<007ooOol0JWoo000bOol00`00Oomoo`0^Ool00`00Oomoo`0VOol0
0`00Oomoo`0LOol00`00Oomoo`1ZOol0039oo`03001oogoo02eoo`03001oogoo02Qoo`03001oogoo
01Yoo`03001oogoo06]oo`00<Woo00<007ooOol0;Goo00<007ooOol0:7oo00<007ooOol06Woo00<0
07ooOol0Jgoo000bOol2000UOol00`00Oomoo`02Ool00`00Oomoo`04000QOol00`00Oomoo`02Ool0
1@00Oomoo`00Ool00`005Woo00<007ooOol01Woo00<007ooOol00Woo00@007ooOomoo`80029oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo029oo`D000Eoo`00<Woo00<007ooOol08goo00<0
07oo00001Woo0P008Woo00<007oo00001Woo00@007ooOol001Moo`03001oogoo00Eoo`03001oo`00
00Moo`03001oo`00021oo`03001oo`0000Moo`03001oo`0002Eoo`03001oogoo00Eoo`00<Woo00<0
07ooOol08goo00<007oo00001Woo00<007oo00008Goo00<007oo00001goo10005Goo00<007ooOol0
1Woo00<007oo00001goo00<007oo000087oo00<007oo00001goo00<007oo00009Goo00<007ooOol0
1Goo000bOol00`00Oomoo`0SOol00`00Ool00005Ool01000Oomoo`008Goo00<007oo00001goo00<0
07oo00005Woo00<007ooOol01Woo00<007oo00001goo0P008Goo00<007oo000027oo00<007ooOol0
97oo00<007ooOol01Goo000bOol00`00Oomoo`0SOol00`00Ool00005Ool01@00Ool007oo000087oo
00<007oo00001goo0`005Goo00<007ooOol01goo00<007oo00001goo00<007ooOol087oo00<007oo
00001goo00<007oo00009Goo00<007ooOol01Goo000bOol00`00Oomoo`0TOol00`00Oomoo`04Ool0
1000Oomoo`008Woo00<007ooOol01goo0P005Goo00<007ooOol027oo00<007ooOol01goo0P008Goo
00<007ooOol01goo00<007ooOol08goo0P001goo000bOol2000[Ool00`00Oomoo`0^Ool00`00Oomo
o`0COol00`00Oomoo`1_Ool0039oo`03001oogoo02Yoo`03001oogoo02moo`D000eoo`@0075oo`00
<Woo00<007ooOol08Woo2@00=Woo0P0000=oo`0000000`0017oo00<007ooOol0Lgoo000bOol00`00
Oomoo`0MOol50010Ool30003Ool200000goo0000001fOol0039oo`03001oogoo01Qoo`D004aoo`<0
07Moo`00;Gooj`00000bOol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool0039oo`03001oogoo02Yoo`03001oogoo02Uoo`03
001oogoo02Yoo`03001oogoo02Uoo`03001oogoo02Yoo`03001oogoo00Aoo`00<Woo00<007ooOol0
hgoo000bOol00`00Oomoo`3SOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo
003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.228846, -0.000278835, 
  0.00449409, 1.77787*^-06}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This is near to the maximum kinetic energy of the body."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(BodyEnergy[rotor] /. sol\) /. T \[Rule] .26\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(0.0125908997580583115`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Tightening the error budget by a factor of 10 with ",
  StyleBox["MaxError",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["0.00001",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will reduce the total energy rise to only 0.12% over the same period, \
with an associated increase in run time. Using the ",
  StyleBox["ConstraintCorrection",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, with the default error budget, will have virtually no effect on \
the error in the total energy. This is because the error stems from the \
deviation in the Euler parameters that are very close to 1, an error on which \
constraint correction has little effect. Using the ",
  StyleBox["FitDegree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Quartic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, with the default error budget, will reduce the total energy rise \
to 0.71%, with only a small increase in run time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Reducing Gyroscopic Models"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"There is one more technique that can be applied to 3D gyroscopic models to \
reduce their size and thereby reduce their run time. This technique can be \
very useful to models with more than one rotor."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["GyroFilter[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["Ixx, Iyy, Izz, Ixy, Iyz, Izx",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "returns a new set of inertia properties that have zero inertia in the \
direction of ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be a principle axis of the body represented by the inertia \
properties, and the two principal moments not associated with ",
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["x, y, z",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " must be equal."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["A function for modifying an inertia tensor."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The restrictions that apply to the use of ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are identical to the restrictions that apply to the use of ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The body represented by the inertia properties must be axially \
symmetric. The purpose of ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is to make it possible to add a zero torque spinning body to a model \
without actually adding a body to the model at all. To demonstrate, the rotor \
body is deleted from the previously defined gyroscope model, and replaced \
with a special load and inertia properties on the gimbal. This time, the \
model is built in Euler coordinates, just to show that the results are the \
same."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the gyroscope constraint set with the rotor deleted."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Euler]\), 
    \(SetConstraints[\n\tRevolute5[1, Axis[ground, 0, Z], Axis[base, 0, Z]], 
      \n\tOrthogonal1[2, Vector[base, X], Vector[ground, Y]], \n\t
      Revolute5[3, Axis[base, 0, Y], Axis[gimbal, 0, Y]], \n\t
      Orthogonal1[4, Vector[gimbal, Z], Vector[base, X]]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is the body object for the gimbal. It now carries the inertia of what \
was the rotor with the component in the direction of the spin axis (the local \
",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis) of the rotor filtered out. Note the return from ",
  StyleBox["GyroFilter",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "; the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " component of the inertia is gone. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetBodies[
      Body[gimbal, Inertia \[Rule] GyroFilter[{2.0, 1.0, 1.0, 0, 0, 0}, X]]]
      \), 
    \(GyroFilter[{2.0, 1.0, 1.0, 0, 0, 0}, X]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 1.`, 1.`, 0.`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here are the load objects. They are unchanged, except that ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the inertia option to explicitly specify the inertia properties. If \
this was not done, ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would pull the inertia properties from the body object that has \
previously had the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " component filtered out."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[Moment[base, Z, 1], 
      GyroMoment[gimbal, X, 2.0  \[Pi], 
        Inertia \[Rule] {2.0, 1.0, 1.0, 0, 0, 0}]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The model is now functionally equivalent to the previously defined model. \
The model can be integrated with ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", after dropping constraints 2 and 4. Constraint 6 was previously dropped \
and is no longer part of the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is integrated from ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0 to 1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(SolveMech[0, Solution \[Rule] Acceleration]; \)\), 
    \(\(fsys = SetFree[{2, 4}, Solution \[Rule] Dynamic]; \)\), 
    \(\(sol = 
      SolveFree[fsys, endt = 1.0, MakeRules \[Rule] {Location, Velocity}]; 
    \)\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is a plot of the angular velocity components of the gimbal. It is \
identical to the response of the previous model, with only two bodies \
required to create it."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[Omega[gimbal] /. sol], {T, 0, endt}, 
      PlotStyle \[Rule] {{}, {Dashing[{.03, .03}]}, {Dashing[{.04, .02}]}}]; 
    \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.406801 2.46898 [
[.21429 .3943 -9 -9 ]
[.21429 .3943 9 0 ]
[.40476 .3943 -9 -9 ]
[.40476 .3943 9 0 ]
[.59524 .3943 -9 -9 ]
[.59524 .3943 9 0 ]
[.78571 .3943 -9 -9 ]
[.78571 .3943 9 0 ]
[.97619 .3943 -3 -9 ]
[.97619 .3943 3 0 ]
[.01131 .03645 -30 -4.5 ]
[.01131 .03645 0 4.5 ]
[.01131 .1599 -24 -4.5 ]
[.01131 .1599 0 4.5 ]
[.01131 .28335 -30 -4.5 ]
[.01131 .28335 0 4.5 ]
[.01131 .53025 -24 -4.5 ]
[.01131 .53025 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .4068 m
.21429 .41305 L
s
[(0.2)] .21429 .3943 0 1 Mshowa
.40476 .4068 m
.40476 .41305 L
s
[(0.4)] .40476 .3943 0 1 Mshowa
.59524 .4068 m
.59524 .41305 L
s
[(0.6)] .59524 .3943 0 1 Mshowa
.78571 .4068 m
.78571 .41305 L
s
[(0.8)] .78571 .3943 0 1 Mshowa
.97619 .4068 m
.97619 .41305 L
s
[(1)] .97619 .3943 0 1 Mshowa
.125 Mabswid
.07143 .4068 m
.07143 .41055 L
s
.11905 .4068 m
.11905 .41055 L
s
.16667 .4068 m
.16667 .41055 L
s
.2619 .4068 m
.2619 .41055 L
s
.30952 .4068 m
.30952 .41055 L
s
.35714 .4068 m
.35714 .41055 L
s
.45238 .4068 m
.45238 .41055 L
s
.5 .4068 m
.5 .41055 L
s
.54762 .4068 m
.54762 .41055 L
s
.64286 .4068 m
.64286 .41055 L
s
.69048 .4068 m
.69048 .41055 L
s
.7381 .4068 m
.7381 .41055 L
s
.83333 .4068 m
.83333 .41055 L
s
.88095 .4068 m
.88095 .41055 L
s
.92857 .4068 m
.92857 .41055 L
s
.25 Mabswid
0 .4068 m
1 .4068 L
s
.02381 .03645 m
.03006 .03645 L
s
[(-0.15)] .01131 .03645 1 0 Mshowa
.02381 .1599 m
.03006 .1599 L
s
[(-0.1)] .01131 .1599 1 0 Mshowa
.02381 .28335 m
.03006 .28335 L
s
[(-0.05)] .01131 .28335 1 0 Mshowa
.02381 .53025 m
.03006 .53025 L
s
[(0.05)] .01131 .53025 1 0 Mshowa
.125 Mabswid
.02381 .06114 m
.02756 .06114 L
s
.02381 .08583 m
.02756 .08583 L
s
.02381 .11052 m
.02756 .11052 L
s
.02381 .13521 m
.02756 .13521 L
s
.02381 .18459 m
.02756 .18459 L
s
.02381 .20928 m
.02756 .20928 L
s
.02381 .23397 m
.02756 .23397 L
s
.02381 .25866 m
.02756 .25866 L
s
.02381 .30804 m
.02756 .30804 L
s
.02381 .33273 m
.02756 .33273 L
s
.02381 .35742 m
.02756 .35742 L
s
.02381 .38211 m
.02756 .38211 L
s
.02381 .43149 m
.02756 .43149 L
s
.02381 .45618 m
.02756 .45618 L
s
.02381 .48087 m
.02756 .48087 L
s
.02381 .50556 m
.02756 .50556 L
s
.02381 .01176 m
.02756 .01176 L
s
.02381 .55494 m
.02756 .55494 L
s
.02381 .57963 m
.02756 .57963 L
s
.02381 .60432 m
.02756 .60432 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4068 m
.02499 .4068 L
.02605 .4068 L
.02729 .4068 L
.02846 .4068 L
.02954 .4068 L
.03053 .4068 L
.03163 .4068 L
.03279 .4068 L
.03395 .4068 L
.0352 .4068 L
.03638 .4068 L
.03746 .4068 L
.03873 .4068 L
.04011 .4068 L
.04141 .4068 L
.04262 .4068 L
.04521 .4068 L
.04765 .4068 L
.04984 .4068 L
.05221 .40681 L
.05481 .40681 L
.05754 .40681 L
.06244 .40682 L
.06507 .40683 L
.06746 .40683 L
.07283 .40685 L
.07781 .40687 L
.08253 .4069 L
.09309 .40699 L
.09906 .40706 L
.10458 .40713 L
.12324 .40749 L
.13387 .40777 L
.14385 .40808 L
.18253 .4096 L
.20218 .41042 L
.21257 .41081 L
.22367 .41116 L
.22921 .4113 L
.23443 .41141 L
.23951 .4115 L
.24174 .41154 L
.2442 .41157 L
.24865 .41161 L
.25109 .41163 L
.25336 .41164 L
.25465 .41165 L
.25587 .41165 L
.25696 .41165 L
Mistroke
.25815 .41166 L
.25945 .41166 L
.26017 .41166 L
.26082 .41165 L
.2621 .41165 L
.2633 .41165 L
.26446 .41164 L
.26571 .41164 L
.26797 .41163 L
.27065 .41161 L
.27309 .41158 L
.27839 .41151 L
.28342 .41142 L
.3019 .41096 L
.32185 .41026 L
.34028 .40953 L
.36058 .40873 L
.3796 .40808 L
.39781 .40758 L
.40804 .40736 L
.4174 .4072 L
.42723 .40707 L
.43637 .40698 L
.44639 .40691 L
.45199 .40687 L
.45708 .40685 L
.46709 .40682 L
.4763 .40679 L
.49711 .40675 L
.50618 .40674 L
.51592 .40672 L
.5215 .40672 L
.52278 .40672 L
.52414 .40672 L
.52541 .40671 L
.52659 .40671 L
.52776 .40671 L
.52904 .40671 L
.53033 .40671 L
.53105 .40671 L
.53171 .40671 L
.53284 .40671 L
.53408 .40671 L
.53537 .40672 L
.53657 .40672 L
.53919 .40672 L
.54161 .40672 L
.54426 .40673 L
.54708 .40674 L
.5518 .40676 L
Mistroke
.557 .40678 L
.56163 .40682 L
.5666 .40686 L
.57558 .40695 L
.5857 .4071 L
.59673 .40732 L
.61683 .40786 L
.65749 .40938 L
.6763 .41014 L
.69664 .41085 L
.7078 .41114 L
.7127 .41125 L
.71807 .41135 L
.72281 .41142 L
.72788 .41147 L
.72932 .41149 L
.73069 .4115 L
.73133 .4115 L
.73201 .41151 L
.73324 .41151 L
.73438 .41152 L
.73564 .41152 L
.73629 .41152 L
.73698 .41152 L
.73824 .41152 L
.7395 .41152 L
.74064 .41152 L
.74196 .41152 L
.74321 .41151 L
.74542 .4115 L
.74782 .41149 L
.75047 .41147 L
.75328 .41144 L
.7583 .41138 L
.76349 .4113 L
.76835 .4112 L
.7794 .41092 L
.81825 .40954 L
.83801 .40879 L
.85954 .40807 L
.86955 .40779 L
.88019 .40753 L
.89017 .40733 L
.89933 .40719 L
.90965 .40706 L
.91497 .407 L
.92079 .40695 L
.93062 .40689 L
.94098 .40684 L
.94988 .40681 L
Mistroke
.95799 .40679 L
.97619 .40676 L
Mfstroke
[ .03 .03 ] 0 setdash
.02381 .4068 m
.02499 .40683 L
.02605 .40678 L
.02729 .40666 L
.02846 .40649 L
.03053 .40609 L
.03279 .40549 L
.03527 .40462 L
.0379 .40348 L
.04262 .40084 L
.05205 .39337 L
.06244 .38187 L
.0842 .3477 L
.10458 .30542 L
.14335 .2091 L
.18458 .10765 L
.20517 .06649 L
.21519 .05012 L
.22428 .03786 L
.2338 .0277 L
.23816 .02398 L
.24277 .0207 L
.2477 .018 L
.25224 .01624 L
.25476 .01555 L
.25597 .01529 L
.25712 .01509 L
.25777 .015 L
.25847 .01491 L
.25971 .0148 L
.2604 .01475 L
.26115 .01473 L
.26178 .01472 L
.26248 .01472 L
.26369 .01476 L
.26483 .01485 L
.26607 .01499 L
.26739 .01519 L
.26879 .01547 L
.27011 .01578 L
.27257 .01653 L
.27701 .0184 L
.28182 .0212 L
.29268 .03015 L
.30268 .04153 L
.32144 .07082 L
.34208 .11253 L
.38242 .21072 L
.42125 .30497 L
.441 .34495 L
Mistroke
.45142 .36257 L
.46252 .3781 L
.47335 .3897 L
.48316 .39717 L
.48789 .39971 L
.49056 .40079 L
.49301 .40157 L
.49516 .4021 L
.4964 .40233 L
.49752 .4025 L
.49871 .40264 L
.49999 .40274 L
.50117 .40278 L
.50229 .40278 L
.50343 .40274 L
.50466 .40265 L
.50582 .40252 L
.50689 .40237 L
.50936 .40187 L
.51196 .40113 L
.51687 .39916 L
.51965 .39768 L
.52223 .39605 L
.53115 .38881 L
.54067 .3785 L
.56205 .34597 L
.58222 .30564 L
.62074 .21346 L
.66171 .11543 L
.6821 .07519 L
.69207 .05892 L
.70116 .04627 L
.70992 .03645 L
.71946 .0283 L
.7247 .025 L
.727 .02381 L
.72954 .02269 L
.73177 .02187 L
.73418 .0212 L
.7355 .02092 L
.73672 .02071 L
.73788 .02055 L
.7391 .02043 L
.74033 .02036 L
.74103 .02034 L
.74167 .02034 L
.74284 .02036 L
.74409 .02043 L
.74521 .02054 L
.74625 .02068 L
Mistroke
.74863 .02111 L
.74994 .02143 L
.75119 .02178 L
.75354 .02257 L
.75882 .02498 L
.76337 .02777 L
.7676 .03103 L
.77718 .04039 L
.78775 .05372 L
.79771 .06903 L
.81633 .10386 L
.8549 .19264 L
.89592 .29087 L
.91636 .33275 L
.92634 .35 L
.93543 .36367 L
.94422 .37485 L
.95377 .38456 L
.95901 .38872 L
.96386 .3918 L
.9685 .39403 L
.97084 .39488 L
.97342 .3956 L
.97475 .39588 L
.97619 .39611 L
Mfstroke
[ .04 .02 ] 0 setdash
.02381 .4068 m
.06244 .50271 L
.08255 .54434 L
.0932 .56263 L
.10458 .5788 L
.11009 .58525 L
.11531 .59048 L
.12038 .59474 L
.12507 .59793 L
.12951 .60027 L
.13178 .60122 L
.13422 .60204 L
.13549 .60239 L
.13666 .60266 L
.13784 .60289 L
.13895 .60306 L
.14022 .6032 L
.1409 .60325 L
.14161 .60329 L
.1423 .60331 L
.14295 .60332 L
.14415 .60329 L
.14531 .60322 L
.14656 .60309 L
.14773 .60291 L
.14881 .60272 L
.15143 .60207 L
.15392 .60124 L
.15886 .59897 L
.16423 .59557 L
.17383 .58717 L
.1827 .57683 L
.20137 .5477 L
.22197 .50579 L
.26217 .40725 L
.30086 .31246 L
.32051 .2721 L
.3309 .25417 L
.342 .23831 L
.35275 .22645 L
.36253 .2187 L
.36724 .21604 L
.3699 .21491 L
.37235 .21406 L
.37449 .21348 L
.37685 .21301 L
.37804 .21284 L
.37932 .21271 L
.38052 .21263 L
.38162 .21261 L
Mistroke
.38292 .21262 L
.38413 .21269 L
.38522 .21278 L
.3864 .21293 L
.3877 .21314 L
.38906 .21343 L
.39149 .21408 L
.39586 .21573 L
.39834 .21697 L
.40065 .21832 L
.41066 .22612 L
.42138 .2378 L
.43158 .25205 L
.44266 .27078 L
.4628 .31162 L
.50363 .4106 L
.54295 .50489 L
.56268 .54381 L
.58075 .57148 L
.5902 .58219 L
.60014 .59062 L
.60531 .59382 L
.60778 .59505 L
.61011 .59605 L
.61288 .59695 L
.61538 .59755 L
.61679 .5978 L
.61808 .59798 L
.61876 .59805 L
.61951 .59811 L
.62028 .59815 L
.62101 .59818 L
.62227 .59818 L
.6229 .59816 L
.6236 .59813 L
.62484 .59803 L
.626 .59789 L
.62737 .59768 L
.62862 .59743 L
.63144 .59669 L
.63374 .5959 L
.63626 .59484 L
.64134 .5921 L
.64598 .58877 L
.65094 .58449 L
.65988 .57494 L
.68121 .54321 L
.70135 .50353 L
.73978 .41242 L
.78067 .31481 L
Mistroke
.801 .27449 L
.81095 .25811 L
.82004 .2453 L
.82877 .23523 L
.83828 .22685 L
.8435 .2234 L
.84834 .22094 L
.85072 .21999 L
.85297 .21927 L
.85421 .21893 L
.85555 .21866 L
.85676 .21846 L
.8579 .21831 L
.85914 .2182 L
.86027 .21814 L
.86149 .21812 L
.86218 .21813 L
.86282 .21815 L
.86388 .21821 L
.86505 .21833 L
.86627 .21849 L
.86741 .21869 L
.87003 .21929 L
.87244 .22003 L
.87785 .22235 L
.88275 .22524 L
.88812 .22933 L
.89892 .24027 L
.91855 .26827 L
.9395 .30819 L
.97619 .39321 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00
8Goo00<007ooOol0m7oo000QOol00`00Oomoo`3dOol0025oo`03001oogoo0?Aoo`008Goo0P00>7oo
1000^Goo000QOol00`00Oomoo`0eOol30002Ool4002fOol0025oo`03001oogoo0?Aoo`008Goo00<0
07ooOol0m7oo000<Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`03Ool00`00Oomo
o`2/Ool00`00Oomoo`08Ool2000kOol000]oo`03001oo`0000Qoo`07001oogooOol007oo000017oo
00<007ooOol0ZWoo0P003Goo00<007ooOol0>7oo0006Ool30002Ool00`00Ool00008Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool2000`Ool2000AOol00`00Oomoo`1TOol00`00Oomoo`0=Ool00`00Oomo
o`0hOol000]oo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`0^Ool00`00Oomoo`0B
Ool00`00Oomoo`1ROol00`00Oomoo`0?Ool00`00Oomoo`0gOol000]oo`03001oo`0000Qoo`05001o
ogooOol00006Ool00`00Oomoo`0^Ool00`00Oomoo`0BOol00`00Oomoo`1QOol00`00Oomoo`0AOol0
0`00Oomoo`0fOol000aoo`03001oogoo00Ioo`8000=oo`<000Aoo`03001oogoo02eoo`03001oogoo
01Aoo`03001oogoo061oo`03001oogoo019oo`03001oogoo03Eoo`008Goo00<007ooOol0;7oo00<0
07ooOol05Goo00<007ooOol0MWoo00<007ooOol0=7oo000QOol00`00Oomoo`0/Ool00`00Oomoo`0F
Ool00`00Oomoo`2/Ool0025oo`8002aoo`03001oogoo01Moo`03001oogoo0:aoo`008Goo00<007oo
Ool0AWoo00<007ooOol0Zgoo000QOol00`00Oomoo`3dOol0025oo`03001oogoo0:=oo`03001oogoo
04ioo`008Goo00<007ooOol0XWoo00<007ooOol077oo00<007ooOol0<7oo000QOol00`00Oomoo`2Q
Ool00`00Oomoo`0MOol00`00Oomoo`0`Ool0025oo`800:9oo`03001oogoo01ioo`03001oogoo02mo
o`008Goo00<007ooOol0:7oo00<007ooOol07goo00<007ooOol0Dgoo00<007ooOol07goo00<007oo
Ool0;goo000QOol00`00Oomoo`0WOol00`00Oomoo`0POol00`00Oomoo`1COol00`00Oomoo`0POol0
0`00Oomoo`0^Ool0025oo`03001oogoo02Moo`03001oogoo025oo`03001oogoo055oo`03001oogoo
025oo`03001oogoo02ioo`008Goo00<007ooOol09Woo00<007ooOol08Woo00<007ooOol0DGoo00<0
07ooOol08Woo00<007ooOol0;Goo000QOol00`00Oomoo`0VOol00`00Oomoo`0SOol00`00Oomoo`1e
Ool00`00Oomoo`0]Ool0025oo`03001oogoo02Eoo`03001oogoo02Aoo`03001oogoo0:Eoo`008Goo
0P009Goo00<007ooOol09Woo00<007ooOol0Y7oo000QOol00`00Oomoo`0TOol00`00Oomoo`0VOol0
0`00Oomoo`2TOol0025oo`03001oogoo0?Aoo`008Goo00<007ooOol0m7oo000QOol00`00Oomoo`2L
Ool00`00Oomoo`1EOol0025oo`03001oogoo09aoo`03001oogoo02Qoo`03001oogoo02Yoo`008Goo
0P00W7oo00<007ooOol0:Goo00<007ooOol0:Woo000QOol00`00Oomoo`2KOol00`00Oomoo`0ZOol0
0`00Oomoo`0YOol0025oo`03001oogoo029oo`03001oogoo02]oo`03001oogoo04Moo`03001oogoo
02]oo`03001oogoo02Uoo`008Goo00<007ooOol08Woo00<007ooOol0:goo00<007ooOol0Agoo00<0
07ooOol0;7oo00<007ooOol0:7oo000AOol00`00Oomoo`02Ool00`00Oomoo`050003Ool00`00Oomo
o`0QOol00`00Oomoo`0]Ool00`00Oomoo`15Ool00`00Oomoo`0]Ool00`00Oomoo`0XOol0011oo`03
001oo`0000Qoo`03001oogoo00=oo`03001oogoo025oo`03001oogoo02eoo`03001oogoo04Eoo`03
001oogoo02ioo`03001oogoo02Moo`002goo0`000Woo00<007oo000027oo00<007ooOol00goo0P00
8Goo00<007ooOol0;goo00<007ooOol0MGoo00<007ooOol09goo000@Ool00`00Ool00008Ool00`00
Oomoo`03Ool00`00Oomoo`0POol00`00Oomoo`0_Ool00`00Oomoo`2OOol0011oo`03001oo`0000Qo
o`03001oogoo00=oo`03001oogoo01moo`03001oogoo035oo`03001oogoo09ioo`004Goo00<007oo
Ool01Woo0P001Goo00<007ooOol07goo00<007ooOol0<Goo00<007ooOol0WWoo000QOol00`00Oomo
o`3dOol0025oo`03001oogoo0?Aoo`008Goo0P00Ugoo00<007ooOol0Fgoo000QOol00`00Oomoo`2F
Ool00`00Oomoo`0dOol00`00Oomoo`0TOol0025oo`03001oogoo09Eoo`03001oogoo03Ioo`03001o
ogoo02=oo`008Goo00<007ooOol0UGoo00<007ooOol0=Woo00<007ooOol08goo000QOol00`00Oomo
o`0LOol00`00Oomoo`0gOol00`00Oomoo`0kOol00`00Oomoo`0hOol00`00Oomoo`0ROol0025oo`03
001oogoo01]oo`03001oogoo03Qoo`03001oogoo03]oo`03001oogoo03Qoo`03001oogoo029oo`00
8Goo0P0077oo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol08Woo000Q
Ool00`00Oomoo`0KOol00`00Oomoo`0gOol5000iOol00`00Oomoo`0jOol00`00Oomoo`0QOol0025o
o`03001oogoo01Yoo`03001oogoo03Ioo`80009oo`03001oo`00008007Aoo`03001oogoo025oo`00
8Goo00<007ooOol06Woo00<007ooOol0=Goo00<007ooOol00goo00@007ooOomoo`8006ioo`P0021o
o`008Goo00<007ooOol06Goo00<007ooOol0=7oo0P001Woo00<007ooOol0L7oo00<007ooOol09Woo
000QOol00`00Oomoo`0IOol00`00Oomoo`0cOol00`00Oomoo`07Ool00`00Oomoo`1^Ool00`00Oomo
o`0WOol0025oo`03001oogoo04ioo`03001oogoo08Ioo`03001oogoo01Yoo`008Goo0P00HGoo00<0
07ooOol0MGoo00<007ooOol06Goo000QOol00`00Oomoo`1QOol00`00Oomoo`0/Ool00`00Oomoo`0c
Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0HOol0025oo`03001oogoo069oo`03001o
ogoo02]oo`03001oogoo039oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo01Moo`008Goo
00<007ooOol0Bgoo00<007ooOol057oo00<007ooOol0:Woo00<007ooOol0<Woo00<007ooOol03Goo
00<007ooOol00goo00<007ooOol05goo000QOol00`00Oomoo`1:Ool00`00Oomoo`0FOol00`00Oomo
o`0YOol00`00Oomoo`0bOol00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0FOol0025oo`03
001oogoo01Ioo`03001oogoo035oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo02Moo`03
001oogoo039oo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo01Eoo`008Goo0P005goo00<0
07ooOol0<7oo00<007ooOol047oo00<007ooOol01Goo00<007ooOol09goo00<007ooOol0<Woo00<0
07ooOol03goo00<007ooOol017oo00<007ooOol05Goo000QOol00`00Oomoo`0EOol00`00Oomoo`0`
Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`0bOol00`00Oomoo`0A
Ool00`00Oomoo`04Ool00`00Oomoo`0DOol0025oo`03001oogoo01Eoo`03001oogoo031oo`03001o
ogoo019oo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo035oo`03001oogoo019oo`03001o
ogoo01]oo`008Goo00<007ooOol057oo00<007ooOol0<7oo00<007ooOol04goo00<007ooOol0HGoo
00<007ooOol0<7oo000<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`0DOol00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`1POol00`00Oomo
o`0aOol000]oo`03001oo`0000Moo`03001oo`00009oo`03001oo`0000Aoo`03001oogoo01=oo`03
001oogoo031oo`03001oogoo01Eoo`03001oogoo09=oo`001Woo0`000Woo00<007oo00001goo00<0
07oo000017oo00<007ooOol00Woo0P0057oo00<007ooOol0<7oo00<007ooOol05Goo00<007ooOol0
Ogoo00<007ooOol04Goo000;Ool00`00Ool00007Ool00`00Ool00002Ool20005Ool00`00Oomoo`1X
Ool00`00Oomoo`1eOol00`00Oomoo`0AOol000]oo`03001oo`0000Moo`03001oo`00009oo`03001o
ogoo00Aoo`03001oogoo06Qoo`03001oogoo05=oo`03001oogoo021oo`03001oogoo011oo`0037oo
00<007ooOol01goo00@007ooOomoo`<000Aoo`03001oogoo06Uoo`03001oogoo01ioo`03001oogoo
031oo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo011oo`008Goo00<007ooOol0JGoo00<0
07ooOol07Woo00<007ooOol0<7oo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol03goo000Q
Ool00`00Oomoo`14Ool00`00Oomoo`0SOol00`00Oomoo`0LOol00`00Oomoo`0`Ool00`00Oomoo`0K
Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool0025oo`8004Aoo`03001oogoo02Aoo`03001oogoo01ao
o`03001oogoo031oo`03001oogoo01]oo`03001oogoo00Ioo`03001oogoo00ioo`008Goo00<007oo
Ool04Goo00<007ooOol0;Woo00<007ooOol077oo00<007ooOol01goo00<007ooOol06Woo00<007oo
Ool0<7oo00<007ooOol07Goo00<007ooOol01Goo00<007ooOol03Woo000QOol00`00Oomoo`0@Ool0
0`00Oomoo`0_Ool00`00Oomoo`0MOol00`00Oomoo`06Ool00`00Oomoo`0JOol00`00Oomoo`0`Ool0
0`00Oomoo`0MOol00`00Oomoo`06Ool00`00Oomoo`0=Ool0025oo`03001oogoo011oo`03001oogoo
02ioo`03001oogoo01ioo`03001oogoo00Moo`03001oogoo01Qoo`03001oogoo035oo`03001oogoo
01ioo`03001oogoo00Eoo`03001oogoo00eoo`008Goo00<007ooOol03goo00<007ooOol0;goo00<0
07ooOol07goo00<007ooOol01Woo00<007ooOol067oo00<007ooOol0<7oo00<007ooOol07goo00<0
07ooOol05Goo000QOol00`00Oomoo`0>Ool00`00Oomoo`0`Ool00`00Oomoo`0OOol00`00Oomoo`1D
Ool00`00Oomoo`0gOol0025oo`8000moo`03001oogoo031oo`03001oogoo021oo`03001oogoo05=o
o`03001oogoo03Moo`008Goo00<007ooOol03Goo00<007ooOol0<7oo00<007ooOol08Goo00<007oo
Ool0DWoo00<007ooOol0:Woo00<007ooOol02goo000QOol00`00Oomoo`10Ool00`00Oomoo`0ROol0
0`00Oomoo`1AOol00`00Oomoo`0ZOol00`00Oomoo`0;Ool0025oo`03001oogoo06ioo`03001oogoo
04Qoo`03001oogoo02]oo`03001oogoo00Yoo`008Goo00<007ooOol0KWoo00<007ooOol04goo00<0
07ooOol0<Goo00<007ooOol0;7oo00<007ooOol02Woo000QOol00`00Oomoo`1_Ool00`00Oomoo`0A
Ool00`00Oomoo`0bOol00`00Oomoo`0UOol00`00Oomoo`05Ool00`00Oomoo`09Ool0025oo`03001o
ogoo06moo`03001oogoo015oo`03001oogoo05]oo`03001oogoo00Aoo`03001oogoo00Uoo`008Goo
0P00?goo00<007ooOol0;goo00<007ooOol03goo00<007ooOol0G7oo00<007ooOol01Goo00<007oo
Ool027oo000QOol00`00Oomoo`0:Ool00`00Oomoo`0JOol00`00Oomoo`02Ool01000Oomoogoo0`00
2goo00<007ooOol05Woo00<007ooOol00Woo00<007ooOol00Woo0`001Goo00<007ooOol017oo00<0
07ooOol03goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`8002Eoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo01ioo`03001oogoo00Aoo`H000Eoo`008Goo00<007ooOol02Goo
00<007ooOol06Woo00<007oo00001goo00<007ooOol02Woo00<007ooOol05Woo00<007oo00002Goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol00Woo00<007oo00001goo
00<007oo00008goo00<007oo00001goo00<007oo000087oo00<007ooOol017oo00<007oo00001goo
000QOol00`00Oomoo`08Ool00`00Oomoo`0KOol00`00Ool00008Ool00`00Oomoo`09Ool00`00Oomo
o`0FOol00`00Ool00007Ool40006Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool0
0`00Ool00007Ool00`00Ool0000SOol00`00Ool00007Ool00`00Ool0000POol00`00Oomoo`04Ool0
0`00Ool00007Ool0025oo`03001oogoo00Qoo`03001oogoo01]oo`03001oo`0000Qoo`03001oogoo
00Qoo`03001oogoo01Moo`03001oo`0000Moo`03001oo`0000Moo`03001oogoo00Eoo`03001oogoo
00]oo`03001oogoo00=oo`03001oo`0000Moo`8002Aoo`03001oo`0000Qoo`03001oogoo021oo`03
001oogoo00Eoo`03001oogoo00Eoo`008Goo00<007ooOol01goo00<007ooOol077oo00<007oo0000
1goo00<007oo00002Goo00<007ooOol05goo00<007oo000027oo0P0027oo00<007ooOol017oo00<0
07ooOol04Goo00<007oo00001goo00<007ooOol08Woo0P0000=oo`00Ool01Woo00<007oo0000:Goo
00<007ooOol01Goo000QOol20007Ool00`00Oomoo`0NOol00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0HOol00`00Oomoo`07Ool2
000ROol00`00Ool00009Ool00`00Oomoo`0WOol20007Ool0025oo`03001oogoo00Eoo`03001oogoo
03=oo`03001oogoo02moo`03001oogoo04Aoo`03001oogoo03eoo`008Goo00<007ooOol0>Woo00<0
07ooOol0Mgoo00<007ooOol0=Goo00<007ooOol01Goo000QOol00`00Oomoo`0jOol00`00Oomoo`0m
Ool2000gOol00`00Oomoo`0dOol40006Ool0025oo`03001oogoo07Aoo`03001oogoo009oo`8003Qo
o`03001oogoo03ioo`008Goo00<007ooOol0M7oo1@00>Goo00<007ooOol0?goo000KOoom0000025o
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qooc@000Uoo`03001oogoo00Uoo`03001o
ogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00MoocH000Qoo`03001oogoo00Uo
o`03001oogoo00Uoo`03001oogoo00Aoo`008Goo00<007ooOol0;Goo00<007ooOol027oo00<007oo
Ool08Woo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol0;Goo00<007ooOol0;Goo00<007oo
Ool017oo000QOol00`00Oomoo`0hOol00`00Oomoo`0kOol00`00Oomoo`1kOol0025oo`8003Qoo`03
001oogoo03aoo`03001oogoo03Moo`03001oogoo045oo`008Goo0P00>7oo00<007ooOol0?Goo00<0
07ooOol0=Woo00<007ooOol0@Goo000QOol3000fOol00`00Oomoo`0nOol00`00Oomoo`0eOol00`00
Oomoo`12Ool0025oo`03001oo`0003Ioo`03001oogoo03moo`03001oogoo03Aoo`03001oogoo049o
o`008Goo00<007oo0000=Goo00<007ooOol0MWoo00<007ooOol0@goo000QOol01000Oomoo`00=7oo
00<007ooOol0MWoo00<007ooOol0@goo000QOol01000Oomoo`00<goo00<007ooOol0Mgoo00<007oo
Ool0@goo000QOol01@00Oomoogoo0000<Woo00<007ooOol0MWoo00<007ooOol0A7oo000QOol01@00
Oomoogoo0000N7oo00<007ooOol0<7oo00<007ooOol0A7oo000QOol2001kOol00`00Oomoo`0_Ool0
0`00Oomoo`15Ool0025oo`03001oogoo07]oo`03001oogoo02ioo`03001oogoo04Eoo`008Goo00<0
07ooOol0Ngoo00<007ooOol0MWoo000QOol00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomoo`17
Ool00`00Oomoo`1eOol0025oo`03001oogoo00=oo`03001oogoo02aoo`03001oogoo04Moo`03001o
ogoo07Eoo`008Goo00<007ooOol017oo00<007ooOol0:Woo00<007ooOol0BGoo00<007ooOol0:Woo
00<007ooOol0Agoo000QOol20005Ool00`00Oomoo`0ZOol00`00Oomoo`19Ool00`00Oomoo`0YOol0
0`00Oomoo`18Ool0025oo`03001oogoo00Aoo`03001oogoo02Yoo`03001oogoo04Yoo`03001oogoo
02Qoo`03001oogoo04Qoo`008Goo00<007ooOol01Goo00<007ooOol0:7oo00<007ooOol0Bgoo00<0
07ooOol09goo00<007ooOol0BGoo000QOol00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`1e
Ool00`00Oomoo`19Ool0025oo`03001oogoo00Ioo`03001oogoo02Moo`03001oogoo07Aoo`03001o
ogoo04Yoo`008Goo00<007ooOol01Woo00<007ooOol09Woo00<007ooOol0MGoo00<007ooOol0BWoo
000QOol20007Ool00`00Oomoo`0VOol00`00Oomoo`1>Ool00`00Oomoo`0TOol00`00Oomoo`1:Ool0
025oo`03001oogoo00Moo`03001oogoo07Ioo`03001oogoo02=oo`03001oogoo04]oo`008Goo00<0
07ooOol0PGoo00<007ooOol08Woo00<007ooOol0Bgoo000QOol00`00Oomoo`21Ool00`00Oomoo`0R
Ool00`00Oomoo`1;Ool000aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo02aoo`03001oogoo05=oo`03001oogoo06moo`002goo00<007oo00001goo
00<007oo00000Woo00<007oo000017oo00<007ooOol02Goo00<007ooOol087oo00<007ooOol0Dgoo
00<007ooOol0Kgoo000;Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`02Ool2000:Ool0
0`00Oomoo`0OOol00`00Oomoo`1EOol00`00Oomoo`1^Ool000]oo`03001oo`0000Moo`03001oo`00
009oo`8000Eoo`03001oogoo00Yoo`03001oogoo01ioo`03001oogoo05Eoo`03001oogoo01eoo`03
001oogoo04ioo`002goo00<007oo00001goo00<007oo00000Woo00<007ooOol017oo00<007ooOol0
2Woo00<007ooOol07Goo00<007ooOol0Egoo00<007ooOol06goo00<007ooOol0Cgoo000<Ool00`00
Oomoo`07Ool01000Oomoogoo0`0017oo00<007ooOol02goo00<007ooOol077oo00<007ooOol0Egoo
00<007ooOol06goo00<007ooOol0Cgoo000QOol00`00Oomoo`0;Ool00`00Oomoo`0KOol00`00Oomo
o`1eOol00`00Oomoo`1@Ool0025oo`03001oogoo00aoo`03001oogoo01Yoo`03001oogoo07Eoo`03
001oogoo051oo`008Goo0P003Goo00<007ooOol06Goo00<007ooOol0MGoo00<007ooOol0DGoo000Q
Ool00`00Oomoo`0=Ool00`00Oomoo`0HOol00`00Oomoo`1eOol00`00Oomoo`1AOol0025oo`03001o
ogoo00ioo`03001oogoo07Ioo`03001oogoo01Eoo`03001oogoo059oo`008Goo00<007ooOol0R7oo
00<007ooOol057oo00<007ooOol0DWoo000QOol00`00Oomoo`28Ool00`00Oomoo`0COol00`00Oomo
o`1COol0025oo`03001oogoo08Uoo`03001oogoo06Qoo`008Goo00<007ooOol04Goo00<007ooOol0
4Goo00<007ooOol0HWoo00<007ooOol0Igoo000QOol2000BOol00`00Oomoo`0@Ool00`00Oomoo`1T
Ool00`00Oomoo`1VOol0025oo`03001oogoo019oo`03001oogoo00ioo`03001oogoo06Ioo`03001o
ogoo00aoo`03001oogoo05Ioo`008Goo00<007ooOol04goo0P003Goo00<007ooOol0J7oo00<007oo
Ool02Goo0P00FGoo000QOol00`00Oomoo`0EOol00`00Oomoo`09Ool00`00Oomoo`1cOol2001KOol0
025oo`03001oogoo01Ioo`03001oogoo00Moo`03001oogoo06moo`D005eoo`008Goo00<007ooOol0
5goo0P0017oo0`00e7oo000QOol2003eOol0025oo`03001oogoo0?Aoo`008Goo00<007ooOol0m7oo
000QOol00`00Oomoo`3dOol00?mooaUoo`00ogoo6Goo003oOolIOol00?mooaUoo`00ogoo6Goo003o
OolIOol00?mooaUoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-0.138206, -0.177913, 0.00416922,
   0.00160823}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph:=Graphics[{\n  {Thickness[0.01],RGBColor[.7,0,0],\n   Edge[{{0,0}, \
Point[slider,1], Point[slider, 2],\n     Point[ground, 1]}]},\n  \
{RGBColor[0,.7,0],\n   Facet[slider, {0, \
{-.5,.2},{-.5,.4},{.5,.4},{.5,.2}}]},\n  \
{Thickness[0.03],RGBColor[0,0,.7],Edge[pendulum, {0, 1}],\n   \
Wheel[Point[pendulum, 0], .3]},\n  PointSize[0.04],Thickness[0.012],\n  \
Vertex[{Point[slider,0],{0,0},{4,0}}]},\n  Axes \[Rule] False,AspectRatio \
\[Rule] Automatic,\n  PlotRange \[Rule] {{0,5},{-4,0}}]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Do[Show[graph/.(sol/.T \[Rule] i)], {i,0,4.5,.25}]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[GraphicsArray[graph/.(sol/.{{T \[Rule] 1}, {T \[Rule] 2}, {T \[Rule] \
3}})]]"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["10.5  Nonholonomic Systems"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Nonholonomic systems, or systems that have a kinematic constraint that is \
an explicit function of velocity, are dealt with using the ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " functions. ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is used to take a normally constrained kinematic model and replace one of \
its constraints with a constraint that is a function of mechanism velocities. \
",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " then integrates the resulting first-order system to obtain a time history \
of the motion of the mechanism."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example Mechanism"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following planar example is probably one of the more common \
nonholonomic systems, a caster, such as a wheel on a shopping cart. The \
caster is modeled in two dimensions by viewing the caster from above, like \
looking down through the shopping cart. The steady state motion of a caster \
is for the wheel to trail directly behind the pivot point of the caster. What \
is modeled here is the motion of the caster when the direction of travel of \
the pivot is reversed. The caster swings out to one side of the pivot and \
then settles in behind the pivot again.\n\nThe wheel of the caster is modeled \
as a single nonholonomic constraint that constrains the direction of travel \
of the wheel to be parallel to the direction that the wheel is pointed. In \
vector algebra terms the velocity vector of the wheel is perpendicular to a \
vector through the wheel's axis of rotation. Normal ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " constraint functions can be used to model first-order relationships such \
as this by making at least one of the geometry specifications in the \
constraint a function of velocity. \n\nBefore the velocity constraint can be \
put in place by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the model must be built in a normal kinematically constrained way. This \
requires a dummy constraint that will be replaced by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " later. The dummy constraint is a ",
  StyleBox["RotationLock1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint to lock the rotation of the caster relative to the ground. The \
other constraint in the model, constraint 1, simply constrains the pivot \
point of the caster to move steadily along the global ",
  StyleBox["X",
    FontSlant->"Italic"],
  " axis."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a pair of constraints for the 2D caster model. The second \
constraint will be replaced with a velocity relationship by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(ground = 1; \)\), 
    \(\(caster = 2; \)\), 
    \(SetConstraints[OriginLock2[1, caster, {T, 0}], 
      RotationLock1[2, caster, 0]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run just to make initial conditions available to ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(SolveMech[0]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is the caster with zero initial angle."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38182 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0909091 0.127273 0.0909091 [
[(0)] .04545 0 0 2 Msboxa
[(2)] .22727 0 0 2 Msboxa
[(4)] .40909 0 0 2 Msboxa
[(6)] .59091 0 0 2 Msboxa
[(8)] .77273 0 0 2 Msboxa
[(10)] .95455 0 0 2 Msboxa
[(-1)] -0.0125 .03636 1 0 Msboxa
[(0)] -0.0125 .12727 1 0 Msboxa
[(1)] -0.0125 .21818 1 0 Msboxa
[(2)] -0.0125 .30909 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .38282 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.04545 0 m
.04545 .00625 L
s
P
[(0)] .04545 0 0 2 Mshowa
p
.002 w
.22727 0 m
.22727 .00625 L
s
P
[(2)] .22727 0 0 2 Mshowa
p
.002 w
.40909 0 m
.40909 .00625 L
s
P
[(4)] .40909 0 0 2 Mshowa
p
.002 w
.59091 0 m
.59091 .00625 L
s
P
[(6)] .59091 0 0 2 Mshowa
p
.002 w
.77273 0 m
.77273 .00625 L
s
P
[(8)] .77273 0 0 2 Mshowa
p
.002 w
.95455 0 m
.95455 .00625 L
s
P
[(10)] .95455 0 0 2 Mshowa
p
.001 w
.08182 0 m
.08182 .00375 L
s
P
p
.001 w
.11818 0 m
.11818 .00375 L
s
P
p
.001 w
.15455 0 m
.15455 .00375 L
s
P
p
.001 w
.19091 0 m
.19091 .00375 L
s
P
p
.001 w
.26364 0 m
.26364 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.33636 0 m
.33636 .00375 L
s
P
p
.001 w
.37273 0 m
.37273 .00375 L
s
P
p
.001 w
.44545 0 m
.44545 .00375 L
s
P
p
.001 w
.48182 0 m
.48182 .00375 L
s
P
p
.001 w
.51818 0 m
.51818 .00375 L
s
P
p
.001 w
.55455 0 m
.55455 .00375 L
s
P
p
.001 w
.62727 0 m
.62727 .00375 L
s
P
p
.001 w
.66364 0 m
.66364 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73636 0 m
.73636 .00375 L
s
P
p
.001 w
.80909 0 m
.80909 .00375 L
s
P
p
.001 w
.84545 0 m
.84545 .00375 L
s
P
p
.001 w
.88182 0 m
.88182 .00375 L
s
P
p
.001 w
.91818 0 m
.91818 .00375 L
s
P
p
.001 w
.00909 0 m
.00909 .00375 L
s
P
p
.001 w
.99091 0 m
.99091 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .03636 m
.00625 .03636 L
s
P
[(-1)] -0.0125 .03636 1 0 Mshowa
p
.002 w
0 .12727 m
.00625 .12727 L
s
P
[(0)] -0.0125 .12727 1 0 Mshowa
p
.002 w
0 .21818 m
.00625 .21818 L
s
P
[(1)] -0.0125 .21818 1 0 Mshowa
p
.002 w
0 .30909 m
.00625 .30909 L
s
P
[(2)] -0.0125 .30909 1 0 Mshowa
p
.001 w
0 .05455 m
.00375 .05455 L
s
P
p
.001 w
0 .07273 m
.00375 .07273 L
s
P
p
.001 w
0 .09091 m
.00375 .09091 L
s
P
p
.001 w
0 .10909 m
.00375 .10909 L
s
P
p
.001 w
0 .14545 m
.00375 .14545 L
s
P
p
.001 w
0 .16364 m
.00375 .16364 L
s
P
p
.001 w
0 .18182 m
.00375 .18182 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23636 m
.00375 .23636 L
s
P
p
.001 w
0 .25455 m
.00375 .25455 L
s
P
p
.001 w
0 .27273 m
.00375 .27273 L
s
P
p
.001 w
0 .29091 m
.00375 .29091 L
s
P
p
.001 w
0 .01818 m
.00375 .01818 L
s
P
p
.001 w
0 .32727 m
.00375 .32727 L
s
P
p
.001 w
0 .34545 m
.00375 .34545 L
s
P
p
.001 w
0 .36364 m
.00375 .36364 L
s
P
p
.002 w
0 0 m
0 .38182 L
s
P
P
p
p
.002 w
.04545 .37557 m
.04545 .38182 L
s
P
p
.002 w
.22727 .37557 m
.22727 .38182 L
s
P
p
.002 w
.40909 .37557 m
.40909 .38182 L
s
P
p
.002 w
.59091 .37557 m
.59091 .38182 L
s
P
p
.002 w
.77273 .37557 m
.77273 .38182 L
s
P
p
.002 w
.95455 .37557 m
.95455 .38182 L
s
P
p
.001 w
.08182 .37807 m
.08182 .38182 L
s
P
p
.001 w
.11818 .37807 m
.11818 .38182 L
s
P
p
.001 w
.15455 .37807 m
.15455 .38182 L
s
P
p
.001 w
.19091 .37807 m
.19091 .38182 L
s
P
p
.001 w
.26364 .37807 m
.26364 .38182 L
s
P
p
.001 w
.3 .37807 m
.3 .38182 L
s
P
p
.001 w
.33636 .37807 m
.33636 .38182 L
s
P
p
.001 w
.37273 .37807 m
.37273 .38182 L
s
P
p
.001 w
.44545 .37807 m
.44545 .38182 L
s
P
p
.001 w
.48182 .37807 m
.48182 .38182 L
s
P
p
.001 w
.51818 .37807 m
.51818 .38182 L
s
P
p
.001 w
.55455 .37807 m
.55455 .38182 L
s
P
p
.001 w
.62727 .37807 m
.62727 .38182 L
s
P
p
.001 w
.66364 .37807 m
.66364 .38182 L
s
P
p
.001 w
.7 .37807 m
.7 .38182 L
s
P
p
.001 w
.73636 .37807 m
.73636 .38182 L
s
P
p
.001 w
.80909 .37807 m
.80909 .38182 L
s
P
p
.001 w
.84545 .37807 m
.84545 .38182 L
s
P
p
.001 w
.88182 .37807 m
.88182 .38182 L
s
P
p
.001 w
.91818 .37807 m
.91818 .38182 L
s
P
p
.001 w
.00909 .37807 m
.00909 .38182 L
s
P
p
.001 w
.99091 .37807 m
.99091 .38182 L
s
P
p
.002 w
0 .38182 m
1 .38182 L
s
P
p
.002 w
.99375 .03636 m
1 .03636 L
s
P
p
.002 w
.99375 .12727 m
1 .12727 L
s
P
p
.002 w
.99375 .21818 m
1 .21818 L
s
P
p
.002 w
.99375 .30909 m
1 .30909 L
s
P
p
.001 w
.99625 .05455 m
1 .05455 L
s
P
p
.001 w
.99625 .07273 m
1 .07273 L
s
P
p
.001 w
.99625 .09091 m
1 .09091 L
s
P
p
.001 w
.99625 .10909 m
1 .10909 L
s
P
p
.001 w
.99625 .14545 m
1 .14545 L
s
P
p
.001 w
.99625 .16364 m
1 .16364 L
s
P
p
.001 w
.99625 .18182 m
1 .18182 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23636 m
1 .23636 L
s
P
p
.001 w
.99625 .25455 m
1 .25455 L
s
P
p
.001 w
.99625 .27273 m
1 .27273 L
s
P
p
.001 w
.99625 .29091 m
1 .29091 L
s
P
p
.001 w
.99625 .01818 m
1 .01818 L
s
P
p
.001 w
.99625 .32727 m
1 .32727 L
s
P
p
.001 w
.99625 .34545 m
1 .34545 L
s
P
p
.001 w
.99625 .36364 m
1 .36364 L
s
P
p
.002 w
1 0 m
1 .38182 L
s
P
P
p
P
0 0 m
1 0 L
1 .38182 L
0 .38182 L
closepath
clip
newpath
p
.05 w
.04545 .12727 Mdot
p
.004 w
.04545 .12727 m
.22727 .12727 L
s
P
.17273 .15455 m
.17273 .1 L
.28182 .1 L
.28182 .15455 L
F
.004 w
newpath
.04545 .12727 .03636 0 365.73 arc
s
p
.13636 .03636 m
.31818 .03636 L
s
.29247 .01065 m
.31818 .03636 L
.29247 .06208 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{383, 146},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005o0000TQ000`40O003h00OogooP7oo003oOon0
Ool00?mooh1oo`00ogooP7oo000^Ool00`00Oomoo`0hOol3000kOol3000hOol2000kOol00`00Oomo
o`0eOol50002Ool00`00Oomoo`0NOol002eoo`03001oo`0003Uoo`03001oogoo03aoo`03001oogoo
03Moo`03001oo`0003Uoo`03001oo`0003Qoo`07001oogooOol007oo00007goo000]Ool00`00Ool0
000jOol00`00Oomoo`0iOol4000hOol00`00Ool0000iOol00`00Ool0000hOol01`00Oomoogoo001o
o`0001moo`00;Goo00<007oo0000>Woo00<007ooOol0>Goo00<007oo0000>Goo0P00>goo00<007oo
Ool0=goo00L007ooOomoo`00Ool0000OOol002eoo`03001oo`0003Uoo`03001oo`0003]oo`8003Uo
o`03001oogoo03Uoo`03001oo`0003Qoo`07001oogooOol007oo00007goo000^Ool00`00Oomoo`0i
Ool00`00Oomoo`0kOol00`00Oomoo`0hOol2000jOol00`00Oomoo`0fOol20004Ool00`00Oomoo`0N
Ool00?mooh1oo`00ogooP7oo003oOon0Ool00?mooh1oo`00ogooP7oo003oOon0Ool00?mooh1oo`00
ogooP7oo000POooo001=000COol0021oo`04001oogoo000;Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09
Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool01000Oomoo`00
4goo000POol01000Oomoo`002goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00@007ooOol001=oo`0087oo00<007ooOol0
37oo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0>Woo00<007ooOol0>Goo00<007ooOol0
>Goo00<007ooOol037oo00<007ooOol04Goo000POol00`00Oomoo`1NOol00`00Oomoo`3WOol00`00
Oomoo`0AOol0021oo`03001oogoo05moo`03001oogoo0>Ioo`03001oogoo015oo`0087oo00<007oo
Ool0H7oo00<007ooOol0iGoo00<007ooOol04Goo000POol2001ROol00`00Oomoo`3SOol2000COol0
021oo`03001oogoo069oo`03001oogoo0>=oo`03001oogoo015oo`0087oo00<007ooOol0HWoo00<0
07ooOol0hgoo00<007ooOol04Goo000POol00`00Oomoo`1SOol00`00Oomoo`3ROol00`00Oomoo`0A
Ool001Ioo`D000Eoo`03001oogoo06Aoo`03001oogoo0>5oo`03001oogoo015oo`0067oo00<007oo
Ool01Goo00<007ooOol0IGoo00<007ooOol0h7oo00<007ooOol04Goo000BOol30003Ool00`00Oomo
o`05Ool3000ZOolm003OOol3000COol001Qoo`03001oogoo00Eoo`03001oogoo06Eoo`03001oogoo
0>1oo`03001oogoo015oo`0067oo00<007ooOol01Goo00<007ooOol0I7oo00<007ooOol0hGoo00<0
07ooOol04Goo000GOol20007Ool00`00Oomoo`1SOol00`00Oomoo`3ROol00`00Oomoo`0AOol0021o
o`03001oogoo069oo`03001oogoo0>=oo`03001oogoo015oo`0087oo00<007ooOol0HGoo00<007oo
Ool0i7oo00<007ooOol04Goo000POol2001QOol00`00Oomoo`3TOol2000COol0021oo`03001oogoo
05moo`03001oogoo0>Ioo`03001oogoo015oo`0087oo00<007ooOol0GWoo00<007ooOol0igoo00<0
07ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`03001oogoo0?moodUo
o`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo000POol2003oOom9Ool2
000COol0021oo`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<0
07ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`03001oogoo0?moodUo
o`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo000POol20009Ool8003o
OolhOol2000COol0021oo`03001oogoo00Ioo`8000Qoo`800?moocMoo`03001oogoo015oo`0087oo
00<007ooOol01Goo00<007ooOol02Woo0P00ogoo=Goo00<007ooOol04Goo000POol00`00Oomoo`04
Ool00`00Oomoo`0=Ool00`00Oomoo`3oOolbOol00`00Oomoo`0AOol0021oo`03001oogoo009oo`80
015oo`03001oogoo01ioob@00>ioo`03001oogoo015oo`0087oo00D007ooOomoo`0000Qoo`<000Qo
o`03001oogoo01ioob@00>ioo`03001oogoo015oo`0087oo0P000Woo00<007ooOol017oo1`001goo
00<007ooOol07Goo9000kGoo0P004goo000POol01@00Oomoogoo000017oo2`001Goo00<007ooOol0
7Goo9000kWoo00<007ooOol04Goo000POol01000Oomoo`001Goo2`001Woo00<007ooOol077oo9000
kWoo00<007ooOol04Goo000POol01000Oomoo`0017oo3@001Goo00<007ooOol077oo9000kWoo00<0
07ooOol04Goo000HOol00`00Oomoo`05Ool01000Oomoo`0017oo3@001Woo00<007ooOol06goo9000
kWoo00<007ooOol04Goo000GOol00`00Ool00006Ool01000Oomoo`000goo3`001Goo00<007ooOol0
6goo9000kWoo00<007ooOol04Goo000GOol00`00Ool00006Ool40003OomF003/Ool3000COol001Mo
o`03001oo`0000Ioo`04001oogoo0003Ool?0004Ool2000MOolT003^Ool00`00Oomoo`0AOol001Mo
o`03001oo`0000Ioo`04001oogoo0004Ool=0005Ool00`00Oomoo`0LOolT003^Ool00`00Oomoo`0A
Ool001Qoo`03001oogoo00Eoo`04001oogoo0004Ool=0005Ool00`00Oomoo`0LOolT003^Ool00`00
Oomoo`0AOol0021oo`04001oogoo0005Ool;0006Ool00`00Oomoo`0LOolT003^Ool00`00Oomoo`0A
Ool0021oo`04001oogoo0005Ool;0006Ool00`00Oomoo`0LOolT003^Ool00`00Oomoo`0AOol0021o
o`80009oo`03001oogoo00Aoo`L000Moo`03001oogoo01eoob@00>eoo`8001=oo`0087oo00<007oo
Ool00Woo00<007ooOol01Goo0`002Goo00<007ooOol07Goo9000kWoo00<007ooOol04Goo000POol0
0`00Oomoo`03Ool00`00Oomoo`0>Ool2000POolT003^Ool00`00Oomoo`0AOol0021oo`03001oogoo
00Aoo`03001oogoo00aoo`03001oogoo021oob@00>ioo`03001oogoo015oo`0087oo00<007ooOol0
1Goo00<007ooOol02Woo00<007ooOol0ogoo=7oo00<007ooOol04Goo000POol00`00Oomoo`06Ool4
0006Ool2003oOolgOol00`00Oomoo`0AOol0021oo`8000]oo`H00?moocQoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`005Woo1@001Goo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000HOol00`00Oomoo`05Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol001Qoo`03001o
ogoo00Eoo`<00?moodMoo`<001=oo`0067oo00<007ooOol01Goo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000HOol00`00Oomoo`05Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol001Moo`8000Mo
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007ooOol04Goo
000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`0087oo00<0
07ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021o
o`03001oogoo0?moodUoo`03001oogoo015oo`005goo0`001Woo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000GOol00`00Oomoo`06Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol001Qoo`03001o
ogoo00Eoo`<00?moodMoo`<001=oo`0067oo00<007ooOol01Goo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000GOol00`00Ool00006Ool00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol001Qoo`03001o
ogoo00Eoo`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`00
87oo00<007ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0A
Ool0021oo`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`00
87oo00<007ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0A
Ool0021oo`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol0ogooBGoo00<007oo
Ool04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0AOol0021oo`800?moodUoo`8001=oo`00
87oo00<007ooOol0ogooBGoo00<007ooOol04Goo000POol00`00Oomoo`3oOom9Ool00`00Oomoo`0A
Ool0021oo`03001oogoo0?moodUoo`03001oogoo015oo`0087oo00<007ooOol037oo00<007ooOol0
>Goo00<007ooOol0>Goo00<007ooOol0>Woo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0
37oo00<007ooOol04Goo000POol01000Oomoo`002goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00@007ooOol001=oo`00
87ooo`00C@004goo0000\
\>"],
  ImageRangeCache->{{{0, 382}, {145, 0}} -> {-1.56221, -1.99687, 0.033158, 
  0.033158}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Nonholonomic Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SetPath[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["constraint",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " builds the differential equations necessary to find the time-domain \
motion of a nonholonomic system. The given velocity-dependent ",
  StyleBox["constraint",
    FontSlant->"Italic"],
  " replaces the kinematic constraints in the current mechanism that have the \
same constraint number. ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the new equations in a ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. \n\n",
  StyleBox["SolvePath[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["pathsys",
    FontSlant->"Italic"],
  ", ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds the solution to the nonholonomic system built by ",
  StyleBox["SetPath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " integrates the equations of motion from the initial time contained in ",
  StyleBox["pathsys",
    FontSlant->"Italic"],
  " or given with the ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option, to ",
  StyleBox["endtime",
    FontSlant->"Italic"],
  ". ",
  StyleBox["SolvePath",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " uses the same integration block that is used by ",
  StyleBox["SolveFree",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and accepts all of the same options."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The nonholonomic system solving functions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This builds the ",
  StyleBox["PathSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object. The second argument of the ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint is interpreted as a vector, in global coordinates, that is \
constrained to be orthogonal to the ",
  StyleBox["Vector",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " on the caster."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(psys = 
      SetPath[\n\t\t
        Orthogonal1[2, \n\t\t\tVelocity[caster, {2, 0}], 
          Vector[caster, {0, 1}]]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(PathSystem["<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The ",
  StyleBox["InitialCondition",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option is used to give the caster a nonzero initial angle. Otherwise, it \
is simply pushed along in front of the pivot indefinitely, instead of \
swinging around behind the pivot as expected."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = 
      SolvePath[psys, 10, InitialCondition \[Rule] \(Th2 \[Rule] 0.1\)]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"X2", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 10.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}], ",", \(Y2 \[Rule] 0\), ",",
         
        RowBox[{"Th2", "\[Rule]", 
          RowBox[{
            TagBox[\(InterpolatingFunction[{{0, 10.`}}, "<>"]\),
              False,
              Editable->False], "[", "T", "]"}]}]}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a plot of the caster angle as a function of time. Note that ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equal to the ",
  StyleBox["X",
    FontSlant->"Italic"],
  " coordinate of the caster."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Evaluate[Th2 /. sol], {T, 0, 10}, Frame \[Rule] True]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.204809 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.21429 -0.0125 -3 -9 ]
[.21429 -0.0125 3 0 ]
[.40476 -0.0125 -3 -9 ]
[.40476 -0.0125 3 0 ]
[.59524 -0.0125 -3 -9 ]
[.59524 -0.0125 3 0 ]
[.78571 -0.0125 -3 -9 ]
[.78571 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11712 -18 -4.5 ]
[-0.0125 .11712 0 4.5 ]
[-0.0125 .21952 -6 -4.5 ]
[-0.0125 .21952 0 4.5 ]
[-0.0125 .32193 -18 -4.5 ]
[-0.0125 .32193 0 4.5 ]
[-0.0125 .42433 -6 -4.5 ]
[-0.0125 .42433 0 4.5 ]
[-0.0125 .52674 -18 -4.5 ]
[-0.0125 .52674 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(4)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(6)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(8)] .78571 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.2619 0 m
.2619 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.5 0 m
.5 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.7381 0 m
.7381 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11712 m
.00625 .11712 L
s
[(0.5)] -0.0125 .11712 1 0 Mshowa
0 .21952 m
.00625 .21952 L
s
[(1)] -0.0125 .21952 1 0 Mshowa
0 .32193 m
.00625 .32193 L
s
[(1.5)] -0.0125 .32193 1 0 Mshowa
0 .42433 m
.00625 .42433 L
s
[(2)] -0.0125 .42433 1 0 Mshowa
0 .52674 m
.00625 .52674 L
s
[(2.5)] -0.0125 .52674 1 0 Mshowa
.125 Mabswid
0 .0352 m
.00375 .0352 L
s
0 .05568 m
.00375 .05568 L
s
0 .07616 m
.00375 .07616 L
s
0 .09664 m
.00375 .09664 L
s
0 .1376 m
.00375 .1376 L
s
0 .15808 m
.00375 .15808 L
s
0 .17856 m
.00375 .17856 L
s
0 .19904 m
.00375 .19904 L
s
0 .24001 m
.00375 .24001 L
s
0 .26049 m
.00375 .26049 L
s
0 .28097 m
.00375 .28097 L
s
0 .30145 m
.00375 .30145 L
s
0 .34241 m
.00375 .34241 L
s
0 .36289 m
.00375 .36289 L
s
0 .38337 m
.00375 .38337 L
s
0 .40385 m
.00375 .40385 L
s
0 .44481 m
.00375 .44481 L
s
0 .4653 m
.00375 .4653 L
s
0 .48578 m
.00375 .48578 L
s
0 .50626 m
.00375 .50626 L
s
0 .54722 m
.00375 .54722 L
s
0 .5677 m
.00375 .5677 L
s
0 .58818 m
.00375 .58818 L
s
0 .60866 m
.00375 .60866 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.21429 .61178 m
.21429 .61803 L
s
.40476 .61178 m
.40476 .61803 L
s
.59524 .61178 m
.59524 .61803 L
s
.78571 .61178 m
.78571 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.2619 .61428 m
.2619 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.7381 .61428 m
.7381 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .11712 m
1 .11712 L
s
.99375 .21952 m
1 .21952 L
s
.99375 .32193 m
1 .32193 L
s
.99375 .42433 m
1 .42433 L
s
.99375 .52674 m
1 .52674 L
s
.125 Mabswid
.99625 .0352 m
1 .0352 L
s
.99625 .05568 m
1 .05568 L
s
.99625 .07616 m
1 .07616 L
s
.99625 .09664 m
1 .09664 L
s
.99625 .1376 m
1 .1376 L
s
.99625 .15808 m
1 .15808 L
s
.99625 .17856 m
1 .17856 L
s
.99625 .19904 m
1 .19904 L
s
.99625 .24001 m
1 .24001 L
s
.99625 .26049 m
1 .26049 L
s
.99625 .28097 m
1 .28097 L
s
.99625 .30145 m
1 .30145 L
s
.99625 .34241 m
1 .34241 L
s
.99625 .36289 m
1 .36289 L
s
.99625 .38337 m
1 .38337 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .44481 m
1 .44481 L
s
.99625 .4653 m
1 .4653 L
s
.99625 .48578 m
1 .48578 L
s
.99625 .50626 m
1 .50626 L
s
.99625 .54722 m
1 .54722 L
s
.99625 .5677 m
1 .5677 L
s
.99625 .58818 m
1 .58818 L
s
.99625 .60866 m
1 .60866 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0352 m
.06244 .03979 L
.10458 .04598 L
.14415 .05316 L
.18221 .06159 L
.22272 .07257 L
.26171 .08547 L
.30316 .1022 L
.34309 .12177 L
.3815 .14426 L
.42237 .17254 L
.46172 .20418 L
.49955 .23854 L
.53984 .27869 L
.57861 .31961 L
.61984 .36384 L
.65954 .40528 L
.69774 .44258 L
.73838 .47842 L
.77751 .50863 L
.81909 .53606 L
.85916 .55822 L
.89771 .57599 L
.93871 .59159 L
.97619 .60332 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 173},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000[A000`40O003h00Oogoo6Goo003oOolI
Ool001Yoo`03001oogoo02eoo`<0031oo`<002eoo`80031oo`03001oogoo02Uoo`D0009oo`03001o
ogoo00=oo`006Goo00<007oo0000;Woo00<007ooOol0<Goo00<007ooOol0;7oo00<007oo0000;Woo
00<007oo0000;7oo00L007ooOomoo`00Ool00004Ool001Uoo`03001oo`0002moo`03001oogoo02io
o`@002eoo`03001oo`0002ioo`03001oo`0002aoo`07001oogooOol007oo000017oo000IOol00`00
Ool0000_Ool00`00Oomoo`0^Ool00`00Ool0000^Ool2000`Ool00`00Oomoo`0[Ool01`00Oomoogoo
001oo`0000Aoo`006Goo00<007oo0000;Woo00<007oo0000<7oo0P00;Woo00<007ooOol0;Woo00<0
07oo0000;7oo00L007ooOomoo`00Ool00004Ool001Yoo`03001oogoo02ioo`03001oogoo031oo`03
001oogoo02eoo`8002moo`03001oogoo02Yoo`8000Aoo`03001oogoo00=oo`00ogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo003oOolIOol001Eoool000<0005oo`005Goo00<007ooOol00goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Goo00<0
07ooOol00goo0@000Goo000?Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0^Ool00`00
Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool10001
Ool000ioo`03001oo`0000Aoo`03001oogoo0?ioo`40005oo`003Woo00<007oo000017oo0P00oWoo
0P000Goo000>Ool00`00Ool00004Ool00`00Oomoo`3nOol10001Ool000ioo`03001oo`0000Aoo`03
001oogoo0?ioo`40005oo`003goo00<007ooOol00goo00<007ooOol0oWoo0@000Goo000EOol00`00
Oomoo`3nOol10001Ool001Eoo`8000Aoo`D00?Eoo`80005oo`005Goo00<007ooOol027oo2000kWoo
0@000Goo000EOol00`00Oomoo`0@Ool6003XOol10001Ool001Eoo`03001oogoo01Ioo`D00>=oo`40
005oo`005Goo00<007ooOol06goo1@00gWoo0@000Goo000EOol2000QOol5003HOol20001Ool001Eo
o`03001oogoo02Eoo`D00=Aoo`40005oo`005Goo00<007ooOol0:Woo1000d7oo0@000Goo000EOol0
0`00Oomoo`0^Ool3003=Ool10001Ool001Eoo`03001oogoo035oo`@00<Uoo`40005oo`005Goo00<0
07ooOol0=Goo0`00aWoo0@000Goo000EOol2000iOol30032Ool20001Ool001Eoo`03001oogoo03]o
o`@00;moo`40005oo`005Goo00<007ooOol0?goo0`00_7oo0@000Goo000EOol00`00Oomoo`12Ool3
002iOol10001Ool001Eoo`03001oogoo04Eoo`800;Moo`40005oo`005Goo0P00B7oo0`00/goo0P00
0Goo000EOol00`00Oomoo`1:Ool2002bOol10001Ool001Eoo`03001oogoo04aoo`800;1oo`40005o
o`001Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0CWoo0P00[Woo
0@000Goo0004Ool00`00Ool00007Ool00`00Ool00004Ool00`00Oomoo`1@Ool2002/Ool10001Ool0
00Aoo`03001oo`0000Uoo`03001oogoo009oo`8005=oo`800:Uoo`80005oo`0017oo00<007oo0000
1goo0P001Goo00<007ooOol0E7oo0P00Z7oo0@000Goo0004Ool00`00Ool00007Ool00`00Oomoo`04
Ool00`00Oomoo`1FOol2002VOol10001Ool000Eoo`03001oogoo00Ioo`<000Aoo`03001oogoo05Qo
o`800:Aoo`40005oo`005Goo00<007ooOol0FWoo00<007ooOol0XGoo0@000Goo000EOol2001LOol2
002POol20001Ool001Eoo`03001oogoo05eoo`8009moo`40005oo`005Goo00<007ooOol0Ggoo00<0
07ooOol0W7oo0@000Goo000EOol00`00Oomoo`1POol2002LOol10001Ool001Eoo`03001oogoo069o
o`03001oogoo09Uoo`40005oo`005Goo00<007ooOol0Hgoo0P00VGoo0@000Goo000EOol2001VOol2
002FOol20001Ool001Eoo`03001oogoo06Moo`03001oogoo09Aoo`40005oo`005Goo00<007ooOol0
J7oo0P00U7oo0@000Goo000EOol00`00Oomoo`1ZOol00`00Oomoo`2AOol10001Ool001Eoo`03001o
ogoo06]oo`03001oogoo091oo`40005oo`005Goo0P00KGoo00<007ooOol0SWoo0P000Goo000EOol0
0`00Oomoo`1]Ool00`00Oomoo`2>Ool10001Ool001Eoo`03001oogoo06ioo`03001oogoo08eoo`40
005oo`005Goo00<007ooOol0Kgoo0P00SGoo0@000Goo000EOol00`00Oomoo`1aOol00`00Oomoo`2:
Ool10001Ool001Eoo`8007=oo`03001oogoo08Qoo`80005oo`005Goo00<007ooOol0Lgoo00<007oo
Ool0R7oo0@000Goo000EOol00`00Oomoo`1dOol00`00Oomoo`27Ool10001Ool001Eoo`03001oogoo
07Eoo`03001oogoo08Ioo`40005oo`003Goo1@000goo00<007ooOol0MWoo00<007ooOol0QGoo0@00
0Goo000?Ool00`00Oomoo`03Ool00`00Oomoo`1gOol00`00Oomoo`24Ool10001Ool000moo`03001o
ogoo00=oo`8007Uoo`8008=oo`80005oo`003goo00<007ooOol00goo00<007ooOol0NWoo00<007oo
Ool0PGoo0@000Goo000?Ool00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomoo`20Ool10001Ool0
00ioo`8000Eoo`03001oogoo07aoo`03001oogoo07moo`40005oo`005Goo00<007ooOol0OGoo00<0
07ooOol0OWoo0@000Goo000EOol2001oOol00`00Oomoo`1lOol20001Ool001Eoo`03001oogoo07mo
o`03001oogoo07aoo`40005oo`005Goo00<007ooOol0P7oo00<007ooOol0Ngoo0@000Goo000EOol0
0`00Oomoo`21Ool00`00Oomoo`1jOol10001Ool001Eoo`03001oogoo089oo`03001oogoo07Uoo`40
005oo`005Goo0P00Q7oo00<007ooOol0Mgoo0P000Goo000EOol00`00Oomoo`24Ool00`00Oomoo`1g
Ool10001Ool001Eoo`03001oogoo08Eoo`03001oogoo07Ioo`40005oo`005Goo00<007ooOol0QWoo
00<007ooOol0MGoo0@000Goo000EOol00`00Oomoo`27Ool00`00Oomoo`1dOol10001Ool001Eoo`80
08Uoo`03001oogoo079oo`80005oo`005Goo00<007ooOol0RGoo00<007ooOol0LWoo0@000Goo000E
Ool00`00Oomoo`2:Ool00`00Oomoo`1aOol10001Ool001Eoo`03001oogoo08]oo`03001oogoo071o
o`40005oo`005Goo00<007ooOol0S7oo00<007ooOol0Kgoo0@000Goo000EOol00`00Oomoo`2=Ool0
0`00Oomoo`1^Ool10001Ool001Eoo`8008moo`03001oogoo06aoo`80005oo`005Goo00<007ooOol0
Sgoo00<007ooOol0K7oo0@000Goo000EOol00`00Oomoo`2@Ool00`00Oomoo`1[Ool10001Ool000=o
o`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo095oo`03001oogoo06Yoo`40005o
o`001Goo00<007ooOol01Woo00<007oo000017oo00<007ooOol0TWoo00<007ooOol0JGoo0@000Goo
0005Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2002DOol00`00Oomoo`1WOol20001Ool000Eoo`03
001oogoo00Ioo`8000Eoo`03001oogoo09Aoo`03001oogoo06Moo`40005oo`001Goo00<007ooOol0
1Woo00<007ooOol017oo00<007ooOol0U7oo00<007ooOol0Igoo0@000Goo0004Ool20008Ool30004
Ool00`00Oomoo`2EOol00`00Oomoo`1VOol10001Ool001Eoo`03001oogoo09Ioo`03001oogoo06Eo
o`40005oo`005Goo0P00V7oo00<007ooOol0Hgoo0P000Goo000EOol00`00Oomoo`2HOol00`00Oomo
o`1SOol10001Ool001Eoo`03001oogoo09Uoo`03001oogoo069oo`40005oo`005Goo00<007ooOol0
VGoo00<007ooOol0HWoo0@000Goo000EOol00`00Oomoo`2JOol00`00Oomoo`1QOol10001Ool001Eo
o`8009aoo`03001oogoo05moo`80005oo`005Goo00<007ooOol0W7oo00<007ooOol0Ggoo0@000Goo
000EOol00`00Oomoo`2MOol00`00Oomoo`1NOol10001Ool001Eoo`03001oogoo09ioo`03001oogoo
05eoo`40005oo`005Goo00<007ooOol0Wgoo00<007ooOol0G7oo0@000Goo000EOol00`00Oomoo`2P
Ool00`00Oomoo`1KOol10001Ool001Eoo`800:9oo`8005Yoo`80005oo`005Goo00<007ooOol0Xgoo
00<007ooOol0F7oo0@000Goo000EOol00`00Oomoo`2TOol00`00Oomoo`1GOol10001Ool001Eoo`03
001oogoo0:Eoo`03001oogoo05Ioo`40005oo`005Goo00<007ooOol0YWoo00<007ooOol0EGoo0@00
0Goo000EOol2002XOol00`00Oomoo`1COol20001Ool001Eoo`03001oogoo0:Qoo`03001oogoo05=o
o`40005oo`005Goo00<007ooOol0ZGoo00<007ooOol0DWoo0@000Goo000>Ool30004Ool00`00Oomo
o`2ZOol00`00Oomoo`1AOol10001Ool000ioo`03001oogoo00Aoo`03001oogoo0:]oo`03001oogoo
051oo`40005oo`003goo00<007ooOol00goo0P00[7oo00<007ooOol0Cgoo0P000Goo000?Ool00`00
Oomoo`03Ool00`00Oomoo`2/Ool00`00Oomoo`1?Ool10001Ool000ioo`03001oo`0000Aoo`03001o
ogoo0:eoo`03001oogoo04ioo`40005oo`003goo00<007ooOol00goo00<007ooOol0[Woo00<007oo
Ool0CGoo0@000Goo000EOol00`00Oomoo`2_Ool00`00Oomoo`1<Ool10001Ool001Eoo`03001oogoo
0;1oo`03001oogoo04]oo`40005oo`005Goo0P00/Woo00<007ooOol0BGoo0P000Goo000EOol00`00
Oomoo`2bOol2001:Ool10001Ool001Eoo`03001oogoo0;Aoo`03001oogoo04Moo`40005oo`005Goo
00<007ooOol0]Goo00<007ooOol0AWoo0@000Goo000EOol00`00Oomoo`2fOol00`00Oomoo`15Ool1
0001Ool001Eoo`800;Qoo`03001oogoo04=oo`80005oo`005Goo00<007ooOol0^7oo0P00A7oo0@00
0Goo000EOol00`00Oomoo`2jOol00`00Oomoo`11Ool10001Ool001Eoo`03001oogoo0;]oo`03001o
ogoo041oo`40005oo`005Goo00<007ooOol0_7oo00<007ooOol0?goo0@000Goo000EOol2002nOol2
000nOol20001Ool001Eoo`03001oogoo0;moo`03001oogoo03aoo`40005oo`005Goo00<007ooOol0
`7oo00<007ooOol0>goo0@000Goo000EOol00`00Oomoo`31Ool00`00Oomoo`0jOol10001Ool001Eo
o`03001oogoo0<9oo`8003Yoo`40005oo`005Goo0P00aGoo00<007ooOol0=Woo0P000Goo000EOol0
0`00Oomoo`35Ool00`00Oomoo`0fOol10001Ool001Eoo`03001oogoo0<Ioo`8003Ioo`40005oo`00
5Goo00<007ooOol0b7oo00<007ooOol0<goo0@000Goo0004Ool30003Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`39Ool2000cOol10001Ool000Aoo`03001oogoo00Moo`03001oo`0000Ao
o`03001oogoo0<]oo`80035oo`40005oo`001Goo00<007ooOol027oo00<007ooOol00Woo0P00cWoo
00<007ooOol0;Goo0P000Goo0005Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`3>Ool2000^Ool1
0001Ool000Aoo`03001oo`0000Moo`03001oogoo00Aoo`03001oogoo0=1oo`03001oogoo02]oo`40
005oo`001Goo00<007ooOol01Woo0`0017oo00<007ooOol0dGoo0P00:goo0@000Goo000EOol00`00
Oomoo`3COol2000YOol10001Ool001Eoo`800=Ioo`03001oogoo02Eoo`80005oo`005Goo00<007oo
Ool0eWoo0P009Woo0@000Goo000EOol00`00Oomoo`3HOol2000TOol10001Ool001Eoo`03001oogoo
0=Yoo`80029oo`40005oo`005Goo00<007ooOol0g7oo0P0087oo0@000Goo000EOol2003OOol3000L
Ool20001Ool001Eoo`03001oogoo0>5oo`8001]oo`40005oo`005Goo00<007ooOol0hgoo0`0067oo
0@000Goo000EOol00`00Oomoo`3VOol3000EOol10001Ool001Eoo`03001oogoo0>Uoo`8001=oo`40
005oo`005Goo00<007ooOol0jgoo0`0047oo0@000Goo000EOol2003_Ool3000<Ool20001Ool001Eo
o`03001oogoo0?5oo`<000Yoo`40005oo`005Goo00<007ooOol0m7oo0`001goo0@000Goo000EOol0
0`00Oomoo`3gOol20005Ool10001Ool001Eoo`03001oogoo0?ioo`40005oo`005Goo0P00oWoo0P00
0Goo000EOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`03Ool10001Ool001Eoool000<0005oo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {172, 0}} -> {-1.11485, -0.308577, 0.0407527, 
  0.0189504}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a graphic of the caster at five positions between ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 1 and ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 10."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .38182 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0909091 0.127273 0.0909091 [
[(0)] .04545 0 0 2 Msboxa
[(2)] .22727 0 0 2 Msboxa
[(4)] .40909 0 0 2 Msboxa
[(6)] .59091 0 0 2 Msboxa
[(8)] .77273 0 0 2 Msboxa
[(10)] .95455 0 0 2 Msboxa
[(-1)] -0.0125 .03636 1 0 Msboxa
[(0)] -0.0125 .12727 1 0 Msboxa
[(1)] -0.0125 .21818 1 0 Msboxa
[(2)] -0.0125 .30909 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .38282 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.04545 0 m
.04545 .00625 L
s
P
[(0)] .04545 0 0 2 Mshowa
p
.002 w
.22727 0 m
.22727 .00625 L
s
P
[(2)] .22727 0 0 2 Mshowa
p
.002 w
.40909 0 m
.40909 .00625 L
s
P
[(4)] .40909 0 0 2 Mshowa
p
.002 w
.59091 0 m
.59091 .00625 L
s
P
[(6)] .59091 0 0 2 Mshowa
p
.002 w
.77273 0 m
.77273 .00625 L
s
P
[(8)] .77273 0 0 2 Mshowa
p
.002 w
.95455 0 m
.95455 .00625 L
s
P
[(10)] .95455 0 0 2 Mshowa
p
.001 w
.08182 0 m
.08182 .00375 L
s
P
p
.001 w
.11818 0 m
.11818 .00375 L
s
P
p
.001 w
.15455 0 m
.15455 .00375 L
s
P
p
.001 w
.19091 0 m
.19091 .00375 L
s
P
p
.001 w
.26364 0 m
.26364 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.33636 0 m
.33636 .00375 L
s
P
p
.001 w
.37273 0 m
.37273 .00375 L
s
P
p
.001 w
.44545 0 m
.44545 .00375 L
s
P
p
.001 w
.48182 0 m
.48182 .00375 L
s
P
p
.001 w
.51818 0 m
.51818 .00375 L
s
P
p
.001 w
.55455 0 m
.55455 .00375 L
s
P
p
.001 w
.62727 0 m
.62727 .00375 L
s
P
p
.001 w
.66364 0 m
.66364 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.73636 0 m
.73636 .00375 L
s
P
p
.001 w
.80909 0 m
.80909 .00375 L
s
P
p
.001 w
.84545 0 m
.84545 .00375 L
s
P
p
.001 w
.88182 0 m
.88182 .00375 L
s
P
p
.001 w
.91818 0 m
.91818 .00375 L
s
P
p
.001 w
.00909 0 m
.00909 .00375 L
s
P
p
.001 w
.99091 0 m
.99091 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .03636 m
.00625 .03636 L
s
P
[(-1)] -0.0125 .03636 1 0 Mshowa
p
.002 w
0 .12727 m
.00625 .12727 L
s
P
[(0)] -0.0125 .12727 1 0 Mshowa
p
.002 w
0 .21818 m
.00625 .21818 L
s
P
[(1)] -0.0125 .21818 1 0 Mshowa
p
.002 w
0 .30909 m
.00625 .30909 L
s
P
[(2)] -0.0125 .30909 1 0 Mshowa
p
.001 w
0 .05455 m
.00375 .05455 L
s
P
p
.001 w
0 .07273 m
.00375 .07273 L
s
P
p
.001 w
0 .09091 m
.00375 .09091 L
s
P
p
.001 w
0 .10909 m
.00375 .10909 L
s
P
p
.001 w
0 .14545 m
.00375 .14545 L
s
P
p
.001 w
0 .16364 m
.00375 .16364 L
s
P
p
.001 w
0 .18182 m
.00375 .18182 L
s
P
p
.001 w
0 .2 m
.00375 .2 L
s
P
p
.001 w
0 .23636 m
.00375 .23636 L
s
P
p
.001 w
0 .25455 m
.00375 .25455 L
s
P
p
.001 w
0 .27273 m
.00375 .27273 L
s
P
p
.001 w
0 .29091 m
.00375 .29091 L
s
P
p
.001 w
0 .01818 m
.00375 .01818 L
s
P
p
.001 w
0 .32727 m
.00375 .32727 L
s
P
p
.001 w
0 .34545 m
.00375 .34545 L
s
P
p
.001 w
0 .36364 m
.00375 .36364 L
s
P
p
.002 w
0 0 m
0 .38182 L
s
P
P
p
p
.002 w
.04545 .37557 m
.04545 .38182 L
s
P
p
.002 w
.22727 .37557 m
.22727 .38182 L
s
P
p
.002 w
.40909 .37557 m
.40909 .38182 L
s
P
p
.002 w
.59091 .37557 m
.59091 .38182 L
s
P
p
.002 w
.77273 .37557 m
.77273 .38182 L
s
P
p
.002 w
.95455 .37557 m
.95455 .38182 L
s
P
p
.001 w
.08182 .37807 m
.08182 .38182 L
s
P
p
.001 w
.11818 .37807 m
.11818 .38182 L
s
P
p
.001 w
.15455 .37807 m
.15455 .38182 L
s
P
p
.001 w
.19091 .37807 m
.19091 .38182 L
s
P
p
.001 w
.26364 .37807 m
.26364 .38182 L
s
P
p
.001 w
.3 .37807 m
.3 .38182 L
s
P
p
.001 w
.33636 .37807 m
.33636 .38182 L
s
P
p
.001 w
.37273 .37807 m
.37273 .38182 L
s
P
p
.001 w
.44545 .37807 m
.44545 .38182 L
s
P
p
.001 w
.48182 .37807 m
.48182 .38182 L
s
P
p
.001 w
.51818 .37807 m
.51818 .38182 L
s
P
p
.001 w
.55455 .37807 m
.55455 .38182 L
s
P
p
.001 w
.62727 .37807 m
.62727 .38182 L
s
P
p
.001 w
.66364 .37807 m
.66364 .38182 L
s
P
p
.001 w
.7 .37807 m
.7 .38182 L
s
P
p
.001 w
.73636 .37807 m
.73636 .38182 L
s
P
p
.001 w
.80909 .37807 m
.80909 .38182 L
s
P
p
.001 w
.84545 .37807 m
.84545 .38182 L
s
P
p
.001 w
.88182 .37807 m
.88182 .38182 L
s
P
p
.001 w
.91818 .37807 m
.91818 .38182 L
s
P
p
.001 w
.00909 .37807 m
.00909 .38182 L
s
P
p
.001 w
.99091 .37807 m
.99091 .38182 L
s
P
p
.002 w
0 .38182 m
1 .38182 L
s
P
p
.002 w
.99375 .03636 m
1 .03636 L
s
P
p
.002 w
.99375 .12727 m
1 .12727 L
s
P
p
.002 w
.99375 .21818 m
1 .21818 L
s
P
p
.002 w
.99375 .30909 m
1 .30909 L
s
P
p
.001 w
.99625 .05455 m
1 .05455 L
s
P
p
.001 w
.99625 .07273 m
1 .07273 L
s
P
p
.001 w
.99625 .09091 m
1 .09091 L
s
P
p
.001 w
.99625 .10909 m
1 .10909 L
s
P
p
.001 w
.99625 .14545 m
1 .14545 L
s
P
p
.001 w
.99625 .16364 m
1 .16364 L
s
P
p
.001 w
.99625 .18182 m
1 .18182 L
s
P
p
.001 w
.99625 .2 m
1 .2 L
s
P
p
.001 w
.99625 .23636 m
1 .23636 L
s
P
p
.001 w
.99625 .25455 m
1 .25455 L
s
P
p
.001 w
.99625 .27273 m
1 .27273 L
s
P
p
.001 w
.99625 .29091 m
1 .29091 L
s
P
p
.001 w
.99625 .01818 m
1 .01818 L
s
P
p
.001 w
.99625 .32727 m
1 .32727 L
s
P
p
.001 w
.99625 .34545 m
1 .34545 L
s
P
p
.001 w
.99625 .36364 m
1 .36364 L
s
P
p
.002 w
1 0 m
1 .38182 L
s
P
P
p
P
0 0 m
1 0 L
1 .38182 L
0 .38182 L
closepath
clip
newpath
p
p
.05 w
.04545 .12727 Mdot
p
.004 w
.04545 .12727 m
.22636 .14542 L
s
P
.16937 .16712 m
.17481 .11284 L
.28336 .12373 L
.27791 .17801 L
F
.004 w
newpath
.04545 .12727 .03636 0 365.73 arc
s
p
.13636 .03636 m
.31818 .03636 L
s
.29247 .01065 m
.31818 .03636 L
.29247 .06208 L
s
P
P
p
.05 w
.27273 .12727 Mdot
p
.004 w
.27273 .12727 m
.44378 .1889 L
s
P
.38322 .19607 m
.40171 .14476 L
.50434 .18173 L
.48585 .23305 L
F
.004 w
newpath
.27273 .12727 .03636 0 365.73 arc
s
p
.36364 .03636 m
.54545 .03636 L
s
.51974 .01065 m
.54545 .03636 L
.51974 .06208 L
s
P
P
p
.05 w
.5 .12727 Mdot
p
.004 w
.5 .12727 m
.58322 .28893 L
s
P
.53401 .25291 m
.5825 .22795 L
.63244 .32494 L
.58394 .3499 L
F
.004 w
newpath
.5 .12727 .03636 0 365.73 arc
s
p
.59091 .03636 m
.77273 .03636 L
s
.74701 .01065 m
.77273 .03636 L
.74701 .06208 L
s
P
P
p
.05 w
.72727 .12727 Mdot
p
.004 w
.72727 .12727 m
.6112 .26722 L
s
P
.62503 .20782 m
.66701 .24265 L
.59737 .32661 L
.55539 .29179 L
F
.004 w
newpath
.72727 .12727 .03636 0 365.73 arc
s
p
.81818 .03636 m
0 0 rlineto
1 .03636 m
.81818 .03636 L
s
s
.97429 .01065 m
0 0 rlineto
1 .03636 m
.97429 .01065 L
s
1 .03636 m
.97429 .06208 L
s
.97429 .06208 m
0 0 rlineto
P
P
p
.05 w
.95455 .12727 Mdot
p
.004 w
.95455 .12727 m
.77919 .17531 L
s
P
.82459 .1346 m
.839 .1872 L
.73379 .21603 L
.71938 .16342 L
F
.004 w
newpath
.95455 .12727 .03636 0 365.73 arc
s
p
s
s
s
s
s
s
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{400, 152},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0000V1000`40O003h00OogooTGoo003oOonA
Ool00?mooi5oo`00ogooTGoo000`Ool00`00Oomoo`0kOol3000mOol3000kOol2000nOol00`00Oomo
o`0hOol50002Ool00`00Oomoo`0OOol002moo`03001oo`0003aoo`03001oogoo03ioo`03001oogoo
03Yoo`03001oo`0003aoo`03001oo`0003]oo`07001oogooOol007oo000087oo000_Ool00`00Ool0
000mOol00`00Oomoo`0kOol4000kOol00`00Ool0000lOol00`00Ool0000kOol01`00Oomoogoo001o
o`00021oo`00;goo00<007oo0000?Goo00<007ooOol0>goo00<007oo0000?7oo0P00?Woo00<007oo
Ool0>Woo00L007ooOomoo`00Ool0000POol002moo`03001oo`0003aoo`03001oo`0003eoo`8003ao
o`03001oogoo03aoo`03001oo`0003]oo`07001oogooOol007oo000087oo000`Ool00`00Oomoo`0l
Ool00`00Oomoo`0mOol00`00Oomoo`0kOol2000mOol00`00Oomoo`0iOol20004Ool00`00Oomoo`0O
Ool00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00ogooTGoo003oOonAOol00?mooi5oo`00
ogooTGoo000POooo001N000COol0021oo`04001oogoo000<Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool01000Oomoo`00
4goo000POol01000Oomoo`0037oo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02Woo00<007ooOol02Woo00@007ooOol001=oo`0087oo00<007ooOol0
3Goo00<007ooOol0?7oo00<007ooOol0?7oo00<007ooOol0?Goo00<007ooOol0?7oo00<007ooOol0
?7oo00<007ooOol017oo00<007ooOol01Woo00<007ooOol04Goo000POol00`00Oomoo`1SOol00`00
Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`06Ool00`00Oomoo`0AOol0021o
o`03001oogoo06Aoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo00Eo
o`03001oogoo015oo`0087oo00<007ooOol0IGoo00<007ooOol0C7oo00<007ooOol0C7oo00<007oo
Ool0C7oo00<007ooOol017oo00<007ooOol04Goo000POol3001VOol00`00Oomoo`1<Ool00`00Oomo
o`1<Ool00`00Oomoo`1<Ool01000Oomoogoo0`004goo000POol00`00Oomoo`1WOol00`00Oomoo`1<
Ool00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0021oo`03001o
ogoo06Qoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo04aoo`05001oogooOol0000COol0
021oo`03001oogoo06Uoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo04aoo`04001oogoo
000COol001Moo`D000Aoo`03001oogoo06Yoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo
04aoo`03001oo`0001=oo`006Goo00<007ooOol017oo00<007ooOol0Jgoo00<007ooOol0C7oo00<0
07ooOol0C7oo00<007ooOol03Goo00<007ooOol0?7oo0P004goo000COol30003Ool00`00Oomoo`04
Ool3000]Oom0000?Oom0000?Oom0000?Oom0000COol001Uoo`03001oogoo00Aoo`03001oogoo06]o
o`03001oogoo04aoo`03001oogoo04aoo`03001oogoo04aoo`8001=oo`006Goo00<007ooOol017oo
00<007ooOol0JWoo00<007ooOol0C7oo00<007ooOol0C7oo00<007ooOol0C7oo00<007oo00004goo
000HOol20006Ool00`00Oomoo`1YOol00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`1<Ool0
1000Oomoo`004goo000POol00`00Oomoo`1XOol00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomo
o`1<Ool01@00Oomoogoo00004goo000POol00`00Oomoo`1WOol00`00Oomoo`1<Ool00`00Oomoo`1<
Ool00`00Oomoo`1<Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0021oo`<006Ioo`03001oogoo04ao
o`03001oogoo04aoo`03001oogoo04aoo`04001oogooOol3000COol0021oo`03001oogoo06Eoo`03
001oogoo04aoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo00Aoo`03001oogoo015oo`00
87oo00<007ooOol0I7oo00<007ooOol0C7oo00<007ooOol0C7oo00<007ooOol0C7oo00<007ooOol0
1Goo00<007ooOol04Goo000POol00`00Oomoo`1SOol00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00
Oomoo`1<Ool00`00Oomoo`06Ool00`00Oomoo`0AOol0021oo`03001oogoo0?mooeYoo`03001oogoo
015oo`0087oo00<007ooOol0ogooFWoo00<007ooOol04Goo000POol00`00Oomoo`3oOomJOol00`00
Oomoo`0AOol0021oo`<00?mooeQoo`<001=oo`0087oo00<007ooOol0ogooFWoo00<007ooOol04Goo
000POol00`00Oomoo`3oOomJOol00`00Oomoo`0AOol0021oo`03001oogoo0?mooeYoo`03001oogoo
015oo`0087oo00<007ooOol0ogooFWoo00<007ooOol04Goo000POol00`00Oomoo`3oOomJOol00`00
Oomoo`0AOol0021oo`<000]oo`D004Yoo`@004]oo`@004]oo`@004]oo`@000aoo`<001=oo`0087oo
00<007ooOol02Goo0P001Goo1000A7oo0P0017oo1@00A7oo0P0017oo1@00A7oo0P0017oo1@00A7oo
0P0017oo1@002Goo00<007ooOol04Goo000POol00`00Oomoo`07Ool2000;Ool00`00Oomoo`0oOol2
000;Ool00`00Oomoo`0oOol2000;Ool00`00Oomoo`0oOol2000;Ool00`00Oomoo`0oOol2000;Ool0
0`00Oomoo`06Ool00`00Oomoo`0AOol0021oo`03001oogoo00Eoo`8000ioo`03001oogoo03aoo`80
00ioo`03001oogoo03aoo`8000ioo`03001oogoo03aoo`8000ioo`03001oogoo03aoo`8000ioo`03
001oogoo00Eoo`03001oogoo015oo`0087oo00<007ooOol017oo00<007ooOol03goo00<007ooOol0
>Woo00<007ooOol03goo00<007ooOol0>Woo00<007ooOol03goo00<007ooOol0>Woo00<007ooOol0
3goo00<007ooOol0>Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol04Goo000POol00`00
Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`0hOol00`00Oomoo`0AOol00`00Oomoo`0hOol00`00
Oomoo`0AOol00`00Oomoo`0hOol00`00Oomoo`0AOol00`00Oomoo`0hOol00`00Oomoo`0AOol00`00
Oomoo`03Ool00`00Oomoo`0AOol0021oo`<0009oo`03001oogoo00Moo`8000Uoo`03001oogoo03Mo
o`03001oogoo00Moo`8000Uoo`03001oogoo03Moo`03001oogoo00Moo`8000Uoo`03001oogoo03Mo
o`03001oogoo00Moo`8000Uoo`03001oogoo03Moo`03001oogoo00Moo`8000Uoo`04001oogooOol3
000COol0021oo`03001oogoo009oo`03001oogoo00Aoo`P000Moo`03001oogoo03Ioo`03001oogoo
00Aoo`P000Moo`03001oogoo03Ioo`03001oogoo00Aoo`P000Moo`03001oogoo03Ioo`03001oogoo
00Aoo`P000Moo`03001oogoo03Ioo`03001oogoo00Aoo`P000Moo`03001oogoo009oo`03001oogoo
015oo`0087oo00<007ooOol00Woo00<007ooOol00Woo2`001Woo00<007ooOol0=Woo00<007ooOol0
0Woo2`001Woo00<007ooOol0=Woo00<007ooOol00Woo2`001Woo00<007ooOol0=Woo00<007ooOol0
0Woo2`001Woo00<007ooOol0=Woo00<007ooOol00Woo2`001Woo00<007ooOol00Woo00<007ooOol0
4Goo000POol01@00Oomoogoo00001Goo30001Woo00<007ooOol07Woo3@002Goo00<007ooOol00goo
30001Woo00<007ooOol0=7oo00<007ooOol00goo30001Woo00<007ooOol0=7oo00<007ooOol00goo
30001Woo00<007ooOol0=7oo00<007ooOol00goo30001Woo00D007ooOomoo`0001=oo`0087oo00D0
07ooOomoo`0000Aoo`h000Eoo`03001oogoo01iooaX00003Ool0000000`000Eoo`03001oogoo03Ao
o`03001oogoo009oo`h000Eoo`03001oogoo03Aoo`03001oogoo009oo`h000Eoo`03001oogoo03Ao
o`03001oogoo009oo`h000Eoo`05001oogooOol0000COol001Uoo`03001oogoo00Aoo`04001oogoo
0005Ool>0006Ool00`00Oomoo`0MOolY0006Ool00`00Oomoo`0bOol00`00Oomoo`03Ool>0006Ool0
0`00Oomoo`0bOol00`00Oomoo`03Ool>0006Ool00`00Oomoo`0bOol00`00Oomoo`03Ool>0005Ool0
1@00Oomoogoo00004goo000HOol00`00Ool00005Ool01000Oomoo`001Goo3P001Woo00<007ooOol0
7Goo:@001Woo00<007ooOol0<Woo00<007ooOol00goo3P001Woo00<007ooOol0<Woo00<007ooOol0
0goo3P001Woo00<007ooOol0<Woo00<007ooOol00goo3P001Goo00D007ooOomoo`0001=oo`0067oo
00<007oo00001Goo100017oo40001Goo00<007ooOol07Goo:P001Goo00<007ooOol0<Woo00<007oo
Ool00Woo40001Goo00<007ooOol0<Woo00<007ooOol00Woo40001Goo00<007ooOol0<Woo00<007oo
Ool00Woo400017oo1@004goo000HOol00`00Ool00005Ool01@00Oomoogoo00000goo60007Goo:P00
17oo0P00=Goo00@007ooOomooa0000Aoo`8003Aoo`03001oogoo009ooa0000Aoo`8003Aoo`03001o
ogoo009ooa0000Aoo`05001oogooOol0000COol001Qoo`03001oo`0000Eoo`05001oogooOol00004
Ool>0005Ool01000Oomoogoo2`004Woo:P0017oo00<007ooOol0=7oo00<007ooOol00Woo3P001Goo
00<007ooOol0<goo00<007ooOol00goo3P001Goo00<007ooOol0<goo00@007ooOomooa0000Eoo`05
001oogooOol0000COol001Uoo`03001oogoo00Aoo`05001oogooOol00004Ool>0005Ool00`00Oomo
o`0<Ool:0008OolY00000goo00000002Ool00`00Oomoo`0dOol00`00Oomoo`02Ool>0005Ool00`00
Oomoo`0cOol00`00Oomoo`03Ool>0005Ool00`00Oomoo`0@Ool4000OOol40002Ool>0005Ool01@00
Oomoogoo00004goo000POol01@00Oomoogoo000017oo3P001Goo00<007ooOol05Woo<@000goo0`00
=Woo00<007ooOol00Woo3P001Goo00<007ooOol0=7oo00<007ooOol00Woo3P001Goo00<007ooOol0
37oo20006goo100000=oo`00Ool00goo3P001Goo00D007ooOomoo`0001=oo`0087oo00D007ooOomo
o`0000Eoo``000Ioo`03001oogoo01eoobT000Ioo`@003=oo`03001oogoo00=oo``000Ioo`03001o
ogoo03Aoo`03001oogoo00=oo``000Ioo`03001oogoo00Qoo``001Qoo`<000Eoo`03001oogoo00=o
o``000Ioo`05001oogooOol0000COol0021oo`<0009oo`03001oogoo00=oo`X000Ioo`03001oogoo
01ioobP000Ioo`03001oogoo009oo`<0035oo`03001oogoo00=oo`X000Ioo`03001oogoo03Ioo`03
001oogoo00=oo`X000Ioo`03001oogoo00Iooa0001=oo`@000Uoo`03001oogoo00=oo`X000Ioo`03
001oogoo00<001=oo`0087oo00<007ooOol00goo00<007ooOol00goo20001goo00<007ooOol07Woo
9`001Woo00<007ooOol01Woo0`005goo0`005Goo00<007ooOol00goo2@001Goo00<007ooOol0>7oo
00H007ooOomoo`00Ool80006Ool00`00Oomoo`03OolD000?Ool4000>Ool00`00Oomoo`03Ool80006
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol0021oo`03001oogoo00Aoo`03001oogoo00Eoo`8000Uo
o`03001oogoo01moobH000Ioo`03001oogoo00Yoo`8001Eoo`H001=oo`03001oogoo00Eoo`8000=o
o`03001oogoo009oo`03001oogoo03Yoo`03001oo`0000Eoo`8000Qoo`03001oogoo01P000]oo`@0
01=oo`03001oogoo00Eoo`8000Qoo`03001oogoo00Aoo`03001oogoo015oo`0087oo00<007ooOol0
1Goo00<007ooOol03Woo00<007ooOol087oo9P001Woo00<007ooOol037oo0`004Goo2P004Goo00<0
07ooOol02Woo00D007ooOomoo`0003eoo`03001oogoo00iooa/000Moo`@001Qoo`03001oogoo00io
o`03001oogoo00Aoo`03001oogoo015oo`0087oo00<007ooOol01Woo00<007ooOol02goo0P008goo
9P0017oo0P004Woo0`003Woo3@003goo00<007ooOol02Goo00@007oo000003ioo`8000]oob00009o
o`@001eoo`03001oogoo00]oo`8000Moo`03001oogoo015oo`0087oo00<007ooOol01goo0P0027oo
0`009Goo9P0000Aoo`00000001Moo`<000]oo`l000ioo`8000Qoo`<003moo`03001oogoo008000Eo
obH0029oo`8000Qoo`<000Uoo`03001oogoo015oo`0087oo0`002Goo2000:7oo9`007Goo0`001goo
4`003Goo20000Woo00<007ooOol0?7oo00<007ooOol00goo:@009Woo20002Woo0`004goo000POol0
0`00Oomoo`0iOolV000QOol20005OolF000EOol00`00Oomoo`0jOol00`00Oomoo`06OolW000jOol0
0`00Oomoo`0AOol0021oo`03001oogoo03QoobL002=oo`<00003Ool0000001P0019oo`03001oogoo
03Uoo`03001oogoo00MoobP003Uoo`03001oogoo015oo`0087oo00<007ooOol0AGoo6P009Woo7@00
4Goo00<007ooOol0=goo00<007ooOol027oo:000>Goo00<007ooOol04Goo000POol00`00Oomoo`1B
Ool=000WOolO000>Ool00`00Oomoo`0gOol00`00Oomoo`09OolW000iOol00`00Oomoo`0AOol0021o
o`03001oogoo08Eoob<000aoo`03001oogoo03Eoo`03001oogoo00YoobL003Uoo`03001oogoo015o
o`0087oo00<007ooOol0QGoo9P002Goo00<007ooOol0=7oo00<007ooOol02goo:000>7oo00<007oo
Ool04Goo000POol30024OolY0008Ool00`00Oomoo`0bOol00`00Oomoo`0<OolX000fOol3000COol0
021oo`03001oogoo08AoobT000Qoo`03001oogoo035oo`03001oogoo00ioobL003Qoo`03001oogoo
015oo`0087oo00<007ooOol0Q7oo:@002Goo00<007ooOol0;goo00<007ooOol03goo9`00>7oo00<0
07ooOol04Goo000POol00`00Oomoo`23OolY000:Ool00`00Oomoo`0_Ool00`00Oomoo`0?OolT000k
Ool00`00Oomoo`0AOol0021oo`03001oogoo08=oobT000]oo`03001oogoo02eoo`03001oogoo011o
ob0003moo`03001oogoo015oo`0087oo00<007ooOol0PWoo:@0037oo00<007ooOol0;7oo00<007oo
Ool04Woo6`00@goo00<007ooOol04Goo000POol30025OolV000=Ool00`00Oomoo`0ZOol00`00Oomo
o`0COolH0014Ool3000COol0021oo`03001oogoo08Qoob<000eoo`03001oogoo02Uoo`03001oogoo
01Aooa@004Yoo`03001oogoo015oo`0087oo00<007ooOol0Rgoo7`003goo00<007ooOol09goo00<0
07ooOol05Goo4000CWoo00<007ooOol04Goo000POol00`00Oomoo`2>OolL000?Ool00`00Oomoo`0W
Ool00`00Oomoo`0FOol<001AOol00`00Oomoo`0AOol001Moo`D000Aoo`03001oogoo095ooaP0015o
o`03001oogoo01Uoo`8000Yoo`03001oogoo01Moo`P005Eoo`03001oogoo015oo`006Goo00<007oo
Ool017oo00<007ooOol0U7oo5@004Woo00<007ooOol05goo100027oo00<007ooOol067oo1000FGoo
00<007ooOol04Goo000IOol00`00Oomoo`04Ool3002GOolB000BOol00`00Oomoo`0FOol60006Ool0
0`00Oomoo`1dOol3000COol001Uoo`03001oogoo00Aoo`03001oogoo09Yoo`h001Aoo`03001oogoo
01Aoo`P000Aoo`03001oogoo07Moo`03001oogoo015oo`006Goo00<007ooOol017oo00<007ooOol0
WGoo2`0057oo00<007ooOol04goo2`0000=oo`00Ool0NGoo00<007ooOol04Goo000HOol20006Ool0
0`00Oomoo`2POol7000FOol00`00Oomoo`0BOol=001jOol00`00Oomoo`0AOol0021oo`03001oogoo
0:=oo`@001Ioo`03001oogoo015oo`h007Yoo`03001oogoo015oo`0087oo00<007ooOol0_Woo00<0
07ooOol01Goo0`001goo4000NGoo00<007ooOol04Goo000POol00`00Oomoo`2nOol00`00Oomoo`03
Ool60005OolC001gOol00`00Oomoo`0AOol0021oo`<00;moo`03001oogoo00P000AooaD007Aoo`<0
01=oo`0087oo00<007ooOol0_goo30000Woo5`00MGoo00<007ooOol04Goo000POol00`00Oomoo`2n
Ool=0002OolH001dOol00`00Oomoo`0AOol0021oo`03001oogoo0;aoobT007Aoo`03001oogoo015o
o`0087oo00<007ooOol0^Woo:P00MGoo00<007ooOol04Goo000POol00`00Oomoo`2gOol/001fOol0
0`00Oomoo`0AOol0021oo`<00;QoobX007Eoo`<001=oo`0087oo00<007ooOol0^7oo:@00N7oo00<0
07ooOol04Goo000POol00`00Oomoo`2iOolX001hOol00`00Oomoo`0AOol0021oo`03001oogoo0;Uo
obL007Uoo`03001oogoo015oo`0087oo00<007ooOol0^Woo9@00NWoo00<007ooOol04Goo000POol0
0`00Oomoo`2jOolT001kOol00`00Oomoo`0AOol0021oo`<00;]oob8007Yoo`<001=oo`0087oo00<0
07ooOol0^goo8@00OGoo00<007ooOol04Goo000POol00`00Oomoo`2lOolP001mOol00`00Oomoo`0A
Ool0021oo`03001oogoo0;aooal007ioo`03001oogoo015oo`0087oo00<007ooOol0_Goo7@00Ogoo
00<007ooOol04Goo000POol00`00Oomoo`2mOolL0020Ool00`00Oomoo`0AOol0021oo`03001oogoo
0;iooaX0085oo`03001oogoo015oo`0087oo0`00_Woo6@00P7oo0`004goo000POol00`00Oomoo`2o
OolH0022Ool00`00Oomoo`0AOol0021oo`03001oogoo0;mooaL008=oo`03001oogoo015oo`0087oo
00<007ooOol0`7oo5@00Q7oo00<007ooOol04Goo000HOol30005Ool00`00Oomoo`30OolF0023Ool0
0`00Oomoo`0AOol001Qoo`03001oogoo00Eoo`03001oogoo0<5ooaD008=oo`03001oogoo015oo`00
6Goo00<007ooOol017oo0`00`Goo5P00P7oo0`004goo000IOol00`00Oomoo`04Ool00`00Oomoo`32
OolE0022Ool00`00Oomoo`0AOol001Qoo`03001oo`0000Eoo`03001oogoo0<9ooaH0085oo`03001o
ogoo015oo`006Goo00<007ooOol017oo00<007ooOol0`goo5@00PGoo00<007ooOol04Goo000POol0
0`00Oomoo`33OolF0020Ool00`00Oomoo`0AOol0021oo`03001oogoo0<AooaD0081oo`03001oogoo
015oo`0087oo0`00a7oo5000Ogoo0`004goo000POol00`00Oomoo`35OolA0023Ool00`00Oomoo`0A
Ool0021oo`03001oogoo0<Eoo`l008Eoo`03001oogoo015oo`0087oo00<007ooOol0aWoo3000Qgoo
00<007ooOol04Goo000POol00`00Oomoo`36Ool:0029Ool00`00Oomoo`0AOol0021oo`03001oogoo
0<Moo`L008]oo`03001oogoo015oo`0087oo00<007ooOol0agoo1@00SGoo00<007ooOol04Goo000P
Ool30038Ool2002=Ool3000COol0021oo`03001oogoo0?mooeYoo`03001oogoo015oo`0087oo00<0
07ooOol0ogooFWoo00<007ooOol04Goo000POol00`00Oomoo`3oOomJOol00`00Oomoo`0AOol0021o
o`03001oogoo0?mooeYoo`03001oogoo015oo`0087oo00<007ooOol0ogooFWoo00<007ooOol04Goo
000POol3003oOomHOol3000COol0021oo`03001oogoo0?mooeYoo`03001oogoo015oo`0087oo00<0
07ooOol0ogooFWoo00<007ooOol04Goo000POol00`00Oomoo`3oOomJOol00`00Oomoo`0AOol0021o
o`03001oogoo00eoo`03001oogoo03aoo`03001oogoo03aoo`03001oogoo03eoo`03001oogoo03ao
o`03001oogoo03aoo`03001oogoo00eoo`03001oogoo015oo`0087oo00@007ooOol000aoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Yoo`04001oogoo000COol0021oool005h001=oo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {151, 0}} -> {-1.53815, -1.96994, 0.0316621, 
  0.0316621}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Undocumented Graphics", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"graph=Graphics[{PointSize[.05],Point[Location[2,0]],\n  Edge[caster, \
{0,{2,0}}],\n  Bar[Line[2,{1.4,0},{2.6,0}], .30],\n  Circle[Location[caster, \
0], .4],\n  Arrow[Axis[Location[caster, 0] + {1,-1}, {1,0}], 2]},\n  \
AspectRatio \[Rule] Automatic,\n  PlotRange \[Rule] {{-.5, 10.5},{-1.4, \
2.8}},\n  Frame \[Rule] True];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[graph/.sol/.Table[{T \[Rule] i}, {i,0,10,2.5}]];"], "Input",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{80, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 46, 0, 150, "Title"],

Cell[CellGroupData[{
Cell[1802, 55, 88, 2, 47, "Subsection"],
Cell[1893, 59, 1944, 64, 269, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3874, 128, 132, 3, 33, "Section",
  PageBreakAbove->True],
Cell[4009, 133, 655, 22, 93, "Text"],

Cell[CellGroupData[{
Cell[4689, 159, 97, 2, 47, "Subsection"],
Cell[4789, 163, 682, 10, 147, "Text"],

Cell[CellGroupData[{
Cell[5496, 177, 233, 8, 24, "SmallText"],
Cell[5732, 187, 159, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5928, 196, 89, 2, 43, "Subsubsection"],
Cell[6020, 200, 225, 5, 52, "Text"],
Cell[6248, 207, 377, 7, 76, "Special1"],
Cell[6628, 216, 351, 6, 76, "Special1"],
Cell[6982, 224, 257, 5, 59, "Special1"],

Cell[CellGroupData[{
Cell[7264, 233, 126, 2, 24, "SmallText"],
Cell[7393, 237, 133, 4, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7563, 246, 144, 4, 24, "SmallText"],
Cell[7710, 252, 437, 8, 145, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8196, 266, 94, 2, 29, "Subsubsection"],
Cell[8293, 270, 134, 3, 33, "Text"],
Cell[8430, 275, 686, 21, 95, "Special1"],
Cell[9119, 298, 434, 13, 60, "Special1"],
Cell[9556, 313, 606, 19, 78, "Special1"],
Cell[10165, 334, 216, 8, 26, "Special1"],
Cell[10384, 344, 337, 12, 43, "Special1"],
Cell[10724, 358, 289, 9, 43, "Special1"],
Cell[11016, 369, 291, 9, 43, "Special1"],

Cell[CellGroupData[{
Cell[11332, 382, 154, 4, 24, "SmallText"],
Cell[11489, 388, 458, 8, 205, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11996, 402, 91, 2, 29, "Subsubsection"],
Cell[12090, 406, 485, 14, 92, "Text"],

Cell[CellGroupData[{
Cell[12600, 424, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[12819, 436, 70, 2, 25, "Input"],
Cell[12892, 440, 427, 10, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13368, 456, 149, 4, 24, "SmallText"],
Cell[13520, 462, 22121, 1142, 271, 6270, 941, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35690, 1610, 89, 2, 29, "Subsubsection"],
Cell[35782, 1614, 332, 6, 71, "Text"],

Cell[CellGroupData[{
Cell[36139, 1624, 134, 3, 24, "SmallText"],
Cell[36276, 1629, 222, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36535, 1639, 269, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[36829, 1648, 120, 3, 25, "Input"],
Cell[36952, 1653, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[37094, 1662, 99, 2, 31, "Subsection"],
Cell[37196, 1666, 337, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[37558, 1679, 1061, 35, 132, "Special3"],
Cell[38622, 1716, 137, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[38774, 1722, 549, 9, 128, "Text"],

Cell[CellGroupData[{
Cell[39348, 1735, 103, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[39476, 1741, 76, 2, 25, "Input"],
Cell[39555, 1745, 58, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39662, 1752, 192, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[39879, 1764, 88, 2, 25, "Input"],
Cell[39970, 1768, 498, 8, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[40517, 1782, 133, 3, 24, "SmallText"],
Cell[40653, 1787, 19281, 1106, 233, 6295, 941, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[59949, 2896, 774, 25, 93, "Text"],
Cell[60726, 2923, 1187, 43, 103, "Special3"],
Cell[61916, 2968, 204, 9, 18, "Special4",
  PageBreakAbove->False],

Cell[CellGroupData[{
Cell[62145, 2981, 225, 8, 24, "SmallText"],
Cell[62373, 2991, 113, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62523, 2998, 335, 12, 40, "SmallText"],

Cell[CellGroupData[{
Cell[62883, 3014, 88, 2, 25, "Input"],
Cell[62974, 3018, 529, 8, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63552, 3032, 149, 4, 24, "SmallText"],
Cell[63704, 3038, 19497, 1109, 233, 6332, 941, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83238, 4152, 240, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[83503, 4164, 158, 3, 45, "Input"],
Cell[83664, 4169, 539, 9, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[84252, 4184, 157, 4, 24, "SmallText"],
Cell[84412, 4190, 19476, 1108, 233, 6332, 941, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103925, 5303, 191, 8, 24, "SmallText"],
Cell[104119, 5313, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[104237, 5321, 91, 2, 31, "Subsection"],
Cell[104331, 5325, 826, 15, 331, "Input"],
Cell[105160, 5342, 99, 2, 25, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[105308, 5350, 127, 3, 33, "Section",
  PageBreakAbove->True],
Cell[105438, 5355, 678, 17, 110, "Text"],

Cell[CellGroupData[{
Cell[106141, 5376, 97, 2, 47, "Subsection"],
Cell[106241, 5380, 701, 11, 166, "Text"],

Cell[CellGroupData[{
Cell[106967, 5395, 235, 8, 24, "SmallText"],
Cell[107205, 5405, 166, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107408, 5415, 132, 3, 24, "SmallText"],
Cell[107543, 5420, 421, 7, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108001, 5432, 202, 4, 40, "SmallText"],
Cell[108206, 5438, 340, 8, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108583, 5451, 248, 9, 24, "SmallText"],

Cell[CellGroupData[{
Cell[108856, 5464, 126, 3, 25, "Input"],
Cell[108985, 5469, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[109098, 5476, 200, 8, 24, "SmallText"],
Cell[109301, 5486, 7322, 196, 158, 1635, 121, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[116672, 5688, 108, 2, 31, "Subsection"],
Cell[116783, 5692, 332, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[117140, 5705, 751, 25, 87, "Special3"],
Cell[117894, 5732, 124, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[118033, 5738, 179, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[118237, 5746, 144, 4, 24, "SmallText"],
Cell[118384, 5752, 110, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118531, 5759, 364, 12, 40, "SmallText"],

Cell[CellGroupData[{
Cell[118920, 5775, 88, 2, 25, "Input"],
Cell[119011, 5779, 926, 18, 105, "Output"]
}, Open  ]]
}, Open  ]],
Cell[119964, 5801, 636, 18, 92, "Text"],

Cell[CellGroupData[{
Cell[120625, 5823, 1167, 37, 134, "Special3"],
Cell[121795, 5862, 291, 13, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[122123, 5880, 187, 4, 24, "SmallText"],
Cell[122313, 5886, 124, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122474, 5894, 301, 12, 24, "SmallText"],
Cell[122778, 5908, 137, 3, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[122952, 5916, 176, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[123153, 5924, 120, 3, 25, "Input"],
Cell[123276, 5929, 19072, 464, 182, 3832, 270, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[142397, 6399, 191, 8, 24, "SmallText"],
Cell[142591, 6409, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[142709, 6417, 91, 2, 31, "Subsection"],
Cell[142803, 6421, 581, 10, 241, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[143433, 6437, 124, 3, 33, "Section",
  PageBreakAbove->True],
Cell[143560, 6442, 633, 16, 111, "Text"],

Cell[CellGroupData[{
Cell[144218, 6462, 100, 2, 47, "Subsection"],
Cell[144321, 6466, 1490, 38, 267, "Text"],

Cell[CellGroupData[{
Cell[145836, 6508, 235, 8, 24, "SmallText"],
Cell[146074, 6518, 165, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146276, 6528, 151, 4, 24, "SmallText"],
Cell[146430, 6534, 433, 8, 145, "Input"],
Cell[146866, 6544, 289, 6, 105, "Input"],
Cell[147158, 6552, 202, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[147397, 6562, 547, 18, 41, "SmallText"],

Cell[CellGroupData[{
Cell[147969, 6584, 120, 3, 25, "Input"],
Cell[148092, 6589, 47, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[148188, 6596, 131, 3, 24, "SmallText"],
Cell[148322, 6601, 21104, 1166, 213, 8178, 1001, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[169475, 7773, 111, 2, 31, "Subsection"],
Cell[169589, 7777, 346, 9, 72, "Text"],

Cell[CellGroupData[{
Cell[169960, 7790, 752, 25, 86, "Special3"],
Cell[170715, 7817, 135, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[170865, 7823, 526, 17, 74, "Text"],

Cell[CellGroupData[{
Cell[171416, 7844, 147, 4, 24, "SmallText"],
Cell[171566, 7850, 113, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171716, 7857, 192, 8, 24, "SmallText"],
Cell[171911, 7867, 86, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[172034, 7874, 146, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[172205, 7882, 98, 2, 25, "Input"],
Cell[172306, 7886, 78, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[172411, 7891, 1156, 41, 134, "Text"],

Cell[CellGroupData[{
Cell[173592, 7936, 301, 12, 24, "SmallText"],
Cell[173896, 7950, 207, 5, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174140, 7960, 475, 17, 42, "SmallText"],

Cell[CellGroupData[{
Cell[174640, 7981, 253, 6, 45, "Input"],
Cell[174896, 7989, 13974, 425, 182, 3859, 294, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[188919, 8420, 190, 8, 24, "SmallText"],
Cell[189112, 8430, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[189230, 8438, 100, 2, 31, "Subsection"],
Cell[189333, 8442, 1990, 36, 472, "Text"],

Cell[CellGroupData[{
Cell[191348, 8482, 236, 8, 24, "SmallText"],
Cell[191587, 8492, 247, 7, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[191871, 8504, 151, 4, 24, "SmallText"],
Cell[192025, 8510, 178, 3, 45, "Input"],
Cell[192206, 8515, 487, 8, 165, "Input"],
Cell[192696, 8525, 126, 3, 25, "Input"],
Cell[192825, 8530, 87, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192949, 8537, 155, 4, 24, "SmallText"],
Cell[193107, 8543, 44869, 1551, 295, 13325, 1156, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[238013, 10099, 314, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[238352, 10115, 120, 3, 25, "Input"],
Cell[238475, 10120, 66, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[238602, 10128, 111, 2, 31, "Subsection"],
Cell[238716, 10132, 661, 14, 148, "Text"],

Cell[CellGroupData[{
Cell[239402, 10150, 152, 4, 24, "SmallText"],
Cell[239557, 10156, 108, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[239702, 10163, 192, 8, 24, "SmallText"],
Cell[239897, 10173, 86, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[240020, 10180, 352, 11, 40, "SmallText"],

Cell[CellGroupData[{
Cell[240397, 10195, 109, 2, 25, "Input"],
Cell[240509, 10199, 105, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[240663, 10207, 295, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[240983, 10219, 83, 2, 25, "Input"],
Cell[241069, 10223, 66, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[241162, 10228, 593, 18, 91, "Text"],

Cell[CellGroupData[{
Cell[241780, 10250, 367, 13, 40, "SmallText"],
Cell[242150, 10265, 188, 6, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[242375, 10276, 282, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[242682, 10288, 109, 2, 25, "Input"],
Cell[242794, 10292, 126, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[242969, 10300, 240, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[243234, 10312, 83, 2, 25, "Input"],
Cell[243320, 10316, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[243430, 10321, 329, 10, 53, "Text"],

Cell[CellGroupData[{
Cell[243784, 10335, 236, 8, 24, "SmallText"],
Cell[244023, 10345, 255, 7, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[244315, 10357, 278, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[244618, 10369, 109, 2, 25, "Input"],
Cell[244730, 10373, 153, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[244932, 10381, 281, 8, 40, "SmallText"],

Cell[CellGroupData[{
Cell[245238, 10393, 83, 2, 25, "Input"],
Cell[245324, 10397, 66, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[245451, 10405, 98, 2, 31, "Subsection"],
Cell[245552, 10409, 1078, 16, 261, "Text"],
Cell[246633, 10427, 1287, 48, 147, "Special3"],
Cell[247923, 10477, 145, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[248071, 10482, 924, 24, 188, "Text"],

Cell[CellGroupData[{
Cell[249020, 10510, 438, 14, 40, "SmallText"],

Cell[CellGroupData[{
Cell[249483, 10528, 238, 4, 85, "Input"],
Cell[249724, 10534, 49, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[249822, 10541, 340, 11, 40, "SmallText"],
Cell[250165, 10554, 250, 7, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[250452, 10566, 209, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[250686, 10574, 109, 2, 25, "Input"],
Cell[250798, 10578, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[250930, 10585, 150, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[251105, 10593, 83, 2, 25, "Input"],
Cell[251191, 10597, 83, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[251323, 10604, 236, 8, 24, "SmallText"],
Cell[251562, 10614, 255, 7, 65, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[251854, 10626, 177, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[252056, 10634, 109, 2, 25, "Input"],
Cell[252168, 10638, 136, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[252353, 10646, 173, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[252551, 10654, 83, 2, 25, "Input"],
Cell[252637, 10658, 66, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[252730, 10663, 435, 11, 91, "Text"],

Cell[CellGroupData[{
Cell[253190, 10678, 579, 20, 56, "SmallText"],

Cell[CellGroupData[{
Cell[253794, 10702, 233, 5, 65, "Input"],
Cell[254030, 10709, 64, 1, 29, "Output"],
Cell[254097, 10712, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[254195, 10717, 427, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[254647, 10728, 190, 8, 24, "SmallText"],
Cell[254840, 10738, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[254958, 10746, 91, 2, 31, "Subsection"],
Cell[255052, 10750, 612, 10, 241, "Input"],
Cell[255667, 10762, 667, 11, 313, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[256383, 10779, 131, 3, 33, "Section",
  PageBreakAbove->True],
Cell[256517, 10784, 835, 23, 132, "Text"],

Cell[CellGroupData[{
Cell[257377, 10811, 101, 2, 47, "Subsection"],

Cell[CellGroupData[{
Cell[257503, 10817, 1274, 48, 119, "Special3"],
Cell[258780, 10867, 219, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[259014, 10879, 2670, 59, 532, "Text"],
Cell[261687, 10940, 105, 2, 43, "Subsubsection"],
Cell[261795, 10944, 737, 22, 114, "Text"],

Cell[CellGroupData[{
Cell[262557, 10970, 1426, 48, 134, "Special3"],
Cell[263986, 11020, 221, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[264222, 11032, 1642, 50, 248, "Text"],
Cell[265867, 11084, 102, 2, 43, "Subsubsection"],
Cell[265972, 11088, 510, 12, 92, "Text"],

Cell[CellGroupData[{
Cell[266507, 11104, 3676, 124, 416, "Special3"],
Cell[270186, 11230, 231, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[270454, 11244, 2105, 69, 258, "Special3"],
Cell[272562, 11315, 147, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[272724, 11321, 3789, 111, 497, "Text"],
Cell[276516, 11434, 109, 2, 43, "Subsubsection"],
Cell[276628, 11438, 229, 5, 52, "Text"],

Cell[CellGroupData[{
Cell[276882, 11447, 836, 28, 118, "Special3"],
Cell[277721, 11477, 241, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[277977, 11489, 1422, 49, 152, "Text"],
Cell[279402, 11540, 105, 2, 43, "Subsubsection"],
Cell[279510, 11544, 271, 8, 53, "Text"],

Cell[CellGroupData[{
Cell[279806, 11556, 3681, 131, 367, "Special3"],
Cell[283490, 11689, 211, 9, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[283716, 11701, 696, 22, 93, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[284449, 11728, 104, 2, 31, "Subsection"],
Cell[284556, 11732, 630, 10, 166, "Text"],

Cell[CellGroupData[{
Cell[285211, 11746, 189, 8, 24, "SmallText"],
Cell[285403, 11756, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285524, 11763, 153, 4, 24, "SmallText"],
Cell[285680, 11769, 500, 9, 165, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286217, 11783, 277, 5, 71, "Text"],
Cell[286497, 11790, 104, 2, 24, "SmallText"],
Cell[286604, 11794, 462, 8, 205, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287103, 11807, 149, 4, 24, "SmallText"],
Cell[287255, 11813, 95, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[287387, 11820, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[287606, 11832, 71, 2, 25, "Input"],
Cell[287680, 11836, 247, 4, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[287976, 11846, 149, 4, 24, "SmallText"],
Cell[288128, 11852, 18848, 1089, 233, 6145, 927, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[307025, 12947, 93, 2, 31, "Subsection"],
Cell[307121, 12951, 756, 21, 113, "Text"],

Cell[CellGroupData[{
Cell[307902, 12976, 332, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[308259, 12989, 116, 2, 25, "Input"],
Cell[308378, 12993, 163, 3, 63, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[308590, 13002, 558, 20, 40, "SmallText"],
Cell[309151, 13024, 136, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[309324, 13032, 199, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[309548, 13043, 109, 2, 25, "Input"],
Cell[309660, 13047, 20006, 657, 181, 7232, 493, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[329693, 13708, 289, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[330007, 13717, 378, 15, 40, "Special3"],
Cell[330388, 13734, 129, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[330532, 13740, 517, 14, 91, "Text"],

Cell[CellGroupData[{
Cell[331074, 13758, 126, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[331225, 13764, 487, 10, 125, "Input"],
Cell[331715, 13776, 16983, 668, 181, 8209, 554, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[348725, 14448, 2287, 61, 383, "Text"],

Cell[CellGroupData[{
Cell[351037, 14513, 222, 8, 24, "SmallText"],
Cell[351262, 14523, 8149, 312, 115, 2535, 238, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[359448, 14840, 190, 8, 24, "SmallText"],
Cell[359641, 14850, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[359759, 14858, 98, 2, 31, "Subsection"],
Cell[359860, 14862, 616, 15, 111, "Text"],

Cell[CellGroupData[{
Cell[360501, 14881, 236, 8, 24, "SmallText"],
Cell[360740, 14891, 247, 7, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[361024, 14903, 151, 4, 24, "SmallText"],
Cell[361178, 14909, 707, 12, 225, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[361922, 14926, 386, 13, 40, "SmallText"],

Cell[CellGroupData[{
Cell[362333, 14943, 120, 3, 25, "Input"],
Cell[362456, 14948, 49, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[362566, 14956, 93, 2, 31, "Subsection"],
Cell[362662, 14960, 915, 17, 205, "Text"],

Cell[CellGroupData[{
Cell[363602, 14981, 162, 4, 24, "SmallText"],
Cell[363767, 14987, 116, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[363920, 14994, 578, 24, 40, "SmallText"],
Cell[364501, 15020, 150, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[364688, 15029, 482, 13, 56, "SmallText"],

Cell[CellGroupData[{
Cell[365195, 15046, 201, 4, 65, "Input"],
Cell[365399, 15052, 23176, 801, 181, 9379, 625, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[388624, 15859, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[388778, 15866, 151, 4, 65, "Input"],
Cell[388932, 15872, 21708, 554, 181, 5064, 343, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[410667, 16430, 1637, 37, 303, "Text"],

Cell[CellGroupData[{
Cell[412329, 16471, 184, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[412538, 16479, 187, 5, 65, "Input"],
Cell[412728, 16486, 20695, 767, 181, 9400, 622, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[433472, 17259, 135, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[433632, 17266, 104, 2, 25, "Input"],
Cell[433739, 17270, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[433822, 17275, 1180, 33, 169, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[435039, 17313, 106, 2, 31, "Subsection"],
Cell[435148, 17317, 276, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[435449, 17326, 1295, 50, 87, "Special3"],
Cell[436747, 17378, 146, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[436908, 17384, 909, 22, 150, "Text"],

Cell[CellGroupData[{
Cell[437842, 17410, 140, 3, 24, "SmallText"],
Cell[437985, 17415, 363, 6, 125, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[438385, 17426, 517, 16, 56, "SmallText"],

Cell[CellGroupData[{
Cell[438927, 17446, 205, 5, 65, "Input"],
Cell[439135, 17453, 64, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[439226, 17458, 563, 17, 56, "SmallText"],
Cell[439792, 17477, 180, 4, 45, "Input"],
Cell[439975, 17483, 382, 10, 72, "Text"],

Cell[CellGroupData[{
Cell[440382, 17497, 198, 8, 24, "SmallText"],
Cell[440583, 17507, 277, 6, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[440897, 17518, 247, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[441169, 17527, 197, 4, 65, "Input"],
Cell[441369, 17533, 23126, 802, 181, 9361, 626, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[464544, 18341, 190, 8, 24, "SmallText"],
Cell[464737, 18351, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[464855, 18359, 91, 2, 31, "Subsection"],
Cell[464949, 18363, 573, 10, 241, "Input"],
Cell[465525, 18375, 125, 2, 25, "Input"],
Cell[465653, 18379, 158, 4, 43, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[465860, 18389, 127, 3, 33, "Section",
  PageBreakAbove->True],
Cell[465990, 18394, 821, 24, 131, "Text"],

Cell[CellGroupData[{
Cell[466836, 18422, 97, 2, 47, "Subsection"],
Cell[466936, 18426, 1935, 39, 415, "Text"],

Cell[CellGroupData[{
Cell[468896, 18469, 188, 8, 24, "SmallText"],
Cell[469087, 18479, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469208, 18486, 294, 9, 40, "SmallText"],
Cell[469505, 18497, 197, 5, 85, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[469739, 18507, 228, 8, 24, "SmallText"],
Cell[469970, 18517, 77, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[470084, 18524, 122, 2, 24, "SmallText"],
Cell[470209, 18528, 14323, 798, 154, 5364, 682, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[484581, 19332, 104, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[484710, 19338, 1804, 63, 180, "Special3"],
Cell[486517, 19403, 145, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[486699, 19411, 507, 17, 40, "SmallText"],

Cell[CellGroupData[{
Cell[487231, 19432, 180, 5, 65, "Input"],
Cell[487414, 19439, 50, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[487513, 19446, 371, 10, 40, "SmallText"],

Cell[CellGroupData[{
Cell[487909, 19460, 140, 4, 25, "Input"],
Cell[488052, 19466, 485, 13, 48, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[488586, 19485, 318, 11, 40, "SmallText"],

Cell[CellGroupData[{
Cell[488929, 19500, 126, 3, 25, "Input"],
Cell[489058, 19505, 14474, 549, 181, 5208, 429, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[503581, 20060, 306, 12, 24, "SmallText"],
Cell[503890, 20074, 21148, 990, 160, 6489, 804, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[525075, 21069, 190, 8, 24, "SmallText"],
Cell[525268, 21079, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[525386, 21087, 91, 2, 31, "Subsection"],
Cell[525480, 21091, 401, 7, 151, "Input"],
Cell[525884, 21100, 129, 3, 25, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

