(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     39523,       1355]*)
(*NotebookOutlinePosition[     40466,       1387]*)
(*  CellTagsIndexPosition[     40422,       1383]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["11.  Performance Improvement", "Title"],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter is intended to help the user improve the performance of \
kinematic and dynamic models built with ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  ". The symbolic mathematical systems that are generated by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " can become quite large, causing their evaluation to proceed very slowly. \
There is no single trick that will speed up the evaluation of all ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " models, except buying a faster computer, and a technique that \
successfully accelerates one type of model may have the opposite affect on \
another. However, attention to the guidelines in the following sections will \
generally prevent the user from building a particularly bad model, and may \
lead to large reductions in run time."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["11.1  Updating Solutions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "The simplest way to get a ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " model to run faster is to ask it to do less work. This is usually \
accomplished by keeping track of and reusing results that have already been \
obtained, instead of generating them again.\n\nWhen mechanism velocity or \
acceleration data are needed, or static or dynamic constraint reaction \
forces, the complete location solution must first be calculated. If this has \
already been done, the ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option prevents ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " from doing it again."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that determines whether or not solution rules passed into ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are assumed to be an approximate solution, and are thus to be used as \
initial guesses, or are assumed to constitute a valid solution to the model. \
The default setting is ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "An option for ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, the solution rules that are passed to ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are not checked against the constraints, they are simply passed to the \
next phase of the solution block. This is useful if a set of lower-order \
solution rules has already been obtained (",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  " location solution) and a set of higher-order (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  " velocity or acceleration) rules is desired.\n\nThe following example uses \
a spatial slider-crank model to demonstrate the time savings that can be \
realized by updating higher-order solutions without regenerating lower-order \
data. The example mechanism consists of two bodies, a crank and a slider, and \
a connecting rod that is simply a distance constraint. No initial guesses are \
needed for the model because both the crank and the slider are initially \
coincident with the local origin. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is an entire slider-crank model built in one step."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(slider = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[
      cs = {\n\t\t\t
          Revolute5[1, Axis[crank, 0, {1, 0, 0}], 
            Axis[ground, 0, {1, 0, 0}]], \n\t\t\t
          ProjectedAngle1[2, Vector[crank, {0, 1, 0}], 
            Axis[ground, 0, {1, 0, 0}], 2\ N[\[Pi]]\ T], \n\t\t\t
          Translate5[3, Axis[slider, 0, {1, 0, 0}], 
            Axis[ground, 0, {1, 0, 0}]], \n\t\t\t
          RelativeDistance1[4, Point[crank, {0, 5, 0}], 
            Point[slider, {15, 5, 0}], 15]}, BuildMech \[Rule] Velocity]\)], 
  "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "Here is a solution to the model near ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(SolveMech[0.05] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.05`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 0\), ",", 
        \(Eo2 \[Rule] 0.987688340595137859`\), ",", 
        \(Ei2 \[Rule] 0.156434465040230907`\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] \(-0.0817954895785880609`\)\), 
        ",", \(Y3 \[Rule] 0\), ",", \(Z3 \[Rule] 0\), ",", 
        \(Eo3 \[Rule] 1.`\), ",", \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] 0\), 
        ",", \(Ek3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[
"To show the difference between regenerating solutions, updating solutions, \
and updating solutions without checking validity, a series of location \
solutions are generated and then updated to velocity solutions."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This generates 21 solutions to the model as time goes from 0 to 1."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(postab = SolveMech[{0, 1}, 21]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This generates the complete location and velocity solution at 21 points."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(Timing[veltab = SolveMech[{0, 1}, 21, Solution \[Rule] Velocity]; ]\)}],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.37399999999999877`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This generates the complete location and velocity solution using the \
location rules already calculated as initial guesses at each step."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[veltab = SolveMech[postab, Solution \[Rule] Velocity]; ]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.84100000000000108`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"This generates only the new velocity solution using the location rules \
already calculated without checking that they in fact satisfy the \
constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      veltab = SolveMech[postab, Solution \[Rule] Velocity, 
          CheckRules \[Rule] False]; ]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.541000000000000369`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "This same technique can be used to update a location solution to a static \
solution, or any other combination of the solution levels generated by ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is specified, the only part of the solution that is actually calculated \
anew is the part explicitly requested by the solution option, and any parts \
of the solution that are not present in the solution rules that are to be \
updated."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["11.2  Simplifying Expressions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section covers some of the ways that a ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " model can be algebraically simplified to improve performance. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Local Coordinate Choices"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " allows considerable flexibility in defining geometric constraints and \
forcing functions. The points and lines that are used to make up these \
elements can be located anywhere in the local coordinate system of any body \
in the model. However, all points are not created equal, in terms of \
efficiency, and choosing a more complicated representation of a geometric \
relationship over a simpler one can result in large changes in the time \
required to run a model.\n\nIn general, it is best to use the local origin of \
a body whenever possible in defining constraint or load functions because the \
local origin is represented by a much simpler expression than a nonorigin \
point. When the local origin cannot be used, the more zeros there are in the \
local coordinates of a point, the better. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the symbolic representations of three points on the crank."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[crank, {0, 0, 0}]\), 
    \(Location[crank, {1, 0, 0}]\), 
    \(Location[crank, {1, 2, 3}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2, Y2, Z2}\)], "Output"],

Cell[BoxData[
    \({2\ \((\(-\(1\/2\)\) + Ei2\^2 + Eo2\^2)\) + X2, 
      2\ \((Ei2\ Ej2 + Ek2\ Eo2)\) + Y2, 2\ \((Ei2\ Ek2 - Ej2\ Eo2)\) + Z2}
      \)], "Output"],

Cell[BoxData[
    \({6\ \((Ei2\ Ek2 + Ej2\ Eo2)\) + 4\ \((Ei2\ Ej2 - Ek2\ Eo2)\) + 
        2\ \((\(-\(1\/2\)\) + Ei2\^2 + Eo2\^2)\) + X2, 
      6\ \((Ej2\ Ek2 - Ei2\ Eo2)\) + 2\ \((Ei2\ Ej2 + Ek2\ Eo2)\) + 
        4\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\) + Y2, 
      4\ \((Ej2\ Ek2 + Ei2\ Eo2)\) + 2\ \((Ei2\ Ek2 - Ej2\ Eo2)\) + 
        6\ \((\(-\(1\/2\)\) + Ek2\^2 + Eo2\^2)\) + Z2}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Obviously, it takes less time to evaluate the first of these three \
expressions than it does to evaluate the others. Further, since all points on \
the ground body are constant, use points on the ground body over points on \
other bodies whenever possible, even over the local origins of the other \
bodies. \n\nThese guidelines also apply to the definition of ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " objects; use the ground body if possible. However, it is usually better \
to use two or three points on the same body to define a ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Plane",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object than it is to use one point on the ground and other points on \
another body.  \n\nFinally, one point where the relative simplicity of the \
local origin is of great importance is in the location of the centroid of a \
dynamic model. While ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " does allow the centroid to be placed arbitrarily on a body, moving the \
centroid off of the local origin of a body results in a great increase in the \
complexity of the model's mass matrix. The mass matrix of a 3D body in local \
coordinates is a 6 x 6 block diagonal constant matrix (completely diagonal if \
the products of inertia are zero), if the centroid is located at the local \
origin. If the centroid is moved off of the local origin, the mass matrix \
becomes a 6 x 6 nonconstant full matrix. This is especially important when \
integrating the equations of motion, when the mass matrix must be evaluated \
at every time step. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraint and Load Choices"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The entire set of constraint functions provided by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is quite redundant. Almost any geometric constraint can be duplicated by \
some other constraint or combination of constraints. However, the algebraic \
expressions generated by functionally identical constraints can be quite \
different. It is important to use the simplest possible representation of a \
mechanism joint to reduce the size of the model.\n\nThe one time when a more \
complicated constraint set should be considered is when it is possible to \
remove a body from a model by replacing the entire body with a compound \
constraint. The ",
  StyleBox["OrthoRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["ParaRevolute4",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraints in ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are good candidates for replacing entire bodies in a model, as is the ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint that is commonly used to replace a connecting rod. It is often \
possible to eliminate multiple bodies, even interlinked bodies, with a \
correctly chosen compound constraint.\n\nA body cannot be eliminated from a \
mechanism when the inertia of the body is relevant to the analysis. But even \
this has an exception: the gyroscopic forces associated with a body that is \
spinning rapidly about an axis of symmetry can be duplicated by a ",
  StyleBox["GyroMoment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " forcing function, thus eliminating the body itself from the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["11.3  Compiling Expressions"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "Most ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " functions that use an iterative Newton-Rhapson solver or numerical \
integration accept the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. Setting ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can result in a substantial reduction in run time, at the expense of some \
increase in the time required to build the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Compile Warning"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In order to reduce the memory required to store models, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " does not store uncompiled versions of the compiled expressions along with \
the compiled part. Thus, if the compiled evaluation of any expression fails, \
",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " cannot continue with an uncompiled evaluation. The results that are \
returned in this event are ",
  StyleBox["never",
    FontSlant->"Italic"],
  " valid. Whenever the ",
  StyleBox["CompiledFunction::cfex",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " error message is generated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the compiled evaluation has failed, and the results are ",
  StyleBox["definitely",
    FontSlant->"Italic"],
  " garbage."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The spatial slider-crank model is rebuilt with the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option to demonstrate the speed increase that is realized by compiling \
the model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This rebuilds the constraints in compiled form. The ",
  StyleBox["BuildMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option forces an immediate build of the velocity equations, which \
prevents the time required to build them from being included in the timing. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[cs, Compiled \[Rule] True, BuildMech \[Rule] Velocity]
      \)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This generates the complete location and velocity solution at 21 points in \
about half the time that was required without the ",
  StyleBox["Compiled",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[]; \)\), 
    \(Timing[veltab = SolveMech[{0, 1}, 21, Solution \[Rule] Velocity]; ]\)}],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1.45199999999999995`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["11.4  Coordinate Systems"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " allows models to be built in several different coordinate systems: ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in two dimensions, and ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Global Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and ",
  StyleBox["Local",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in three dimensions. If the mechanism is planar, use a planar model \
because 2D models run much faster than 3D models."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["2D Coordinate Systems"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "There is no clear rule for the best choice of coordinate systems in planar \
or spatial models, with respect to minimizing run time. In 2D, it would seem \
that ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " would always be better, because only three constraint expressions are \
required per body, instead of four. But, this is largely offset by the fact \
that the 2D degenerate ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " coordinate system uses no trigonometric functions in the formulation of \
geometric constraints, and that the first and second derivatives of \
expressions written in terms of 2D Euler parameters are very simple."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This sets the 2D coordinate system to ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and defines a bogus constraint so that the symbolic derivatives of the \
coordinates of body 2 are defined by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech2D`\>"]\), 
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[bc = Constraint[1, {X2 == 0, Y2 == 0, Th2 == 0}, {2}]]
      \)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the location and velocity of an arbitrary point in angular \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[2, {x, y}]\), 
    \(Acceleration[2, {x, y}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 + x\ Cos[Th2] - y\ Sin[Th2], Y2 + y\ Cos[Th2] + x\ Sin[Th2]}\)], 
  "Output"],

Cell[BoxData[
    \({X2dd + y\ \((\(-Th2dd\)\ Cos[Th2] + Th2d\^2\ Sin[Th2])\) + 
        x\ \((\(-Th2d\^2\)\ Cos[Th2] - Th2dd\ Sin[Th2])\), 
      Y2dd + x\ \((Th2dd\ Cos[Th2] - Th2d\^2\ Sin[Th2])\) + 
        y\ \((\(-Th2d\^2\)\ Cos[Th2] - Th2dd\ Sin[Th2])\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the coordinate system is changed to ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Euler]\), 
    \(SetConstraints[bc]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the location and velocity of an arbitrary point in 2D Euler \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Location[2, {x, y}]\), 
    \(Acceleration[2, {x, y}]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({Ei2\ x + X2 - Ej2\ y, Ej2\ x + Ei2\ y + Y2}\)], "Output"],

Cell[BoxData[
    \({Ei2dd\ x + X2dd - Ej2dd\ y, Ej2dd\ x + Ei2dd\ y + Y2dd}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In conclusion, models that are to be used for acceleration analysis ",
  StyleBox["may",
    FontSlant->"Italic"],
  " run faster if the degenerate Euler coordinates are used, but they may \
not."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3D Coordinate Systems"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"In 3D models, there is no difference between the respective coordinate \
systems with regard to the constraint equations alone because all 3D models \
must use Euler parameters to represent the angular orientation of each body. \
Thus, the choice of coordinate systems comes down to differences in first- \
and second-order expressions, and in the dynamic equations of motion.\n\nAs \
with 2D coordinates, the first and second derivatives of expressions written \
in terms of 3D Euler parameters are simpler than the same expressions written \
in terms of angular velocities and accelerations."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This sets the 3D coordinate system to ",
  StyleBox["Angular",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and defines a bogus constraint so that the symbolic derivatives of the \
coordinates of body 2 are defined by ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[
      bc = Constraint[1, Thread[{X2, Y2, Z2, Ei2, Ej2, Ek2} == 0], {2}]]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the location and velocity of an arbitrary point in angular \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ByteCount[Acceleration[2, {x, y, z}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(7832\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now the coordinate system is changed to ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Euler]\), 
    \(SetConstraints[bc]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here are the location and velocity of an arbitrary point in Euler \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(ByteCount[Acceleration[2, {x, y, z}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(2960\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"However, the relative sizes of the expressions generated by applied forces \
and moments in a static or dynamic model are also affected by the choice of \
coordinate system. Usually, the expressions that are generated by applied \
forces and moments are simpler in angular coordinates than they are in Euler \
coordinates."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is the expression that results from an applied moment in angular \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular]\), 
    \(SetConstraints[bc]\), 
    \(SetLoads[Moment[2, {1, 2, 3}, 10, Magnitude \[Rule] Relative]]\), 
    \(Loads[2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0, 10, 20, 30}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Here is the expression that results from the same applied moment in Euler \
coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Euler]\), 
    \(SetConstraints[bc]\), 
    \(SetLoads[Moment[2, {1, 2, 3}, 10, Magnitude \[Rule] Relative]]\), 
    \(Loads[2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0, 2\ \((\(-10\)\ Ei2 - 20\ Ej2 - 30\ Ek2)\), 
      2\ \((\(-30\)\ Ej2 + 20\ Ek2 + 10\ Eo2)\), 
      2\ \((30\ Ei2 - 10\ Ek2 + 20\ Eo2)\), 
      2\ \((\(-20\)\ Ei2 + 10\ Ej2 + 30\ Eo2)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"However, here is the expression that results from the same applied moment in \
local angular coordinates."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetSymbols[Method \[Rule] Angular, Coordinates \[Rule] Local]\), 
    \(SetConstraints[bc]\), 
    \(SetLoads[Moment[2, {1, 2, 3}, 10, Magnitude \[Rule] Relative]]\), 
    \(Loads[2]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0, 
      60\ \((Ei2\ Ek2 - Ej2\ Eo2)\) + 40\ \((Ei2\ Ej2 + Ek2\ Eo2)\) + 
        20\ \((\(-\(1\/2\)\) + Ei2\^2 + Eo2\^2)\), 
      60\ \((Ej2\ Ek2 + Ei2\ Eo2)\) + 20\ \((Ei2\ Ej2 - Ek2\ Eo2)\) + 
        40\ \((\(-\(1\/2\)\) + Ej2\^2 + Eo2\^2)\), 
      40\ \((Ej2\ Ek2 - Ei2\ Eo2)\) + 20\ \((Ei2\ Ek2 + Ej2\ Eo2)\) + 
        60\ \((\(-\(1\/2\)\) + Ek2\^2 + Eo2\^2)\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"If this is not yet sufficiently murky, consider that if the applied moment \
in the previous example was specified as a constant moment in local \
coordinates on body 2, the conditions of the moment expressions in local \
versus global angular coordinates would be reversed. The moment would be a \
constant in local coordinates and a function of the Euler parameters in \
global coordinates.\n\nIn conclusion, the fastest run times usually result \
from matching the coordinate system to the types of applied forces and \
moments on the body. If the applied loads are in global coordinates, use the \
global coordinate system, and visa versa."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["11.5  Locking Variables"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "The ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function is a special function provided by ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " that allows dependent variables in a model to be \"locked\" in to \
accelerate the evaluation of large models."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LockMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " finds a solution to the mechanism equations at time ",
  StyleBox["t",
    FontSlant->"Italic"],
  " and then embeds the numerical values of the model's dependent variables \
into the mechanism equations so that they cannot be changed until a new model \
is built with ",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " accepts the solution option to specify what level of dependent variables \
are to be locked in. Valid settings for ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Velocity",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Acceleration",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The default setting is ",
  StyleBox["Solution",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["Location",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A special function for locking dependent variables."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " replaces the dependent variables in the constraint equations with \
constant values so that they cannot be changed until the constraints are \
rebuilt. This function is useful when the model must be solved many times \
with different applied loads or different inertia properties, all at the same \
physical configuration. After ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has been run, the dependent variables (",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ...) in a model are replaced by numeric values so that they no longer \
need to be replaced at run time, essentially eliminating the time required to \
replace them.\n\nTo demonstrate the use of ",
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", the 3D slider-crank model that was used in Section 11.1 is redefined \
with applied forces."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is an entire slider-crank model built in one step."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(ground = 1; \)\), 
    \(\(crank = 2; \)\), 
    \(\(slider = 3; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetConstraints[
      cs = {\n\t\t\t
          Revolute5[1, Axis[crank, 0, {1, 0, 0}], 
            Axis[ground, 0, {1, 0, 0}]], \n\t\t\t
          ProjectedAngle1[2, Vector[crank, {0, 1, 0}], 
            Axis[ground, 0, {1, 0, 0}], 2.0  \[Pi]\ T], \n\t\t\t
          Translate5[3, Axis[slider, 0, {1, 0, 0}], 
            Axis[ground, 0, {1, 0, 0}]], \n\t\t\t
          RelativeDistance1[4, Point[crank, {0, 5, 0}], 
            Point[slider, {15, 5, 0}], 15]}]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "And here are the locations of each body at ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0.1."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(pos = SolveMech[0.1] // Chop\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"T", "\[Rule]", 
          StyleBox["0.1`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", \(X2 \[Rule] 0\), ",", 
        \(Y2 \[Rule] 0\), ",", \(Z2 \[Rule] 0\), ",", 
        \(Eo2 \[Rule] 0.951056516295153464`\), ",", 
        \(Ei2 \[Rule] 0.309016994374947406`\), ",", \(Ej2 \[Rule] 0\), ",", 
        \(Ek2 \[Rule] 0\), ",", \(X3 \[Rule] \(-0.321755904783864776`\)\), 
        ",", \(Y3 \[Rule] 0\), ",", \(Z3 \[Rule] 0\), ",", 
        \(Eo3 \[Rule] 1.`\), ",", \(Ei3 \[Rule] 0\), ",", \(Ej3 \[Rule] 0\), 
        ",", \(Ek3 \[Rule] 0\)}], "}"}]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "We can now add an applied force to the model and solve for the static \
reaction forces at several values of a parameter that affects the direction \
of the applied force. A valid location solution ",
  StyleBox["pos",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is passed into ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with the ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option so that regeneration of the location solution does not occur."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"This applies force to the origin of the slider with constant magnitude and \
variable direction."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(SetLoads[Force[slider, Axis[slider, 0, {1, k, 0}], 10]]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Now the model is solved for the static reaction forces at 11 different \
values of k. "], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      statab = Table[
          SolveMech[pos, Solution \[Rule] Static, CheckRules \[Rule] False], {
            k, 0, 1, .1}]; ]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.421000000000000262`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["LockMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run to embed the location coordinates of the model into all of the \
equations of motion, including the load vector. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(LockMech[0.1]\), 
    \(BuildMech[Static]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is solved again for the static reaction forces at 11 different \
values of ",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". It is not necessary to use the ",
  StyleBox["CheckRules",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option now because the constraint equations are constant. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[
      statab = Table[
          SolveMech[0.1, Solution \[Rule] Static], {k, 0, 1, 0.1}]; ]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.290000000000000035`\ Second, Null}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{480, 684},
WindowMargins->{{Automatic, 273}, {31, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 45, 0, 150, "Title"],

Cell[CellGroupData[{
Cell[1801, 55, 88, 2, 47, "Subsection"],
Cell[1892, 59, 893, 19, 166, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2822, 83, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2950, 88, 741, 19, 148, "Text"],
Cell[3694, 109, 782, 26, 87, "Special3"],
Cell[4479, 137, 206, 9, 18, "Special4",
  PageBreakAbove->False],
Cell[4688, 148, 1228, 30, 205, "Text"],

Cell[CellGroupData[{
Cell[5941, 182, 135, 3, 24, "SmallText"],
Cell[6079, 187, 166, 5, 85, "Input"],
Cell[6248, 194, 554, 12, 205, "Input"]
}, Open  ]],
Cell[6817, 209, 201, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[7043, 221, 82, 2, 25, "Input"],
Cell[7128, 225, 660, 13, 67, "Output"]
}, Open  ]],
Cell[7803, 241, 288, 5, 71, "Text"],

Cell[CellGroupData[{
Cell[8116, 250, 149, 4, 24, "SmallText"],
Cell[8268, 256, 95, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8400, 263, 155, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[8580, 271, 158, 4, 65, "Input"],
Cell[8741, 277, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8860, 284, 220, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[9105, 293, 125, 3, 25, "Input"],
Cell[9233, 298, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[9352, 305, 233, 5, 40, "SmallText"],

Cell[CellGroupData[{
Cell[9610, 314, 166, 4, 45, "Input"],
Cell[9779, 320, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[9877, 325, 721, 20, 111, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10635, 350, 130, 3, 33, "Section",
  PageBreakAbove->True],
Cell[10768, 355, 252, 7, 52, "Text"],

Cell[CellGroupData[{
Cell[11045, 366, 104, 2, 47, "Subsection"],
Cell[11152, 370, 941, 16, 223, "Text"],

Cell[CellGroupData[{
Cell[12118, 390, 150, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[12293, 398, 161, 4, 65, "Input"],
Cell[12457, 404, 46, 1, 29, "Output"],
Cell[12506, 407, 165, 3, 67, "Output"],
Cell[12674, 412, 402, 6, 154, "Output"]
}, Open  ]]
}, Open  ]],
Cell[13103, 422, 1912, 43, 377, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[15052, 470, 107, 2, 31, "Subsection"],
Cell[15162, 474, 1769, 39, 359, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16980, 519, 128, 3, 33, "Section",
  PageBreakAbove->True],
Cell[17111, 524, 634, 21, 91, "Text"],

Cell[CellGroupData[{
Cell[17770, 549, 98, 2, 43, "Subsubsection"],
Cell[17871, 553, 873, 26, 130, "Text"]
}, Open  ]],
Cell[18759, 582, 296, 9, 53, "Text"],

Cell[CellGroupData[{
Cell[19080, 595, 364, 9, 40, "SmallText"],
Cell[19447, 606, 135, 3, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19619, 614, 301, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[19945, 627, 158, 4, 65, "Input"],
Cell[20106, 633, 70, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20225, 640, 190, 8, 24, "SmallText"],
Cell[20418, 650, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20536, 658, 125, 3, 33, "Section",
  PageBreakAbove->True],
Cell[20664, 663, 881, 32, 93, "Text"],

Cell[CellGroupData[{
Cell[21570, 699, 101, 2, 47, "Subsection"],
Cell[21674, 703, 786, 18, 130, "Text"],
Cell[22463, 723, 402, 13, 40, "SmallText"],
Cell[22868, 738, 218, 5, 85, "Input"],

Cell[CellGroupData[{
Cell[23111, 747, 162, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[23298, 755, 114, 3, 45, "Input"],
Cell[23415, 760, 101, 2, 29, "Output"],
Cell[23519, 764, 274, 4, 86, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23842, 774, 204, 8, 24, "SmallText"],
Cell[24049, 784, 122, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24208, 792, 163, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[24396, 800, 114, 3, 45, "Input"],
Cell[24513, 805, 78, 1, 29, "Output"],
Cell[24594, 808, 90, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[24711, 813, 275, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[25011, 825, 190, 8, 24, "SmallText"],
Cell[25204, 835, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[25322, 843, 101, 2, 31, "Subsection"],
Cell[25426, 847, 668, 10, 185, "Text"],
Cell[26097, 859, 402, 13, 40, "SmallText"],
Cell[26502, 874, 233, 6, 85, "Input"],

Cell[CellGroupData[{
Cell[26760, 884, 162, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[26947, 892, 96, 2, 25, "Input"],
Cell[27046, 896, 38, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[27133, 903, 204, 8, 24, "SmallText"],
Cell[27340, 913, 122, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27499, 921, 160, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[27684, 929, 96, 2, 25, "Input"],
Cell[27783, 933, 38, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[27848, 938, 397, 7, 90, "Text"],

Cell[CellGroupData[{
Cell[28270, 949, 164, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[28459, 957, 216, 5, 85, "Input"],
Cell[28678, 964, 55, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[28782, 971, 168, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[28975, 979, 214, 5, 85, "Input"],
Cell[29192, 986, 231, 4, 67, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29472, 996, 185, 4, 40, "SmallText"],

Cell[CellGroupData[{
Cell[29682, 1004, 243, 5, 85, "Input"],
Cell[29928, 1011, 412, 7, 154, "Output"]
}, Open  ]]
}, Open  ]],
Cell[30367, 1022, 718, 11, 185, "Text"],

Cell[CellGroupData[{
Cell[31110, 1037, 190, 8, 24, "SmallText"],
Cell[31303, 1047, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[31433, 1056, 124, 3, 33, "Section",
  PageBreakAbove->True],
Cell[31560, 1061, 385, 12, 53, "Text"],
Cell[31948, 1075, 1366, 50, 134, "Special3"],
Cell[33317, 1127, 155, 4, 18, "Special4",
  PageBreakAbove->False],
Cell[33475, 1133, 1129, 30, 208, "Text"],

Cell[CellGroupData[{
Cell[34629, 1167, 135, 3, 24, "SmallText"],
Cell[34767, 1172, 166, 5, 85, "Input"],
Cell[34936, 1179, 522, 11, 185, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35495, 1195, 209, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[35729, 1207, 87, 2, 25, "Input"],
Cell[35819, 1211, 658, 13, 67, "Output"]
}, Open  ]]
}, Open  ]],
Cell[36504, 1228, 701, 22, 91, "Text"],

Cell[CellGroupData[{
Cell[37230, 1254, 176, 4, 24, "SmallText"],
Cell[37409, 1260, 114, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37560, 1267, 166, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[37751, 1275, 196, 5, 65, "Input"],
Cell[37950, 1282, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38070, 1289, 281, 8, 40, "SmallText"],
Cell[38354, 1299, 102, 3, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38493, 1307, 419, 13, 40, "SmallText"],

Cell[CellGroupData[{
Cell[38937, 1324, 161, 5, 45, "Input"],
Cell[39101, 1331, 71, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39221, 1338, 190, 8, 24, "SmallText"],
Cell[39414, 1348, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

