(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64835,       2256]*)
(*NotebookOutlinePosition[     65777,       2288]*)
(*  CellTagsIndexPosition[     65733,       2284]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["12.  Debugging Models", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Overview"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "This chapter is intended to help the ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  " user diagnose and repair common errors in mechanism models. There is a \
penalty to be paid for the tremendous flexibility available within any \
symbolic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " model, that is, an equally tremendous number of ways that a model can \
fail. This chapter can only scratch the surface of the full breadth of \
possible modeling errors that can occur in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model, but the basic debugging methods presented should be applicable to \
all models that are so afflicted."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["12.1  Model Building Errors"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section deals with model building errors that prevent ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " from building the constraint or load expressions or prevent the completed \
model from running."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Bad Arguments"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions are written with as much type checking as is possible without \
restricting the user from incorporating arbitrary mathematical expressions \
into a model. Unfortunately, this caveat means that there can be essentially \
no type checking on any symbolic argument that is intended to evaluate to a \
number.\n\nMany arguments to ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " functions are type checked, such as point and vector arguments, but since \
point objects and vector objects may also contain symbolic expressions buried \
in their local coordinates, these items cannot be rigorously type checked \
until run time. The following examples show where ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  "'s type checking catches bad arguments and where others slip through."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "A ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " body, constraint, or load function is returned unevaluated if it is \
called with invalid arguments. For example, the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint expects a pair of axis objects that have the head ",
  StyleBox["Axis",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or ",
  StyleBox["Line",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " recognizes that these arguments are incorrect, the entire constraint \
function is returned unevaluated."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a misspelled axis object."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = Translate2[1, Axxx[2, {0, 0}, {2, 0}], Axis[1, {0, 0}, {0, 1}]]\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mech::"argmcaaqe" \( : \ \) 
      "\!\(\"Translate2\"\) called with invalid arguments.  \
\!\(\"Translate2\"\)[cnum, axis1, axis2] or \!\(\"Translate2\"\)[cnum, axis1, \
axis2, expr] is expected.  Axes are specified by point and direction with a \
Mech2D Axis object, or by two points with a Mech2D Line object.  Expr must \
evaluate to a number.  "\)], "Message"],

Cell[BoxData[
    \(Translate2[1, Axxx[2, {0, 0}, {2, 0}], Axis[1, {0, 0}, {0, 1}]]\)], 
  "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "If a constraint function is passed the correct argument types, but the \
contents of these arguments are invalid, a constraint object is returned with \
some assumptions made about what to do with the invalid arguments. In the \
following example, the 3D point specification is not recognized by ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", so ",
  StyleBox["Point[2, {1,0,0}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is replaced with ",
  StyleBox["Point[2, {0,0}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This is certainly not what the user intended, but it causes a valid \
constraint object to be returned."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a constraint with a 3D local coordinate that should be 2D."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = Revolute2[1, Point[1, {0, 0}], Point[2, {1, 0, 0}]]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mech::"badpoint" \( : \ \) 
      "A point object is expected instead of \!\(Point[\(2, \({1, 0, \
0}\)\)]\)."\)], "Message"],

Cell[BoxData[
    \(SysCon["Revolute2", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The types of errors shown above are diagnosed fairly easily. More elusive \
problems result when a bad value is given for arguments of type ",
  StyleBox["expr",
    FontSlant->"Italic"],
  ". When a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " usage statement specifies that an argument of type ",
  StyleBox["expr",
    FontSlant->"Italic"],
  " is required, it means any expression that will evaluate to a number at \
run time may be used. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has no way of telling in advance whether or not an expression will \
evaluate to a number, so these arguments cannot be type checked at all."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a constraint with an unchecked expression argument."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs = RelativeDistance1[1, Point[1, {0, 0}], Point[2, {1, 0}], 2\ a]\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(SysCon["RelativeDistance1", "<>"]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The last argument to the ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint (",
  StyleBox["2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") is supposed to evaluate to a number. If, at run time, the symbol ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to a number, then the constraint is valid. If the symbol ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has no definition, or it evaluates to a ",
  StyleBox["List",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " or other function at run time, then ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " will fail. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has no way of knowing what the symbol ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will do at run time, so it cannot be type checked.\n\nNote that the first \
argument of a ",
  StyleBox["SysCon",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " object is a list of the constraint expressions contained in the object."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are the constraint expressions contained in ",
  StyleBox["cs",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cs\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-4\)\ a\^2 + \((\(-X2\) - Cos[Th2])\)\^2 + 
        \((\(-Y2\) - Sin[Th2])\)\^2}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Constraint Inspection"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "When an expression in a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model is supposed to evaluate to a number but it does not, it can often \
be caught by the ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates the constraint expressions in the current model, subject to the \
current initial guesses and parameters, and reports any nonnumeric \
expressions found. Consider the following simple model of a reciprocating \
slider. If ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is run before the symbols ",
  StyleBox["amp",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["freq",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are defined, they are identified. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a reciprocating slider model."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(Clear[amp, freq]; \)\), 
    \(SetConstraints[\n\t
      Translate2[1, \n\t\tAxis[1, {0, 0}, {1, 0}], Axis[2, {0, 0}, {1, 0}]], 
      \n\tRelativeX1[2, Point[2, {0, 0}], amp\ Sin[freq\ T]]]\)}], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CheckSystem[]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"undef" \( : \ \) 
      "The current system contains the following undefined Symbols: \!\({amp, \
freq}\)"\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "If the symbols ",
  StyleBox["amp",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["freq",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are defined at run time, but not defined in such a way that the \
expression ",
  StyleBox["amp Sin[freq T]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to a number, ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " cannot determine exactly what is wrong."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a bogus definition for the symbol ",
  StyleBox["freq",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(amp = 1; \)\), 
    \(\(freq = {2, 4}; \)\), 
    \(\(CheckSystem[]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"cnum" \( : \ \) 
      "The vector of constraint expressions does not evaluate to a list of \
numbers when subject to the current initial guesses and parameters.  Use \
Constraints to inspect the equations."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of constraint expressions that were generated by \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Constraints[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cn",
    FontSlant->"Italic"],
  StyleBox["um, ",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["eqn1, eqn2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of the constraint expressions generated by the equations ",
  
  StyleBox["eqni",
    FontSlant->"Italic"],
  " in constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Constraints[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the entire vector of constraint expressions."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The constraint inspection function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that is used to return all or part of the vector of constraint \
expressions in the current model. Often, direct inspection of the constraints \
immediately gives a clue as to the cause of an error. Usually, the \
constraints are inspected subject to the values of the current guesses and \
parameters, which shows exactly what ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " saw to be an error."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the entire current constraint vector."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[All] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, {0, 0}}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In ",
  StyleBox["all",
    FontSlant->"Italic"],
  " cases, the input shown above should return a vector of numbers. In this \
case, the third constraint expression evaluates to a list of numbers, instead \
of a single number. Obviously this is due to the bogus definition of ",
  StyleBox["freq = {2,4}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " given above."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"We can repair the bogus definition and try again."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(freq = 2; \)\), 
    \(\(CheckSystem[]; \)\), 
    \(Constraints[All] /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Now the constraints evaluate to a list of numbers, as is required. The fact \
that each of the constraint expressions evaluates to zero simply means that \
all of the constraints are perfectly satisfied at the current values of the \
initial guesses, which is not usually the case."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Load Inspection"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mech",
    FontSlant->"Italic"],
  " load expressions may be rendered invalid by the presence of nonnumeric \
expressions in the same way as constraint expressions. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates the current load expressions, if any exist, subject to the \
current values of the initial guesses, parameters, and Lagrange multipliers, \
and reports any nonnumeric expressions found. To demonstrate, a simple load \
is added to the reciprocating slider model defined above. "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["A force applied to body 2."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(Clear[b, k]\), 
    \(SetLoads[Force[2, Axis[2, {0, 0}, {0, \(-1\)}], Exp[k\ T + b]]]\)}], 
  "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(CheckSystem[]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"undef" \( : \ \) 
      "The current system contains the following undefined Symbols: \!\({b, \
k}\)"\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "If the symbols ",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " are defined at run time, but not defined in such a way that the \
expression ",
  StyleBox["Exp[k t + b]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " evaluates to a number, ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " will not be able to determine exactly what is wrong. For example, ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is limited to recognizing raw symbols only. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not recognize a user-defined variable of the form ",
  StyleBox["c[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["n",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = c[1]; \)\), 
    \(\(k = c[2]; \)\), 
    \(\(CheckSystem[]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"lnum" \( : \ \) 
      "The vector of system loads does not evaluate to a list of numbers when \
subject to the current initial guesses, Lagrange multipliers, and parameters. \
 Use Loads to inspect the loads."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Loads[{",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum1, bnum2, ...",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the part of the generalized load vector that is associated with \
the bodies ",
  StyleBox["bnumi",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Loads[All]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a list of the loads on all current bodies."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["The load inspection function."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  StyleBox["Loads",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " function that is used to return all or part of the vector of load \
expressions that are applied to the current model. Usually, the loads are \
inspected subject to the values of the current guesses, parameters, and \
Lagrange multipliers, which shows exactly what ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " saw to be an error."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is the current vector of applied loads."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Loads[All] /. LastSolve[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, \(-E\^c[1]\), 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "In ",
  StyleBox["all",
    FontSlant->"Italic"],
  " cases, the input shown above should return a list of numbers. In this \
case, the second load expression, the ",
  StyleBox["Y",
    FontSlant->"Italic"],
  " component of the force applied to body 2, evaluates to a symbolic \
expression instead of a single number. Obviously this is due to the \
definition of ",
  StyleBox["b",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["=",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["c[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " given above.\n\nHowever, ",
  StyleBox["c[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not appear in the applied loads. This is because ",
  StyleBox["c[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " (",
  StyleBox["k",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ") is multiplied by time ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". The current initial guess for ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is ",
  StyleBox["T",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["\[Rule]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontFamily->"Times"],
  StyleBox["0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", so ",
  StyleBox["c[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is canceled entirely. Thus, ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " does not even recognize the presence of ",
  StyleBox["c[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " until the initial guesses are perturbed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"We can repair one of the bogus definitions, but the other still remains."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(b = 2; \)\), 
    \(CheckSystem[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " thinks that all is well, which is definitely not the case. This is an \
often frustrating flaw in ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", but it cannot tell what is and is not a number until it evaluates it, \
and zero times anything ",
  StyleBox["is",
    FontSlant->"Italic"],
  " a number. If the value of time is perturbed, ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " sees that the loads are not purely numeric."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "If we change the current value of time with ",
  StyleBox["SetGuess",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " recognizes an error."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[T \[Rule] .001]; \)\), 
    \(\(CheckSystem[]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"lnum" \( : \ \) 
      "The vector of system loads does not evaluate to a list of numbers when \
subject to the current initial guesses, Lagrange multipliers, and parameters. \
 Use Loads to inspect the loads."\)], "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Now we repair the other bogus definition."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(k = 4; \)\), 
    \(\(CheckSystem[]; \)\), 
    \(Loads[All] /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0, \(-7.41867151467064278`\), 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"Now the loads evaluate to a nested list of numbers, as is required."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["12.2  Failure to Converge"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section deals with mechanism modeling errors that prevent a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model from converging to a solution or cause it to converge to an \
incorrect solution."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Inconsistent Constraints"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The most basic error in kinematic modeling is to simply define a set of \
constraints that is not consistent with the mechanism that is being modeled. \
If a model to which no solution exists is defined, ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " must fail to converge. \n\nFor example, consider a rotating crank with a \
single link between an eccentric point on the crank and a point on the \
ground. If the link is insufficiently long, it will not reach from the crank \
to the ground, regardless of the orientation of the crank. In this case, the \
link is only 1.75 units long, while the minimum possible distance between its \
two attachment points is 2 units. No assembled configuration of the mechanism \
exists, so the Newton-Rhapson solution block fails."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This loads the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Needs["\<Mech`Mech2D`\>"]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here is a simple crank-with-link mechanism."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(len =. \), 
    \(SetConstraints[\n\tRevolute2[1, Point[1, 0], Point[2, 0]], \n\t
      RelativeDistance1[2, \n\t\tPoint[1, {3, 0}], Point[2, {0, 1}], len]]
      \)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " attempts to find a solution, but it cannot."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(len = 1.75; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mech::"noconverge" \( : \ \) 
      "Newton's method failed to converge in \!\(15\) iterations."\)], 
  "Message"],

Cell[BoxData[
    \({X2 \[Rule] \(-2.50404791009134974`*^-17\), Y2 \[Rule] 0.`, 
      Th2 \[Rule] \(-4.45320597224643499`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The diagnosis of this type of problem can be quite difficult. No specific \
tool to help isolate such a problem is provided by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " because ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can only know what is said, not what is meant.\n\nThe first thing to try \
is usually to make a quick sketch of the mechanism, and make sure that its \
assembly is feasible. If it is clear that the problem is a modeling error, \
not a conceptual one, then an examination of the constraint expressions can \
yield some insight."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here are the current values of constraints 1 and 2."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Constraints[1] /. LastSolve[]\), 
    \(Constraints[2] /. LastSolve[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2.50404791009134974`*^-17, 0.`}\)], "Output"],

Cell[BoxData[
    \({12.7370981298537611`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Since the expressions in constraint 1 are equal to zero at the current \
values of the initial guesses, they are satisfied and are probably not the \
cause of the problem. Constraint 2, the ",
  StyleBox["RelativeDistance1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " constraint, is not equal to zero, therefore it is the constraint that ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " was unable to satisfy.\n\nWhile this method may prove to be helpful in \
isolating a problem, there is no guarantee that a constraint that is not \
satisfied is actually the one that is in error. For example, it is possible \
that the length of the link in the example is correct and is what the \
designer intended, and what really needs correction is the location of the \
center of the crank.\n\nAnother tool that can prove helpful is ",
  StyleBox["StepMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". This function causes the iterative solver to take a single \
Newton-Rhapson step towards the solution and return the result, regardless of \
any convergence criteria. This allows the solution to be inspected at each \
step, so that if it starts to diverge, the user can see \"which way it \
goes\"."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StepMech[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["t",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " advances the current model through one Newton-Rhapson iteration at time ",
  
  StyleBox["t",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[" A debugging utility."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["StepMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is equivalent to ",
  StyleBox["SolveMech",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " with ",
  StyleBox["MaxIterations",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " set to ",
  StyleBox["1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and an infinitely accurate convergence criteria."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Bifurcation"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Another common modeling problem is bifurcation, a condition where more than \
one solution to the system of constraint equations exists, representing \
multiple possible assembled configurations. When the previously defined \
crank-with-link model is modified so that it can converge, it is able to \
converge to either of two solutions depending on the values of the initial \
guesses."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is one possible configuration of the crank-with-link model with a \
reasonable value of ",
  StyleBox["len",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(len = 2.25; \)\), 
    \(\(SetGuess[Th2 \[Rule] 0]; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] \(-5.28339027600226174`*^-25\), Y2 \[Rule] 0.`, 
      Th2 \[Rule] \(-0.966525608533238944`\)}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[
"And here is the other possible configuration of the crank-with-link model."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetGuess[Th2 \[Rule] \(-N[\[Pi]]\)]; \)\), 
    \(SolveMech[]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({X2 \[Rule] \(-5.28339027600226174`*^-25\), Y2 \[Rule] 0.`, 
      Th2 \[Rule] \(-2.17506704505655434`\)}\)], "Output"]
}, Open  ]],

Cell[TextData[
"Once a model is apparently functioning properly, the value of a graphic \
image of the model cannot be overemphasized. A rudimentary graphic image can \
immediately show errors that may have gone unnoticed, such as the fact that a \
model has converged on the wrong side of a bifurcation, or simply that the \
model has been defined incorrectly. Errors that are difficult to detect from \
the numbers alone are often easily seen in the graphic."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a simple graphic of the crank-with-link model at both positions."], 
  "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      Graphics[{\n\t\t\tPointSize[.05], \n\t\t\tCircle[{0, 0}, 1.2], \n\t\t\t
          Point[{3, 0}], \n
          \t\t\t{Point[Location[2, {0, 1}]], \n\t\t\t\t
              Line[{Location[2, {0, 1}], {3, 0}}]} /. {%, %%%}}], 
      AspectRatio \[Rule] Automatic]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .57143 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.295918 0.226757 0.285714 0.226757 [
[ 0 0 0 0 ]
[ 1 .57143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .57143 L
0 .57143 L
closepath
clip
newpath
0 g
.5 Mabswid
newpath
.29592 .28571 .27211 0 365.73 arc
s
.05 w
.97619 .28571 Mdot
.48252 .15688 Mdot
.5 Mabswid
.48252 .15688 m
.97619 .28571 L
s
.05 w
.48252 .41455 Mdot
.5 Mabswid
.48252 .41455 m
.97619 .28571 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{280, 160},
  ImageMargins->{{34, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0000X1000`40O003h00Oogoo6Goo003oOolI
Ool00?mooaUoo`00ogoo6Goo001=Ool<002oOol004Eoo`P000aoo`L00;Qoo`00@Goo10006goo1000
]7oo000nOol3000SOol4002`Ool003Yoo`@002Yoo`<00:eoo`00>7oo0P00<Goo0P00Zgoo000eOol3
000eOol4002WOol003=oo`8003aoo`03001oogoo0:Aoo`00<Goo0P00?goo0P00Y7oo000^Ool30013
Ool2002ROol002aoo`8004Qoo`<009moo`00:goo00<007ooOol0Bgoo0P00WGoo000YOol2001@Ool0
0`00Oomoo`2JOol002Qoo`03001oogoo055oo`8009Yoo`009goo00<007ooOol0Dgoo00<007ooOol0
V7oo000VOol00`00Oomoo`1EOol00`00Oomoo`2GOol002Eoo`03001oogoo05Moo`8009Moo`008goo
0P00G7oo00<007ooOol0U7oo000QOol2001OOol2002DOol0021oo`03001oogoo065oo`03001oogoo
095oo`007goo00<007ooOol0Hgoo00<007ooOol0T7oo000NOol00`00Oomoo`1UOol00`00Oomoo`2?
Ool001eoo`03001oogoo06Moo`03001oogoo08ioo`0077oo00<007ooOol0JGoo00<007ooOol0SGoo
000KOol00`00Oomoo`1[Ool00`00Oomoo`2<Ool001Yoo`03001oogoo06eoo`03001oogoo08]oo`00
6Goo00<007ooOol0Kgoo00<007ooOol0RWoo000HOol00`00Oomoo`1aOol00`00Oomoo`29Ool001Mo
o`03001oogoo07=oo`03001oogoo08Qoo`005goo00<007ooOol0M7oo00<007ooOol0Qgoo000FOol0
0`00Oomoo`1fOol00`00Oomoo`26Ool001Eoo`03001oogoo07Moo`03001oogoo08Ioo`005Goo00<0
07ooOol0N7oo00<007ooOol0QGoo000DOol00`00Oomoo`1jOol00`00Oomoo`24Ool001=oo`03001o
ogoo07]oo`03001oogoo08Aoo`004goo00<007ooOol0O7oo00<007ooOol0Pgoo000BOol00`00Oomo
o`1`Ool2000;Ool00`00Oomoo`23Ool0019oo`03001oogoo06ioo`H000Yoo`03001oogoo089oo`00
4Goo00<007ooOol0KWoo20002Woo00<007ooOol0PGoo000@Ool00`00Oomoo`1^Ool:0009Ool00`00
Oomoo`21Ool0011oo`03001oogoo06ioo`X000Yoo`03001oogoo081oo`003goo00<007ooOol0KWoo
30002Woo00<007ooOol0Ogoo000>Ool00`00Oomoo`1_Ool@0006Ool00`00Oomoo`1oOol000ioo`03
001oogoo071oo`X000Eoo`@0009oo`03001oogoo07moo`003Goo00<007ooOol0LGoo2P002Goo1000
P7oo000=Ool00`00Oomoo`1bOol8000=Ool5001lOol000aoo`03001oogoo07Aoo`H000ioo`03001o
ogoo009oo`<007Uoo`0037oo00<007ooOol0MWoo0P004Goo00<007ooOol017oo1000MGoo000<Ool0
0`00Oomoo`2:Ool00`00Oomoo`07Ool4001aOol000]oo`03001oogoo08]oo`03001oogoo00]oo`@0
06eoo`002goo00<007ooOol0Rgoo00<007ooOol03goo1000JGoo000:Ool00`00Oomoo`2<Ool00`00
Oomoo`0COol4001UOol000Yoo`03001oogoo08eoo`03001oogoo01Ioo`<0069oo`002Woo00<007oo
Ool0SGoo00<007ooOol06Goo1000GWoo000:Ool00`00Oomoo`2>Ool00`00Oomoo`0LOol4001JOol0
00Uoo`03001oogoo08moo`03001oogoo021oo`@005Ioo`002Goo00<007ooOol0Sgoo00<007ooOol0
97oo1000DWoo0009Ool00`00Oomoo`2@Ool00`00Oomoo`0WOol4001>Ool000Qoo`03001oogoo095o
o`03001oogoo02]oo`<004]oo`0027oo00<007ooOol0TGoo00<007ooOol0;Woo1000Agoo0008Ool0
0`00Oomoo`2AOol00`00Oomoo`0bOol40013Ool000Qoo`03001oogoo095oo`03001oogoo03Ioo`@0
03moo`0027oo00<007ooOol0TGoo00<007ooOol0>Woo1000>goo0008Ool00`00Oomoo`2BOol00`00
Oomoo`0mOol4000gOol000Moo`03001oogoo09=oo`03001oogoo045oo`<003Aoo`001goo00<007oo
Ool0Tgoo00<007ooOol0A7oo1000<7oo0007Ool00`00Oomoo`2COol00`00Oomoo`18Ool4000/Ool0
00Moo`03001oogoo09=oo`03001oogoo04aoo`@002Qoo`001goo00<007ooOol0U7oo00<007ooOol0
Cgoo100097oo0007Ool00`00Oomoo`2DOol00`00Oomoo`1COol4000POol000Moo`03001oogoo09Ao
o`03001oogoo05Moo`<001eoo`001goo00<007ooOol0U7oo00<007ooOol0FWoo10003goo0P0027oo
0007Ool00`00Oomoo`2DOol00`00Oomoo`1NOol40009Ool60006Ool000Moo`03001oogoo09Aoo`03
001oogoo069oo`@000Aoo`P000Eoo`001goo00<007ooOol0U7oo00<007ooOol0IWoo3@0017oo0007
Ool00`00Oomoo`2DOol00`00Oomoo`1YOol:0004Ool000Moo`03001oogoo09Aoo`03001oogoo06Qo
o``000=oo`001goo00<007ooOol0U7oo00<007ooOol0J7oo30000goo0007Ool00`00Oomoo`2DOol0
0`00Oomoo`1VOol=0004Ool000Moo`03001oogoo09Aoo`03001oogoo069oo`@000=oo`X000Aoo`00
1goo00<007ooOol0U7oo00<007ooOol0GWoo100027oo20001Goo0007Ool00`00Oomoo`2DOol00`00
Oomoo`1JOol4000=Ool60006Ool000Moo`03001oogoo09Aoo`03001oogoo05Moo`<001=oo`8000Qo
o`001goo00<007ooOol0U7oo00<007ooOol0Dgoo100087oo0007Ool00`00Oomoo`2DOol00`00Oomo
o`1?Ool4000TOol000Moo`03001oogoo09=oo`03001oogoo04aoo`@002Qoo`001goo00<007ooOol0
Tgoo00<007ooOol0B7oo1000;7oo0007Ool00`00Oomoo`2COol00`00Oomoo`14Ool4000`Ool000Mo
o`03001oogoo09=oo`03001oogoo045oo`<003Aoo`0027oo00<007ooOol0TWoo00<007ooOol0?Goo
1000=goo0008Ool00`00Oomoo`2AOol00`00Oomoo`0jOol4000kOol000Qoo`03001oogoo095oo`03
001oogoo03Ioo`@003moo`0027oo00<007ooOol0TGoo00<007ooOol0<Woo1000@goo0008Ool00`00
Oomoo`2AOol00`00Oomoo`0^Ool40017Ool000Qoo`03001oogoo095oo`03001oogoo02]oo`<004]o
o`002Goo00<007ooOol0T7oo00<007ooOol09goo1000CWoo0009Ool00`00Oomoo`2?Ool00`00Oomo
o`0TOol4001BOol000Uoo`03001oogoo08moo`03001oogoo021oo`@005Ioo`002Woo00<007ooOol0
SWoo00<007ooOol077oo1000FWoo000:Ool00`00Oomoo`2=Ool00`00Oomoo`0IOol4001NOol000Yo
o`03001oogoo08eoo`03001oogoo01Ioo`<0069oo`002Woo00<007ooOol0S7oo00<007ooOol04goo
1000IGoo000;Ool00`00Oomoo`2;Ool00`00Oomoo`0?Ool4001YOol000]oo`03001oogoo08]oo`03
001oogoo00]oo`@006eoo`0037oo00<007ooOol0RWoo00<007ooOol01goo1000LGoo000<Ool00`00
Oomoo`29Ool00`00Oomoo`04Ool4001eOol000aoo`03001oogoo08Qoo`03001oogoo009oo`<007Uo
o`003Goo00<007ooOol0MGoo0P0047oo1@00O7oo000=Ool00`00Oomoo`1cOol6000;Ool40020Ool0
00ioo`03001oogoo075oo`P000Ioo`@0009oo`03001oogoo07moo`003Woo00<007ooOol0L7oo2P00
00=oo`0000000P001Woo00<007ooOol0Ogoo000?Ool00`00Oomoo`1_Ool;000:Ool00`00Oomoo`1o
Ool0011oo`03001oogoo06eoo``000Uoo`03001oogoo081oo`0047oo00<007ooOol0KGoo300027oo
00<007ooOol0PGoo000AOol00`00Oomoo`1]Ool:0009Ool00`00Oomoo`21Ool0019oo`03001oogoo
06aoo`X000Qoo`03001oogoo089oo`004Woo00<007ooOol0KGoo200027oo00<007ooOol0Pgoo000C
Ool00`00Oomoo`1]Ool60009Ool00`00Oomoo`23Ool001=oo`03001oogoo06moo`8000Yoo`03001o
ogoo08Aoo`0057oo00<007ooOol0NWoo00<007ooOol0Q7oo000EOol00`00Oomoo`1hOol00`00Oomo
o`25Ool001Eoo`03001oogoo07Moo`03001oogoo08Ioo`005Woo00<007ooOol0MWoo00<007ooOol0
QWoo000GOol00`00Oomoo`1dOol00`00Oomoo`27Ool001Moo`03001oogoo07=oo`03001oogoo08Qo
o`0067oo00<007ooOol0LGoo00<007ooOol0RGoo000IOol2001`Ool00`00Oomoo`2:Ool001]oo`03
001oogoo06aoo`03001oogoo08]oo`0077oo00<007ooOol0JWoo00<007ooOol0S7oo000LOol00`00
Oomoo`1YOol00`00Oomoo`2=Ool001eoo`03001oogoo06Moo`03001oogoo08ioo`007Woo00<007oo
Ool0IGoo00<007ooOol0Sgoo000OOol00`00Oomoo`1SOol00`00Oomoo`2@Ool0021oo`03001oogoo
065oo`03001oogoo095oo`008Goo0P00Ggoo0P00U7oo000SOol00`00Oomoo`1KOol00`00Oomoo`2D
Ool002Aoo`8005Uoo`8009Moo`009Woo00<007ooOol0EGoo00<007ooOol0Ugoo000WOol00`00Oomo
o`1COol00`00Oomoo`2HOol002Qoo`03001oogoo059oo`03001oogoo09Qoo`00:Goo00<007ooOol0
Cgoo0P00Vgoo000ZOol2001>Ool00`00Oomoo`2KOol002aoo`<004Moo`@009ioo`00;goo0P00A7oo
00<007ooOol0X7oo000aOol00`00Oomoo`0oOol2002SOol0039oo`8003eoo`800:Eoo`00=7oo1000
=Woo0`00Ygoo000hOol00`00Oomoo`0aOol2002ZOol003Uoo`@002aoo`<00:aoo`00?Goo100097oo
1000[goo0011Ool3000MOol4002cOol004Aoo`X000Yoo`T00;Moo`00CWoo2P00`7oo003oOolIOol0
0?mooaUoo`00ogoo6Goo0000\
\>"],
  ImageRangeCache->{{{0, 279}, {159, 0}} -> {-1.31097, -1.26001, 0.0158493, 
  0.0158493}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Redundancy"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "A mechanism model with a redundant constraint set can be thought of as \
having more than one constraint controlling the same degree of freedom. Since \
",
  StyleBox["SetConstraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " only allows models to be defined if they have equal numbers of \
constraints and degrees of freedom, the presence of one redundant constraint \
implies the presence of one unconstrained degree of freedom. ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " may be used to detect such errors."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Here is a model with a redundant constraint set."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SetConstraints[Translate2[1, Axis[2, 0, {1, 1}], Axis[1, 0, {1, 1}]], 
      Orthogonal1[2, Vector[2, {1, 0}], Vector[1, {0, 1}]]]\), 
    \(\(CheckSystem[]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(CheckSystem::"redund" \( : \ \) 
      "Redundant constraints occur at positions \!\({\({1, 1}\), \({2, \
1}\)}\) in the constraints list.  Better initial guesses may be needed."\)], 
  "Message"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "\nThe constraint position numbers given in the error message generated by \
",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " refer to the position of the offending constraints in the current \
constraint list. For example, the current constraint vector has three \
expressions, the first two from ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and the last from ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[". T",
    FontFamily->"Times"],
  "he \"positions {{1, 1}, {2, 1}}\" given by the error message refers to the \
first expression in constraint 1, the ",
  StyleBox["Translate2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the first and only expression in constraint 2, the ",
  StyleBox["Orthogonal1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is usually, but not always, able to detect redundancies in a constraint \
set. Because of the Euler generalized parameters used in the 3D constraint \
formulation, it is possible for ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be unable to detect a redundancy if the current initial guesses for \
the Euler parameters do not constitute a valid set.\n\nSpecifically, a valid \
set of four Euler parameters representing an arbitrary angular orientation \
must satisfy the following relation."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[OutputFormData["\<\
The Unformatted text for this cell was not generated.
Use options in the Actions Preferences dialog box to 
control when Unformatted text is generated.\
\>", "\<\
  2     2     2     2
Ei  + Ej  + Ek  + Eo  == 1\
\>"], "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If the Euler parameters in the current initial guesses do not satisfy this \
relationship, it is possible for ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to be unable to detect a redundant constraint set.\n\nAnother weakness in \
the redundancy checking used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " is that numerical inaccuracies may cause ",
  StyleBox["CheckSystem",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to report that more constraint expressions are participating in a \
redundancy than really are. This is only a problem in relatively large \
systems where numerical errors are more pronounced."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["12.3  Mathematical Anomalies"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "In this section artifacts of the mathematical methods used by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " are discussed."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Zero Unit Vectors"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "If the concept of a zero-length unit vector seems a little strange, rest \
assured that ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " also finds it difficult. Unit vectors are used internally by ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " to generate an applied force vector when the magnitude of the force is \
specified, and the direction of the force is given as a vector based on \
mechanism geometry. The applied force vector, in this case, is the supplied \
direction vector divided by its own magnitude, times the specified force \
magnitude. If the magnitude of the supplied direction vector becomes zero at \
some point in the mechanism motion, a singularity results.\n\nThe most common \
occurrence of this problem is in the application of frictional forces. If the \
negation of the velocity vector of a point is used to specify the direction \
of a force, the velocity of the point may not go to zero at any point in time \
when a solution is sought. If it does, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " evaluates 0/0 and produces an error message.\n\nWhile this is to be \
expected since a zero vector makes no sense as a direction specification, it \
can be quite difficult to formulate a workaround. Setting the magnitude of \
the force equal to zero for all points in time at which the direction vector \
becomes zero may not work, because this still results in 0*0/0, which is no \
better than 0/0."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(0\ 0\)\/0\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Power::"infy" \( : \ \) 
      "Infinite expression \!\(1\/0\) encountered."\)], "Message"],

Cell[BoxData[
    RowBox[{
    \(\[Infinity]::"indet"\), \( : \ \), 
      "\<\"Indeterminate expression \\!\\(0\\\\ \
\\*InterpretationBox[\\\"ComplexInfinity\\\", DirectedInfinity[]]\\) \
encountered.\"\>"}]], "Message"],

Cell[BoxData[
    \(Indeterminate\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The simplest workaround is to use the ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is an option for ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["Moment",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " that specifies a cutoff value for the magnitude of an applied load. If ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is nonzero, the magnitude of the load drops to 1/2 of the specified \
magnitude when the length of the line of action is equal to ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and the magnitude of the load drops to zero when the length of the line \
of action is zero. The default setting is ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " \[Rule] ",
  StyleBox["0",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".",
    FontFamily->"Times"]
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"A fix for problems with zero-length force vectors."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The following example shows the effect that ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " has on the force vector generated by a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " ",
  StyleBox["Force",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. The force is defined with a constant magnitude, but the \
direction vector of the force is a function of ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Clearly, the force is indeterminate if ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " goes to zero."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  "Here is a force that fails if ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " = 0."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<Mech`Mech3D`\>"]\), 
    \(\(Force[2, Axis[1, 0, {a, 0, 0}], 10]\)\[LeftDoubleBracket]1, 1
      \[RightDoubleBracket]\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(Vector[1, {\(10\ a\)\/\@a\^2, 0, 0}]\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Here is the same force using the ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Force[2, Axis[1, 0, {a, 0, 0}], 10, CutOff \[Rule] .0001]
        \)\[LeftDoubleBracket]1, 1\[RightDoubleBracket]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    RowBox[{"Vector", "[", 
      RowBox[{"1", ",", 
        RowBox[{"{", 
          RowBox[{
            FractionBox[\(10\ a\), 
              RowBox[{
                RowBox[{
                  StyleBox["0.0001`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "\[InvisibleSpace]"}], "+", 
                \(\@a\^2\)}]], ",", "0", ",", "0"}], "}"}]}], "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The value of ",
  StyleBox["CutOff",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " should be extremely small so that it has a negligible effect on the \
magnitude of the load in the operating range of the variable ",
  StyleBox["a",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["12.4  Equations of Motion"], "Section",
  Evaluatable->False,
  PageBreakAbove->True,
  AspectRatioFixed->True],

Cell[TextData[{
  "This section shows how to access the complete system of equations that is \
generated by a ",
  StyleBox["Mech",
    FontSlant->"Italic"],
  " model."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Internal Expression Access"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "The following functions are used to access the symbolic expressions that \
are generated by ",
  StyleBox["Mechanical Systems",
    FontSlant->"Italic"],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Constraints[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the list of constraint expressions that were generated by \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". The expressions returned are set equal to zero to satisfy the \
constraint.\n\n",
  StyleBox["Jacobian[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  ", ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the submatrix of the constraint Jacobian associated with \
constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " and body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["VelocityTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a part of the right-hand term of the velocity constraint \
expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". The full velocity constraint expression is given by\n",
  StyleBox["VelocityTerms[_] + Jacobian[_,_].Velocity[_]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["AccelerationTerms[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns a part of the right hand term of the acceleration constraint \
expressions associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". The full acceleration constraint is\n",
  StyleBox["AccelerationTerms[_] + Jacobian[_,_].Acceleration[_]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\n",
  StyleBox["Loads[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the total external load vector applied to body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["Centrifugal[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the vector of centrifugal forces associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ".\n\n",
  StyleBox["MassMatrix[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the submatrix of the mass matrix associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  "."
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Functions to provide access to internally stored expressions."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Location[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the location coordinates ",
  StyleBox["X2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc. associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Velocity[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the velocity coordinates ",
  StyleBox["X2d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc. associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Acceleration[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["bnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the acceleration coordinates ",
  StyleBox["X2dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Y3dd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc. associated with body ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  ". \n\n",
  StyleBox["Generalized[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["cnum",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " returns the Lagrange multipliers ",
  StyleBox["Lmb1",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Lmb2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", etc. associated with constraint ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  ". \n\nIn all of these functions, the body number ",
  StyleBox["bnum",
    FontSlant->"Italic"],
  " can be a single positive integer, a list of integers, ",
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or ",
  StyleBox["Rest",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n\nThe constraint number ",
  StyleBox["cnum",
    FontSlant->"Italic"],
  " can be a single positive integer constraint number, a list of integers, ",
  
  StyleBox["All",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", ",
  StyleBox["Euler",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", or any of the forms of partial constraint specifications accepted by ",
  StyleBox["Constraints",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". "
}], "Special3",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Functions that return a model's dependent variables."], "Special4",
  Evaluatable->False,
  PageBreakAbove->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[TextData[{
  "The complete set of equations that are solved by the ",
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution block is given by ",
  StyleBox["Transpose[Jacobian[_,_]].Generalized[_] == Loads[_]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".\n\nThe equations of motion that are solved by the ",
    FontFamily->"Times"],
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" solution block are the ",
    FontFamily->"Times"],
  StyleBox["Static",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" equations with ",
    FontFamily->"Times"],
  StyleBox["Centrifugal[_] + MassMatrix[_].Acceleration[_]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" added to the left-hand side.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Examples"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Here is a simple model to provide some values for the dependent variables."],
   "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(SetConstraints[\n\tSpherical3[1, Point[2, {1, 0, 0}], {0, 0, 0}], \n\t
      RotationLock3[2, 2, {0.1\ T, {1., 1., 0}}]]\), 
    \(SetBodies[\n\t
      Body[2, Mass \[Rule] 10, Inertia \[Rule] {2, 1, 1, .5, .5, 1}]]\), 
    \(SetLoads[\n\tGravity[{0, 0, \(-1\)}, 9.8]]\)}], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "The model is run with the ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " solution option, and very tight convergence criteria."
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(sol = 
      Chop[SolveMech[0, Solution \[Rule] Dynamic, 
          ZeroTest \[Rule] \((#1 == 0&)\)]]; \)\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are all the kinematic constraint equations."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Constraints[All] /. sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 0, 0, 0, 0, 0, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the velocity constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Jacobian[All, All].Velocity[All] + VelocityTerms[All] /. sol\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({0, 0, 0.`, 0, 0.`, 0.`, 0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the acceleration constraints."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Jacobian[All, All].Acceleration[All] + AccelerationTerms[All] /. sol\)],
   "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 0.`, 0, 0.`, 0, 0, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Here are the static reaction force equations. They are not satisfied \
because the model was solved with the ",
  StyleBox["Dynamic",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option. "
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[Jacobian[All, All]].Generalized[All] - Loads[All] /. sol\)], 
  "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({\(-0.05`\), 0.05`, 0.`, 0.0399999999999999822`, \(-0.015`\), 
      0.0149999999999863575`, 0.00999999999999999644`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Here are the dynamic equations of motion."], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[Jacobian[All, All]].Generalized[All] + 
        MassMatrix[All].Acceleration[All] + Centrifugal[All] - Loads[All] /. 
      sol\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({0.`, 0.`, 0.`, 0.`, 0.`, 0.`, 0.`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "This removes the ",
  StyleBox["Mech2D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " package"
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(KillMech[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1152}, {0, 808}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 700},
WindowMargins->{{160, Automatic}, {Automatic, 5}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
StyleDefinitions -> "MechStyles.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 86, 2, 105, "Title"],

Cell[CellGroupData[{
Cell[1842, 57, 88, 2, 47, "Subsection"],
Cell[1933, 61, 747, 18, 128, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2717, 84, 128, 3, 33, "Section",
  PageBreakAbove->True],
Cell[2848, 89, 286, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[3159, 101, 93, 2, 47, "Subsection"],
Cell[3255, 105, 917, 19, 204, "Text"],

Cell[CellGroupData[{
Cell[4197, 128, 189, 8, 24, "SmallText"],
Cell[4389, 138, 84, 2, 25, "Input"]
}, Open  ]],
Cell[4488, 143, 748, 25, 92, "Text"],

Cell[CellGroupData[{
Cell[5261, 172, 112, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[5398, 178, 130, 3, 45, "Input"],
Cell[5531, 183, 385, 6, 120, "Message"],
Cell[5919, 191, 100, 2, 48, "Output"]
}, Open  ]]
}, Open  ]],
Cell[6046, 197, 761, 20, 130, "Text"],

Cell[CellGroupData[{
Cell[6832, 221, 149, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[7006, 229, 115, 2, 25, "Input"],
Cell[7124, 233, 145, 3, 44, "Message"],
Cell[7272, 238, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[7358, 243, 729, 19, 128, "Text"],

Cell[CellGroupData[{
Cell[8112, 266, 139, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[8276, 273, 129, 3, 45, "Input"],
Cell[8408, 278, 67, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[8502, 283, 1306, 44, 171, "Text"],

Cell[CellGroupData[{
Cell[9833, 331, 211, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[10069, 343, 103, 2, 25, "Input"],
Cell[10175, 347, 117, 2, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[10353, 356, 101, 2, 31, "Subsection"],
Cell[10457, 360, 963, 31, 130, "Text"],

Cell[CellGroupData[{
Cell[11445, 395, 116, 2, 24, "SmallText"],
Cell[11564, 399, 253, 5, 105, "Input"],

Cell[CellGroupData[{
Cell[11842, 408, 78, 2, 25, "Input"],
Cell[11923, 412, 155, 3, 44, "Message"]
}, Open  ]]
}, Open  ]],
Cell[12105, 419, 567, 21, 73, "Text"],

Cell[CellGroupData[{
Cell[12697, 444, 205, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[12927, 456, 134, 4, 65, "Input"],
Cell[13064, 462, 256, 4, 101, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13369, 472, 1171, 45, 132, "Special3"],
Cell[14543, 519, 138, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[14696, 525, 657, 18, 112, "Text"],

Cell[CellGroupData[{
Cell[15378, 547, 124, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[15527, 553, 90, 2, 25, "Input"],
Cell[15620, 557, 48, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[15695, 562, 455, 13, 72, "Text"],

Cell[CellGroupData[{
Cell[16175, 579, 129, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[16329, 586, 147, 4, 65, "Input"],
Cell[16479, 592, 43, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[16549, 597, 356, 6, 71, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[16942, 608, 95, 2, 31, "Subsection"],
Cell[17040, 612, 625, 14, 110, "Text"],

Cell[CellGroupData[{
Cell[17690, 630, 105, 2, 24, "SmallText"],
Cell[17798, 634, 149, 4, 45, "Input"],

Cell[CellGroupData[{
Cell[17972, 642, 78, 2, 25, "Input"],
Cell[18053, 646, 150, 3, 44, "Message"]
}, Open  ]]
}, Open  ]],
Cell[18230, 653, 1041, 38, 114, "Text"],

Cell[CellGroupData[{
Cell[19296, 695, 130, 4, 65, "Input"],
Cell[19429, 701, 259, 4, 82, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19725, 710, 587, 21, 86, "Special3"],
Cell[20315, 733, 132, 3, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[20462, 739, 579, 17, 93, "Text"],

Cell[CellGroupData[{
Cell[21066, 760, 123, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[21214, 766, 84, 2, 25, "Input"],
Cell[21301, 770, 54, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[21382, 775, 1915, 73, 189, "Text"],

Cell[CellGroupData[{
Cell[23322, 852, 155, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[23502, 860, 96, 3, 45, "Input"],
Cell[23601, 865, 38, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[23666, 870, 662, 20, 94, "Text"],

Cell[CellGroupData[{
Cell[24353, 894, 317, 12, 24, "SmallText"],

Cell[CellGroupData[{
Cell[24695, 910, 121, 3, 45, "Input"],
Cell[24819, 915, 259, 4, 82, "Message"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[25127, 925, 120, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[25272, 931, 138, 4, 65, "Input"],
Cell[25413, 937, 67, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[25507, 942, 144, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[25676, 950, 190, 8, 24, "SmallText"],
Cell[25869, 960, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[25999, 969, 126, 3, 33, "Section",
  PageBreakAbove->True],
Cell[26128, 974, 284, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[26437, 986, 104, 2, 47, "Subsection"],
Cell[26544, 990, 853, 15, 204, "Text"],

Cell[CellGroupData[{
Cell[27422, 1009, 189, 8, 24, "SmallText"],
Cell[27614, 1019, 84, 2, 25, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27735, 1026, 122, 2, 24, "SmallText"],
Cell[27860, 1030, 224, 5, 105, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28121, 1040, 205, 7, 24, "SmallText"],

Cell[CellGroupData[{
Cell[28351, 1051, 99, 3, 45, "Input"],
Cell[28453, 1056, 134, 3, 44, "Message"],
Cell[28590, 1061, 139, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[28756, 1067, 652, 15, 147, "Text"],

Cell[CellGroupData[{
Cell[29433, 1086, 131, 3, 24, "SmallText"],

Cell[CellGroupData[{
Cell[29589, 1093, 130, 3, 45, "Input"],
Cell[29722, 1098, 66, 1, 29, "Output"],
Cell[29791, 1101, 56, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[29874, 1106, 1333, 27, 284, "Text"],
Cell[31210, 1135, 395, 16, 55, "Special3"],
Cell[31608, 1153, 124, 3, 18, "Special4",
  PageBreakAbove->False],
Cell[31735, 1158, 479, 19, 53, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[32251, 1182, 91, 2, 31, "Subsection"],
Cell[32345, 1186, 461, 8, 109, "Text"],

Cell[CellGroupData[{
Cell[32831, 1198, 255, 9, 24, "SmallText"],

Cell[CellGroupData[{
Cell[33111, 1211, 139, 4, 65, "Input"],
Cell[33253, 1217, 140, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],
Cell[33420, 1223, 157, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[33602, 1231, 124, 3, 45, "Input"],
Cell[33729, 1236, 139, 2, 29, "Output"]
}, Open  ]],
Cell[33883, 1241, 519, 8, 109, "Text"],

Cell[CellGroupData[{
Cell[34427, 1253, 155, 4, 24, "SmallText"],

Cell[CellGroupData[{
Cell[34607, 1261, 336, 7, 145, "Input"],
Cell[34946, 1270, 7465, 141, 168, 759, 52, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[42472, 1418, 90, 2, 31, "Subsection"],
Cell[42565, 1422, 645, 16, 111, "Text"],

Cell[CellGroupData[{
Cell[43235, 1442, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[43387, 1448, 221, 4, 85, "Input"],
Cell[43611, 1454, 216, 4, 63, "Message"]
}, Open  ]]
}, Open  ]],
Cell[43854, 1462, 1605, 43, 306, "Text"],
Cell[45462, 1507, 301, 9, 38, "Output"],
Cell[45766, 1518, 753, 19, 149, "Text"],

Cell[CellGroupData[{
Cell[46544, 1541, 190, 8, 24, "SmallText"],
Cell[46737, 1551, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[46867, 1560, 129, 3, 33, "Section",
  PageBreakAbove->True],
Cell[46999, 1565, 208, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[47232, 1576, 97, 2, 47, "Subsection"],
Cell[47332, 1580, 1527, 28, 337, "Text"],

Cell[CellGroupData[{
Cell[48884, 1612, 70, 2, 37, "Input"],
Cell[48957, 1616, 111, 2, 38, "Message"],
Cell[49071, 1620, 222, 5, 44, "Message"],
Cell[49296, 1627, 47, 1, 29, "Output"]
}, Open  ]],
Cell[49358, 1631, 407, 17, 34, "Text"],

Cell[CellGroupData[{
Cell[49790, 1652, 1014, 34, 103, "Special3"],
Cell[50807, 1688, 154, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[50976, 1695, 692, 24, 74, "Text"],

Cell[CellGroupData[{
Cell[51693, 1723, 194, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[51912, 1735, 188, 4, 45, "Input"],
Cell[52103, 1741, 70, 1, 46, "Output"]
}, Open  ]]
}, Open  ]],
Cell[52200, 1746, 205, 8, 24, "SmallText"],

Cell[CellGroupData[{
Cell[52430, 1758, 174, 3, 25, "Input"],
Cell[52607, 1763, 424, 11, 46, "Output"]
}, Open  ]],
Cell[53046, 1777, 379, 13, 54, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[53474, 1796, 126, 3, 33, "Section",
  PageBreakAbove->True],
Cell[53603, 1801, 229, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[53857, 1813, 106, 2, 47, "Subsection"],
Cell[53966, 1817, 238, 8, 52, "Text"],

Cell[CellGroupData[{
Cell[54229, 1829, 2936, 106, 363, "Special3"],
Cell[57168, 1937, 165, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[57370, 1946, 2743, 110, 301, "Special3"],
Cell[60116, 2058, 156, 4, 18, "Special4",
  PageBreakAbove->False]
}, Open  ]],
Cell[60287, 2065, 903, 28, 132, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[61227, 2098, 88, 2, 31, "Subsection"],

Cell[CellGroupData[{
Cell[61340, 2104, 157, 4, 24, "SmallText"],
Cell[61500, 2110, 329, 6, 145, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61866, 2121, 245, 8, 24, "SmallText"],
Cell[62114, 2131, 166, 4, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62317, 2140, 127, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[62469, 2146, 82, 2, 25, "Input"],
Cell[62554, 2150, 59, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[62662, 2157, 113, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[62800, 2163, 121, 3, 45, "Input"],
Cell[62924, 2168, 61, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63034, 2175, 117, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[63176, 2181, 130, 3, 65, "Input"],
Cell[63309, 2186, 63, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[63421, 2193, 283, 9, 40, "SmallText"],

Cell[CellGroupData[{
Cell[63729, 2206, 128, 3, 65, "Input"],
Cell[63860, 2211, 151, 2, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64060, 2219, 120, 2, 24, "SmallText"],

Cell[CellGroupData[{
Cell[64205, 2225, 196, 4, 85, "Input"],
Cell[64404, 2231, 69, 1, 29, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64522, 2238, 189, 8, 24, "SmallText"],
Cell[64714, 2248, 69, 2, 25, "Input"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

